---

# 3rd-Party Software for [git@github.com:dbt-labs/metricflow.git]()



The following 3rd-party software packages may be used by or distributed with **git@github.com:dbt-labs/metricflow.git**.  Any information relevant to third-party vendors listed below are collected using common, reasonable means.


Date generated | Revision ID
:------------: | :----------:
02/22/25 | f98ab1dac65434ebc489d0019b4d75fa8c09e7ae

---


## Declared License

No declared license found for git@github.com:dbt-labs/metricflow.git



## First Party Licenses

**No licenses found.**




## Dependencies




### [agate (1.9.1)](https://agate.readthedocs.org/)


#### Declared Licenses
MIT


```
The MIT License

Copyright (c) 2017 Christopher Groskopf and contributors 

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```






#### Other Licenses














---

### [annotated-types (0.7.0)](https://pypi.org/project/annotated-types/)


#### Declared Licenses
MIT


```
The MIT License (MIT)

Copyright (c) 2022 the contributors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses














---

### [attrs (24.3.0)](https://pypi.org/project/attrs/)


#### Declared Licenses
MIT


```
The MIT License (MIT)

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses














---

### [certifi (2024.12.14)](https://github.com/certifi/python-certifi)


#### Declared Licenses
MPL-2.0


```
This package contains a modified version of ca-bundle.crt:

ca-bundle.crt -- Bundle of CA Root Certificates

This is a bundle of X.509 certificates of public Certificate Authorities
(CA). These were automatically extracted from Mozilla's root certificates
file (certdata.txt).  This file can be found in the mozilla source tree:
https://hg.mozilla.org/mozilla-central/file/tip/security/nss/lib/ckfw/builtins/certdata.txt
It contains the certificates in PEM format and therefore
can be directly used with curl / libcurl / php_curl, or with
an Apache+mod_ssl webserver for SSL client authentication.
Just configure this file as the SSLCACertificateFile.#

***** BEGIN LICENSE BLOCK *****
This Source Code Form is subject to the terms of the Mozilla Public License,
v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain
one at http://mozilla.org/MPL/2.0/.

***** END LICENSE BLOCK *****
@(#) $RCSfile: certdata.txt,v $ $Revision: 1.80 $ $Date: 2011/11/03 15:11:58 $

```






#### Other Licenses














---

### [charset-normalizer (3.4.1)](https://pypi.org/project/charset-normalizer/)


#### Declared Licenses
MIT


```
MIT License

Copyright (c) 2025 TAHRI Ahmed R.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses














---

### [click (8.1.6)](https://pypi.org/project/click/)


#### Declared Licenses
BSD-3-Clause


```
Copyright 2014 Pallets

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1\.  Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

2\.  Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.

3\.  Neither the name of the copyright holder nor the names of its
    contributors may be used to endorse or promote products derived from
    this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






#### Other Licenses














---

### [click (8.1.8)](https://pypi.org/project/click/)


#### Declared Licenses
BSD-3-Clause


```
Copyright 2014 Pallets

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1\.  Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

2\.  Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.

3\.  Neither the name of the copyright holder nor the names of its
    contributors may be used to endorse or promote products derived from
    this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






#### Other Licenses














---

### [colorama (0.4.6)](https://pypi.org/project/colorama/)


#### Declared Licenses
BSD-3-Clause


```
Copyright (c) 2010 Jonathan Hartley
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

\* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

\* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

\* Neither the name of the copyright holders, nor those of its contributors
  may be used to endorse or promote products derived from this software without
  specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






#### Other Licenses














---

### [daff (1.3.46)](https://github.com/paulfitz/daff)


#### Declared Licenses
MIT


```
Copyright (c) <year> <copyright holders>
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```






#### Other Licenses














---

### [dbt-adapters (1.13.2)](https://pypi.org/project/dbt-adapters/)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright 2024 dbt Labs, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-bigquery (1.9.0)](https://github.com/dbt-labs/dbt-bigquery)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "{}"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright 2021 dbt Labs, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-common (1.14.0)](https://pypi.org/project/dbt-common/)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright [yyyy] [name of copyright owner]

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-core (1.9.0)](https://github.com/dbt-labs/dbt-core)


#### Declared Licenses
Apache-2.0


```
Copyright [yyyy] [name of copyright owner]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

See the License for the specific language governing permissions and limitations under the License.
```






#### Other Licenses














---

### [dbt-core (1.9.1)](https://github.com/dbt-labs/dbt-core)


#### Declared Licenses
Apache-2.0


```
Copyright [yyyy] [name of copyright owner]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

See the License for the specific language governing permissions and limitations under the License.
```






#### Other Licenses














---

### [dbt-databricks (1.9.0)](https://pypi.org/project/dbt-databricks/)


#### Declared Licenses



#### Other Licenses














---

### [dbt-duckdb (1.9.0)](https://github.com/jwills/dbt-duckdb)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright [yyyy] [name of copyright owner]

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-extractor (0.5.1)](https://github.com/dbt-labs/dbt-parser-generator/)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright 2021 dbt Labs, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-postgres (1.9.0)](https://pypi.org/project/dbt-postgres/)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright 2024 dbt Labs, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-redshift (1.9.0)](https://github.com/dbt-labs/dbt-redshift)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "{}"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright 2021 dbt Labs, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-semantic-interfaces (0.7.2)](https://pypi.org/project/dbt-semantic-interfaces/)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright [yyyy] [name of copyright owner]

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-semantic-interfaces (0.7.4)](https://pypi.org/project/dbt-semantic-interfaces/)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright [yyyy] [name of copyright owner]

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-semantic-interfaces (0.8.3)](https://pypi.org/project/dbt-semantic-interfaces/)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright [yyyy] [name of copyright owner]

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-snowflake (1.9.0)](https://github.com/dbt-labs/dbt-snowflake)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "{}"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright 2021 dbt Labs, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [dbt-trino (1.9.0)](https://github.com/starburstdata/dbt-trino)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "{}"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright 2021 Starburst Data, Inc.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [deepdiff (7.0.1)](https://github.com/seperman/deepdiff)


#### Declared Licenses
MIT


```
The MIT License (MIT)

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors
www.zepworks.com

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.


```






#### Other Licenses














---

### [duckdb (1.1.3)](https://www.duckdb.org)


#### Declared Licenses
MIT


```
Copyright (c) 2022 Max Bachmann
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```






#### Other Licenses
Apache-2.0, GPL-2.0-or-later, GPL-2.0-with-bison-exception, BSD-3-Clause, BSD-2-Clause, GPL-2.0-only, proprietary-license, public-domain, Zlib


```
Copyright 2014-2017 Melissa O'Neill <oneill@pcg-random.org>,

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

See the License for the specific language governing permissions and limitations under the License.
```






```
Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; version 2 or any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
```






```
As a special exception, you may create a larger work that contains part or all of the Bison parser skeleton and distribute that work under terms of your choice, so long as that work isn't itself a parser generator using the skeleton or a modified version thereof as a parser skeleton. Alternatively, if you modify or redistribute the parser skeleton itself, you may (at your option) remove this special exception, which will cause the skeleton and the resulting Bison output files to be licensed under the GNU General Public License without this special exception.
This special exception was added by the Free Software Foundation in version 2.2 of Bison.
```






```
Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

   3. Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






```
Copyright (c) 2013-2016 Cameron Desrochers.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice, this
      list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation

      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






```
Copyright (C) 2016-2020 Yann Collet, Facebook, Inc.
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; version 2.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
```






```
This is a catch-all license used when we find many different proprietary licenses.
```











```
This software is provided 'as-is', without any express or implied warranty. In no event will the authors be held liable for any damages arising from the use of this software.
Permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the following restrictions:
   1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
   2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.
```

















---

### [graphviz (0.18.2)](https://github.com/xflr6/graphviz)


#### Declared Licenses
MIT


```
The MIT License (MIT)

Copyright (c) 2013-2021 Sebastian Bank

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```






#### Other Licenses














---

### [graphviz (0.20.3)](https://github.com/xflr6/graphviz)


#### Declared Licenses
MIT


```
The MIT License (MIT)

Copyright (c) 2013-2024 Sebastian Bank

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```






#### Other Licenses














---

### [halo (0.0.31)](https://github.com/manrajgrover/halo)


#### Declared Licenses
MIT


```
MIT License

Copyright (c) 2017 Manraj Singh

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses














---

### [idna (3.10)](https://pypi.org/project/idna/)


#### Declared Licenses
BSD-3-Clause


```
BSD 3-Clause License

Copyright (c) 2013-2024, Kim Davies and contributors.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1\. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2\. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3\. Neither the name of the copyright holder nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






#### Other Licenses














---

### [importlib-metadata (6.11.0)](https://pypi.org/project/importlib-metadata/)


#### Declared Licenses
Apache-2.0


```

                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright [yyyy] [name of copyright owner]

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [isodate (0.6.1)](https://pypi.org/project/isodate/)


#### Declared Licenses
BSD-3-Clause


```
Copyright (c) 2009 Gerhard Weis . All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

   3. Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






#### Other Licenses














---

### [Jinja2 (3.1.3)](https://pypi.org/project/Jinja2/)


#### Declared Licenses
BSD-3-Clause


```
Copyright 2007 Pallets

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1\.  Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

2\.  Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.

3\.  Neither the name of the copyright holder nor the names of its
    contributors may be used to endorse or promote products derived from
    this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






#### Other Licenses














---

### [Jinja2 (3.1.5)](https://pypi.org/project/Jinja2/)


#### Declared Licenses
BSD-3-Clause


```
Copyright 2007 Pallets

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1\.  Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

2\.  Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.

3\.  Neither the name of the copyright holder nor the names of its
    contributors may be used to endorse or promote products derived from
    this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






#### Other Licenses














---

### [jsonschema (4.23.0)](https://pypi.org/project/jsonschema/)


#### Declared Licenses
MIT


```
Copyright (c) 2013 Julian Berman

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```






#### Other Licenses














---

### [jsonschema-specifications (2024.10.1)](https://pypi.org/project/jsonschema-specifications/)


#### Declared Licenses
MIT


```
Copyright (c) 2022 Julian Berman

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```






#### Other Licenses














---

### [leather (0.4.0)](https://leather.readthedocs.io/)


#### Declared Licenses
MIT


```
The MIT License

Copyright (c) 2016 Christopher Groskopf and contributors 

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```






#### Other Licenses














---

### [log-symbols (0.0.14)](https://github.com/manrajgrover/py-log-symbols)


#### Declared Licenses
MIT


```
MIT License

Copyright (c) 2017 Manraj Singh

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses














---

### [MarkupSafe (3.0.2)](https://pypi.org/project/MarkupSafe/)


#### Declared Licenses
BSD-3-Clause


```
Copyright 2010 Pallets

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1\.  Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

2\.  Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.

3\.  Neither the name of the copyright holder nor the names of its
    contributors may be used to endorse or promote products derived from
    this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






#### Other Licenses














---

### [mashumaro (3.14)](https://github.com/Fatal1ty/mashumaro)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   Copyright 2017 Alexander Tikhonov

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [metricflow (0.207.1)](https://pypi.org/project/metricflow/)


#### Declared Licenses
business-source-license-1.1, Apache-2.0


```
Terms

The Licensor hereby grants you the right to copy, modify, create derivative works, redistribute, and make non-production use of the Licensed Work. The Licensor may make an Additional Use Grant, above, permitting limited production use.

Effective on the Change Date, or the fourth anniversary of the first publicly available distribution of a specific version of the Licensed Work under this License, whichever comes first, the Licensor hereby grants you rights under the terms of the Change License, and the rights granted in the paragraph above terminate.

If your use of the Licensed Work does not comply with the requirements currently in effect as described in this License, you must purchase a commercial license from the Licensor, its affiliated entities, or authorized resellers, or you must refrain from using the Licensed Work.

All copies of the original and modified Licensed Work, and derivative works of the Licensed Work, are subject to this License. This License applies separately for each version of the Licensed Work and the Change Date may vary for each version of the Licensed Work released by Licensor.

You must conspicuously display this License on each original or modified copy of the Licensed Work. If you receive the Licensed Work in original or modified form from a third party, the terms and conditions set forth in this License apply to your use of that work.

Any use of the Licensed Work in violation of this License will automatically terminate your rights under this License for the current and all other versions of the Licensed Work.

This License does not grant you any right in any trademark or logo of Licensor or its affiliates (provided that you may use a trademark or logo of Licensor as expressly required by this License).TO THE EXTENT PERMITTED BY APPLICABLE LAW, THE LICENSED WORK IS PROVIDED ON AN “AS IS” BASIS. LICENSOR HEREBY DISCLAIMS ALL WARRANTIES AND CONDITIONS, EXPRESS OR IMPLIED, INCLUDING (WITHOUT LIMITATION) WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NON-INFRINGEMENT, AND TITLE.MariaDB hereby grants you permission to use this License’s text to license your works, and to refer to it using the trademark “Business Source License”, as long as you comply with the Covenants of Licensor below.
Covenants of Licensor

In consideration of the right to use this License’s text and the “Business Source License” name and trademark, Licensor covenants to MariaDB, and to all other recipients of the licensed work to be provided by Licensor:

To specify as the Change License the GPL Version 2.0 or any later version, or a license that is compatible with GPL Version 2.0 or a later version, where “compatible” means that software provided under the Change License can be included in a program with software provided under GPL Version 2.0 or a later version. Licensor may specify additional Change Licenses without limitation.
To either: (a) specify an additional grant of rights to use that does not impose any additional restriction on the right granted in this License, as the Additional Use Grant; or (b) insert the text “None”.
To specify a Change Date.
Not to modify this License in any other way.
Notice

The Business Source License (this document, or the “License”) is not an Open Source license. However, the Licensed Work will eventually be made available under an Open Source License, as stated in this License.

For more information on the use of the Business Source License for MariaDB products, please visit the MariaDB Business Source License FAQ. For more information on the use of the Business Source License generally, please visit the Adopting and Developing Business Source License FAQ.
```






```
License text copyright © 2017 MariaDB Corporation Ab, All Rights Reserved.
“Business Source License” is a trademark of MariaDB Corporation Ab.

Licensed Work: MetricFlow

Change Date: The change date for each release of the Licensed Work will
be the 3rd anniversary of the initial release date of that
release of the Licensed Work.

Change License: Apache 2.0 https://www.apache.org/licenses/LICENSE-2.0

Additional Use Grant: The Licensor hereby grants you the right to use the
Licensed Work for production purposes that consist of
your internal business purposes, but not for the purpose
of providing managed services or software-as-a-service
to others.

Terms

The Licensor hereby grants you the right to copy, modify, create derivative
works, redistribute, and make non-production use of the Licensed Work. The
Licensor may make an Additional Use Grant, above, permitting limited production
use.

Effective on the Change Date, or the fourth anniversary of the first publicly
available distribution of a specific version of the Licensed Work under this
License, whichever comes first, the Licensor hereby grants you rights under the
terms of the Change License, and the rights granted in the paragraph above
terminate.

If your use of the Licensed Work does not comply with the requirements currently
in effect as described in this License, you must purchase a commercial license
from the Licensor, its affiliated entities, or authorized resellers, or you must
refrain from using the Licensed Work.

All copies of the original and modified Licensed Work, and derivative works of
the Licensed Work, are subject to this License. This License applies separately
for each version of the Licensed Work and the Change Date may vary for each
version of the Licensed Work released by Licensor.

You must conspicuously display this License on each original or modified copy of
the Licensed Work. If you receive the Licensed Work in original or modified form
from a third party, the terms and conditions set forth in this License apply to
your use of that work.

Any use of the Licensed Work in violation of this License will automatically
terminate your rights under this License for the current and all other versions
of the Licensed Work.

This License does not grant you any right in any trademark or logo of Licensor
or its affiliates (provided that you may use a trademark or logo of Licensor as
expressly required by this License).TO THE EXTENT PERMITTED BY APPLICABLE LAW,
THE LICENSED WORK IS PROVIDED ON AN “AS IS” BASIS. LICENSOR HEREBY DISCLAIMS ALL
WARRANTIES AND CONDITIONS, EXPRESS OR IMPLIED, INCLUDING (WITHOUT LIMITATION)
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE,
NON-INFRINGEMENT, AND TITLE.MariaDB hereby grants you permission to use this
License’s text to license your works, and to refer to it using the trademark
“Business Source License”, as long as you comply with the Covenants of Licensor
below.

Covenants of Licensor

In consideration of the right to use this License’s text and the “Business
Source License” name and trademark, Licensor covenants to MariaDB, and to all
other recipients of the licensed work to be provided by Licensor:

To specify as the Change License the GPL Version 2.0 or any later version, or a
license that is compatible with GPL Version 2.0 or a later version, where
“compatible” means that software provided under the Change License can be
included in a program with software provided under GPL Version 2.0 or a later
version. Licensor may specify additional Change Licenses without limitation.

To either: (a) specify an additional grant of rights to use that does not impose
any additional restriction on the right granted in this License, as the
Additional Use Grant; or (b) insert the text “None”.

To specify a Change Date.

Not to modify this License in any other way.

Notice

The Business Source License (this document, or the “License”) is not an Open
Source license. However, the Licensed Work will eventually be made available
under an Open Source License, as stated in this License.

For more information on the use of the Business Source License for MariaDB
products, please visit the MariaDB Business Source License FAQ. For more
information on the use of the Business Source License generally, please visit
the Adopting and Developing Business Source License FAQ.

```






#### Other Licenses
Zlib, X11, NCSA, Unlicense, SunPro, PSF-2.0, Protobuf, openssl-ssleay, openpub, Python-2.0, OLDAP-1.1, OPL-1.0, MPL-2.0, mit-old-style-no-advert, mit-nagy, mit-0, mit-taylor-variant, LGPL-3.0-or-later, MIT, ISC, IPA, Info-ZIP, GPL-3.0-only, GPL-3.0-or-later, GPL-2.0-or-later, GPL-2.0-only, GPL-1.0-or-later, CNRI-Python, gpl-2.0 WITH bison-exception-2.2, GPL-3.0-with-GCC-exception, BSD-3-Clause-Clear, CC0-1.0, CC-BY-SA-4.0, GPL-1.0-only, 0BSD, CC-BY-4.0, CC-BY-SA-3.0, BSD-2-Clause, BSD-3-Clause, bsd-3-clause-open-mpi, bsd-2-clause-views, BSL-1.0, GPL-2.0-with-bison-exception, AAL, Artistic-1.0, AGPL-3.0-or-later, Artistic-1.0-Perl


```
This software is provided 'as-is', without any express or implied warranty. In no event will the authors be held liable for any damages arising from the use of this software.
Permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the following restrictions:
   1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
   2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.
```






```
Copyright (C) 1996 X Consortium
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
Except as contained in this notice, the name of the X Consortium shall not be used in advertising or otherwise to promote the sale, use or other dealings in this Software without prior written authorization from the X Consortium.
X Window System is a trademark of X Consortium, Inc.
```






```
Copyright (c) 2017 Christopher Groskopf and contributors . All rights reserved.
Developed by: 
<Name of Development Group>
<Name of Institution>
<URL for Development Group/Institution>
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal with the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
   * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimers.
   * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimers in the documentation and/or other materials provided with the distribution.
   * Neither the names of <Name of Development Group, Name of Institution> , nor the names of its contributors may be used to endorse or promote products derived from this Software without specific prior written permission.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
```






```
This is free and unencumbered software released into the public domain.
Anyone is free to copy, modify, publish, use, compile, sell, or distribute this software, either in source code form or as a compiled binary, for any purpose, commercial or non-commercial, and by any means.
In jurisdictions that recognize copyright laws, the author or authors of this software dedicate any and all copyright interest in the software to the public domain. We make this dedication for the benefit of the public at large and to the detriment of our heirs and
successors. We intend this dedication to be an overt act of relinquishment in perpetuity of all present and future rights to this software under copyright law.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
For more information, please refer to <http://unlicense.org/>
```






```
Copyright (C) 1993 by Sun Microsystems, Inc. All rights reserved.
Developed at SunPro, a Sun Microsystems, Inc. business.

Permission to use, copy, modify, and distribute this
software is freely granted, provided that this notice
is preserved.
```






```
PYTHON SOFTWARE FOUNDATION LICENSE VERSION 2

  1. This LICENSE AGREEMENT is between the Python Software Foundation ("PSF"), and the Individual or Organization ("Licensee") accessing and otherwise using this software ("Python") in source or binary form and its associated documentation.
  2. Subject to the terms and conditions of this License Agreement, PSF hereby grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python alone or in any derivative version, provided, however, that PSF's License Agreement and PSF's notice of copyright, i.e., "Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved" are retained in Python alone or in any derivative version prepared by Licensee.
  3. In the event Licensee prepares a derivative work that is based on or incorporates Python or any part thereof, and wants to make the derivative work available to others as provided herein, then Licensee hereby agrees to include in any such work a brief summary of the changes made to Python.
  4. PSF is making Python available to Licensee on an "AS IS" basis. PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
  5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
  6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
  7. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between PSF and Licensee. This License Agreement does not grant permission to use PSF trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
  8. By copying, installing or otherwise using Python, Licensee agrees to be bound by the terms and conditions of this License Agreement.
```






```
Copyright 2008 Google Inc.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.
    * Neither the name of Google Inc. nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Code generated by the Protocol Buffer compiler is owned by the owner
of the input file used when generating it.  This code is not
standalone and requires a support library to be linked with it.  This
support library is itself covered by the above license.
```






```
LICENSE ISSUES
  ==============

  The OpenSSL toolkit stays under a dual license, i.e. both the conditions of
  the OpenSSL License and the original SSLeay license apply to the toolkit.
  See below for the actual license texts. Actually both licenses are BSD-style
  Open Source licenses. In case of any license issues related to OpenSSL
  please contact openssl-core@openssl.org.

  OpenSSL License
  ---------------

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1\. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer. 

2\. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3\. All advertising materials mentioning features or use of this
   software must display the following acknowledgment:
   "This product includes software developed by the OpenSSL Project
   for use in the OpenSSL Toolkit. (http://www.openssl.org/)"

4\. The names "OpenSSL Toolkit" and "OpenSSL Project" must not be used to
   endorse or promote products derived from this software without
   prior written permission. For written permission, please contact
   openssl-core@openssl.org.

5\. Products derived from this software may not be called "OpenSSL"
   nor may "OpenSSL" appear in their names without prior written
   permission of the OpenSSL Project.

6\. Redistributions of any form whatsoever must retain the following
   acknowledgment:
   "This product includes software developed by the OpenSSL Project
   for use in the OpenSSL Toolkit (http://www.openssl.org/)"

THIS SOFTWARE IS PROVIDED BY THE OpenSSL PROJECT ``AS IS'' AND ANY
EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE OpenSSL PROJECT OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
OF THE POSSIBILITY OF SUCH DAMAGE.


This product includes cryptographic software written by Eric Young
(eay@cryptsoft.com).  This product includes software written by Tim
Hudson (tjh@cryptsoft.com).


 Original SSLeay License
 -----------------------

Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
All rights reserved.

This package is an SSL implementation written
by Eric Young (eay@cryptsoft.com).
The implementation was written so as to conform with Netscapes SSL.

This library is free for commercial and non-commercial use as long as
the following conditions are aheared to.  The following conditions
apply to all code found in this distribution, be it the RC4, RSA,
lhash, DES, etc., code; not just the SSL code.  The SSL documentation
included with this distribution is covered by the same copyright terms
except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright remains Eric Young's, and as such any Copyright notices in
the code are not to be removed.
If this package is used in a product, Eric Young should be given attribution
as the author of the parts of the library used.
This can be in the form of a textual message at program startup or
in documentation (online or textual) provided with the package.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1\. Redistributions of source code must retain the copyright
   notice, this list of conditions and the following disclaimer.
2\. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3\. All advertising materials mentioning features or use of this software
   must display the following acknowledgement:
   "This product includes cryptographic software written by
    Eric Young (eay@cryptsoft.com)"
   The word 'cryptographic' can be left out if the rouines from the library
   being used are not cryptographic related :-).
4\. If you include any Windows specific code (or a derivative thereof) from 
   the apps directory (application code) you must include an acknowledgement:
   "This product includes software written by Tim Hudson (tjh@cryptsoft.com)"

THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.

The licence and distribution terms for any publically available version or
derivative of this code cannot be changed.  i.e. this code cannot simply be
copied and put under another distribution licence
[including the GNU Public Licence.]
```






```
Open Publication License
v1.0, 8 June 1999

I. REQUIREMENTS ON BOTH UNMODIFIED AND MODIFIED VERSIONS

The Open Publication works may be reproduced and distributed in whole or in part, in any medium physical or electronic, provided that the terms of this license are adhered to, and that this license or an incorporation of it by reference (with any options elected by the author(s) and/or publisher) is displayed in the reproduction.

Proper form for an incorporation by reference is as follows:

    Copyright (c) <year> by <author's name or designee>. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

The reference must be immediately followed with any options elected by the author(s) and/or publisher of the document (see section VI).

Commercial redistribution of Open Publication-licensed material is permitted.

Any publication in standard (paper) book form shall require the citation of the original publisher and author. The publisher and author's names shall appear on all outer surfaces of the book. On all outer surfaces of the book the original publisher's name shall be as large as the title of the work and cited as possessive with respect to the title.


II. COPYRIGHT

The copyright to each Open Publication is owned by its author(s) or designee.


III. SCOPE OF LICENSE

The following license terms apply to all Open Publication works, unless otherwise explicitly stated in the document.

Mere aggregation of Open Publication works or a portion of an Open Publication work with other works or programs on the same media shall not cause this license to apply to those other works. The aggregate work shall contain a notice specifying the inclusion of the Open Publication material and appropriate copyright notice.

SEVERABILITY. If any part of this license is found to be unenforceable in any jurisdiction, the remaining portions of the license remain in force.

NO WARRANTY. Open Publication works are licensed and provided "as is" without warranty of any kind, express or implied, including, but not limited to, the implied warranties of merchantability and fitness for a particular purpose or a warranty of non-infringement.


IV. REQUIREMENTS ON MODIFIED WORKS

All modified versions of documents covered by this license, including translations, anthologies, compilations and partial documents, must meet the following requirements:

   1. The modified version must be labeled as such.
   2. The person making the modifications must be identified and the modifications dated.
   3. Acknowledgement of the original author and publisher if applicable must be retained according to normal academic citation practices.
   4. The location of the original unmodified document must be identified.
   5. The original author's (or authors') name(s) may not be used to assert or imply endorsement of the resulting document without the original author's (or authors') permission. 


V. GOOD-PRACTICE RECOMMENDATIONS

In addition to the requirements of this license, it is requested from and strongly recommended of redistributors that:

   1. If you are distributing Open Publication works on hardcopy or CD-ROM, you provide email notification to the authors of your intent to redistribute at least thirty days before your manuscript or media freeze, to give the authors time to provide updated documents. This notification should describe modifications, if any, made to the document.
   2. All substantive modifications (including deletions) be either clearly marked up in the document or else described in an attachment to the document.
   3. Finally, while it is not mandatory under this license, it is considered good form to offer a free copy of any hardcopy and CD-ROM expression of an Open Publication-licensed work to its author(s). 


VI. LICENSE OPTIONS

The author(s) and/or publisher of an Open Publication-licensed document may elect certain options by appending language to the reference to or copy of the license. These options are considered part of the license instance and must be included with the license (or its incorporation by reference) in derived works.

A. To prohibit distribution of substantively modified versions without the explicit permission of the author(s). "Substantive modification" is defined as a change to the semantic content of the document, and excludes mere changes in format or typographical corrections.

To accomplish this, add the phrase `Distribution of substantively modified versions of this document is prohibited without the explicit permission of the copyright holder.' to the license reference or copy.

B. To prohibit any publication of this work or derivative works in whole or in part in standard (paper) book form for commercial purposes unless prior permission is obtained from the copyright holder.

To accomplish this, add the phrase 'Distribution of the work or derivative of the work in any standard (paper) book form is prohibited unless prior permission is obtained from the copyright holder.' to the license reference or copy.


OPEN PUBLICATION POLICY APPENDIX:

(This is not considered part of the license.)

Open Publication works are available in source format via the Open Publication home page at http://works.opencontent.org/.

Open Publication authors who want to include their own license on Open Publication works may do so, as long as their terms are not more restrictive than the Open Publication license.

If you have questions about the Open Publication License, please contact David Wiley, and/or the Open Publication Authors' List at opal@opencontent.org, via email.

To subscribe to the Open Publication Authors' List:
Send E-mail to opal-request@opencontent.org with the word "subscribe" in the body.

To post to the Open Publication Authors' List:
Send E-mail to opal@opencontent.org or simply reply to a previous post.

To unsubscribe from the Open Publication Authors' List:
Send E-mail to opal-request@opencontent.org with the word "unsubscribe" in the body.
```






```
1\. This LICENSE AGREEMENT is between the Python Software Foundation ("PSF"), and the Individual or Organization ("Licensee") accessing and otherwise using this software ("Python") in source or binary form and its associated documentation.
   2. Subject to the terms and conditions of this License Agreement, PSF hereby grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python alone or in any derivative version, provided, however, that PSF's License Agreement and PSF's notice of copyright, i.e., "Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved" are retained in Python alone or in any derivative version prepared by Licensee.
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python or any part thereof, and wants to make the derivative work available to others as provided herein, then Licensee hereby agrees to include in any such work a brief summary of the changes made to Python.
   4. PSF is making Python available to Licensee on an "AS IS" basis. PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between PSF and Licensee. This License Agreement does not grant permission to use PSF trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By copying, installing or otherwise using Python, Licensee agrees to be bound by the terms and conditions of this License Agreement.
   1. This LICENSE AGREEMENT is between BeOpen.com ("BeOpen"), having an office at 160 Saratoga Avenue, Santa Clara, CA 95051, and the Individual or Organization ("Licensee") accessing and otherwise using this software in source or binary form and its associated documentation ("the Software").
   2. Subject to the terms and conditions of this BeOpen Python License Agreement, BeOpen hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use the Software alone or in any derivative version, provided, however, that the BeOpen Python License is retained in the Software, alone or in any derivative version prepared by Licensee.
   3. BeOpen is making the Software available to Licensee on an "AS IS" basis. BEOPEN MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, BEOPEN MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF THE SOFTWARE WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   4. BEOPEN SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THE SOFTWARE, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   5. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   6. This License Agreement shall be governed by and interpreted in all respects by the law of the State of California, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between BeOpen and Licensee. This License Agreement does not grant permission to use BeOpen trademarks or trade names in a trademark sense to endorse or promote products or services of Licensee, or any third party. As an exception, the "BeOpen Python" logos available at http://www.pythonlabs.com/logos.html may be used according to the permissions granted on that web page.
   7. By copying, installing or otherwise using the software, Licensee agrees to be bound by the terms and conditions of this License Agreement.
   1. This LICENSE AGREEMENT is between the Corporation for National Research Initiatives, having an office at 1895 Preston White Drive, Reston, VA 20191 ("CNRI"), and the Individual or Organization ("Licensee") accessing and otherwise using Python 1.6, beta 1 software in source or binary form and its associated documentation, as released at the www.python.org Internet site on August 4, 2000 ("Python 1.6b1").
   2. Subject to the terms and conditions of this License Agreement, CNRI hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python 1.6b1 alone or in any derivative version, provided, however, that CNRIs License Agreement is retained in Python 1.6b1, alone or in any derivative version prepared by Licensee.
   Alternately, in lieu of CNRIs License Agreement, Licensee may substitute the following text (omitting the quotes): "Python 1.6, beta 1, is made available subject to the terms and conditions in CNRIs License Agreement. This Agreement may be located on the Internet using the following unique, persistent identifier (known as a handle): 1895.22/1011. This Agreement may also be obtained from a proxy server on the Internet using the URL:http://hdl.handle.net/1895.22/1011".
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python 1.6b1 or any part thereof, and wants to make the derivative work available to the public as provided herein, then Licensee hereby agrees to indicate in any such work the nature of the modifications made to Python 1.6b1.
   4. CNRI is making Python 1.6b1 available to Licensee on an "AS IS" basis. CNRI MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, CNRI MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON 1.6b1 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. CNRI SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING PYTHON 1.6b1, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. This License Agreement shall be governed by and interpreted in all respects by the law of the State of Virginia, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between CNRI and Licensee. This License Agreement does not grant permission to use CNRI trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By clicking on the "ACCEPT" button where indicated, or by copying, installing or otherwise using Python 1.6b1, Licensee agrees to be bound by the terms and conditions of this License Agreement.
Copyright (c) 1991 - 1995, Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.
Permission to use, copy, modify, and distribute this software and its documentation for any purpose and without fee is hereby granted, provided that the above copyright notice appear in all copies and that both that copyright notice and this permission notice appear in supporting documentation, and that the name of Stichting Mathematisch Centrum or CWI not be used in advertising or publicity pertaining to distribution of the software without specific, written prior permission.
STICHTING MATHEMATISCH CENTRUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL STICHTING MATHEMATISCH CENTRUM BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
```






```
Copyright 1998, The OpenLDAP Foundation. All Rights Reserved.
Definitions:
"Package" refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
"Standard Version" refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder.
"Copyright Holder" is whoever is named in the copyright or copyrights for the package.
"You" is you, if you're thinking about copying or distributing this Package.
"Reasonable copying fee" is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
"Freely Available" means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as uunet.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
      b) use the modified Package only within your corporation or organization.
      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
      b) accompany the distribution with the machine-readable source of the Package with your modifications.
      c) accompany any non-standard executables with their corresponding Standard Version executables, giving the non-standard executables non-standard names, and clearly documenting the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own.
   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.
   7. C subroutines supplied by you and linked into this Package in order to emulate subroutines and variables of the language defined by this Package shall not be considered part of this Package, but are the equivalent of input as in Paragraph 6, provided these subroutines do not change the language in any way that would cause it to fail the regression tests for the language.
   8. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
   9. THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
```






```
1\. Definitions.
      1.1. "Contributor" means each entity that creates or contributes to the creation of Modifications.
      1.2. "Contributor Version" means the combination of the Original Code, prior Modifications used by a Contributor, and the Modifications made by that particular Contributor.
      1.3. "Covered Code" means the Original Code or Modifications or the combination of the Original Code and Modifications, in each case including portions thereof.
      1.4. "Electronic Distribution Mechanism" means a mechanism generally accepted in the software development community for the electronic transfer of data.
      1.5. "Executable" means Covered Code in any form other than Source Code.
      1.6. "Initial Developer" means the individual or entity identified as the Initial Developer in the Source Code notice required by Exhibit A.
      1.7. "Larger Work" means a work, which combines Covered Code or portions thereof with code not governed by the terms of this License.
      1.8. "License" means this document and the corresponding addendum described in section 6.4 below.
      1.9. "Modifications" means any addition to or deletion from the substance or structure of either the Original Code or any previous Modifications. When Covered Code is released as a series of files, a Modification is:
         A. Any addition to or deletion from the contents of a file containing Original Code or previous Modifications.
         B. Any new file that contains any part of the Original Code or previous Modifications.
      1.10. "Original Code" means Source Code of computer software code which is described in the Source Code notice required by Exhibit A as Original Code, and which, at the time of its release under this License is not already Covered Code governed by this License.
      1.11. "Source Code" means the preferred form of the Covered Code for making modifications to it, including all modules it contains, plus any associated interface definition files, scripts used to control compilation and installation of an Executable, or a list of source code differential comparisons against either the Original Code or another well known, available Covered Code of the Contributor's choice. The Source Code can be in a compressed or archival form, provided the appropriate decompression or de-archiving software is widely available for no charge.
      1.12. "You" means an individual or a legal entity exercising rights under, and complying with all of the terms of, this License or a future version of this License issued under Section 6.1. For legal entities, "You'' includes any entity which controls, is controlled by, or is under common control with You. For purposes of this definition, "control'' means (a) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (b) ownership of fifty percent (50%) or more of the outstanding shares or beneficial ownership of such entity.
      1.13 "License Author" means Lutris Technologies, Inc.
   2. Source Code License.
      2.1. The Initial Developer Grant. The Initial Developer hereby grants You a worldwide, royalty-free, non-exclusive license, subject to third party intellectual property claims:
         (a) under intellectual property rights (other than patent or trademark) to use, reproduce, modify, display, perform, sublicense and distribute the Original Code (or portions thereof) with or without Modifications, or as part of a Larger Work; and
         (b) under patents now or hereafter owned or controlled by Initial Developer, to make, have made, use and sell (``offer to sell and import'') the Original Code (or portions thereof), but solely to the extent that any such patent is reasonably necessary to enable You to Utilize the Original Code (or portions thereof) and not to any greater extent that may be necessary to Utilize further Modifications or combinations.
      2.2. Contributor Grant. Each Contributor hereby grants You a worldwide, royalty-free, non-exclusive license, subject to third party intellectual property claims:
         (a) under intellectual property rights (other than patent or trademark) to use, reproduce, modify, display, perform, sublicense and distribute the Modifications created by such Contributor (or portions thereof) either on an unmodified basis, with other Modifications, as Covered Code or as part of a Larger Work; and
         (b) under patents now or hereafter owned or controlled by Contributor, to to make, have made, use and sell (``offer to sell and import'') the Contributor Version (or portions thereof), but solely to the extent that any such patent is reasonably necessary to enable You to Utilize the Contributor Version (or portions thereof), and not to any greater extent that may be necessary to Utilize further Modifications or combinations
   3. Distribution Obligations.
      3.1. Application of License. The Modifications which You create or to which You contribute are governed by the terms of this License, including without limitation Section 2.2. The Source Code version of Covered Code may be distributed only under the terms of this License or a future version of this License released under Section 6.1, and You must include a copy of this License with every copy of the Source Code You distribute. You may not offer or impose any terms on any Source Code version that alters or restricts the applicable version of this License or the recipients' rights hereunder. However, You may include an additional document offering the additional rights described in Section 3.5.
      3.2. Availability of Source Code. Any Modification which You create or to which You contribute must be made available, prior to any use, except for internal development and practice, in Source Code form under the terms of this License either on the same media as an Executable version or via an accepted Electronic Distribution Mechanism to anyone to whom you made an Executable version available; and if made available via Electronic Distribution Mechanism, must remain available for at least twelve (12) months after the date it initially became available, or at least six (6) months after a subsequent version of that particular Modification has been made available to such recipients. You shall notify the Initial Developer of the Modification and the location of the Source Code via the contact means provided for in the Developer Specific license. Initial Developer will be acting as maintainer of the Source Code and may provide an Electronic Distribution mechanism for the Modification to be made available.
      3.3. Description of Modifications. You must cause all Covered Code to which you contribute to contain a file documenting the changes You made to create that Covered Code and the date of any change. You must include a prominent statement that the Modification is derived, directly or indirectly, from Original Code provided by the Initial Developer and including the name of the Initial Developer in (a) the Source Code, and (b) in any notice in an Executable version or related documentation in which You describe the origin or ownership of the Covered Code.
      3.4. Intellectual Property Matters
         (a) Third Party Claims. If You have knowledge that a party claims an intellectual property right in particular functionality or code (or its utilization under this License), you must include a text file with the source code distribution titled "LEGAL" which describes the claim and the party making the claim in sufficient detail that a recipient will know whom to contact. If you obtain such knowledge after You make Your Modification available as described in Section 3.2, You shall promptly modify the LEGAL file in all copies You make available thereafter and shall take other steps (such as notifying appropriate mailing lists or newsgroups) reasonably calculated to inform those who received the Covered Code that new knowledge has been obtained.
         (b) Representations. Contributor represents that, except as disclosed pursuant to Section 3.4(a) above, Contributor believes that Contributor's Modifications are Contributor's original creation(s) and/or Contributor has sufficient rights to grant the rights conveyed by this License.
      3.5. Required Notices. You must duplicate the notice in Exhibit A in each file of the Source Code, and this License in any documentation for the Source Code, where You describe recipients' rights relating to Covered Code. If You created one or more Modification(s), You may add your name as a Contributor to the notice described in Exhibit A. If it is not possible to put such notice in a particular Source Code file due to its structure, then you must include such notice in a location (such as a relevant directory file) where a user would be likely to look for such a notice. You may choose to offer, and to charge a fee for, warranty, support, indemnity or liability obligations to one or more recipients of Covered Code. However, You may do so only on Your own behalf, and not on behalf of the Initial Developer or any Contributor. You must make it absolutely clear that any such warranty, support, indemnity or liability obligation is offered by You alone, and You hereby agree to indemnify the Initial Developer and every Contributor for any liability incurred by the Initial Developer or such Contributor as a result of warranty, support, indemnity or liability terms You offer.
      3.6. Distribution of Executable Versions. You may distribute Covered Code in Executable form only if the requirements of Section 3.1-3.5 have been met for that Covered Code, and if You include a notice stating that the Source Code version of the Covered Code is available under the terms of this License, including a description of how and where You have fulfilled the obligations of Section 3.2. The notice must be conspicuously included in any notice in an Executable version, related documentation or collateral in which You describe recipients' rights relating to the Covered Code. You may distribute the Executable version of Covered Code under a license of Your choice, which may contain terms different from this License, provided that You are in compliance with the terms of this License and that the license for the Executable version does not attempt to limit or alter the recipient's rights in the Source Code version from the rights set forth in this License. If You distribute the Executable version under a different license You must make it absolutely clear that any terms which differ from this License are offered by You alone, not by the Initial Developer or any Contributor. You hereby agree to indemnify the Initial Developer and every Contributor for any liability incurred by the Initial Developer or such Contributor as a result of any such terms You offer. If you distribute executable versions containing Covered Code, you must reproduce the notice in Exhibit B in the documentation and/or other materials provided with the product.
      3.7. Larger Works. You may create a Larger Work by combining Covered Code with other code not governed by the terms of this License and distribute the Larger Work as a single product. In such a case, You must make sure the requirements of this License are fulfilled for the Covered Code.
   4. Inability to Comply Due to Statute or Regulation.
   If it is impossible for You to comply with any of the terms of this License with respect to some or all of the Covered Code due to statute or regulation then You must: (a) comply with the terms of this License to the maximum extent possible; and (b) Cite all of the statutes or regulations that prohibit you from complying fully with this license. (c) describe the limitations and the code they affect. Such description must be included in the LEGAL file described in Section 3.4 and must be included with all distributions of the Source Code. Except to the extent prohibited by statute or regulation, such description must be sufficiently detailed for a recipient of ordinary skill to be able to understand it.
   5. Application of this License.
   This License applies to code to which the Initial Developer has attached the notice in Exhibit A, and to related Covered Code.
   6. Versions of the License.
      6.1. New Versions. License Author may publish revised and/or new versions of the License from time to time. Each version will be given a distinguishing version number and shall be submitted to opensource.org for certification.
      6.2. Effect of New Versions. Once Covered Code has been published under a particular version of the License, You may always continue to use it under the terms of that version. You may also choose to use such Covered Code under the terms of any subsequent version of the License published by Initial Developer. No one other than Initial Developer has the right to modify the terms applicable to Covered Code created under this License.
      6.3. Derivative Works. If you create or use a modified version of this License, except in association with the required Developer Specific License described in section 6.4, (which you may only do in order to apply it to code which is not already Covered Code governed by this License), you must (a) rename Your license so that the phrases ``Open'', ``OpenPL'', ``OPL'' or any confusingly similar phrase do not appear anywhere in your license and (b) otherwise make it clear that your version of the license contains terms which differ from the Open Public License. (Filling in the name of the Initial Developer, Original Code or Contributor in the notice described in Exhibit A shall not of themselves be deemed to be modifications of this License.)
      6.4. Required Additional Developer Specific License
      This license is a union of the following two parts that should be found as text files in the same place (directory), in the order of preeminence:
         [1] A Developer specific license.
         [2] The contents of this file OPL_1_0.TXT, stating the general licensing policy of the software.
      In case of conflicting dispositions in the parts of this license, the terms of the lower-numbered part will always be superseded by the terms of the higher numbered part.
   7. DISCLAIMER OF WARRANTY.
   COVERED CODE IS PROVIDED UNDER THIS LICENSE ON AN "AS IS" BASIS, WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES THAT THE COVERED CODE IS FREE OF DEFECTS, MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE OR NON-INFRINGING. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE COVERED CODE IS WITH YOU. SHOULD ANY COVERED CODE PROVE DEFECTIVE IN ANY RESPECT, YOU (NOT THE INITIAL DEVELOPER OR ANY OTHER CONTRIBUTOR) ASSUME THE COST OF ANY NECESSARY SERVICING, REPAIR OR CORRECTION. THIS DISCLAIMER OF WARRANTY CONSTITUTES AN ESSENTIAL PART OF THIS LICENSE. NO USE OF ANY COVERED CODE IS AUTHORIZED HEREUNDER EXCEPT UNDER THIS DISCLAIMER.
   8. TERMINATION.
      8.1 Termination upon Breach
      This License and the rights granted hereunder will terminate automatically if You fail to comply with terms herein and fail to cure such breach within 30 days of becoming aware of the breach. All sublicenses to the Covered Code, which are properly granted, shall survive any termination of this License. Provisions that, by their nature, must remain in effect beyond the termination of this License shall survive.
      8.2. Termination Upon Litigation. If You initiate litigation by asserting a patent infringement claim (excluding declatory judgment actions) against Initial Developer or a Contributor (the Initial Developer or Contributor against whom You file such action is referred to as "Participant") alleging that:
         (a) such Participant's Contributor Version directly or indirectly infringes any patent, then any and all rights granted by such Participant to You under Sections 2.1 and/or 2.2 of this License shall, upon 60 days notice from Participant terminate prospectively, unless if within 60 days after receipt of notice You either: (i) agree in writing to pay Participant a mutually agreeable reasonable royalty for Your past and future use of Modifications made by such Participant, or (ii) withdraw Your litigation claim with respect to the Contributor Version against such Participant. If within 60 days of notice, a reasonable royalty and payment arrangement are not mutually agreed upon in writing by the parties or the litigation claim is not withdrawn, the rights granted by Participant to You under Sections 2.1 and/or 2.2 automatically terminate at the expiration of the 60 day notice period specified above.
         (b) any software, hardware, or device, other than such Participant's Contributor Version, directly or indirectly infringes any patent, then any rights granted to You by such Participant under Sections 2.1(b) and 2.2(b) are revoked effective as of the date You first made, used, sold, distributed, or had made, Modifications made by that Participant.
      8.3. If You assert a patent infringement claim against Participant alleging that such Participant's Contributor Version directly or indirectly infringes any patent where such claim is resolved (such as by license or settlement) prior to the initiation of patent infringement litigation, then the reasonable value of the licenses granted by such Participant under Sections 2.1 or 2.2 shall be taken into account in determining the amount or value of any payment or license.
      8.4. In the event of termination under Sections 8.1 or 8.2 above, all end user license agreements (excluding distributors and resellers) which have been validly granted by You or any distributor hereunder prior to termination shall survive termination.
   9. LIMITATION OF LIABILITY.
   UNDER NO CIRCUMSTANCES AND UNDER NO LEGAL THEORY, WHETHER TORT (INCLUDING NEGLIGENCE), CONTRACT, OR OTHERWISE, SHALL THE INITIAL DEVELOPER, ANY OTHER CONTRIBUTOR, OR ANY DISTRIBUTOR OF COVERED CODE, OR ANY SUPPLIER OF ANY OF SUCH PARTIES, BE LIABLE TO YOU OR ANY OTHER PERSON FOR ANY INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES OF ANY CHARACTER INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF GOODWILL, WORK STOPPAGE, COMPUTER FAILURE OR MALFUNCTION, OR ANY AND ALL OTHER COMMERCIAL DAMAGES OR LOSSES, EVEN IF SUCH PARTY SHALL HAVE BEEN INFORMED OF THE POSSIBILITY OF SUCH DAMAGES. THIS LIMITATION OF LIABILITY SHALL NOT APPLY TO LIABILITY FOR DEATH OR PERSONAL INJURY RESULTING FROM SUCH PARTY'S NEGLIGENCE TO THE EXTENT APPLICABLE LAW PROHIBITS SUCH LIMITATION. SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OR LIMITATION OF INCIDENTAL OR CONSEQUENTIAL DAMAGES, SO THAT EXCLUSION AND LIMITATION MAY NOT APPLY TO YOU.
   10. U.S. GOVERNMENT END USERS.
   The Covered Code is a ``commercial item,'' as that term is defined in 48 C.F.R. 2.101 (Oct. 1995), consisting of ``commercial computer software'' and ``commercial computer software documentation,'' as such terms are used in 48 C.F.R. 12.212 (Sept. 1995). Consistent with 48 C.F.R. 12.212 and 48 C.F.R. 227.7202-1 through 227.7202-4 (June 1995), all U.S. Government End Users acquire Covered Code with only those rights set forth herein.
   11. MISCELLANEOUS.
   his section was intentionally left blank. The contents of this section are found in the corresponding addendum described above.
   12. RESPONSIBILITY FOR CLAIMS.
Except in cases where another Contributor has failed to comply with Section 3.4, You are responsible for damages arising, directly or indirectly, out of Your utilization of rights under this License, based on the number of copies of Covered Code you made available, the revenues you received from utilizing such rights, and other relevant factors. You agree to work with affected parties to distribute with Initial Developer responsibility on an equitable basis.
```






```
1\. Definitions
      1.1. "Contributor" means each individual or legal entity that creates, contributes to the creation of, or owns Covered Software.
      1.2. "Contributor Version" means the combination of the Contributions of others (if any) used by a Contributor and that particular Contributor's Contribution.
      1.3. "Contribution" means Covered Software of a particular Contributor.
      1.4. "Covered Software" means Source Code Form to which the initial Contributor has attached the notice in Exhibit A, the Executable Form of such Source Code Form, and Modifications of such Source Code Form, in each case including portions thereof.
      1.5. "Incompatible With Secondary Licenses" means
         (a) that the initial Contributor has attached the notice described in Exhibit B to the Covered Software; or
         (b) that the Covered Software was made available under the terms of version 1.1 or earlier of the License, but not also under the terms of a Secondary License.
      1.6. "Executable Form" means any form of the work other than Source Code Form.
      1.7. "Larger Work" means a work that combines Covered Software with other material, in a separate file or files, that is not Covered Software.
      1.8. "License" means this document.
      1.9. "Licensable" means having the right to grant, to the maximum extent possible, whether at the time of the initial grant or subsequently, any and all of the rights conveyed by this License.
      1.10. "Modifications" means any of the following:
         (a) any file in Source Code Form that results from an addition to, deletion from, or modification of the contents of Covered Software; or
         (b) any new file in Source Code Form that contains any Covered Software.
      1.11. "Patent Claims" of a Contributor means any patent claim(s), including without limitation, method, process, and apparatus claims, in any patent Licensable by such Contributor that would be infringed, but for the grant of the License, by the making, using, selling, offering for sale, having made, import, or transfer of either its Contributions or its Contributor Version.
      1.12. "Secondary License" means either the GNU General Public License, Version 2.0, the GNU Lesser General Public License, Version 2.1, the GNU Affero General Public License, Version 3.0, or any later versions of those licenses.
      1.13. "Source Code Form" means the form of the work preferred for making modifications.
      1.14. "You" (or "Your") means an individual or a legal entity exercising rights under this License. For legal entities, "You" includes any entity that controls, is controlled by, or is under common control with You. For purposes of this definition, "control" means (a) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (b) ownership of more than fifty percent (50%) of the outstanding shares or beneficial ownership of such entity.
   2. License Grants and Conditions
      2.1. Grants
      Each Contributor hereby grants You a world-wide, royalty-free, non-exclusive license:
         (a) under intellectual property rights (other than patent or trademark) Licensable by such Contributor to use, reproduce, make available, modify, display, perform, distribute, and otherwise exploit its Contributions, either on an unmodified basis, with Modifications, or as part of a Larger Work; and
         (b) under Patent Claims of such Contributor to make, use, sell, offer for sale, have made, import, and otherwise transfer either its Contributions or its Contributor Version.
      2.2. Effective Date
      The licenses granted in Section 2.1 with respect to any Contribution become effective for each Contribution on the date the Contributor first distributes such Contribution.
      2.3. Limitations on Grant Scope
      The licenses granted in this Section 2 are the only rights granted under this License. No additional rights or licenses will be implied from the distribution or licensing of Covered Software under this License. Notwithstanding Section 2.1(b) above, no patent license is granted by a Contributor:
         (a) for any code that a Contributor has removed from Covered Software; or
         (b) for infringements caused by: (i) Your and any other third party's modifications of Covered Software, or (ii) the combination of its Contributions with other software (except as part of its Contributor Version); or
         (c) under Patent Claims infringed by Covered Software in the absence of its Contributions.
      This License does not grant any rights in the trademarks, service marks, or logos of any Contributor (except as may be necessary to comply with the notice requirements in Section 3.4).
      2.4. Subsequent Licenses
      No Contributor makes additional grants as a result of Your choice to distribute the Covered Software under a subsequent version of this License (see Section 10.2) or under the terms of a Secondary License (if permitted under the terms of Section 3.3).
      2.5. Representation
      Each Contributor represents that the Contributor believes its Contributions are its original creation(s) or it has sufficient rights to grant the rights to its Contributions conveyed by this License.
      2.6. Fair Use
      This License is not intended to limit any rights You have under applicable copyright doctrines of fair use, fair dealing, or other equivalents.
      2.7. Conditions
      Sections 3.1, 3.2, 3.3, and 3.4 are conditions of the licenses granted in Section 2.1.
   3. Responsibilities
      3.1. Distribution of Source Form
      All distribution of Covered Software in Source Code Form, including any Modifications that You create or to which You contribute, must be under the terms of this License. You must inform recipients that the Source Code Form of the Covered Software is governed by the terms of this License, and how they can obtain a copy of this License. You may not attempt to alter or restrict the recipients' rights in the Source Code Form.
      3.2. Distribution of Executable Form
      If You distribute Covered Software in Executable Form then:
         (a) such Covered Software must also be made available in Source Code Form, as described in Section 3.1, and You must inform recipients of the Executable Form how they can obtain a copy of such Source Code Form by reasonable means in a timely manner, at a charge no more than the cost of distribution to the recipient; and
         (b) You may distribute such Executable Form under the terms of this License, or sublicense it under different terms, provided that the license for the Executable Form does not attempt to limit or alter the recipients' rights in the Source Code Form under this License.
      3.3. Distribution of a Larger Work
      You may create and distribute a Larger Work under terms of Your choice, provided that You also comply with the requirements of this License for the Covered Software. If the Larger Work is a combination of Covered Software with a work governed by one or more Secondary Licenses, and the Covered Software is not Incompatible With Secondary Licenses, this License permits You to additionally distribute such Covered Software under the terms of such Secondary License(s), so that the recipient of the Larger Work may, at their option, further distribute the Covered Software under the terms of either this License or such Secondary License(s).
      3.4. Notices
      You may not remove or alter the substance of any license notices (including copyright notices, patent notices, disclaimers of warranty, or limitations of liability) contained within the Source Code Form of the Covered Software, except that You may alter any license notices to the extent required to remedy known factual inaccuracies.
      3.5. Application of Additional Terms
      You may choose to offer, and to charge a fee for, warranty, support, indemnity or liability obligations to one or more recipients of Covered Software. However, You may do so only on Your own behalf, and not on behalf of any Contributor. You must make it absolutely clear that any such warranty, support, indemnity, or liability obligation is offered by You alone, and You hereby agree to indemnify every Contributor for any liability incurred by such Contributor as a result of warranty, support, indemnity or liability terms You offer. You may include additional disclaimers of warranty and limitations of liability specific to any jurisdiction.
   4. Inability to Comply Due to Statute or Regulation
   If it is impossible for You to comply with any of the terms of this License with respect to some or all of the Covered Software due to statute, judicial order, or regulation then You must: (a) comply with the terms of this License to the maximum extent possible; and (b) describe the limitations and the code they affect. Such description must be placed in a text file included with all distributions of the Covered Software under this License. Except to the extent prohibited by statute or regulation, such description must be sufficiently detailed for a recipient of ordinary skill to be able to understand it.
   5. Termination
      5.1. The rights granted under this License will terminate automatically if You fail to comply with any of its terms. However, if You become compliant, then the rights granted under this License from a particular Contributor are reinstated (a) provisionally, unless and until such Contributor explicitly and finally terminates Your grants, and (b) on an ongoing basis, if such Contributor fails to notify You of the non-compliance by some reasonable means prior to 60 days after You have come back into compliance. Moreover, Your grants from a particular Contributor are reinstated on an ongoing basis if such Contributor notifies You of the non-compliance by some reasonable means, this is the first time You have received notice of non-compliance with this License from such Contributor, and You become compliant prior to 30 days after Your receipt of the notice.
      5.2. If You initiate litigation against any entity by asserting a patent infringement claim (excluding declaratory judgment actions, counter-claims, and cross-claims) alleging that a Contributor Version directly or indirectly infringes any patent, then the rights granted to You by any and all Contributors for the Covered Software under Section 2.1 of this License shall terminate.
      5.3. In the event of termination under Sections 5.1 or 5.2 above, all end user license agreements (excluding distributors and resellers) which have been validly granted by You or Your distributors under this License prior to termination shall survive termination.
   6. Disclaimer of Warranty
   Covered Software is provided under this License on an "as is" basis, without warranty of any kind, either expressed, implied, or statutory, including, without limitation, warranties that the Covered Software is free of defects, merchantable, fit for a particular purpose or non-infringing. The entire risk as to the quality and performance of the Covered Software is with You. Should any Covered Software prove defective in any respect, You (not any Contributor) assume the cost of any necessary servicing, repair, or correction. This disclaimer of warranty constitutes an essential part of this License. No use of any Covered Software is authorized under this License except under this disclaimer.
   7. Limitation of Liability
   Under no circumstances and under no legal theory, whether tort (including negligence), contract, or otherwise, shall any Contributor, or anyone who distributes Covered Software as permitted above, be liable to You for any direct, indirect, special, incidental, or consequential damages of any character including, without limitation, damages for lost profits, loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses, even if such party shall have been informed of the possibility of such damages. This limitation of liability shall not apply to liability for death or personal injury resulting from such party's negligence to the extent applicable law prohibits such limitation. Some jurisdictions do not allow the exclusion or limitation of incidental or consequential damages, so this exclusion and limitation may not apply to You.
   8. Litigation
   Any litigation relating to this License may be brought only in the courts of a jurisdiction where the defendant maintains its principal place of business and such litigation shall be governed by laws of that jurisdiction, without reference to its conflict-of-law provisions. Nothing in this Section shall prevent a party's ability to bring cross-claims or counter-claims.
   9. Miscellaneous
   This License represents the complete agreement concerning the subject matter hereof. If any provision of this License is held to be unenforceable, such provision shall be reformed only to the extent necessary to make it enforceable. Any law or regulation which provides that the language of a contract shall be construed against the drafter shall not be used to construe this License against a Contributor.
   10. Versions of the License
      10.1. New Versions
      Mozilla Foundation is the license steward. Except as provided in Section 10.3, no one other than the license steward has the right to modify or publish new versions of this License. Each version will be given a distinguishing version number.
      10.2. Effect of New Versions
      You may distribute the Covered Software under the terms of the version of the License under which You originally received the Covered Software, or under the terms of any subsequent version published by the license steward.
      10.3. Modified Versions
      If you create software not governed by this License, and you want to create a new license for such software, you may create and use a modified version of this License if you rename the license and remove any references to the name of the license steward (except to note that such modified license differs from this License).
      10.4. Distributing Source Code Form that is Incompatible With Secondary Licenses
      If You choose to distribute Source Code Form that is Incompatible With Secondary Licenses under the terms of this version of the License, the notice described in Exhibit B of this License must be attached.
```






```
Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and
that both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the authors not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission. The authors
makes no representations about the suitability of this software for any
purpose. It is provided "as is" without express or implied warranty.
```






```
Permission to use, copy, modify, and/or distribute this code
for any purpose with or without fee is hereby granted.
There is no warranty.
```






```
Permission is hereby granted, free of charge, to any person obtaining a copy of this
software and associated documentation files (the "Software"), to deal in the Software
without restriction, including without limitation the rights to use, copy, modify,
merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
```






```
Permission to use, copy, modify, and/or distribute this software for any purpose
with or without fee is hereby granted, provided that the above copyright notice
and this permission notice appear in all copies.

The software is  provided "as is", without warranty of any kind, including all
implied warranties of merchantability and fitness. In no event shall the authors
or copyright holders be liable for any claim, damages, or other liability,
whether in an action of contract, tort, or otherwise, arising from, out of, or
in connection with the software or the use or other dealings in the software.
```






```
Copyright (C) 2007 Free Software Foundation, Inc. <http ://fsf.org/>
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
This version of the GNU Lesser General Public License incorporates the terms and conditions of version 3 of the GNU General Public License, supplemented by the additional permissions listed below.
   0. Additional Definitions.
      
      As used herein, "this License" refers to version 3 of the GNU Lesser General Public License, and the "GNU GPL" refers to version 3 of the GNU General Public License.
      
      "The Library" refers to a covered work governed by this License, other than an Application or a Combined Work as defined below.
      
      An "Application" is any work that makes use of an interface provided by the Library, but which is not otherwise based on the Library. Defining a subclass of a class defined by the Library is deemed a mode of using an interface provided by the Library.
      
      A "Combined Work" is a work produced by combining or linking an Application with the Library. The particular version of the Library with which the Combined Work was made is also called the "Linked Version".
      
      The "Minimal Corresponding Source" for a Combined Work means the Corresponding Source for the Combined Work, excluding any source code for portions of the Combined Work that, considered in isolation, are based on the Application, and not on the Linked Version.
      
      The "Corresponding Application Code" for a Combined Work means the object code and/or source code for the Application, including any data and utility programs needed for reproducing the Combined Work from the Application, but excluding the System Libraries of the Combined Work.
   1. Exception to Section 3 of the GNU GPL.
   You may convey a covered work under sections 3 and 4 of this License without being bound by section 3 of the GNU GPL.
   2. Conveying Modified Versions.
   If you modify a copy of the Library, and, in your modifications, a facility refers to a function or data to be supplied by an Application that uses the facility (other than as an argument passed when the facility is invoked), then you may convey a copy of the modified version:
      a) under this License, provided that you make a good faith effort to ensure that, in the event an Application does not supply the function or data, the facility still operates, and performs whatever part of its purpose remains meaningful, or
      b) under the GNU GPL, with none of the additional permissions of this License applicable to that copy.
   3. Object Code Incorporating Material from Library Header Files.
   The object code form of an Application may incorporate material from a header file that is part of the Library. You may convey such object code under terms of your choice, provided that, if the incorporated material is not limited to numerical parameters, data structure layouts and accessors, or small macros, inline functions and templates (ten or fewer lines in length), you do both of the following:
      a) Give prominent notice with each copy of the object code that the Library is used in it and that the Library and its use are covered by this License.
      b) Accompany the object code with a copy of the GNU GPL and this license document.
   4. Combined Works.
   You may convey a Combined Work under terms of your choice that, taken together, effectively do not restrict modification of the portions of the Library contained in the Combined Work and reverse engineering for debugging such modifications, if you also do each of the following:
      a) Give prominent notice with each copy of the Combined Work that the Library is used in it and that the Library and its use are covered by this License.
      b) Accompany the Combined Work with a copy of the GNU GPL and this license document.
      c) For a Combined Work that displays copyright notices during execution, include the copyright notice for the Library among these notices, as well as a reference directing the user to the copies of the GNU GPL and this license document.
      d) Do one of the following:
         0) Convey the Minimal Corresponding Source under the terms of this License, and the Corresponding Application Code in a form suitable for, and under terms that permit, the user to recombine or relink the Application with a modified version of the Linked Version to produce a modified Combined Work, in the manner specified by section 6 of the GNU GPL for conveying Corresponding Source.
         1) Use a suitable shared library mechanism for linking with the Library. A suitable mechanism is one that (a) uses at run time a copy of the Library already present on the user's computer system, and (b) will operate properly with a modified version of the Library that is interface-compatible with the Linked Version.
      e) Provide Installation Information, but only if you would otherwise be required to provide such information under section 6 of the GNU GPL, and only to the extent that such information is necessary to install and execute a modified version of the Combined Work produced by recombining or relinking the Application with a modified version of the Linked Version. (If you use option 4d0, the Installation Information must accompany the Minimal Corresponding Source and Corresponding Application Code. If you use option 4d1, you must provide the Installation Information in the manner specified by section 6 of the GNU GPL for conveying Corresponding Source.)
   5. Combined Libraries.
   You may place library facilities that are a work based on the Library side by side in a single library together with other library facilities that are not Applications and are not covered by this License, and convey such a combined library under terms of your choice, if you do both of the following:
      a) Accompany the combined library with a copy of the same work based on the Library, uncombined with any other library facilities, conveyed under the terms of this License.
      b) Give prominent notice with the combined library that part of it is a work based on the Library, and explaining where to find the accompanying uncombined form of the same work.
   6. Revised Versions of the GNU Lesser General Public License.
   The Free Software Foundation may publish revised and/or new versions of the GNU Lesser General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Library as you received it specifies that a certain numbered version of the GNU Lesser General Public License "or any later version" applies to it, you have the option of following the terms and conditions either of that published version or of any later version published by the Free Software Foundation. If the Library as you received it does not specify a version number of the GNU Lesser General Public License, you may choose any version of the GNU Lesser General Public License ever published by the Free Software Foundation.
   If the Library as you received it specifies that a proxy can decide whether future versions of the GNU Lesser General Public License shall apply, that proxy's public statement of acceptance of any version is permanent authorization for you to choose that version for the Library.
```






```
Copyright (c) 2017 Christopher Groskopf and contributors
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```






```
Copyright (c) 2017 Christopher Groskopf and contributors
Permission to use, copy, modify, and distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
```






```
The Licensor provides the Licensed Program (as defined in Article 1 below) under the terms of this license agreement ("Agreement"). Any use, reproduction or distribution of the Licensed Program, or any exercise of rights under this Agreement by a Recipient (as defined in Article 1 below) constitutes the Recipient's acceptance of this Agreement.
Article 1 (Definitions)
   1. "Digital Font Program" shall mean a computer program containing, or used to render or display fonts.
   2. "Licensed Program" shall mean a Digital Font Program licensed by the Licensor under this Agreement.
   3. "Derived Program" shall mean a Digital Font Program created as a result of a modification, addition, deletion, replacement or any other adaptation to or of a part or all of the Licensed Program, and includes a case where a Digital Font Program newly created by retrieving font information from a part or all of the Licensed Program or Embedded Fonts from a Digital Document File with or without modification of the retrieved font information.
   4. "Digital Content" shall mean products provided to end users in the form of digital data, including video content, motion and/or still pictures, TV programs or other broadcasting content and products consisting of character text, pictures, photographic images, graphic symbols and/or the like.
   5. "Digital Document File" shall mean a PDF file or other Digital Content created by various software programs in which a part or all of the Licensed Program becomes embedded or contained in the file for the display of the font ("Embedded Fonts"). Embedded Fonts are used only in the display of characters in the particular Digital Document File within which they are embedded, and shall be distinguished from those in any Digital Font Program, which may be used for display of characters outside that particular Digital Document File.
   6. "Computer" shall include a server in this Agreement.
   7. "Reproduction and Other Exploitation" shall mean reproduction, transfer, distribution, lease, public transmission, presentation, exhibition, adaptation and any other exploitation.
   8. "Recipient" shall mean anyone who receives the Licensed Program under this Agreement, including one that receives the Licensed Program from a Recipient.
Article 2 (Grant of License)
The Licensor grants to the Recipient a license to use the Licensed Program in any and all countries in accordance with each of the provisions set forth in this Agreement. However, any and all rights underlying in the Licensed Program shall be held by the Licensor. In no sense is this Agreement intended to transfer any right relating to the Licensed Program held by the Licensor except as specifically set forth herein or any right relating to any trademark, trade name, or service mark to the Recipient.
   1. The Recipient may install the Licensed Program on any number of Computers and use the same in accordance with the provisions set forth in this Agreement.
   2. The Recipient may use the Licensed Program, with or without modification in printed materials or in Digital Content as an expression of character texts or the like.
   3. The Recipient may conduct Reproduction and Other Exploitation of the printed materials and Digital Content created in accordance with the preceding Paragraph, for commercial or non-commercial purposes and in any form of media including but not limited to broadcasting, communication and various recording media.
   4. If any Recipient extracts Embedded Fonts from a Digital Document File to create a Derived Program, such Derived Program shall be subject to the terms of this agreement.
   5. If any Recipient performs Reproduction or Other Exploitation of a Digital Document File in which Embedded Fonts of the Licensed Program are used only for rendering the Digital Content within such Digital Document File then such Recipient shall have no further obligations under this Agreement in relation to such actions.
   6. The Recipient may reproduce the Licensed Program as is without modification and transfer such copies, publicly transmit or otherwise redistribute the Licensed Program to a third party for commercial or non-commercial purposes ("Redistribute"), in accordance with the provisions set forth in Article 3 Paragraph 2.
   7. The Recipient may create, use, reproduce and/or Redistribute a Derived Program under the terms stated above for the Licensed Program: provided, that the Recipient shall follow the provisions set forth in Article 3 Paragraph 1 when Redistributing the Derived Program.
Article 3 (Restriction)
The license granted in the preceding Article shall be subject to the following restrictions:
   1. If a Derived Program is Redistributed pursuant to Paragraph 4 and 7 of the preceding Article, the following conditions must be met :
      (1) The following must be also Redistributed together with the Derived Program, or be made available online or by means of mailing mechanisms in exchange for a cost which does not exceed the total costs of postage, storage medium and handling fees:
         (a) a copy of the Derived Program; and
         (b) any additional file created by the font developing program in the course of creating the Derived Program that can be used for further modification of the Derived Program, if any.
      (2) It is required to also Redistribute means to enable recipients of the Derived Program to replace the Derived Program with the Licensed Program first released under this License (the "Original Program"). Such means may be to provide a difference file from the Original Program, or instructions setting out a method to replace the Derived Program with the Original Program.
      (3) The Recipient must license the Derived Program under the terms and conditions of this Agreement.
      (4) No one may use or include the name of the Licensed Program as a program name, font name or file name of the Derived Program.
      (5) Any material to be made available online or by means of mailing a medium to satisfy the requirements of this paragraph may be provided, verbatim, by any party wishing to do so.
   2. If the Recipient Redistributes the Licensed Program pursuant to Paragraph 6 of the preceding Article, the Recipient shall meet all of the following conditions:
      (1) The Recipient may not change the name of the Licensed Program.
      (2) The Recipient may not alter or otherwise modify the Licensed Program.
      (3) The Recipient must attach a copy of this Agreement to the Licensed Program.
   3. THIS LICENSED PROGRAM IS PROVIDED BY THE LICENSOR "AS IS" AND ANY EXPRESSED OR IMPLIED WARRANTY AS TO THE LICENSED PROGRAM OR ANY DERIVED PROGRAM, INCLUDING, BUT NOT LIMITED TO, WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY, OR FITNESS FOR A PARTICULAR PURPOSE, ARE DISCLAIMED. IN NO EVENT SHALL THE LICENSOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXTENDED, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO; PROCUREMENT OF SUBSTITUTED GOODS OR SERVICE; DAMAGES ARISING FROM SYSTEM FAILURE; LOSS OR CORRUPTION OF EXISTING DATA OR PROGRAM; LOST PROFITS), HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE INSTALLATION, USE, THE REPRODUCTION OR OTHER EXPLOITATION OF THE LICENSED PROGRAM OR ANY DERIVED PROGRAM OR THE EXERCISE OF ANY RIGHTS GRANTED HEREUNDER, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   4. The Licensor is under no obligation to respond to any technical questions or inquiries, or provide any other user support in connection with the installation, use or the Reproduction and Other Exploitation of the Licensed Program or Derived Programs thereof.
Article 4 (Termination of Agreement)
   1. The term of this Agreement shall begin from the time of receipt of the Licensed Program by the Recipient and shall continue as long as the Recipient retains any such Licensed Program in any way.
   2. Notwithstanding the provision set forth in the preceding Paragraph, in the event of the breach of any of the provisions set forth in this Agreement by the Recipient, this Agreement shall automatically terminate without any notice. In the case of such termination, the Recipient may not use or conduct Reproduction and Other Exploitation of the Licensed Program or a Derived Program: provided that such termination shall not affect any rights of any other Recipient receiving the Licensed Program or the Derived Program from such Recipient who breached this Agreement.
Article 5 (Governing Law)
   1. IPA may publish revised and/or new versions of this License. In such an event, the Recipient may select either this Agreement or any subsequent version of the Agreement in using, conducting the Reproduction and Other Exploitation of, or Redistributing the Licensed Program or a Derived Program. Other matters not specified above shall be subject to the Copyright Law of Japan and other related laws and regulations of Japan.
   2. This Agreement shall be construed under the laws of Japan.
```






```
Copyright (c) 1990-2009 Info-ZIP. All rights reserved.
For the purposes of this copyright and license, "Info-ZIP" is defined as the following set of individuals:
Mark Adler, John Bush, Karl Davis, Harald Denker, Jean-Michel Dubois, Jean-loup Gailly, Hunter Goatley, Ed Gordon, Ian Gorman, Chris Herborth, Dirk Haase, Greg Hartwig, Robert Heath, Jonathan Hudson, Paul Kienitz, David Kirschbaum, Johnny Lee, Onno van der Linden, Igor Mandrichenko, Steve P. Miller, Sergio Monesi, Keith Owens, George Petrov, Greg Roelofs, Kai Uwe Rommel, Steve Salisbury, Dave Smith, Steven M. Schweda, Christian Spieler, Cosmin Truta, Antoine Verheijen, Paul von Behren, Rich Wales, Mike White.
This software is provided "as is," without warranty of any kind, express or implied. In no event shall Info-ZIP or its contributors be held liable for any direct, indirect, incidental, special or consequential damages arising out of the use of or inability to use this software.
Permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the above disclaimer and the following restrictions:
   * Redistributions of source code (in whole or in part) must retain the above copyright notice, definition, disclaimer, and this list of conditions.
   * Redistributions in binary form (compiled executables and libraries) must reproduce the above copyright notice, definition, disclaimer, and this list of conditions in documentation and/or other materials provided with the distribution. Additional documentation is not needed for executables where a command line license option provides these and a note regarding this option is in the executable's startup banner. The sole exception to this condition is redistribution of a standard UnZipSFX binary (including SFXWiz) as part of a self-extracting archive; that is permitted without inclusion of this license, as long as the normal SFX banner has not been removed from the binary or disabled.
   * Altered versions--including, but not limited to, ports to new operating systems, existing ports with new graphical interfaces, versions with modified or added functionality, and dynamic, shared, or static library versions not from Info-ZIP--must be plainly marked as such and must not be misrepresented as being the original source or, if binaries, compiled from the original source. Such altered versions also must not be misrepresented as being Info-ZIP releases--including, but not limited to, labeling of the altered versions with the names "Info-ZIP" (or any variation thereof, including, but not limited to, different capitalizations), "Pocket UnZip," "WiZ" or "MacZip" without the explicit permission of Info-ZIP. Such altered versions are further prohibited from misrepresentative use of the Zip-Bugs or Info-ZIP e-mail addresses or the Info-ZIP URL(s), such as to imply Info-ZIP will provide support for the altered versions.
   * Info-ZIP retains the right to use the names "Info-ZIP," "Zip," "UnZip," "UnZipSFX," "WiZ," "Pocket UnZip," "Pocket Zip," and "MacZip" for its own source and binary releases.
```






```
Copyright (C) 2017 Christopher Groskopf and contributors
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/
```






```
Copyright (C) 2017 Christopher Groskopf and contributors
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3 or any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/
```






```
Copyright (C) 2017 Christopher Groskopf and contributors
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; version 2 or any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
```






```
Copyright (C) 2017 Christopher Groskopf and contributors
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; version 2.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
```






```
Copyright (C) 2017 Christopher Groskopf and contributors
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; version 1 or any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
```






```
IMPORTANT: PLEASE READ THE FOLLOWING AGREEMENT CAREFULLY.
BY CLICKING ON "ACCEPT" WHERE INDICATED BELOW, OR BY COPYING, INSTALLING OR OTHERWISE USING PYTHON 1.6, beta 1 SOFTWARE, YOU ARE DEEMED TO HAVE AGREED TO THE TERMS AND CONDITIONS OF THIS LICENSE AGREEMENT.
   1. This LICENSE AGREEMENT is between the Corporation for National Research Initiatives, having an office at 1895 Preston White Drive, Reston, VA 20191 ("CNRI"), and the Individual or Organization ("Licensee") accessing and otherwise using Python 1.6, beta 1 software in source or binary form and its associated documentation, as released at the www.python.org Internet site on August 4, 2000 ("Python 1.6b1").
   2. Subject to the terms and conditions of this License Agreement, CNRI hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python 1.6b1 alone or in any derivative version, provided, however, that CNRIs License Agreement is retained in Python 1.6b1, alone or in any derivative version prepared by Licensee.
   Alternately, in lieu of CNRIs License Agreement, Licensee may substitute the following text (omitting the quotes): "Python 1.6, beta 1, is made available subject to the terms and conditions in CNRIs License Agreement. This Agreement may be located on the Internet using the following unique, persistent identifier (known as a handle): 1895.22/1011. This Agreement may also be obtained from a proxy server on the Internet using the URL:http://hdl.handle.net/1895.22/1011".
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python 1.6b1 or any part thereof, and wants to make the derivative work available to the public as provided herein, then Licensee hereby agrees to indicate in any such work the nature of the modifications made to Python 1.6b1.
   4. CNRI is making Python 1.6b1 available to Licensee on an "AS IS" basis. CNRI MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, CNRI MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON 1.6b1 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. CNRI SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING PYTHON 1.6b1, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. This License Agreement shall be governed by and interpreted in all respects by the law of the State of Virginia, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between CNRI and Licensee. This License Agreement does not grant permission to use CNRI trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By clicking on the "ACCEPT" button where indicated, or by copying, installing or otherwise using Python 1.6b1, Licensee agrees to be bound by the terms and conditions of this License Agreement.
ACCEPT
```






```
﻿insert GPL v2 text here

Bison Exception

As a special exception, you may create a larger work that contains part or all of the Bison parser skeleton and distribute that work under terms of your choice, so long as that work isn't itself a parser generator using the skeleton or a modified version thereof as a parser skeleton. Alternatively, if you modify or redistribute the parser skeleton itself, you may (at your option) remove this special exception, which will cause the skeleton and the resulting Bison output files to be licensed under the GNU General Public License without this special exception.

This special exception was added by the Free Software Foundation in version 2.2 of Bison.
```






```
insert GPL v3 text here
General information: http://www.gnu.org/licenses/gcc-exception.html
Copyright (C) 2009 Free Software Foundation, Inc. <http://fsf.org/>
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
This GCC Runtime Library Exception ("Exception") is an additional permission under section 7 of the GNU General Public License, version 3 ("GPLv3"). It applies to a given file (the "Runtime Library") that bears a notice placed by the copyright holder of the file stating that the file is governed by GPLv3 along with this Exception.
When you use GCC to compile a program, GCC may combine portions of certain GCC header files and runtime libraries with the compiled program. The purpose of this Exception is to allow compilation of non-GPL (including proprietary) programs to use, in this way, the header files and runtime libraries covered by this Exception.
   0. Definitions.
   A file is an "Independent Module" if it either requires the Runtime Library for execution after a Compilation Process, or makes use of an interface provided by the Runtime Library, but is not otherwise based on the Runtime Library.
   "GCC" means a version of the GNU Compiler Collection, with or without modifications, governed by version 3 (or a specified later version) of the GNU General Public License (GPL) with the option of using any subsequent versions published by the FSF.
   "GPL-compatible Software" is software whose conditions of propagation, modification and use would permit combination with GCC in accord with the license of GCC.
   "Target Code" refers to output from any compiler for a real or virtual target processor architecture, in executable form or suitable for input to an assembler, loader, linker and/or execution phase. Notwithstanding that, Target Code does not include data in any format that is used as a compiler intermediate representation, or used for producing a compiler intermediate representation.
   The "Compilation Process" transforms code entirely represented in non-intermediate languages designed for human-written code, and/or in Java Virtual Machine byte code, into Target Code. Thus, for example, use of source code generators and preprocessors need not be considered part of the Compilation Process, since the Compilation Process can be understood as starting with the output of the generators or preprocessors.
   A Compilation Process is "Eligible" if it is done using GCC, alone or with other GPL-compatible software, or if it is done without using any work based on GCC. For example, using non-GPL-compatible Software to optimize any GCC intermediate representations would not qualify as an Eligible Compilation Process.
   1. Grant of Additional Permission.
   You have permission to propagate a work of Target Code formed by combining the Runtime Library with Independent Modules, even if such propagation would otherwise violate the terms of GPLv3, provided that all Target Code was generated by Eligible Compilation Processes. You may then convey such a combination under terms of your choice, consistent with the licensing of the Independent Modules.
   2. No Weakening of GCC Copyleft.
The availability of this Exception does not imply any general presumption that third-party software is unaffected by the copyleft requirements of the license of GCC.
```






```
Copyright (c) 2017 Christopher Groskopf and contributors
All rights reserved.
Redistribution and use in source and binary forms, with or without modification, are permitted (subject to the limitations in the disclaimer below) provided that the following conditions are met:
      * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
      * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
      * Neither the name of [Owner Organization] nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE GRANTED BY THIS LICENSE. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






```
<<endOptional>>
CC0 1.0 Universal<<endOptional>>
Statement of Purpose
The laws of most jurisdictions throughout the world automatically confer exclusive Copyright and Related Rights (defined below) upon the creator and subsequent owner(s) (each and all, an "owner") of an original work of authorship and/or a database (each, a "Work").
Certain owners wish to permanently relinquish those rights to a Work for the purpose of contributing to a commons of creative, cultural and scientific works ("Commons") that the public can reliably and without fear of later claims of infringement build upon, modify, incorporate in other works, reuse and redistribute as freely as possible in any form whatsoever and for any purposes, including without limitation commercial purposes. These owners may contribute to the Commons to promote the ideal of a free culture and the further production of creative, cultural and scientific works, or to gain reputation or greater distribution for their Work in part through the use and efforts of others.
For these and/or other purposes and motivations, and without any expectation of additional consideration or compensation, the person associating CC0 with a Work (the "Affirmer"), to the extent that he or she is an owner of Copyright and Related Rights in the Work, voluntarily elects to apply CC0 to the Work and publicly distribute the Work under its terms, with knowledge of his or her Copyright and Related Rights in the Work and the meaning and intended legal effect of CC0 on those rights.
   1. Copyright and Related Rights. A Work made available under CC0 may be protected by copyright and related or neighboring rights ("Copyright and Related Rights"). Copyright and Related Rights include, but are not limited to, the following:
      i. the right to reproduce, adapt, distribute, perform, display, communicate, and translate a Work;
      ii. moral rights retained by the original author(s) and/or performer(s);
      iii. publicity and privacy rights pertaining to a person's image or likeness depicted in a Work;
      iv. rights protecting against unfair competition in regards to a Work, subject to the limitations in paragraph 4(a), below;
      v. rights protecting the extraction, dissemination, use and reuse of data in a Work;
      vi. database rights (such as those arising under Directive 96/9/EC of the European Parliament and of the Council of 11 March 1996 on the legal protection of databases, and under any national implementation thereof, including any amended or successor version of such directive); and
      vii. other similar, equivalent or corresponding rights throughout the world based on applicable law or treaty, and any national implementations thereof.
   2. Waiver. To the greatest extent permitted by, but not in contravention of, applicable law, Affirmer hereby overtly, fully, permanently, irrevocably and unconditionally waives, abandons, and surrenders all of Affirmer's Copyright and Related Rights and associated claims and causes of action, whether now known or unknown (including existing as well as future claims and causes of action), in the Work (i) in all territories worldwide, (ii) for the maximum duration provided by applicable law or treaty (including future time extensions), (iii) in any current or future medium and for any number of copies, and (iv) for any purpose whatsoever, including without limitation commercial, advertising or promotional purposes (the "Waiver"). Affirmer makes the Waiver for the benefit of each member of the public at large and to the detriment of Affirmer's heirs and successors, fully intending that such Waiver shall not be subject to revocation, rescission, cancellation, termination, or any other legal or equitable action to disrupt the quiet enjoyment of the Work by the public as contemplated by Affirmer's express Statement of Purpose.
   3. Public License Fallback. Should any part of the Waiver for any reason be judged legally invalid or ineffective under applicable law, then the Waiver shall be preserved to the maximum extent permitted taking into account Affirmer's express Statement of Purpose. In addition, to the extent the Waiver is so judged Affirmer hereby grants to each affected person a royalty-free, non transferable, non sublicensable, non exclusive, irrevocable and unconditional license to exercise Affirmer's Copyright and Related Rights in the Work (i) in all territories worldwide, (ii) for the maximum duration provided by applicable law or treaty (including future time extensions), (iii) in any current or future medium and for any number of copies, and (iv) for any purpose whatsoever, including without limitation commercial, advertising or promotional purposes (the "License"). The License shall be deemed effective as of the date CC0 was applied by Affirmer to the Work. Should any part of the License for any reason be judged legally invalid or ineffective under applicable law, such partial invalidity or ineffectiveness shall not invalidate the remainder of the License, and in such case Affirmer hereby affirms that he or she will not (i) exercise any of his or her remaining Copyright and Related Rights in the Work or (ii) assert any associated claims and causes of action with respect to the Work, in either case contrary to Affirmer's express Statement of Purpose.
   4. Limitations and Disclaimers.
      a. No trademark or patent rights held by Affirmer are waived, abandoned, surrendered, licensed or otherwise affected by this document.
      b. Affirmer offers the Work as-is and makes no representations or warranties of any kind concerning the Work, express, implied, statutory or otherwise, including without limitation warranties of title, merchantability, fitness for a particular purpose, non infringement, or the absence of latent or other defects, accuracy, or the present or absence of errors, whether or not discoverable, all to the greatest extent permissible under applicable law.
      c. Affirmer disclaims responsibility for clearing rights of other persons that may apply to the Work or any use thereof, including without limitation any person's Copyright and Related Rights in the Work. Further, Affirmer disclaims responsibility for obtaining any necessary consents, permissions or other rights required for any use of the Work.
      d. Affirmer understands and acknowledges that Creative Commons is not a party to this document and has no duty or obligation with respect to this CC0 or use of the Work.
```






```
Attribution-ShareAlike 4.0 International<<endOptional>>
Using Creative Commons Public Licenses
Creative Commons public licenses provide a standard set of terms and conditions that creators and other rights holders may use to share original works of authorship and other material subject to copyright and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.
Considerations for licensors: Our public licenses are intended for use by those authorized to give the public permission to use material in ways otherwise restricted by copyright and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors
Considerations for the public: By using one of our public licenses, a licensor grants the public permission to use the licensed material under specified terms and conditions. If the licensor's permission is not necessary for any reason–for example, because of any applicable exception or limitation to copyright–then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.
Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees
Creative Commons Attribution-ShareAlike 4.0 International Public License
By exercising the Licensed Rights (defined below), You accept and agree to be bound by the terms and conditions of this Creative Commons Attribution-ShareAlike 4.0 International Public License ("Public License"). To the extent this Public License may be interpreted as a contract, You are granted the Licensed Rights in consideration of Your acceptance of these terms and conditions, and the Licensor grants You such rights in consideration of benefits the Licensor receives from making the Licensed Material available under these terms and conditions.
Section 1 – Definitions.
   a. Adapted Material means material subject to Copyright and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.
   b. Adapter's License means the license You apply to Your Copyright and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.
   c. BY-SA Compatible License means a license listed at creativecommons.org/compatiblelicenses, approved by Creative Commons as essentially the equivalent of this Public License.
   d. Copyright and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.
   e. Effective Technological Measures means those measures that, in the absence of proper authority, may not be circumvented under laws fulfilling obligations under Article 11 of the WIPO Copyright Treaty adopted on December 20, 1996, and/or similar international agreements.
   f. Exceptions and Limitations means fair use, fair dealing, and/or any other exception or limitation to Copyright and Similar Rights that applies to Your use of the Licensed Material.
   g. License Elements means the license attributes listed in the name of a Creative Commons Public License. The License Elements of this Public License are Attribution and ShareAlike.
   h. Licensed Material means the artistic or literary work, database, or other material to which the Licensor applied this Public License.
   i. Licensed Rights means the rights granted to You subject to the terms and conditions of this Public License, which are limited to all Copyright and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.
   j. Licensor means the individual(s) or entity(ies) granting rights under this Public License.
   k. Share means to provide material to the public by any means or process that requires permission under the Licensed Rights, such as reproduction, public display, public performance, distribution, dissemination, communication, or importation, and to make material available to the public including in ways that members of the public may access the material from a place and at a time individually chosen by them.
   l. Sui Generis Database Rights means rights other than copyright resulting from Directive 96/9/EC of the European Parliament and of the Council of 11 March 1996 on the legal protection of databases, as amended and/or succeeded, as well as other essentially equivalent rights anywhere in the world.
   m. You means the individual or entity exercising the Licensed Rights under this Public License. Your has a corresponding meaning.
Section 2 – Scope.
   a. License grant.
      1. Subject to the terms and conditions of this Public License, the Licensor hereby grants You a worldwide, royalty-free, non-sublicensable, non-exclusive, irrevocable license to exercise the Licensed Rights in the Licensed Material to:
         A. reproduce and Share the Licensed Material, in whole or in part; and
         B. produce, reproduce, and Share Adapted Material.
      2. Exceptions and Limitations. For the avoidance of doubt, where Exceptions and Limitations apply to Your use, this Public License does not apply, and You do not need to comply with its terms and conditions.
      3. Term. The term of this Public License is specified in Section 6(a).
      4. Media and formats; technical modifications allowed. The Licensor authorizes You to exercise the Licensed Rights in all media and formats whether now known or hereafter created, and to make technical modifications necessary to do so. The Licensor waives and/or agrees not to assert any right or authority to forbid You from making technical modifications necessary to exercise the Licensed Rights, including technical modifications necessary to circumvent Effective Technological Measures. For purposes of this Public License, simply making modifications authorized by this Section 2(a)(4) never produces Adapted Material.
      5. Downstream recipients.
         A. Offer from the Licensor – Licensed Material. Every recipient of the Licensed Material automatically receives an offer from the Licensor to exercise the Licensed Rights under the terms and conditions of this Public License.
         B. Additional offer from the Licensor – Adapted Material. Every recipient of Adapted Material from You automatically receives an offer from the Licensor to exercise the Licensed Rights in the Adapted Material under the conditions of the Adapter's License You apply.
         C. No downstream restrictions. You may not offer or impose any additional or different terms or conditions on, or apply any Effective Technological Measures to, the Licensed Material if doing so restricts exercise of the Licensed Rights by any recipient of the Licensed Material.
      6. No endorsement. Nothing in this Public License constitutes or may be construed as permission to assert or imply that You are, or that Your use of the Licensed Material is, connected with, or sponsored, endorsed, or granted official status by, the Licensor or others designated to receive attribution as provided in Section 3(a)(1)(A)(i).
   b. Other rights.
      1. Moral rights, such as the right of integrity, are not licensed under this Public License, nor are publicity, privacy, and/or other similar personality rights; however, to the extent possible, the Licensor waives and/or agrees not to assert any such rights held by the Licensor to the limited extent necessary to allow You to exercise the Licensed Rights, but not otherwise.
      2. Patent and trademark rights are not licensed under this Public License.
      3. To the extent possible, the Licensor waives any right to collect royalties from You for the exercise of the Licensed Rights, whether directly or through a collecting society under any voluntary or waivable statutory or compulsory licensing scheme. In all other cases the Licensor expressly reserves any right to collect such royalties.
Section 3 – License Conditions.
Your exercise of the Licensed Rights is expressly made subject to the following conditions.
   a. Attribution.
      1. If You Share the Licensed Material (including in modified form), You must:
         A. retain the following if it is supplied by the Licensor with the Licensed Material:
            i. identification of the creator(s) of the Licensed Material and any others designated to receive attribution, in any reasonable manner requested by the Licensor (including by pseudonym if designated);
            ii. a copyright notice;
            iii. a notice that refers to this Public License;
            iv. a notice that refers to the disclaimer of warranties;
            v. a URI or hyperlink to the Licensed Material to the extent reasonably practicable;
         B. indicate if You modified the Licensed Material and retain an indication of any previous modifications; and
         C. indicate the Licensed Material is licensed under this Public License, and include the text of, or the URI or hyperlink to, this Public License.
      2. You may satisfy the conditions in Section 3(a)(1) in any reasonable manner based on the medium, means, and context in which You Share the Licensed Material. For example, it may be reasonable to satisfy the conditions by providing a URI or hyperlink to a resource that includes the required information.
      3. If requested by the Licensor, You must remove any of the information required by Section 3(a)(1)(A) to the extent reasonably practicable.
   b. ShareAlike.In addition to the conditions in Section 3(a), if You Share Adapted Material You produce, the following conditions also apply.
      1. The Adapter's License You apply must be a Creative Commons license with the same License Elements, this version or later, or a BY-SA Compatible License.
      2. You must include the text of, or the URI or hyperlink to, the Adapter's License You apply. You may satisfy this condition in any reasonable manner based on the medium, means, and context in which You Share Adapted Material.
      3. You may not offer or impose any additional or different terms or conditions on, or apply any Effective Technological Measures to, Adapted Material that restrict exercise of the rights granted under the Adapter's License You apply.
Section 4 – Sui Generis Database Rights.
Where the Licensed Rights include Sui Generis Database Rights that apply to Your use of the Licensed Material:
   a. for the avoidance of doubt, Section 2(a)(1) grants You the right to extract, reuse, reproduce, and Share all or a substantial portion of the contents of the database;
   b. if You include all or a substantial portion of the database contents in a database in which You have Sui Generis Database Rights, then the database in which You have Sui Generis Database Rights (but not its individual contents) is Adapted Material, including for purposes of Section 3(b); and
   c. You must comply with the conditions in Section 3(a) if You Share all or a substantial portion of the contents of the database.
   For the avoidance of doubt, this Section 4 supplements and does not replace Your obligations under this Public License where the Licensed Rights include other Copyright and Similar Rights.
Section 5 – Disclaimer of Warranties and Limitation of Liability.
   a. Unless otherwise separately undertaken by the Licensor, to the extent possible, the Licensor offers the Licensed Material as-is and as-available, and makes no representations or warranties of any kind concerning the Licensed Material, whether express, implied, statutory, or other. This includes, without limitation, warranties of title, merchantability, fitness for a particular purpose, non-infringement, absence of latent or other defects, accuracy, or the presence or absence of errors, whether or not known or discoverable. Where disclaimers of warranties are not allowed in full or in part, this disclaimer may not apply to You.
   b. To the extent possible, in no event will the Licensor be liable to You on any legal theory (including, without limitation, negligence) or otherwise for any direct, special, indirect, incidental, consequential, punitive, exemplary, or other losses, costs, expenses, or damages arising out of this Public License or use of the Licensed Material, even if the Licensor has been advised of the possibility of such losses, costs, expenses, or damages. Where a limitation of liability is not allowed in full or in part, this limitation may not apply to You.
   c. The disclaimer of warranties and limitation of liability provided above shall be interpreted in a manner that, to the extent possible, most closely approximates an absolute disclaimer and waiver of all liability.
Section 6 – Term and Termination.
   a. This Public License applies for the term of the Copyright and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.
   b. Where Your right to use the Licensed Material has terminated under Section 6(a), it reinstates:
      1. automatically as of the date the violation is cured, provided it is cured within 30 days of Your discovery of the violation; or
      2. upon express reinstatement by the Licensor.
   c. For the avoidance of doubt, this Section 6(b) does not affect any right the Licensor may have to seek remedies for Your violations of this Public License.
   d. For the avoidance of doubt, the Licensor may also offer the Licensed Material under separate terms or conditions or stop distributing the Licensed Material at any time; however, doing so will not terminate this Public License.
   e. Sections 1, 5, 6, 7, and 8 survive termination of this Public License.
Section 7 – Other Terms and Conditions.
   a. The Licensor shall not be bound by any additional or different terms or conditions communicated by You unless expressly agreed.
   b. Any arrangements, understandings, or agreements regarding the Licensed Material not stated herein are separate from and independent of the terms and conditions of this Public License.
Section 8 – Interpretation.
   a. For the avoidance of doubt, this Public License does not, and shall not be interpreted to, reduce, limit, restrict, or impose conditions on any use of the Licensed Material that could lawfully be made without permission under this Public License.
   b. To the extent possible, if any provision of this Public License is deemed unenforceable, it shall be automatically reformed to the minimum extent necessary to make it enforceable. If the provision cannot be reformed, it shall be severed from this Public License without affecting the enforceability of the remaining terms and conditions.
   c. No term or condition of this Public License will be waived and no failure to comply consented to unless expressly agreed to by the Licensor.
   d. Nothing in this Public License constitutes or may be interpreted as a limitation upon, or waiver of, any privileges and immunities that apply to the Licensor or You, including from the legal processes of any jurisdiction or authority.
Creative Commons is not a party to its public licenses. Notwithstanding, Creative Commons may elect to apply one of its public licenses to material it publishes and in those instances will be considered the "Licensor." Except for the limited purpose of indicating that material is shared under a Creative Commons public license or as otherwise permitted by the Creative Commons policies published at creativecommons.org/policies, Creative Commons does not authorize the use of the trademark "Creative Commons" or any other trademark or logo of Creative Commons without its prior written consent including, without limitation, in connection with any unauthorized modifications to any of its public licenses or any other arrangements, understandings, or agreements concerning use of licensed material. For the avoidance of doubt, this paragraph does not form part of the public licenses.
Creative Commons may be contacted at creativecommons.org.
```






```
Copyright (C) 2017 Christopher Groskopf and contributors
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; version 1.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
```






```
Copyright (C) 2006 by Rob Landley <rob@landley.net>
Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted.
THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
```






```
Attribution 4.0 International<<endOptional>>
By exercising the Licensed Rights (defined below), You accept and agree to be bound by the terms and conditions of this Creative Commons Attribution 4.0 International Public License ("Public License"). To the extent this Public License may be interpreted as a contract, You are granted the Licensed Rights in consideration of Your acceptance of these terms and conditions, and the Licensor grants You such rights in consideration of benefits the Licensor receives from making the Licensed Material available under these terms and conditions.
Section 1 – Definitions.
   a. Adapted Material means material subject to Copyright and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.
   b. Adapter's License means the license You apply to Your Copyright and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.
   c. Copyright and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.
   d. Effective Technological Measures means those measures that, in the absence of proper authority, may not be circumvented under laws fulfilling obligations under Article 11 of the WIPO Copyright Treaty adopted on December 20, 1996, and/or similar international agreements.
   e. Exceptions and Limitations means fair use, fair dealing, and/or any other exception or limitation to Copyright and Similar Rights that applies to Your use of the Licensed Material.
   f. Licensed Material means the artistic or literary work, database, or other material to which the Licensor applied this Public License.
   g. Licensed Rights means the rights granted to You subject to the terms and conditions of this Public License, which are limited to all Copyright and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.
   h. Licensor means the individual(s) or entity(ies) granting rights under this Public License.
   i. Share means to provide material to the public by any means or process that requires permission under the Licensed Rights, such as reproduction, public display, public performance, distribution, dissemination, communication, or importation, and to make material available to the public including in ways that members of the public may access the material from a place and at a time individually chosen by them.
   j. Sui Generis Database Rights means rights other than copyright resulting from Directive 96/9/EC of the European Parliament and of the Council of 11 March 1996 on the legal protection of databases, as amended and/or succeeded, as well as other essentially equivalent rights anywhere in the world.
   k. You means the individual or entity exercising the Licensed Rights under this Public License. Your has a corresponding meaning.
Section 2 – Scope.
   a. License grant.
      1. Subject to the terms and conditions of this Public License, the Licensor hereby grants You a worldwide, royalty-free, non-sublicensable, non-exclusive, irrevocable license to exercise the Licensed Rights in the Licensed Material to:
         A. reproduce and Share the Licensed Material, in whole or in part; and
         B. produce, reproduce, and Share Adapted Material.
      2. Exceptions and Limitations. For the avoidance of doubt, where Exceptions and Limitations apply to Your use, this Public License does not apply, and You do not need to comply with its terms and conditions.
      3. Term. The term of this Public License is specified in Section 6(a).
      4. Media and formats; technical modifications allowed. The Licensor authorizes You to exercise the Licensed Rights in all media and formats whether now known or hereafter created, and to make technical modifications necessary to do so. The Licensor waives and/or agrees not to assert any right or authority to forbid You from making technical modifications necessary to exercise the Licensed Rights, including technical modifications necessary to circumvent Effective Technological Measures. For purposes of this Public License, simply making modifications authorized by this Section 2(a)(4) never produces Adapted Material.
      5. Downstream recipients.
         A. Offer from the Licensor – Licensed Material. Every recipient of the Licensed Material automatically receives an offer from the Licensor to exercise the Licensed Rights under the terms and conditions of this Public License.
         B. No downstream restrictions. You may not offer or impose any additional or different terms or conditions on, or apply any Effective Technological Measures to, the Licensed Material if doing so restricts exercise of the Licensed Rights by any recipient of the Licensed Material.
      6. No endorsement. Nothing in this Public License constitutes or may be construed as permission to assert or imply that You are, or that Your use of the Licensed Material is, connected with, or sponsored, endorsed, or granted official status by, the Licensor or others designated to receive attribution as provided in Section 3(a)(1)(A)(i).
   b. Other rights.
      1. Moral rights, such as the right of integrity, are not licensed under this Public License, nor are publicity, privacy, and/or other similar personality rights; however, to the extent possible, the Licensor waives and/or agrees not to assert any such rights held by the Licensor to the limited extent necessary to allow You to exercise the Licensed Rights, but not otherwise.
      2. Patent and trademark rights are not licensed under this Public License.
      3. To the extent possible, the Licensor waives any right to collect royalties from You for the exercise of the Licensed Rights, whether directly or through a collecting society under any voluntary or waivable statutory or compulsory licensing scheme. In all other cases the Licensor expressly reserves any right to collect such royalties.
Section 3 – License Conditions.
Your exercise of the Licensed Rights is expressly made subject to the following conditions.
   a. Attribution.
      1. If You Share the Licensed Material (including in modified form), You must:
         A. retain the following if it is supplied by the Licensor with the Licensed Material:
            i. identification of the creator(s) of the Licensed Material and any others designated to receive attribution, in any reasonable manner requested by the Licensor (including by pseudonym if designated);
            ii. a copyright notice;
            iii. a notice that refers to this Public License;
            iv. a notice that refers to the disclaimer of warranties;
            v. a URI or hyperlink to the Licensed Material to the extent reasonably practicable;
         B. indicate if You modified the Licensed Material and retain an indication of any previous modifications; and
         C. indicate the Licensed Material is licensed under this Public License, and include the text of, or the URI or hyperlink to, this Public License.
      2. You may satisfy the conditions in Section 3(a)(1) in any reasonable manner based on the medium, means, and context in which You Share the Licensed Material. For example, it may be reasonable to satisfy the conditions by providing a URI or hyperlink to a resource that includes the required information.
      3. If requested by the Licensor, You must remove any of the information required by Section 3(a)(1)(A) to the extent reasonably practicable.
      4. If You Share Adapted Material You produce, the Adapter's License You apply must not prevent recipients of the Adapted Material from complying with this Public License.
Section 4 – Sui Generis Database Rights.
Where the Licensed Rights include Sui Generis Database Rights that apply to Your use of the Licensed Material:
   a. for the avoidance of doubt, Section 2(a)(1) grants You the right to extract, reuse, reproduce, and Share all or a substantial portion of the contents of the database;
   b. if You include all or a substantial portion of the database contents in a database in which You have Sui Generis Database Rights, then the database in which You have Sui Generis Database Rights (but not its individual contents) is Adapted Material; and
   c. You must comply with the conditions in Section 3(a) if You Share all or a substantial portion of the contents of the database.
For the avoidance of doubt, this Section 4 supplements and does not replace Your obligations under this Public License where the Licensed Rights include other Copyright and Similar Rights.
Section 5 – Disclaimer of Warranties and Limitation of Liability.
   a. Unless otherwise separately undertaken by the Licensor, to the extent possible, the Licensor offers the Licensed Material as-is and as-available, and makes no representations or warranties of any kind concerning the Licensed Material, whether express, implied, statutory, or other. This includes, without limitation, warranties of title, merchantability, fitness for a particular purpose, non-infringement, absence of latent or other defects, accuracy, or the presence or absence of errors, whether or not known or discoverable. Where disclaimers of warranties are not allowed in full or in part, this disclaimer may not apply to You.
   b. To the extent possible, in no event will the Licensor be liable to You on any legal theory (including, without limitation, negligence) or otherwise for any direct, special, indirect, incidental, consequential, punitive, exemplary, or other losses, costs, expenses, or damages arising out of this Public License or use of the Licensed Material, even if the Licensor has been advised of the possibility of such losses, costs, expenses, or damages. Where a limitation of liability is not allowed in full or in part, this limitation may not apply to You.
   c. The disclaimer of warranties and limitation of liability provided above shall be interpreted in a manner that, to the extent possible, most closely approximates an absolute disclaimer and waiver of all liability.
Section 6 – Term and Termination.
   a. This Public License applies for the term of the Copyright and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.
   b. Where Your right to use the Licensed Material has terminated under Section 6(a), it reinstates:
      1. automatically as of the date the violation is cured, provided it is cured within 30 days of Your discovery of the violation; or
      2. upon express reinstatement by the Licensor.
   c. For the avoidance of doubt, this Section 6(b) does not affect any right the Licensor may have to seek remedies for Your violations of this Public License.
   d. For the avoidance of doubt, the Licensor may also offer the Licensed Material under separate terms or conditions or stop distributing the Licensed Material at any time; however, doing so will not terminate this Public License.
   e. Sections 1, 5, 6, 7, and 8 survive termination of this Public License.
Section 7 – Other Terms and Conditions.
   a. The Licensor shall not be bound by any additional or different terms or conditions communicated by You unless expressly agreed.
   b. Any arrangements, understandings, or agreements regarding the Licensed Material not stated herein are separate from and independent of the terms and conditions of this Public License.
Section 8 – Interpretation.
   a. For the avoidance of doubt, this Public License does not, and shall not be interpreted to, reduce, limit, restrict, or impose conditions on any use of the Licensed Material that could lawfully be made without permission under this Public License.
   b. To the extent possible, if any provision of this Public License is deemed unenforceable, it shall be automatically reformed to the minimum extent necessary to make it enforceable. If the provision cannot be reformed, it shall be severed from this Public License without affecting the enforceability of the remaining terms and conditions.
   c. No term or condition of this Public License will be waived and no failure to comply consented to unless expressly agreed to by the Licensor.
   d. Nothing in this Public License constitutes or may be interpreted as a limitation upon, or waiver of, any privileges and immunities that apply to the Licensor or You, including from the legal processes of any jurisdiction or authority.
Creative Commons is not a party to its public licenses. Notwithstanding, Creative Commons may elect to apply one of its public licenses to material it publishes and in those instances will be considered the "Licensor." Except for the limited purpose of indicating that material is shared under a Creative Commons public license or as otherwise permitted by the Creative Commons policies published at creativecommons.org/policies, Creative Commons does not authorize the use of the trademark "Creative Commons" or any other trademark or logo of Creative Commons without its prior written consent including, without limitation, in connection with any unauthorized modifications to any of its public licenses or any other arrangements, understandings, or agreements concerning use of licensed material. For the avoidance of doubt, this paragraph does not form part of the public licenses.
Creative Commons may be contacted at creativecommons.org.
```






```
THE WORK (AS DEFINED BELOW) IS PROVIDED UNDER THE TERMS OF THIS CREATIVE COMMONS PUBLIC LICENSE ("CCPL" OR "LICENSE"). THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.
BY EXERCISING ANY RIGHTS TO THE WORK PROVIDED HERE, YOU ACCEPT AND AGREE TO BE BOUND BY THE TERMS OF THIS LICENSE. TO THE EXTENT THIS LICENSE MAY BE CONSIDERED TO BE A CONTRACT, THE LICENSOR GRANTS YOU THE RIGHTS CONTAINED HERE IN CONSIDERATION OF YOUR ACCEPTANCE OF SUCH TERMS AND CONDITIONS.
   1. Definitions
      a. "Adaptation" means a work based upon the Work, or upon the Work and other pre-existing works, such as a translation, adaptation, derivative work, arrangement of music or other alterations of a literary or artistic work, or phonogram or performance and includes cinematographic adaptations or any other form in which the Work may be recast, transformed, or adapted including in any form recognizably derived from the original, except that a work that constitutes a Collection will not be considered an Adaptation for the purpose of this License. For the avoidance of doubt, where the Work is a musical work, performance or phonogram, the synchronization of the Work in timed-relation with a moving image ("synching") will be considered an Adaptation for the purpose of this License.
      b. "Collection" means a collection of literary or artistic works, such as encyclopedias and anthologies, or performances, phonograms or broadcasts, or other works or subject matter other than works listed in Section 1(f) below, which, by reason of the selection and arrangement of their contents, constitute intellectual creations, in which the Work is included in its entirety in unmodified form along with one or more other contributions, each constituting separate and independent works in themselves, which together are assembled into a collective whole. A work that constitutes a Collection will not be considered an Adaptation (as defined below) for the purposes of this License.
      c. "Creative Commons Compatible License" means a license that is listed at http://creativecommons.org/compatiblelicenses that has been approved by Creative Commons as being essentially equivalent to this License, including, at a minimum, because that license: (i) contains terms that have the same purpose, meaning and effect as the License Elements of this License; and, (ii) explicitly permits the relicensing of adaptations of works made available under that license under this License or a Creative Commons jurisdiction license with the same License Elements as this License.
      d. "Distribute" means to make available to the public the original and copies of the Work or Adaptation, as appropriate, through sale or other transfer of ownership.
      e. "License Elements" means the following high-level license attributes as selected by Licensor and indicated in the title of this License: Attribution, ShareAlike.
      f. "Licensor" means the individual, individuals, entity or entities that offer(s) the Work under the terms of this License.
      g. "Original Author" means, in the case of a literary or artistic work, the individual, individuals, entity or entities who created the Work or if no individual or entity can be identified, the publisher; and in addition (i) in the case of a performance the actors, singers, musicians, dancers, and other persons who act, sing, deliver, declaim, play in, interpret or otherwise perform literary or artistic works or expressions of folklore; (ii) in the case of a phonogram the producer being the person or legal entity who first fixes the sounds of a performance or other sounds; and, (iii) in the case of broadcasts, the organization that transmits the broadcast.
      h. "Work" means the literary and/or artistic work offered under the terms of this License including without limitation any production in the literary, scientific and artistic domain, whatever may be the mode or form of its expression including digital form, such as a book, pamphlet and other writing; a lecture, address, sermon or other work of the same nature; a dramatic or dramatico-musical work; a choreographic work or entertainment in dumb show; a musical composition with or without words; a cinematographic work to which are assimilated works expressed by a process analogous to cinematography; a work of drawing, painting, architecture, sculpture, engraving or lithography; a photographic work to which are assimilated works expressed by a process analogous to photography; a work of applied art; an illustration, map, plan, sketch or three-dimensional work relative to geography, topography, architecture or science; a performance; a broadcast; a phonogram; a compilation of data to the extent it is protected as a copyrightable work; or a work performed by a variety or circus performer to the extent it is not otherwise considered a literary or artistic work.
      i. "You" means an individual or entity exercising rights under this License who has not previously violated the terms of this License with respect to the Work, or who has received express permission from the Licensor to exercise rights under this License despite a previous violation.
      j. "Publicly Perform" means to perform public recitations of the Work and to communicate to the public those public recitations, by any means or process, including by wire or wireless means or public digital performances; to make available to the public Works in such a way that members of the public may access these Works from a place and at a place individually chosen by them; to perform the Work to the public by any means or process and the communication to the public of the performances of the Work, including by public digital performance; to broadcast and rebroadcast the Work by any means including signs, sounds or images.
      k. "Reproduce" means to make copies of the Work by any means including without limitation by sound or visual recordings and the right of fixation and reproducing fixations of the Work, including storage of a protected performance or phonogram in digital form or other electronic medium.
   2. Fair Dealing Rights. Nothing in this License is intended to reduce, limit, or restrict any uses free from copyright or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.
   3. License Grant. Subject to the terms and conditions of this License, Licensor hereby grants You a worldwide, royalty-free, non-exclusive, perpetual (for the duration of the applicable copyright) license to exercise the rights in the Work as stated below:
      a. to Reproduce the Work, to incorporate the Work into one or more Collections, and to Reproduce the Work as incorporated in the Collections;
      b. to create and Reproduce Adaptations provided that any such Adaptation, including any translation in any medium, takes reasonable steps to clearly label, demarcate or otherwise identify that changes were made to the original Work. For example, a translation could be marked "The original work was translated from English to Spanish," or a modification could indicate "The original work has been modified.";
      c. to Distribute and Publicly Perform the Work including as incorporated in Collections; and,
      d. to Distribute and Publicly Perform Adaptations.
      e. For the avoidance of doubt:
         i. Non-waivable Compulsory License Schemes. In those jurisdictions in which the right to collect royalties through any statutory or compulsory licensing scheme cannot be waived, the Licensor reserves the exclusive right to collect such royalties for any exercise by You of the rights granted under this License;
         ii. Waivable Compulsory License Schemes. In those jurisdictions in which the right to collect royalties through any statutory or compulsory licensing scheme can be waived, the Licensor waives the exclusive right to collect such royalties for any exercise by You of the rights granted under this License; and,
         iii. Voluntary License Schemes. The Licensor waives the right to collect royalties, whether individually or, in the event that the Licensor is a member of a collecting society that administers voluntary licensing schemes, via that society, from any exercise by You of the rights granted under this License.
   The above rights may be exercised in all media and formats whether now known or hereafter devised. The above rights include the right to make such modifications as are technically necessary to exercise the rights in other media and formats. Subject to Section 8(f), all rights not expressly granted by Licensor are hereby reserved.
   4. Restrictions. The license granted in Section 3 above is expressly made subject to and limited by the following restrictions:
      a. You may Distribute or Publicly Perform the Work only under the terms of this License. You must include a copy of, or the Uniform Resource Identifier (URI) for, this License with every copy of the Work You Distribute or Publicly Perform. You may not offer or impose any terms on the Work that restrict the terms of this License or the ability of the recipient of the Work to exercise the rights granted to that recipient under the terms of the License. You may not sublicense the Work. You must keep intact all notices that refer to this License and to the disclaimer of warranties with every copy of the Work You Distribute or Publicly Perform. When You Distribute or Publicly Perform the Work, You may not impose any effective technological measures on the Work that restrict the ability of a recipient of the Work from You to exercise the rights granted to that recipient under the terms of the License. This Section 4(a) applies to the Work as incorporated in a Collection, but this does not require the Collection apart from the Work itself to be made subject to the terms of this License. If You create a Collection, upon notice from any Licensor You must, to the extent practicable, remove from the Collection any credit as required by Section 4(c), as requested. If You create an Adaptation, upon notice from any Licensor You must, to the extent practicable, remove from the Adaptation any credit as required by Section 4(c), as requested.
      b. You may Distribute or Publicly Perform an Adaptation only under the terms of: (i) this License; (ii) a later version of this License with the same License Elements as this License; (iii) a Creative Commons jurisdiction license (either this or a later license version) that contains the same License Elements as this License (e.g., Attribution-ShareAlike 3.0 US)); (iv) a Creative Commons Compatible License. If you license the Adaptation under one of the licenses mentioned in (iv), you must comply with the terms of that license. If you license the Adaptation under the terms of any of the licenses mentioned in (i), (ii) or (iii) (the "Applicable License"), you must comply with the terms of the Applicable License generally and the following provisions: (I) You must include a copy of, or the URI for, the Applicable License with every copy of each Adaptation You Distribute or Publicly Perform; (II) You may not offer or impose any terms on the Adaptation that restrict the terms of the Applicable License or the ability of the recipient of the Adaptation to exercise the rights granted to that recipient under the terms of the Applicable License; (III) You must keep intact all notices that refer to the Applicable License and to the disclaimer of warranties with every copy of the Work as included in the Adaptation You Distribute or Publicly Perform; (IV) when You Distribute or Publicly Perform the Adaptation, You may not impose any effective technological measures on the Adaptation that restrict the ability of a recipient of the Adaptation from You to exercise the rights granted to that recipient under the terms of the Applicable License. This Section 4(b) applies to the Adaptation as incorporated in a Collection, but this does not require the Collection apart from the Adaptation itself to be made subject to the terms of the Applicable License.
      c. If You Distribute, or Publicly Perform the Work or any Adaptations or Collections, You must, unless a request has been made pursuant to Section 4(a), keep intact all copyright notices for the Work and provide, reasonable to the medium or means You are utilizing: (i) the name of the Original Author (or pseudonym, if applicable) if supplied, and/or if the Original Author and/or Licensor designate another party or parties (e.g., a sponsor institute, publishing entity, journal) for attribution ("Attribution Parties") in Licensor's copyright notice, terms of service or by other reasonable means, the name of such party or parties; (ii) the title of the Work if supplied; (iii) to the extent reasonably practicable, the URI, if any, that Licensor specifies to be associated with the Work, unless such URI does not refer to the copyright notice or licensing information for the Work; and (iv), consistent with Section 3(b), in the case of an Adaptation, a credit identifying the use of the Work in the Adaptation (e.g., "French translation of the Work by Original Author," or "Screenplay based on original Work by Original Author"). The credit required by this Section 4(c) may be implemented in any reasonable manner; provided, however, that in the case of a Adaptation or Collection, at a minimum such credit will appear, if a credit for all contributing authors of the Adaptation or Collection appears, then as part of these credits and in a manner at least as prominent as the credits for the other contributing authors. For the avoidance of doubt, You may only use the credit required by this Section for the purpose of attribution in the manner set out above and, by exercising Your rights under this License, You may not implicitly or explicitly assert or imply any connection with, sponsorship or endorsement by the Original Author, Licensor and/or Attribution Parties, as appropriate, of You or Your use of the Work, without the separate, express prior written permission of the Original Author, Licensor and/or Attribution Parties.
      d. Except as otherwise agreed in writing by the Licensor or as may be otherwise permitted by applicable law, if You Reproduce, Distribute or Publicly Perform the Work either by itself or as part of any Adaptations or Collections, You must not distort, mutilate, modify or take other derogatory action in relation to the Work which would be prejudicial to the Original Author's honor or reputation. Licensor agrees that in those jurisdictions (e.g. Japan), in which any exercise of the right granted in Section 3(b) of this License (the right to make Adaptations) would be deemed to be a distortion, mutilation, modification or other derogatory action prejudicial to the Original Author's honor and reputation, the Licensor will waive or not assert, as appropriate, this Section, to the fullest extent permitted by the applicable national law, to enable You to reasonably exercise Your right under Section 3(b) of this License (right to make Adaptations) but not otherwise.
   5. Representations, Warranties and Disclaimer
   UNLESS OTHERWISE MUTUALLY AGREED TO BY THE PARTIES IN WRITING, LICENSOR OFFERS THE WORK AS-IS AND MAKES NO REPRESENTATIONS OR WARRANTIES OF ANY KIND CONCERNING THE WORK, EXPRESS, IMPLIED, STATUTORY OR OTHERWISE, INCLUDING, WITHOUT LIMITATION, WARRANTIES OF TITLE, MERCHANTIBILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, ACCURACY, OR THE PRESENCE OF ABSENCE OF ERRORS, WHETHER OR NOT DISCOVERABLE. SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OF IMPLIED WARRANTIES, SO SUCH EXCLUSION MAY NOT APPLY TO YOU.
   6. Limitation on Liability. EXCEPT TO THE EXTENT REQUIRED BY APPLICABLE LAW, IN NO EVENT WILL LICENSOR BE LIABLE TO YOU ON ANY LEGAL THEORY FOR ANY SPECIAL, INCIDENTAL, CONSEQUENTIAL, PUNITIVE OR EXEMPLARY DAMAGES ARISING OUT OF THIS LICENSE OR THE USE OF THE WORK, EVEN IF LICENSOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   7. Termination
      a. This License and the rights granted hereunder will terminate automatically upon any breach by You of the terms of this License. Individuals or entities who have received Adaptations or Collections from You under this License, however, will not have their licenses terminated provided such individuals or entities remain in full compliance with those licenses. Sections 1, 2, 5, 6, 7, and 8 will survive any termination of this License.
      b. Subject to the above terms and conditions, the license granted here is perpetual (for the duration of the applicable copyright in the Work). Notwithstanding the above, Licensor reserves the right to release the Work under different license terms or to stop distributing the Work at any time; provided, however that any such election will not serve to withdraw this License (or any other license that has been, or is required to be, granted under the terms of this License), and this License will continue in full force and effect unless terminated as stated above.
   8. Miscellaneous
      a. Each time You Distribute or Publicly Perform the Work or a Collection, the Licensor offers to the recipient a license to the Work on the same terms and conditions as the license granted to You under this License.
      b. Each time You Distribute or Publicly Perform an Adaptation, Licensor offers to the recipient a license to the original Work on the same terms and conditions as the license granted to You under this License.
      c. If any provision of this License is invalid or unenforceable under applicable law, it shall not affect the validity or enforceability of the remainder of the terms of this License, and without further action by the parties to this agreement, such provision shall be reformed to the minimum extent necessary to make such provision valid and enforceable.
      d. No term or provision of this License shall be deemed waived and no breach consented to unless such waiver or consent shall be in writing and signed by the party to be charged with such waiver or consent.
      e. This License constitutes the entire agreement between the parties with respect to the Work licensed here. There are no understandings, agreements or representations with respect to the Work not specified here. Licensor shall not be bound by any additional provisions that may appear in any communication from You. This License may not be modified without the mutual written agreement of the Licensor and You.
      f. The rights granted under, and the subject matter referenced, in this License were drafted utilizing the terminology of the Berne Convention for the Protection of Literary and Artistic Works (as amended on September 28, 1979), the Rome Convention of 1961, the WIPO Copyright Treaty of 1996, the WIPO Performances and Phonograms Treaty of 1996 and the Universal Copyright Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.
Creative Commons Notice
Creative Commons is not a party to this License, and makes no warranty whatsoever in connection with the Work. Creative Commons will not be liable to You or any party on any legal theory for any damages whatsoever, including without limitation any general, special, incidental or consequential damages arising in connection to this license. Notwithstanding the foregoing two (2) sentences, if Creative Commons has expressly identified itself as the Licensor hereunder, it shall have all rights and obligations of Licensor.
Except for the limited purpose of indicating to the public that the Work is licensed under the CCPL, Creative Commons does not authorize the use by either party of the trademark "Creative Commons" or any related trademark or logo of Creative Commons without the prior written consent of Creative Commons. Any permitted use will be in compliance with Creative Commons' then-current trademark usage guidelines, as may be published on its website or otherwise made available upon request from time to time. For the avoidance of doubt, this trademark restriction does not form part of the License.
Creative Commons may be contacted at http://creativecommons.org/.
```






```
Copyright (c) 2017 Christopher Groskopf and contributors

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice, this
      list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation

      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






```
Copyright (c) 2017 Christopher Groskopf and contributors . All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

   3. Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






```
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

\- Redistributions of source code must retain the above copyright
  notice, this list of conditions and the following disclaimer.

\- Redistributions in binary form must reproduce the above copyright
  notice, this list of conditions and the following disclaimer listed
  in this license in the documentation and/or other materials
  provided with the distribution.

\- Neither the name of the copyright holders nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

The copyright holders provide no reassurances that the source code
provided does not infringe any patent, copyright, or any other
intellectual property rights of third parties.  The copyright holders
disclaim any liability to any recipient for claims brought against
recipient by any third party for infringement of that parties
intellectual property rights.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






```
Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those
of the authors and should not be interpreted as representing official policies,
either expressed or implied, of the FreeBSD Project.
```






```
Permission is hereby granted, free of charge, to any person or organization obtaining a copy of the software and accompanying documentation covered by this license (the "Software") to use, reproduce, display, distribute, execute, and transmit the Software, and to prepare derivative works of the Software, and to permit third-parties to whom the Software is furnished to do so, all subject to the following:
The copyright notices in the Software and this entire statement, including the above license grant, this restriction and the following disclaimer, must be included in all copies of the Software, in whole or in part, and all derivative works of the Software, unless such copies or derivative works are solely in the form of machine-executable object code generated by a source language processor.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
```






```
As a special exception, you may create a larger work that contains part or all of the Bison parser skeleton and distribute that work under terms of your choice, so long as that work isn't itself a parser generator using the skeleton or a modified version thereof as a parser skeleton. Alternatively, if you modify or redistribute the parser skeleton itself, you may (at your option) remove this special exception, which will cause the skeleton and the resulting Bison output files to be licensed under the GNU General Public License without this special exception.
This special exception was added by the Free Software Foundation in version 2.2 of Bison.
```






```
Copyright (c) 2017 Christopher Groskopf and contributors
All Rights Reserved
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the conditions below are met. These conditions require a modest attribution to <AUTHOR> (the "Author"), who hopes that its promotional value may help justify the thousands of dollars in otherwise billable time invested in writing this and other freely available, open-source software.
   1. Redistributions of source code, in whole or part and with or without modification (the "Code"), must prominently display this GPG-signed text in verifiable form.
   2. Redistributions of the Code in binary form must be accompanied by this GPG-signed text in any documentation and, each time the resulting executable program or a program dependent thereon is launched, a prominent display (e.g., splash screen or banner text) of the Author's attribution information, which includes:
      (a) Name ("AUTHOR"),
      (b) Professional identification ("PROFESSIONAL IDENTIFICATION"), and
      (c) URL ("URL").
   3. Neither the name nor any trademark of the Author may be used to endorse or promote products derived from this software without specific prior written permission.
   4. Users are entirely responsible, to the exclusion of the Author and any other persons, for compliance with (1) regulations set by owners or administrators of employed equipment, (2) licensing terms of any other software, and (3) local regulations regarding use, including those regarding import, export, and use of encryption software.
THIS FREE SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR ANY CONTRIBUTOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, EFFECTS OF UNAUTHORIZED OR MALICIOUS NETWORK ACCESS; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






```
Preamble
The intent of this document is to state the conditions under which a Package may be copied, such that the Copyright Holder maintains some semblance of artistic control over the development of the package, while giving the users of the package the right to use and distribute the Package in a more-or-less customary fashion, plus the right to make reasonable modifications.
Definitions:
"Package" refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
"Standard Version" refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder.
"Copyright Holder" is whoever is named in the copyright or copyrights for the package.
"You" is you, if you're thinking about copying or distributing this Package.
"Reasonable copying fee" is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
"Freely Available" means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as ftp.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
      b) use the modified Package only within your corporation or organization.
      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
      b) accompany the distribution with the machine-readable source of the Package with your modifications.
      c) accompany any non-standard executables with their corresponding Standard Version executables, giving the non-standard executables non-standard names, and clearly documenting the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own.
   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.
   7. C or perl subroutines supplied by you and linked into this Package shall not be considered part of this Package.
   8. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
   9. THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
```






```
Copyright (C) 2017 Christopher Groskopf and contributors
This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
You should have received a copy of the GNU Affero General Public License along with this program. If not, see <http ://www.gnu.org/licenses/>
```






```
Preamble
The intent of this document is to state the conditions under which a Package may be copied, such that the Copyright Holder maintains some semblance of artistic control over the development of the package, while giving the users of the package the right to use and distribute the Package in a more-or-less customary fashion, plus the right to make reasonable modifications.
Definitions:
"Package" refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
"Standard Version" refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder as specified below.
"Copyright Holder" is whoever is named in the copyright or copyrights for the package.
"You" is you, if you're thinking about copying or distributing this Package.
"Reasonable copying fee" is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
"Freely Available" means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as uunet.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
      b) use the modified Package only within your corporation or organization.
      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
      b) accompany the distribution with the machine-readable source of the Package with your modifications.
      c) give non-standard executables non-standard names, and clearly document the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own. You may embed this Package's interpreter within an executable of yours (by linking); this shall be construed as a mere form of aggregation, provided that the complete Standard Version of the interpreter is so embedded.
   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called "undump" or "unexec" methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.
   7. C subroutines (or comparably compiled subroutines in other languages) supplied by you and linked into this Package in order to emulate subroutines and variables of the language defined by this Package shall not be considered part of this Package, but are the equivalent of input as in Paragraph 6, provided these subroutines do not change the language in any way that would cause it to fail the regression tests for the language.
   8. Aggregation of this Package with a commercial distribution is always permitted provided that the use of this Package is embedded; that is, when no overt attempt is made to make this Package's interfaces visible to the end user of the commercial distribution. Such use shall not be construed as a distribution of this Package.
   9. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
   10. THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
```

















---

### [more-itertools (8.10.0)](https://pypi.org/project/more-itertools/)


#### Declared Licenses
MIT


```
Copyright (c) 2012 Erik Rose

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses














---

### [more-itertools (10.1.0)](https://pypi.org/project/more-itertools/)


#### Declared Licenses
MIT


```
Copyright (c) 2012 Erik Rose

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses














---

### [networkx (3.4.2)](https://pypi.org/project/networkx/)


#### Declared Licenses
BSD-3-Clause, psf-3.7.2


```
NetworkX is distributed with the 3-clause BSD license.

::

   Copyright (C) 2004-2024, NetworkX Developers
   Aric Hagberg <hagberg@lanl.gov>
   Dan Schult <dschult@colgate.edu>
   Pieter Swart <swart@lanl.gov>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are
   met:

     * Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.

     * Redistributions in binary form must reproduce the above
       copyright notice, this list of conditions and the following
       disclaimer in the documentation and/or other materials provided
       with the distribution.

     * Neither the name of the NetworkX Developers nor the names of its
       contributors may be used to endorse or promote products derived
       from this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






```
PSF LICENSE AGREEMENT FOR PYTHON 3.7.2

1\. This LICENSE AGREEMENT is between the Python Software Foundation ("PSF"), and
   the Individual or Organization ("Licensee") accessing and otherwise using Python
   3.7.2 software in source or binary form and its associated documentation.

2\. Subject to the terms and conditions of this License Agreement, PSF hereby
   grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce,
   analyze, test, perform and/or display publicly, prepare derivative works,
   distribute, and otherwise use Python 3.7.2 alone or in any derivative
   version, provided, however, that PSF's License Agreement and PSF's notice of
   copyright, i.e., "Copyright © 2001-2019 Python Software Foundation; All Rights
   Reserved" are retained in Python 3.7.2 alone or in any derivative version
   prepared by Licensee.

3\. In the event Licensee prepares a derivative work that is based on or
   incorporates Python 3.7.2 or any part thereof, and wants to make the
   derivative work available to others as provided herein, then Licensee hereby
   agrees to include in any such work a brief summary of the changes made to Python
   3.7.2.

4\. PSF is making Python 3.7.2 available to Licensee on an "AS IS" basis.
   PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.  BY WAY OF
   EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR
   WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE
   USE OF PYTHON 3.7.2 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.

5\. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON 3.7.2
   FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF
   MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON 3.7.2, OR ANY DERIVATIVE
   THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.

6\. This License Agreement will automatically terminate upon a material breach of
   its terms and conditions.

7\. Nothing in this License Agreement shall be deemed to create any relationship
   of agency, partnership, or joint venture between PSF and Licensee.  This License
   Agreement does not grant permission to use PSF trademarks or trade name in a
   trademark sense to endorse or promote products or services of Licensee, or any
   third party.

8\. By copying, installing or otherwise using Python 3.7.2, Licensee agrees
   to be bound by the terms and conditions of this License Agreement.
```






#### Other Licenses
CC-BY-SA-3.0, BSD-3-Clause-Clear


```
THE WORK (AS DEFINED BELOW) IS PROVIDED UNDER THE TERMS OF THIS CREATIVE COMMONS PUBLIC LICENSE ("CCPL" OR "LICENSE"). THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.
BY EXERCISING ANY RIGHTS TO THE WORK PROVIDED HERE, YOU ACCEPT AND AGREE TO BE BOUND BY THE TERMS OF THIS LICENSE. TO THE EXTENT THIS LICENSE MAY BE CONSIDERED TO BE A CONTRACT, THE LICENSOR GRANTS YOU THE RIGHTS CONTAINED HERE IN CONSIDERATION OF YOUR ACCEPTANCE OF SUCH TERMS AND CONDITIONS.
   1. Definitions
      a. "Adaptation" means a work based upon the Work, or upon the Work and other pre-existing works, such as a translation, adaptation, derivative work, arrangement of music or other alterations of a literary or artistic work, or phonogram or performance and includes cinematographic adaptations or any other form in which the Work may be recast, transformed, or adapted including in any form recognizably derived from the original, except that a work that constitutes a Collection will not be considered an Adaptation for the purpose of this License. For the avoidance of doubt, where the Work is a musical work, performance or phonogram, the synchronization of the Work in timed-relation with a moving image ("synching") will be considered an Adaptation for the purpose of this License.
      b. "Collection" means a collection of literary or artistic works, such as encyclopedias and anthologies, or performances, phonograms or broadcasts, or other works or subject matter other than works listed in Section 1(f) below, which, by reason of the selection and arrangement of their contents, constitute intellectual creations, in which the Work is included in its entirety in unmodified form along with one or more other contributions, each constituting separate and independent works in themselves, which together are assembled into a collective whole. A work that constitutes a Collection will not be considered an Adaptation (as defined below) for the purposes of this License.
      c. "Creative Commons Compatible License" means a license that is listed at http://creativecommons.org/compatiblelicenses that has been approved by Creative Commons as being essentially equivalent to this License, including, at a minimum, because that license: (i) contains terms that have the same purpose, meaning and effect as the License Elements of this License; and, (ii) explicitly permits the relicensing of adaptations of works made available under that license under this License or a Creative Commons jurisdiction license with the same License Elements as this License.
      d. "Distribute" means to make available to the public the original and copies of the Work or Adaptation, as appropriate, through sale or other transfer of ownership.
      e. "License Elements" means the following high-level license attributes as selected by Licensor and indicated in the title of this License: Attribution, ShareAlike.
      f. "Licensor" means the individual, individuals, entity or entities that offer(s) the Work under the terms of this License.
      g. "Original Author" means, in the case of a literary or artistic work, the individual, individuals, entity or entities who created the Work or if no individual or entity can be identified, the publisher; and in addition (i) in the case of a performance the actors, singers, musicians, dancers, and other persons who act, sing, deliver, declaim, play in, interpret or otherwise perform literary or artistic works or expressions of folklore; (ii) in the case of a phonogram the producer being the person or legal entity who first fixes the sounds of a performance or other sounds; and, (iii) in the case of broadcasts, the organization that transmits the broadcast.
      h. "Work" means the literary and/or artistic work offered under the terms of this License including without limitation any production in the literary, scientific and artistic domain, whatever may be the mode or form of its expression including digital form, such as a book, pamphlet and other writing; a lecture, address, sermon or other work of the same nature; a dramatic or dramatico-musical work; a choreographic work or entertainment in dumb show; a musical composition with or without words; a cinematographic work to which are assimilated works expressed by a process analogous to cinematography; a work of drawing, painting, architecture, sculpture, engraving or lithography; a photographic work to which are assimilated works expressed by a process analogous to photography; a work of applied art; an illustration, map, plan, sketch or three-dimensional work relative to geography, topography, architecture or science; a performance; a broadcast; a phonogram; a compilation of data to the extent it is protected as a copyrightable work; or a work performed by a variety or circus performer to the extent it is not otherwise considered a literary or artistic work.
      i. "You" means an individual or entity exercising rights under this License who has not previously violated the terms of this License with respect to the Work, or who has received express permission from the Licensor to exercise rights under this License despite a previous violation.
      j. "Publicly Perform" means to perform public recitations of the Work and to communicate to the public those public recitations, by any means or process, including by wire or wireless means or public digital performances; to make available to the public Works in such a way that members of the public may access these Works from a place and at a place individually chosen by them; to perform the Work to the public by any means or process and the communication to the public of the performances of the Work, including by public digital performance; to broadcast and rebroadcast the Work by any means including signs, sounds or images.
      k. "Reproduce" means to make copies of the Work by any means including without limitation by sound or visual recordings and the right of fixation and reproducing fixations of the Work, including storage of a protected performance or phonogram in digital form or other electronic medium.
   2. Fair Dealing Rights. Nothing in this License is intended to reduce, limit, or restrict any uses free from copyright or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.
   3. License Grant. Subject to the terms and conditions of this License, Licensor hereby grants You a worldwide, royalty-free, non-exclusive, perpetual (for the duration of the applicable copyright) license to exercise the rights in the Work as stated below:
      a. to Reproduce the Work, to incorporate the Work into one or more Collections, and to Reproduce the Work as incorporated in the Collections;
      b. to create and Reproduce Adaptations provided that any such Adaptation, including any translation in any medium, takes reasonable steps to clearly label, demarcate or otherwise identify that changes were made to the original Work. For example, a translation could be marked "The original work was translated from English to Spanish," or a modification could indicate "The original work has been modified.";
      c. to Distribute and Publicly Perform the Work including as incorporated in Collections; and,
      d. to Distribute and Publicly Perform Adaptations.
      e. For the avoidance of doubt:
         i. Non-waivable Compulsory License Schemes. In those jurisdictions in which the right to collect royalties through any statutory or compulsory licensing scheme cannot be waived, the Licensor reserves the exclusive right to collect such royalties for any exercise by You of the rights granted under this License;
         ii. Waivable Compulsory License Schemes. In those jurisdictions in which the right to collect royalties through any statutory or compulsory licensing scheme can be waived, the Licensor waives the exclusive right to collect such royalties for any exercise by You of the rights granted under this License; and,
         iii. Voluntary License Schemes. The Licensor waives the right to collect royalties, whether individually or, in the event that the Licensor is a member of a collecting society that administers voluntary licensing schemes, via that society, from any exercise by You of the rights granted under this License.
   The above rights may be exercised in all media and formats whether now known or hereafter devised. The above rights include the right to make such modifications as are technically necessary to exercise the rights in other media and formats. Subject to Section 8(f), all rights not expressly granted by Licensor are hereby reserved.
   4. Restrictions. The license granted in Section 3 above is expressly made subject to and limited by the following restrictions:
      a. You may Distribute or Publicly Perform the Work only under the terms of this License. You must include a copy of, or the Uniform Resource Identifier (URI) for, this License with every copy of the Work You Distribute or Publicly Perform. You may not offer or impose any terms on the Work that restrict the terms of this License or the ability of the recipient of the Work to exercise the rights granted to that recipient under the terms of the License. You may not sublicense the Work. You must keep intact all notices that refer to this License and to the disclaimer of warranties with every copy of the Work You Distribute or Publicly Perform. When You Distribute or Publicly Perform the Work, You may not impose any effective technological measures on the Work that restrict the ability of a recipient of the Work from You to exercise the rights granted to that recipient under the terms of the License. This Section 4(a) applies to the Work as incorporated in a Collection, but this does not require the Collection apart from the Work itself to be made subject to the terms of this License. If You create a Collection, upon notice from any Licensor You must, to the extent practicable, remove from the Collection any credit as required by Section 4(c), as requested. If You create an Adaptation, upon notice from any Licensor You must, to the extent practicable, remove from the Adaptation any credit as required by Section 4(c), as requested.
      b. You may Distribute or Publicly Perform an Adaptation only under the terms of: (i) this License; (ii) a later version of this License with the same License Elements as this License; (iii) a Creative Commons jurisdiction license (either this or a later license version) that contains the same License Elements as this License (e.g., Attribution-ShareAlike 3.0 US)); (iv) a Creative Commons Compatible License. If you license the Adaptation under one of the licenses mentioned in (iv), you must comply with the terms of that license. If you license the Adaptation under the terms of any of the licenses mentioned in (i), (ii) or (iii) (the "Applicable License"), you must comply with the terms of the Applicable License generally and the following provisions: (I) You must include a copy of, or the URI for, the Applicable License with every copy of each Adaptation You Distribute or Publicly Perform; (II) You may not offer or impose any terms on the Adaptation that restrict the terms of the Applicable License or the ability of the recipient of the Adaptation to exercise the rights granted to that recipient under the terms of the Applicable License; (III) You must keep intact all notices that refer to the Applicable License and to the disclaimer of warranties with every copy of the Work as included in the Adaptation You Distribute or Publicly Perform; (IV) when You Distribute or Publicly Perform the Adaptation, You may not impose any effective technological measures on the Adaptation that restrict the ability of a recipient of the Adaptation from You to exercise the rights granted to that recipient under the terms of the Applicable License. This Section 4(b) applies to the Adaptation as incorporated in a Collection, but this does not require the Collection apart from the Adaptation itself to be made subject to the terms of the Applicable License.
      c. If You Distribute, or Publicly Perform the Work or any Adaptations or Collections, You must, unless a request has been made pursuant to Section 4(a), keep intact all copyright notices for the Work and provide, reasonable to the medium or means You are utilizing: (i) the name of the Original Author (or pseudonym, if applicable) if supplied, and/or if the Original Author and/or Licensor designate another party or parties (e.g., a sponsor institute, publishing entity, journal) for attribution ("Attribution Parties") in Licensor's copyright notice, terms of service or by other reasonable means, the name of such party or parties; (ii) the title of the Work if supplied; (iii) to the extent reasonably practicable, the URI, if any, that Licensor specifies to be associated with the Work, unless such URI does not refer to the copyright notice or licensing information for the Work; and (iv), consistent with Section 3(b), in the case of an Adaptation, a credit identifying the use of the Work in the Adaptation (e.g., "French translation of the Work by Original Author," or "Screenplay based on original Work by Original Author"). The credit required by this Section 4(c) may be implemented in any reasonable manner; provided, however, that in the case of a Adaptation or Collection, at a minimum such credit will appear, if a credit for all contributing authors of the Adaptation or Collection appears, then as part of these credits and in a manner at least as prominent as the credits for the other contributing authors. For the avoidance of doubt, You may only use the credit required by this Section for the purpose of attribution in the manner set out above and, by exercising Your rights under this License, You may not implicitly or explicitly assert or imply any connection with, sponsorship or endorsement by the Original Author, Licensor and/or Attribution Parties, as appropriate, of You or Your use of the Work, without the separate, express prior written permission of the Original Author, Licensor and/or Attribution Parties.
      d. Except as otherwise agreed in writing by the Licensor or as may be otherwise permitted by applicable law, if You Reproduce, Distribute or Publicly Perform the Work either by itself or as part of any Adaptations or Collections, You must not distort, mutilate, modify or take other derogatory action in relation to the Work which would be prejudicial to the Original Author's honor or reputation. Licensor agrees that in those jurisdictions (e.g. Japan), in which any exercise of the right granted in Section 3(b) of this License (the right to make Adaptations) would be deemed to be a distortion, mutilation, modification or other derogatory action prejudicial to the Original Author's honor and reputation, the Licensor will waive or not assert, as appropriate, this Section, to the fullest extent permitted by the applicable national law, to enable You to reasonably exercise Your right under Section 3(b) of this License (right to make Adaptations) but not otherwise.
   5. Representations, Warranties and Disclaimer
   UNLESS OTHERWISE MUTUALLY AGREED TO BY THE PARTIES IN WRITING, LICENSOR OFFERS THE WORK AS-IS AND MAKES NO REPRESENTATIONS OR WARRANTIES OF ANY KIND CONCERNING THE WORK, EXPRESS, IMPLIED, STATUTORY OR OTHERWISE, INCLUDING, WITHOUT LIMITATION, WARRANTIES OF TITLE, MERCHANTIBILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, ACCURACY, OR THE PRESENCE OF ABSENCE OF ERRORS, WHETHER OR NOT DISCOVERABLE. SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OF IMPLIED WARRANTIES, SO SUCH EXCLUSION MAY NOT APPLY TO YOU.
   6. Limitation on Liability. EXCEPT TO THE EXTENT REQUIRED BY APPLICABLE LAW, IN NO EVENT WILL LICENSOR BE LIABLE TO YOU ON ANY LEGAL THEORY FOR ANY SPECIAL, INCIDENTAL, CONSEQUENTIAL, PUNITIVE OR EXEMPLARY DAMAGES ARISING OUT OF THIS LICENSE OR THE USE OF THE WORK, EVEN IF LICENSOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   7. Termination
      a. This License and the rights granted hereunder will terminate automatically upon any breach by You of the terms of this License. Individuals or entities who have received Adaptations or Collections from You under this License, however, will not have their licenses terminated provided such individuals or entities remain in full compliance with those licenses. Sections 1, 2, 5, 6, 7, and 8 will survive any termination of this License.
      b. Subject to the above terms and conditions, the license granted here is perpetual (for the duration of the applicable copyright in the Work). Notwithstanding the above, Licensor reserves the right to release the Work under different license terms or to stop distributing the Work at any time; provided, however that any such election will not serve to withdraw this License (or any other license that has been, or is required to be, granted under the terms of this License), and this License will continue in full force and effect unless terminated as stated above.
   8. Miscellaneous
      a. Each time You Distribute or Publicly Perform the Work or a Collection, the Licensor offers to the recipient a license to the Work on the same terms and conditions as the license granted to You under this License.
      b. Each time You Distribute or Publicly Perform an Adaptation, Licensor offers to the recipient a license to the original Work on the same terms and conditions as the license granted to You under this License.
      c. If any provision of this License is invalid or unenforceable under applicable law, it shall not affect the validity or enforceability of the remainder of the terms of this License, and without further action by the parties to this agreement, such provision shall be reformed to the minimum extent necessary to make such provision valid and enforceable.
      d. No term or provision of this License shall be deemed waived and no breach consented to unless such waiver or consent shall be in writing and signed by the party to be charged with such waiver or consent.
      e. This License constitutes the entire agreement between the parties with respect to the Work licensed here. There are no understandings, agreements or representations with respect to the Work not specified here. Licensor shall not be bound by any additional provisions that may appear in any communication from You. This License may not be modified without the mutual written agreement of the Licensor and You.
      f. The rights granted under, and the subject matter referenced, in this License were drafted utilizing the terminology of the Berne Convention for the Protection of Literary and Artistic Works (as amended on September 28, 1979), the Rome Convention of 1961, the WIPO Copyright Treaty of 1996, the WIPO Performances and Phonograms Treaty of 1996 and the Universal Copyright Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.
Creative Commons Notice
Creative Commons is not a party to this License, and makes no warranty whatsoever in connection with the Work. Creative Commons will not be liable to You or any party on any legal theory for any damages whatsoever, including without limitation any general, special, incidental or consequential damages arising in connection to this license. Notwithstanding the foregoing two (2) sentences, if Creative Commons has expressly identified itself as the Licensor hereunder, it shall have all rights and obligations of Licensor.
Except for the limited purpose of indicating to the public that the Work is licensed under the CCPL, Creative Commons does not authorize the use by either party of the trademark "Creative Commons" or any related trademark or logo of Creative Commons without the prior written consent of Creative Commons. Any permitted use will be in compliance with Creative Commons' then-current trademark usage guidelines, as may be published on its website or otherwise made available upon request from time to time. For the avoidance of doubt, this trademark restriction does not form part of the License.
Creative Commons may be contacted at http://creativecommons.org/.
```






```
Copyright (c) 2015 Thomson Licensing, SAS
All rights reserved.
Redistribution and use in source and binary forms, with or without modification, are permitted (subject to the limitations in the disclaimer below) provided that the following conditions are met:
      * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
      * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
      * Neither the name of [Owner Organization] nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE GRANTED BY THIS LICENSE. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```

















---

### [ordered-set (4.1.0)](https://pypi.org/project/ordered-set/)


#### Declared Licenses
MIT


```
Copyright (c) 2012-2022 Elia Robyn Lake
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```






#### Other Licenses














---

### [packaging (24.2)](https://pypi.org/project/packaging/)


#### Declared Licenses
BSD-3-Clause, Apache-2.0, BSD-2-Clause


```
Copyright (c) <year> <owner> . All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

   3. Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






```
This software is made available under the terms of *either* of the licenses
found in LICENSE.APACHE or LICENSE.BSD. Contributions to this software is made
under the terms of *both* these licenses.

```






```
Copyright (c) Donald Stufft and individual contributors.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    1. Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.

    2. Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






#### Other Licenses
MIT


```
Copyright (c) 2017 present Ofek Lev <oss@ofek.dev>
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

















---

### [parsedatetime (2.6)](https://github.com/bear/parsedatetime)


#### Declared Licenses
Apache-2.0


```
                               Apache License
                          Version 2.0, January 2004
                       http://www.apache.org/licenses/

TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

1\. Definitions.

   "License" shall mean the terms and conditions for use, reproduction, and
   distribution as defined by Sections 1 through 9 of this document.

   "Licensor" shall mean the copyright owner or entity authorized by the
   copyright owner that is granting the License.

   "Legal Entity" shall mean the union of the acting entity and all other
   entities that control, are controlled by, or are under common control with
   that entity. For the purposes of this definition, "control" means (i) the
   power, direct or indirect, to cause the direction or management of such
   entity, whether by contract or otherwise, or (ii) ownership of fifty percent
   (50%) or more of the outstanding shares, or (iii) beneficial ownership of
   such entity.

   "You" (or "Your") shall mean an individual or Legal Entity exercising
   permissions granted by this License.

   "Source" form shall mean the preferred form for making modifications,
   including but not limited to software source code, documentation source,
   and configuration files.

   "Object" form shall mean any form resulting from mechanical
   transformation or translation of a Source form, including but not limited
   to compiled object code, generated documentation, and conversions to
   other media types.

   "Work" shall mean the work of authorship, whether in Source or Object
   form, made available under the License, as indicated by a copyright
   notice that is included in or attached to the work (an example is
   provided in the Appendix below).

   "Derivative Works" shall mean any work, whether in Source or Object form,
   that is based on (or derived from) the Work and for which the editorial
   revisions, annotations, elaborations, or other modifications represent,
   as a whole, an original work of authorship. For the purposes of this
   License, Derivative Works shall not include works that remain separable
   from, or merely link (or bind by name) to the interfaces of, the Work and
   Derivative Works thereof.

   "Contribution" shall mean any work of authorship, including the original
   version of the Work and any modifications or additions to that Work or
   Derivative Works thereof, that is intentionally submitted to Licensor for
   inclusion in the Work by the copyright owner or by an individual or Legal
   Entity authorized to submit on behalf of the copyright owner. For the
   purposes of this definition, "submitted" means any form of electronic,
   verbal, or written communication sent to the Licensor or its
   representatives, including but not limited to communication on electronic
   mailing lists, source code control systems, and issue tracking systems
   that are managed by, or on behalf of, the Licensor for the purpose of
   discussing and improving the Work, but excluding communication that is
   conspicuously marked or otherwise designated in writing by the copyright
   owner as "Not a Contribution."

   "Contributor" shall mean Licensor and any individual or Legal Entity on
   behalf of whom a Contribution has been received by Licensor and
   subsequently incorporated within the Work.

2\. Grant of Copyright License. Subject to the terms and conditions of this
   License, each Contributor hereby grants to You a perpetual, worldwide,
   non-exclusive, no-charge, royalty-free, irrevocable copyright license to
   reproduce, prepare Derivative Works of, publicly display, publicly
   perform, sublicense, and distribute the Work and such Derivative Works in
   Source or Object form.

3\. Grant of Patent License. Subject to the terms and conditions of this
   License, each Contributor hereby grants to You a perpetual, worldwide,
   non-exclusive, no-charge, royalty-free, irrevocable (except as stated in
   this section) patent license to make, have made, use, offer to sell,
   sell, import, and otherwise transfer the Work, where such license applies
   only to those patent claims licensable by such Contributor that are
   necessarily infringed by their Contribution(s) alone or by combination of
   their Contribution(s) with the Work to which such Contribution(s) was
   submitted. If You institute patent litigation against any entity
   (including a cross-claim or counterclaim in a lawsuit) alleging that the
   Work or a Contribution incorporated within the Work constitutes direct or
   contributory patent infringement, then any patent licenses granted to You
   under this License for that Work shall terminate as of the date such
   litigation is filed.

4\. Redistribution. You may reproduce and distribute copies of the Work or
   Derivative Works thereof in any medium, with or without modifications,
   and in Source or Object form, provided that You meet the following
   conditions:

   1. You must give any other recipients of the Work or Derivative Works a
      copy of this License; and

   2. You must cause any modified files to carry prominent notices stating
      that You changed the files; and

   3. You must retain, in the Source form of any Derivative Works that You
      distribute, all copyright, patent, trademark, and attribution notices
      from the Source form of the Work, excluding those notices that do not
      pertain to any part of the Derivative Works; and

   4. If the Work includes a "NOTICE" text file as part of its distribution,
      then any Derivative Works that You distribute must include a readable
      copy of the attribution notices contained within such NOTICE file,
      excluding those notices that do not pertain to any part of the
      Derivative Works, in at least one of the following places: within a
      NOTICE text file distributed as part of the Derivative Works; within
      the Source form or documentation, if provided along with the
      Derivative Works; or, within a display generated by the Derivative
      Works, if and wherever such third-party notices normally appear. The
      contents of the NOTICE file are for informational purposes only and do
      not modify the License. You may add Your own attribution notices
      within Derivative Works that You distribute, alongside or as an
      addendum to the NOTICE text from the Work, provided that such
      additional attribution notices cannot be construed as modifying the
      License.

   You may add Your own copyright statement to Your modifications and may
   provide additional or different license terms and conditions for use,
   reproduction, or distribution of Your modifications, or for any such
   Derivative Works as a whole, provided Your use, reproduction, and
   distribution of the Work otherwise complies with the conditions stated in
   this License.

5\. Submission of Contributions. Unless You explicitly state otherwise, any
   Contribution intentionally submitted for inclusion in the Work by You to
   the Licensor shall be under the terms and conditions of this License,
   without any additional terms or conditions. Notwithstanding the above,
   nothing herein shall supersede or modify the terms of any separate
   license agreement you may have executed with Licensor regarding such
   Contributions.

6\. Trademarks. This License does not grant permission to use the trade
   names, trademarks, service marks, or product names of the Licensor,
   except as required for reasonable and customary use in describing the
   origin of the Work and reproducing the content of the NOTICE file.

7\. Disclaimer of Warranty. Unless required by applicable law or agreed to in
   writing, Licensor provides the Work (and each Contributor provides its
   Contributions) on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
   ANY KIND, either express or implied, including, without limitation, any
   warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or
   FITNESS FOR A PARTICULAR PURPOSE. You are solely responsible for
   determining the appropriateness of using or redistributing the Work and
   assume any risks associated with Your exercise of permissions under this
   License.

8\. Limitation of Liability. In no event and under no legal theory, whether
   in tort (including negligence), contract, or otherwise, unless required
   by applicable law (such as deliberate and grossly negligent acts) or
   agreed to in writing, shall any Contributor be liable to You for damages,
   including any direct, indirect, special, incidental, or consequential
   damages of any character arising as a result of this License or out of
   the use or inability to use the Work (including but not limited to
   damages for loss of goodwill, work stoppage, computer failure or
   malfunction, or any and all other commercial damages or losses), even if
   such Contributor has been advised of the possibility of such damages.

9\. Accepting Warranty or Additional Liability. While redistributing the Work
   or Derivative Works thereof, You may choose to offer, and charge a fee
   for, acceptance of support, warranty, indemnity, or other liability
   obligations and/or rights consistent with this License. However, in
   accepting such obligations, You may act only on Your own behalf and on
   Your sole responsibility, not on behalf of any other Contributor, and
   only if You agree to indemnify, defend, and hold each Contributor
   harmless for any liability incurred by, or claims asserted against, such
   Contributor by reason of your accepting any such warranty or additional
   liability.

END OF TERMS AND CONDITIONS

```






#### Other Licenses
X11


```
Copyright (C) 1996 X Consortium
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
Except as contained in this notice, the name of the X Consortium shall not be used in advertising or otherwise to promote the sale, use or other dealings in this Software without prior written authorization from the X Consortium.
X Window System is a trademark of X Consortium, Inc.
```

















---

### [pathspec (0.12.1)](https://pypi.org/project/pathspec/)


#### Declared Licenses
MPL-2.0


```
Mozilla Public License Version 2.0
==================================

1\. Definitions
--------------

1.1. "Contributor"
    means each individual or legal entity that creates, contributes to
    the creation of, or owns Covered Software.

1.2. "Contributor Version"
    means the combination of the Contributions of others (if any) used
    by a Contributor and that particular Contributor's Contribution.

1.3. "Contribution"
    means Covered Software of a particular Contributor.

1.4. "Covered Software"
    means Source Code Form to which the initial Contributor has attached
    the notice in Exhibit A, the Executable Form of such Source Code
    Form, and Modifications of such Source Code Form, in each case
    including portions thereof.

1.5. "Incompatible With Secondary Licenses"
    means

    (a) that the initial Contributor has attached the notice described
        in Exhibit B to the Covered Software; or

    (b) that the Covered Software was made available under the terms of
        version 1.1 or earlier of the License, but not also under the
        terms of a Secondary License.

1.6. "Executable Form"
    means any form of the work other than Source Code Form.

1.7. "Larger Work"
    means a work that combines Covered Software with other material, in 
    a separate file or files, that is not Covered Software.

1.8. "License"
    means this document.

1.9. "Licensable"
    means having the right to grant, to the maximum extent possible,
    whether at the time of the initial grant or subsequently, any and
    all of the rights conveyed by this License.

1.10. "Modifications"
    means any of the following:

    (a) any file in Source Code Form that results from an addition to,
        deletion from, or modification of the contents of Covered
        Software; or

    (b) any new file in Source Code Form that contains any Covered
        Software.

1.11. "Patent Claims" of a Contributor
    means any patent claim(s), including without limitation, method,
    process, and apparatus claims, in any patent Licensable by such
    Contributor that would be infringed, but for the grant of the
    License, by the making, using, selling, offering for sale, having
    made, import, or transfer of either its Contributions or its
    Contributor Version.

1.12. "Secondary License"
    means either the GNU General Public License, Version 2.0, the GNU
    Lesser General Public License, Version 2.1, the GNU Affero General
    Public License, Version 3.0, or any later versions of those
    licenses.

1.13. "Source Code Form"
    means the form of the work preferred for making modifications.

1.14. "You" (or "Your")
    means an individual or a legal entity exercising rights under this
    License. For legal entities, "You" includes any entity that
    controls, is controlled by, or is under common control with You. For
    purposes of this definition, "control" means (a) the power, direct
    or indirect, to cause the direction or management of such entity,
    whether by contract or otherwise, or (b) ownership of more than
    fifty percent (50%) of the outstanding shares or beneficial
    ownership of such entity.

2\. License Grants and Conditions
--------------------------------

2.1. Grants

Each Contributor hereby grants You a world-wide, royalty-free,
non-exclusive license:

(a) under intellectual property rights (other than patent or trademark)
    Licensable by such Contributor to use, reproduce, make available,
    modify, display, perform, distribute, and otherwise exploit its
    Contributions, either on an unmodified basis, with Modifications, or
    as part of a Larger Work; and

(b) under Patent Claims of such Contributor to make, use, sell, offer
    for sale, have made, import, and otherwise transfer either its
    Contributions or its Contributor Version.

2.2. Effective Date

The licenses granted in Section 2.1 with respect to any Contribution
become effective for each Contribution on the date the Contributor first
distributes such Contribution.

2.3. Limitations on Grant Scope

The licenses granted in this Section 2 are the only rights granted under
this License. No additional rights or licenses will be implied from the
distribution or licensing of Covered Software under this License.
Notwithstanding Section 2.1(b) above, no patent license is granted by a
Contributor:

(a) for any code that a Contributor has removed from Covered Software;
    or

(b) for infringements caused by: (i) Your and any other third party's
    modifications of Covered Software, or (ii) the combination of its
    Contributions with other software (except as part of its Contributor
    Version); or

(c) under Patent Claims infringed by Covered Software in the absence of
    its Contributions.

This License does not grant any rights in the trademarks, service marks,
or logos of any Contributor (except as may be necessary to comply with
the notice requirements in Section 3.4).

2.4. Subsequent Licenses

No Contributor makes additional grants as a result of Your choice to
distribute the Covered Software under a subsequent version of this
License (see Section 10.2) or under the terms of a Secondary License (if
permitted under the terms of Section 3.3).

2.5. Representation

Each Contributor represents that the Contributor believes its
Contributions are its original creation(s) or it has sufficient rights
to grant the rights to its Contributions conveyed by this License.

2.6. Fair Use

This License is not intended to limit any rights You have under
applicable copyright doctrines of fair use, fair dealing, or other
equivalents.

2.7. Conditions

Sections 3.1, 3.2, 3.3, and 3.4 are conditions of the licenses granted
in Section 2.1.

3\. Responsibilities
-------------------

3.1. Distribution of Source Form

All distribution of Covered Software in Source Code Form, including any
Modifications that You create or to which You contribute, must be under
the terms of this License. You must inform recipients that the Source
Code Form of the Covered Software is governed by the terms of this
License, and how they can obtain a copy of this License. You may not
attempt to alter or restrict the recipients' rights in the Source Code
Form.

3.2. Distribution of Executable Form

If You distribute Covered Software in Executable Form then:

(a) such Covered Software must also be made available in Source Code
    Form, as described in Section 3.1, and You must inform recipients of
    the Executable Form how they can obtain a copy of such Source Code
    Form by reasonable means in a timely manner, at a charge no more
    than the cost of distribution to the recipient; and

(b) You may distribute such Executable Form under the terms of this
    License, or sublicense it under different terms, provided that the
    license for the Executable Form does not attempt to limit or alter
    the recipients' rights in the Source Code Form under this License.

3.3. Distribution of a Larger Work

You may create and distribute a Larger Work under terms of Your choice,
provided that You also comply with the requirements of this License for
the Covered Software. If the Larger Work is a combination of Covered
Software with a work governed by one or more Secondary Licenses, and the
Covered Software is not Incompatible With Secondary Licenses, this
License permits You to additionally distribute such Covered Software
under the terms of such Secondary License(s), so that the recipient of
the Larger Work may, at their option, further distribute the Covered
Software under the terms of either this License or such Secondary
License(s).

3.4. Notices

You may not remove or alter the substance of any license notices
(including copyright notices, patent notices, disclaimers of warranty,
or limitations of liability) contained within the Source Code Form of
the Covered Software, except that You may alter any license notices to
the extent required to remedy known factual inaccuracies.

3.5. Application of Additional Terms

You may choose to offer, and to charge a fee for, warranty, support,
indemnity or liability obligations to one or more recipients of Covered
Software. However, You may do so only on Your own behalf, and not on
behalf of any Contributor. You must make it absolutely clear that any
such warranty, support, indemnity, or liability obligation is offered by
You alone, and You hereby agree to indemnify every Contributor for any
liability incurred by such Contributor as a result of warranty, support,
indemnity or liability terms You offer. You may include additional
disclaimers of warranty and limitations of liability specific to any
jurisdiction.

4\. Inability to Comply Due to Statute or Regulation
---------------------------------------------------

If it is impossible for You to comply with any of the terms of this
License with respect to some or all of the Covered Software due to
statute, judicial order, or regulation then You must: (a) comply with
the terms of this License to the maximum extent possible; and (b)
describe the limitations and the code they affect. Such description must
be placed in a text file included with all distributions of the Covered
Software under this License. Except to the extent prohibited by statute
or regulation, such description must be sufficiently detailed for a
recipient of ordinary skill to be able to understand it.

5\. Termination
--------------

5.1. The rights granted under this License will terminate automatically
if You fail to comply with any of its terms. However, if You become
compliant, then the rights granted under this License from a particular
Contributor are reinstated (a) provisionally, unless and until such
Contributor explicitly and finally terminates Your grants, and (b) on an
ongoing basis, if such Contributor fails to notify You of the
non-compliance by some reasonable means prior to 60 days after You have
come back into compliance. Moreover, Your grants from a particular
Contributor are reinstated on an ongoing basis if such Contributor
notifies You of the non-compliance by some reasonable means, this is the
first time You have received notice of non-compliance with this License
from such Contributor, and You become compliant prior to 30 days after
Your receipt of the notice.

5.2. If You initiate litigation against any entity by asserting a patent
infringement claim (excluding declaratory judgment actions,
counter-claims, and cross-claims) alleging that a Contributor Version
directly or indirectly infringes any patent, then the rights granted to
You by any and all Contributors for the Covered Software under Section
2.1 of this License shall terminate.

5.3. In the event of termination under Sections 5.1 or 5.2 above, all
end user license agreements (excluding distributors and resellers) which
have been validly granted by You or Your distributors under this License
prior to termination shall survive termination.

************************************************************************
\*                                                                      *
\*  6. Disclaimer of Warranty                                           *
\*  -------------------------                                           *
\*                                                                      *
\*  Covered Software is provided under this License on an "as is"       *
\*  basis, without warranty of any kind, either expressed, implied, or  *
\*  statutory, including, without limitation, warranties that the       *
\*  Covered Software is free of defects, merchantable, fit for a        *
\*  particular purpose or non-infringing. The entire risk as to the     *
\*  quality and performance of the Covered Software is with You.        *
\*  Should any Covered Software prove defective in any respect, You     *
\*  (not any Contributor) assume the cost of any necessary servicing,   *
\*  repair, or correction. This disclaimer of warranty constitutes an   *
\*  essential part of this License. No use of any Covered Software is   *
\*  authorized under this License except under this disclaimer.         *
\*                                                                      *
************************************************************************

************************************************************************
\*                                                                      *
\*  7. Limitation of Liability                                          *
\*  --------------------------                                          *
\*                                                                      *
\*  Under no circumstances and under no legal theory, whether tort      *
\*  (including negligence), contract, or otherwise, shall any           *
\*  Contributor, or anyone who distributes Covered Software as          *
\*  permitted above, be liable to You for any direct, indirect,         *
\*  special, incidental, or consequential damages of any character      *
\*  including, without limitation, damages for lost profits, loss of    *
\*  goodwill, work stoppage, computer failure or malfunction, or any    *
\*  and all other commercial damages or losses, even if such party      *
\*  shall have been informed of the possibility of such damages. This   *
\*  limitation of liability shall not apply to liability for death or   *
\*  personal injury resulting from such party's negligence to the       *
\*  extent applicable law prohibits such limitation. Some               *
\*  jurisdictions do not allow the exclusion or limitation of           *
\*  incidental or consequential damages, so this exclusion and          *
\*  limitation may not apply to You.                                    *
\*                                                                      *
************************************************************************

8\. Litigation
-------------

Any litigation relating to this License may be brought only in the
courts of a jurisdiction where the defendant maintains its principal
place of business and such litigation shall be governed by laws of that
jurisdiction, without reference to its conflict-of-law provisions.
Nothing in this Section shall prevent a party's ability to bring
cross-claims or counter-claims.

9\. Miscellaneous
----------------

This License represents the complete agreement concerning the subject
matter hereof. If any provision of this License is held to be
unenforceable, such provision shall be reformed only to the extent
necessary to make it enforceable. Any law or regulation which provides
that the language of a contract shall be construed against the drafter
shall not be used to construe this License against a Contributor.

10\. Versions of the License
---------------------------

10.1. New Versions

Mozilla Foundation is the license steward. Except as provided in Section
10.3, no one other than the license steward has the right to modify or
publish new versions of this License. Each version will be given a
distinguishing version number.

10.2. Effect of New Versions

You may distribute the Covered Software under the terms of the version
of the License under which You originally received the Covered Software,
or under the terms of any subsequent version published by the license
steward.

10.3. Modified Versions

If you create software not governed by this License, and you want to
create a new license for such software, you may create and use a
modified version of this License if you rename the license and remove
any references to the name of the license steward (except to note that
such modified license differs from this License).

10.4. Distributing Source Code Form that is Incompatible With Secondary
Licenses

If You choose to distribute Source Code Form that is Incompatible With
Secondary Licenses under the terms of this version of the License, the
notice described in Exhibit B of this License must be attached.

Exhibit A - Source Code Form License Notice
-------------------------------------------

  This Source Code Form is subject to the terms of the Mozilla Public
  License, v. 2.0. If a copy of the MPL was not distributed with this
  file, You can obtain one at http://mozilla.org/MPL/2.0/.

If it is not possible or desirable to put the notice in a particular
file, then You may include the notice in a location (such as a LICENSE
file in a relevant directory) where a recipient would be likely to look
for such a notice.

You may add additional accurate notices of copyright ownership.

Exhibit B - "Incompatible With Secondary Licenses" Notice
---------------------------------------------------------

  This Source Code Form is "Incompatible With Secondary Licenses", as
  defined by the Mozilla Public License, v. 2.0.

```






#### Other Licenses














---

### [protobuf (5.29.3)](https://developers.google.com/protocol-buffers/)


#### Declared Licenses
Protobuf


```
Copyright 2008 Google Inc.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.
    * Neither the name of Google Inc. nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Code generated by the Protocol Buffer compiler is owned by the owner
of the input file used when generating it.  This code is not
standalone and requires a support library to be linked with it.  This
support library is itself covered by the above license.

```






#### Other Licenses
BSD-3-Clause, MIT


```
Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

   3. Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






```
Copyright (c) 2023 Google LLC
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

















---

### [pydantic (1.10.0)](https://pypi.org/project/pydantic/)


#### Declared Licenses
MIT


```
The MIT License (MIT)

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses














---

### [pydantic (2.10.5)](https://pypi.org/project/pydantic/)


#### Declared Licenses
MIT


```
The MIT License (MIT)

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses














---

### [python-dateutil (2.9.0)](https://github.com/dateutil/dateutil)


#### Declared Licenses
BSD-3-Clause, Apache-2.0


```
Copyright (c) 2017 Paul Ganssle <paul@ganssle.io> . All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

   3. Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






```
Copyright 2017- Paul Ganssle <paul@ganssle.io>
Copyright 2017- dateutil contributors (see AUTHORS file)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

The above license applies to all contributions after 2017-12-01, as well as
all contributions that have been re-licensed (see AUTHORS file for the list of
contributors who have re-licensed their code).
--------------------------------------------------------------------------------
dateutil - Extensions to the standard Python datetime module.

Copyright (c) 2003-2011 - Gustavo Niemeyer <gustavo@niemeyer.net>
Copyright (c) 2012-2014 - Tomi Pieviläinen <tomi.pievilainen@iki.fi>
Copyright (c) 2014-2016 - Yaron de Leeuw <me@jarondl.net>
Copyright (c) 2015-     - Paul Ganssle <paul@ganssle.io>
Copyright (c) 2015-     - dateutil contributors (see AUTHORS file)

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.
    * Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The above BSD License Applies to all code, even that also covered by Apache 2.0.
```






#### Other Licenses














---

### [python-dateutil (2.9.0.post0)](https://github.com/dateutil/dateutil)


#### Declared Licenses
Apache-2.0, BSD-3-Clause


```
Copyright 2017- Paul Ganssle <paul@ganssle.io>
Copyright 2017- dateutil contributors (see AUTHORS file)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

The above license applies to all contributions after 2017-12-01, as well as
all contributions that have been re-licensed (see AUTHORS file for the list of
contributors who have re-licensed their code).
--------------------------------------------------------------------------------
dateutil - Extensions to the standard Python datetime module.

Copyright (c) 2003-2011 - Gustavo Niemeyer <gustavo@niemeyer.net>
Copyright (c) 2012-2014 - Tomi Pieviläinen <tomi.pievilainen@iki.fi>
Copyright (c) 2014-2016 - Yaron de Leeuw <me@jarondl.net>
Copyright (c) 2015-     - Paul Ganssle <paul@ganssle.io>
Copyright (c) 2015-     - dateutil contributors (see AUTHORS file)

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.
    * Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The above BSD License Applies to all code, even that also covered by Apache 2.0.
```






```
Copyright (c) 2017 Paul Ganssle <paul@ganssle.io> . All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

   3. Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```






#### Other Licenses














---

### [python-slugify (8.0.4)](https://github.com/un33k/python-slugify)


#### Declared Licenses
MIT


```
The MIT License

Copyright (c) Val Neekman @ Neekware Inc. http://neekware.com

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```






#### Other Licenses














---

### [pytimeparse (1.1.8)](https://github.com/wroberts/pytimeparse)


#### Declared Licenses
MIT


```
The MIT License (MIT)

Copyright (c) 2014 Will Roberts

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

```






#### Other Licenses














---

### [pytz (2024.2)](http://pythonhosted.org/pytz)


#### Declared Licenses
MIT


```
Copyright (c) 2003-2019 Stuart Bishop <stuart@stuartbishop.net>

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.

```






#### Other Licenses
public-domain


















---

### [RapidFuzz (3.0.0)](https://pypi.org/project/RapidFuzz/)


#### Declared Licenses
MIT


```
Copyright © 2020-present Max Bachmann
Copyright © 2011 Adam Cohen

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

```






#### Other Licenses
BSL-1.0, MPL-2.0


```
Permission is hereby granted, free of charge, to any person or organization obtaining a copy of the software and accompanying documentation covered by this license (the "Software") to use, reproduce, display, distribute, execute, and transmit the Software, and to prepare derivative works of the Software, and to permit third-parties to whom the Software is furnished to do so, all subject to the following:
The copyright notices in the Software and this entire statement, including the above license grant, this restriction and the following disclaimer, must be included in all copies of the Software, in whole or in part, and all derivative works of the Software, unless such copies or derivative works are solely in the form of machine-executable object code generated by a source language processor.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
```






```
1\. Definitions
      1.1. "Contributor" means each individual or legal entity that creates, contributes to the creation of, or owns Covered Software.
      1.2. "Contributor Version" means the combination of the Contributions of others (if any) used by a Contributor and that particular Contributor's Contribution.
      1.3. "Contribution" means Covered Software of a particular Contributor.
      1.4. "Covered Software" means Source Code Form to which the initial Contributor has attached the notice in Exhibit A, the Executable Form of such Source Code Form, and Modifications of such Source Code Form, in each case including portions thereof.
      1.5. "Incompatible With Secondary Licenses" means
         (a) that the initial Contributor has attached the notice described in Exhibit B to the Covered Software; or
         (b) that the Covered Software was made available under the terms of version 1.1 or earlier of the License, but not also under the terms of a Secondary License.
      1.6. "Executable Form" means any form of the work other than Source Code Form.
      1.7. "Larger Work" means a work that combines Covered Software with other material, in a separate file or files, that is not Covered Software.
      1.8. "License" means this document.
      1.9. "Licensable" means having the right to grant, to the maximum extent possible, whether at the time of the initial grant or subsequently, any and all of the rights conveyed by this License.
      1.10. "Modifications" means any of the following:
         (a) any file in Source Code Form that results from an addition to, deletion from, or modification of the contents of Covered Software; or
         (b) any new file in Source Code Form that contains any Covered Software.
      1.11. "Patent Claims" of a Contributor means any patent claim(s), including without limitation, method, process, and apparatus claims, in any patent Licensable by such Contributor that would be infringed, but for the grant of the License, by the making, using, selling, offering for sale, having made, import, or transfer of either its Contributions or its Contributor Version.
      1.12. "Secondary License" means either the GNU General Public License, Version 2.0, the GNU Lesser General Public License, Version 2.1, the GNU Affero General Public License, Version 3.0, or any later versions of those licenses.
      1.13. "Source Code Form" means the form of the work preferred for making modifications.
      1.14. "You" (or "Your") means an individual or a legal entity exercising rights under this License. For legal entities, "You" includes any entity that controls, is controlled by, or is under common control with You. For purposes of this definition, "control" means (a) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (b) ownership of more than fifty percent (50%) of the outstanding shares or beneficial ownership of such entity.
   2. License Grants and Conditions
      2.1. Grants
      Each Contributor hereby grants You a world-wide, royalty-free, non-exclusive license:
         (a) under intellectual property rights (other than patent or trademark) Licensable by such Contributor to use, reproduce, make available, modify, display, perform, distribute, and otherwise exploit its Contributions, either on an unmodified basis, with Modifications, or as part of a Larger Work; and
         (b) under Patent Claims of such Contributor to make, use, sell, offer for sale, have made, import, and otherwise transfer either its Contributions or its Contributor Version.
      2.2. Effective Date
      The licenses granted in Section 2.1 with respect to any Contribution become effective for each Contribution on the date the Contributor first distributes such Contribution.
      2.3. Limitations on Grant Scope
      The licenses granted in this Section 2 are the only rights granted under this License. No additional rights or licenses will be implied from the distribution or licensing of Covered Software under this License. Notwithstanding Section 2.1(b) above, no patent license is granted by a Contributor:
         (a) for any code that a Contributor has removed from Covered Software; or
         (b) for infringements caused by: (i) Your and any other third party's modifications of Covered Software, or (ii) the combination of its Contributions with other software (except as part of its Contributor Version); or
         (c) under Patent Claims infringed by Covered Software in the absence of its Contributions.
      This License does not grant any rights in the trademarks, service marks, or logos of any Contributor (except as may be necessary to comply with the notice requirements in Section 3.4).
      2.4. Subsequent Licenses
      No Contributor makes additional grants as a result of Your choice to distribute the Covered Software under a subsequent version of this License (see Section 10.2) or under the terms of a Secondary License (if permitted under the terms of Section 3.3).
      2.5. Representation
      Each Contributor represents that the Contributor believes its Contributions are its original creation(s) or it has sufficient rights to grant the rights to its Contributions conveyed by this License.
      2.6. Fair Use
      This License is not intended to limit any rights You have under applicable copyright doctrines of fair use, fair dealing, or other equivalents.
      2.7. Conditions
      Sections 3.1, 3.2, 3.3, and 3.4 are conditions of the licenses granted in Section 2.1.
   3. Responsibilities
      3.1. Distribution of Source Form
      All distribution of Covered Software in Source Code Form, including any Modifications that You create or to which You contribute, must be under the terms of this License. You must inform recipients that the Source Code Form of the Covered Software is governed by the terms of this License, and how they can obtain a copy of this License. You may not attempt to alter or restrict the recipients' rights in the Source Code Form.
      3.2. Distribution of Executable Form
      If You distribute Covered Software in Executable Form then:
         (a) such Covered Software must also be made available in Source Code Form, as described in Section 3.1, and You must inform recipients of the Executable Form how they can obtain a copy of such Source Code Form by reasonable means in a timely manner, at a charge no more than the cost of distribution to the recipient; and
         (b) You may distribute such Executable Form under the terms of this License, or sublicense it under different terms, provided that the license for the Executable Form does not attempt to limit or alter the recipients' rights in the Source Code Form under this License.
      3.3. Distribution of a Larger Work
      You may create and distribute a Larger Work under terms of Your choice, provided that You also comply with the requirements of this License for the Covered Software. If the Larger Work is a combination of Covered Software with a work governed by one or more Secondary Licenses, and the Covered Software is not Incompatible With Secondary Licenses, this License permits You to additionally distribute such Covered Software under the terms of such Secondary License(s), so that the recipient of the Larger Work may, at their option, further distribute the Covered Software under the terms of either this License or such Secondary License(s).
      3.4. Notices
      You may not remove or alter the substance of any license notices (including copyright notices, patent notices, disclaimers of warranty, or limitations of liability) contained within the Source Code Form of the Covered Software, except that You may alter any license notices to the extent required to remedy known factual inaccuracies.
      3.5. Application of Additional Terms
      You may choose to offer, and to charge a fee for, warranty, support, indemnity or liability obligations to one or more recipients of Covered Software. However, You may do so only on Your own behalf, and not on behalf of any Contributor. You must make it absolutely clear that any such warranty, support, indemnity, or liability obligation is offered by You alone, and You hereby agree to indemnify every Contributor for any liability incurred by such Contributor as a result of warranty, support, indemnity or liability terms You offer. You may include additional disclaimers of warranty and limitations of liability specific to any jurisdiction.
   4. Inability to Comply Due to Statute or Regulation
   If it is impossible for You to comply with any of the terms of this License with respect to some or all of the Covered Software due to statute, judicial order, or regulation then You must: (a) comply with the terms of this License to the maximum extent possible; and (b) describe the limitations and the code they affect. Such description must be placed in a text file included with all distributions of the Covered Software under this License. Except to the extent prohibited by statute or regulation, such description must be sufficiently detailed for a recipient of ordinary skill to be able to understand it.
   5. Termination
      5.1. The rights granted under this License will terminate automatically if You fail to comply with any of its terms. However, if You become compliant, then the rights granted under this License from a particular Contributor are reinstated (a) provisionally, unless and until such Contributor explicitly and finally terminates Your grants, and (b) on an ongoing basis, if such Contributor fails to notify You of the non-compliance by some reasonable means prior to 60 days after You have come back into compliance. Moreover, Your grants from a particular Contributor are reinstated on an ongoing basis if such Contributor notifies You of the non-compliance by some reasonable means, this is the first time You have received notice of non-compliance with this License from such Contributor, and You become compliant prior to 30 days after Your receipt of the notice.
      5.2. If You initiate litigation against any entity by asserting a patent infringement claim (excluding declaratory judgment actions, counter-claims, and cross-claims) alleging that a Contributor Version directly or indirectly infringes any patent, then the rights granted to You by any and all Contributors for the Covered Software under Section 2.1 of this License shall terminate.
      5.3. In the event of termination under Sections 5.1 or 5.2 above, all end user license agreements (excluding distributors and resellers) which have been validly granted by You or Your distributors under this License prior to termination shall survive termination.
   6. Disclaimer of Warranty
   Covered Software is provided under this License on an "as is" basis, without warranty of any kind, either expressed, implied, or statutory, including, without limitation, warranties that the Covered Software is free of defects, merchantable, fit for a particular purpose or non-infringing. The entire risk as to the quality and performance of the Covered Software is with You. Should any Covered Software prove defective in any respect, You (not any Contributor) assume the cost of any necessary servicing, repair, or correction. This disclaimer of warranty constitutes an essential part of this License. No use of any Covered Software is authorized under this License except under this disclaimer.
   7. Limitation of Liability
   Under no circumstances and under no legal theory, whether tort (including negligence), contract, or otherwise, shall any Contributor, or anyone who distributes Covered Software as permitted above, be liable to You for any direct, indirect, special, incidental, or consequential damages of any character including, without limitation, damages for lost profits, loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses, even if such party shall have been informed of the possibility of such damages. This limitation of liability shall not apply to liability for death or personal injury resulting from such party's negligence to the extent applicable law prohibits such limitation. Some jurisdictions do not allow the exclusion or limitation of incidental or consequential damages, so this exclusion and limitation may not apply to You.
   8. Litigation
   Any litigation relating to this License may be brought only in the courts of a jurisdiction where the defendant maintains its principal place of business and such litigation shall be governed by laws of that jurisdiction, without reference to its conflict-of-law provisions. Nothing in this Section shall prevent a party's ability to bring cross-claims or counter-claims.
   9. Miscellaneous
   This License represents the complete agreement concerning the subject matter hereof. If any provision of this License is held to be unenforceable, such provision shall be reformed only to the extent necessary to make it enforceable. Any law or regulation which provides that the language of a contract shall be construed against the drafter shall not be used to construe this License against a Contributor.
   10. Versions of the License
      10.1. New Versions
      Mozilla Foundation is the license steward. Except as provided in Section 10.3, no one other than the license steward has the right to modify or publish new versions of this License. Each version will be given a distinguishing version number.
      10.2. Effect of New Versions
      You may distribute the Covered Software under the terms of the version of the License under which You originally received the Covered Software, or under the terms of any subsequent version published by the license steward.
      10.3. Modified Versions
      If you create software not governed by this License, and you want to create a new license for such software, you may create and use a modified version of this License if you rename the license and remove any references to the name of the license steward (except to note that such modified license differs from this License).
      10.4. Distributing Source Code Form that is Incompatible With Secondary Licenses
      If You choose to distribute Source Code Form that is Incompatible With Secondary Licenses under the terms of this version of the License, the notice described in Exhibit B of this License must be attached.
```

















---

### [referencing (0.36.1)](https://pypi.org/project/referencing/)


#### Declared Licenses
MIT


```
Copyright (c) 2022 Julian Berman

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```






#### Other Licenses














---

### [requests (2.32.3)](https://requests.readthedocs.io)


#### Declared Licenses
Apache-2.0


```

                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

```






#### Other Licenses














---

### [rpds-py (0.22.3)](https://pypi.org/project/rpds-py/)


#### Declared Licenses
MIT


```
Copyright (c) 2023 Julian Berman

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```






#### Other Licenses














---

### [six (1.17.0)](https://github.com/benjaminp/six)


#### Declared Licenses
MIT


```
Copyright (c) 2010-2024 Benjamin Peterson

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

```






#### Other Licenses














---

### [snowplow-tracker (1.0.4)](http://snowplow.io)


#### Declared Licenses
Apache-2.0


```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright 2013-2023 Snowplow Analytics Ltd.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```






#### Other Licenses














---

### [spinners (0.0.24)](https://github.com/ManrajGrover/py-spinners)


#### Declared Licenses
MIT


```
MIT License

Copyright (c) 2017 Manraj Singh

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses














---

### [sqlparse (0.5.3)](https://pypi.org/project/sqlparse/)


#### Declared Licenses
BSD-3-Clause


```
Copyright (c) 2016, Andi Albrecht <albrecht.andi@gmail.com>
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.
    * Neither the name of the authors nor the names of its contributors may be
      used to endorse or promote products derived from this software without
      specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






#### Other Licenses














---

### [tabulate (0.8.9)](https://pypi.org/project/tabulate/)


#### Declared Licenses
MIT


```
Copyright (c) 2011-2020 Sergey Astanin and contributors

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

```






#### Other Licenses














---

### [tabulate (0.9.0)](https://pypi.org/project/tabulate/)


#### Declared Licenses
MIT


```
Copyright (c) 2011-2020 Sergey Astanin and contributors

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

```






#### Other Licenses














---

### [termcolor (2.5.0)](https://pypi.org/project/termcolor/)


#### Declared Licenses
MIT


```
Copyright (c) 2008-2011 Volvox Development Team

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```






#### Other Licenses














---

### [text-unidecode (1.3)](https://github.com/kmike/text-unidecode/)


#### Declared Licenses
GPL-1.0-or-later, Artistic-1.0, GPL-2.0-or-later, Artistic-1.0-Perl


```
Copyright (C)  or
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; version 1 or any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
```






```
text-unidecode is a free software; you can redistribute
it and/or modify it under the terms of either:

\* GPL or GPLv2+ (see https://www.gnu.org/licenses/license-list.html#GNUGPL), or
\* Artistic License - see below:


                         The "Artistic License"

                                Preamble

The intent of this document is to state the conditions under which a
Package may be copied, such that the Copyright Holder maintains some
semblance of artistic control over the development of the package,
while giving the users of the package the right to use and distribute
the Package in a more-or-less customary fashion, plus the right to make
reasonable modifications.

Definitions:

        "Package" refers to the collection of files distributed by the
        Copyright Holder, and derivatives of that collection of files
        created through textual modification.

        "Standard Version" refers to such a Package if it has not been
        modified, or has been modified in accordance with the wishes
        of the Copyright Holder as specified below.

        "Copyright Holder" is whoever is named in the copyright or
        copyrights for the package.

        "You" is you, if you're thinking about copying or distributing
        this Package.

        "Reasonable copying fee" is whatever you can justify on the
        basis of media cost, duplication charges, time of people involved,
        and so on.  (You will not be required to justify it to the
        Copyright Holder, but only to the computing community at large
        as a market that must bear the fee.)

        "Freely Available" means that no fee is charged for the item
        itself, though there may be fees involved in handling the item.
        It also means that recipients of the item may redistribute it
        under the same conditions they received it.

1\. You may make and give away verbatim copies of the source form of the
Standard Version of this Package without restriction, provided that you
duplicate all of the original copyright notices and associated disclaimers.

2\. You may apply bug fixes, portability fixes and other modifications
derived from the Public Domain or from the Copyright Holder.  A Package
modified in such a way shall still be considered the Standard Version.

3\. You may otherwise modify your copy of this Package in any way, provided
that you insert a prominent notice in each changed file stating how and
when you changed that file, and provided that you do at least ONE of the
following:

    a) place your modifications in the Public Domain or otherwise make them
    Freely Available, such as by posting said modifications to Usenet or
    an equivalent medium, or placing the modifications on a major archive
    site such as uunet.uu.net, or by allowing the Copyright Holder to include
    your modifications in the Standard Version of the Package.

    b) use the modified Package only within your corporation or organization.

    c) rename any non-standard executables so the names do not conflict
    with standard executables, which must also be provided, and provide
    a separate manual page for each non-standard executable that clearly
    documents how it differs from the Standard Version.

    d) make other distribution arrangements with the Copyright Holder.

4\. You may distribute the programs of this Package in object code or
executable form, provided that you do at least ONE of the following:

    a) distribute a Standard Version of the executables and library files,
    together with instructions (in the manual page or equivalent) on where
    to get the Standard Version.

    b) accompany the distribution with the machine-readable source of
    the Package with your modifications.

    c) give non-standard executables non-standard names, and clearly
    document the differences in manual pages (or equivalent), together
    with instructions on where to get the Standard Version.

    d) make other distribution arrangements with the Copyright Holder.

5\. You may charge a reasonable copying fee for any distribution of this
Package.  You may charge any fee you choose for support of this
Package.  You may not charge a fee for this Package itself.  However,
you may distribute this Package in aggregate with other (possibly
commercial) programs as part of a larger (possibly commercial) software
distribution provided that you do not advertise this Package as a
product of your own.  You may embed this Package's interpreter within
an executable of yours (by linking); this shall be construed as a mere
form of aggregation, provided that the complete Standard Version of the
interpreter is so embedded.

6\. The scripts and library files supplied as input to or produced as
output from the programs of this Package do not automatically fall
under the copyright of this Package, but belong to whoever generated
them, and may be sold commercially, and may be aggregated with this
Package.  If such scripts or library files are aggregated with this
Package via the so-called "undump" or "unexec" methods of producing a
binary executable image, then distribution of such an image shall
neither be construed as a distribution of this Package nor shall it
fall under the restrictions of Paragraphs 3 and 4, provided that you do
not represent such an executable image as a Standard Version of this
Package.

7\. C subroutines (or comparably compiled subroutines in other
languages) supplied by you and linked into this Package in order to
emulate subroutines and variables of the language defined by this
Package shall not be considered part of this Package, but are the
equivalent of input as in Paragraph 6, provided these subroutines do
not change the language in any way that would cause it to fail the
regression tests for the language.

8\. Aggregation of this Package with a commercial distribution is always
permitted provided that the use of this Package is embedded; that is,
when no overt attempt is made to make this Package's interfaces visible
to the end user of the commercial distribution.  Such use shall not be
construed as a distribution of this Package.

9\. The name of the Copyright Holder may not be used to endorse or promote
products derived from this software without specific prior written permission.

10\. THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

                                The End

```






```
Copyright (C)  or
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; version 2 or any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
```






```
Preamble
The intent of this document is to state the conditions under which a Package may be copied, such that the Copyright Holder maintains some semblance of artistic control over the development of the package, while giving the users of the package the right to use and distribute the Package in a more-or-less customary fashion, plus the right to make reasonable modifications.
Definitions:
"Package" refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
"Standard Version" refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder as specified below.
"Copyright Holder" is whoever is named in the copyright or copyrights for the package.
"You" is you, if you're thinking about copying or distributing this Package.
"Reasonable copying fee" is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
"Freely Available" means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as uunet.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
      b) use the modified Package only within your corporation or organization.
      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
      b) accompany the distribution with the machine-readable source of the Package with your modifications.
      c) give non-standard executables non-standard names, and clearly document the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own. You may embed this Package's interpreter within an executable of yours (by linking); this shall be construed as a mere form of aggregation, provided that the complete Standard Version of the interpreter is so embedded.
   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called "undump" or "unexec" methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.
   7. C subroutines (or comparably compiled subroutines in other languages) supplied by you and linked into this Package in order to emulate subroutines and variables of the language defined by this Package shall not be considered part of this Package, but are the equivalent of input as in Paragraph 6, provided these subroutines do not change the language in any way that would cause it to fail the regression tests for the language.
   8. Aggregation of this Package with a commercial distribution is always permitted provided that the use of this Package is embedded; that is, when no overt attempt is made to make this Package's interfaces visible to the end user of the commercial distribution. Such use shall not be construed as a distribution of this Package.
   9. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
   10. THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
```






#### Other Licenses














---

### [types-requests (2.32.0.20241016)](https://github.com/python/typeshed)


#### Declared Licenses
Apache-2.0


```
Copyright [yyyy] [name of copyright owner]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

See the License for the specific language governing permissions and limitations under the License.
```






#### Other Licenses














---

### [typing-extensions (4.4.0)](https://pypi.org/project/typing-extensions/)


#### Declared Licenses
Python-2.0


```
1\. This LICENSE AGREEMENT is between the Python Software Foundation ("PSF"), and the Individual or Organization ("Licensee") accessing and otherwise using this software ("Python") in source or binary form and its associated documentation.
   2. Subject to the terms and conditions of this License Agreement, PSF hereby grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python alone or in any derivative version, provided, however, that PSF's License Agreement and PSF's notice of copyright, i.e., "Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved" are retained in Python alone or in any derivative version prepared by Licensee.
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python or any part thereof, and wants to make the derivative work available to others as provided herein, then Licensee hereby agrees to include in any such work a brief summary of the changes made to Python.
   4. PSF is making Python available to Licensee on an "AS IS" basis. PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between PSF and Licensee. This License Agreement does not grant permission to use PSF trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By copying, installing or otherwise using Python, Licensee agrees to be bound by the terms and conditions of this License Agreement.
   1. This LICENSE AGREEMENT is between BeOpen.com ("BeOpen"), having an office at 160 Saratoga Avenue, Santa Clara, CA 95051, and the Individual or Organization ("Licensee") accessing and otherwise using this software in source or binary form and its associated documentation ("the Software").
   2. Subject to the terms and conditions of this BeOpen Python License Agreement, BeOpen hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use the Software alone or in any derivative version, provided, however, that the BeOpen Python License is retained in the Software, alone or in any derivative version prepared by Licensee.
   3. BeOpen is making the Software available to Licensee on an "AS IS" basis. BEOPEN MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, BEOPEN MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF THE SOFTWARE WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   4. BEOPEN SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THE SOFTWARE, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   5. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   6. This License Agreement shall be governed by and interpreted in all respects by the law of the State of California, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between BeOpen and Licensee. This License Agreement does not grant permission to use BeOpen trademarks or trade names in a trademark sense to endorse or promote products or services of Licensee, or any third party. As an exception, the "BeOpen Python" logos available at http://www.pythonlabs.com/logos.html may be used according to the permissions granted on that web page.
   7. By copying, installing or otherwise using the software, Licensee agrees to be bound by the terms and conditions of this License Agreement.
   1. This LICENSE AGREEMENT is between the Corporation for National Research Initiatives, having an office at 1895 Preston White Drive, Reston, VA 20191 ("CNRI"), and the Individual or Organization ("Licensee") accessing and otherwise using Python 1.6, beta 1 software in source or binary form and its associated documentation, as released at the www.python.org Internet site on August 4, 2000 ("Python 1.6b1").
   2. Subject to the terms and conditions of this License Agreement, CNRI hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python 1.6b1 alone or in any derivative version, provided, however, that CNRIs License Agreement is retained in Python 1.6b1, alone or in any derivative version prepared by Licensee.
   Alternately, in lieu of CNRIs License Agreement, Licensee may substitute the following text (omitting the quotes): "Python 1.6, beta 1, is made available subject to the terms and conditions in CNRIs License Agreement. This Agreement may be located on the Internet using the following unique, persistent identifier (known as a handle): 1895.22/1011. This Agreement may also be obtained from a proxy server on the Internet using the URL:http://hdl.handle.net/1895.22/1011".
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python 1.6b1 or any part thereof, and wants to make the derivative work available to the public as provided herein, then Licensee hereby agrees to indicate in any such work the nature of the modifications made to Python 1.6b1.
   4. CNRI is making Python 1.6b1 available to Licensee on an "AS IS" basis. CNRI MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, CNRI MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON 1.6b1 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. CNRI SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING PYTHON 1.6b1, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. This License Agreement shall be governed by and interpreted in all respects by the law of the State of Virginia, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between CNRI and Licensee. This License Agreement does not grant permission to use CNRI trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By clicking on the "ACCEPT" button where indicated, or by copying, installing or otherwise using Python 1.6b1, Licensee agrees to be bound by the terms and conditions of this License Agreement.
Copyright (c) 1991 - 1995, Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.
Permission to use, copy, modify, and distribute this software and its documentation for any purpose and without fee is hereby granted, provided that the above copyright notice appear in all copies and that both that copyright notice and this permission notice appear in supporting documentation, and that the name of Stichting Mathematisch Centrum or CWI not be used in advertising or publicity pertaining to distribution of the software without specific, written prior permission.
STICHTING MATHEMATISCH CENTRUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL STICHTING MATHEMATISCH CENTRUM BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
```






#### Other Licenses














---

### [update-checker (0.18.0)](https://github.com/bboe/update_checker)


#### Declared Licenses
BSD-2-Clause


```
Copyright (c) 2012, Bryce Boe
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1\. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
2\. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```






#### Other Licenses














---

### [urllib3 (2.3.0)](https://pypi.org/project/urllib3/)


#### Declared Licenses
MIT


```
MIT License

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```






#### Other Licenses
MPL-2.0


```
1\. Definitions
      1.1. "Contributor" means each individual or legal entity that creates, contributes to the creation of, or owns Covered Software.
      1.2. "Contributor Version" means the combination of the Contributions of others (if any) used by a Contributor and that particular Contributor's Contribution.
      1.3. "Contribution" means Covered Software of a particular Contributor.
      1.4. "Covered Software" means Source Code Form to which the initial Contributor has attached the notice in Exhibit A, the Executable Form of such Source Code Form, and Modifications of such Source Code Form, in each case including portions thereof.
      1.5. "Incompatible With Secondary Licenses" means
         (a) that the initial Contributor has attached the notice described in Exhibit B to the Covered Software; or
         (b) that the Covered Software was made available under the terms of version 1.1 or earlier of the License, but not also under the terms of a Secondary License.
      1.6. "Executable Form" means any form of the work other than Source Code Form.
      1.7. "Larger Work" means a work that combines Covered Software with other material, in a separate file or files, that is not Covered Software.
      1.8. "License" means this document.
      1.9. "Licensable" means having the right to grant, to the maximum extent possible, whether at the time of the initial grant or subsequently, any and all of the rights conveyed by this License.
      1.10. "Modifications" means any of the following:
         (a) any file in Source Code Form that results from an addition to, deletion from, or modification of the contents of Covered Software; or
         (b) any new file in Source Code Form that contains any Covered Software.
      1.11. "Patent Claims" of a Contributor means any patent claim(s), including without limitation, method, process, and apparatus claims, in any patent Licensable by such Contributor that would be infringed, but for the grant of the License, by the making, using, selling, offering for sale, having made, import, or transfer of either its Contributions or its Contributor Version.
      1.12. "Secondary License" means either the GNU General Public License, Version 2.0, the GNU Lesser General Public License, Version 2.1, the GNU Affero General Public License, Version 3.0, or any later versions of those licenses.
      1.13. "Source Code Form" means the form of the work preferred for making modifications.
      1.14. "You" (or "Your") means an individual or a legal entity exercising rights under this License. For legal entities, "You" includes any entity that controls, is controlled by, or is under common control with You. For purposes of this definition, "control" means (a) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (b) ownership of more than fifty percent (50%) of the outstanding shares or beneficial ownership of such entity.
   2. License Grants and Conditions
      2.1. Grants
      Each Contributor hereby grants You a world-wide, royalty-free, non-exclusive license:
         (a) under intellectual property rights (other than patent or trademark) Licensable by such Contributor to use, reproduce, make available, modify, display, perform, distribute, and otherwise exploit its Contributions, either on an unmodified basis, with Modifications, or as part of a Larger Work; and
         (b) under Patent Claims of such Contributor to make, use, sell, offer for sale, have made, import, and otherwise transfer either its Contributions or its Contributor Version.
      2.2. Effective Date
      The licenses granted in Section 2.1 with respect to any Contribution become effective for each Contribution on the date the Contributor first distributes such Contribution.
      2.3. Limitations on Grant Scope
      The licenses granted in this Section 2 are the only rights granted under this License. No additional rights or licenses will be implied from the distribution or licensing of Covered Software under this License. Notwithstanding Section 2.1(b) above, no patent license is granted by a Contributor:
         (a) for any code that a Contributor has removed from Covered Software; or
         (b) for infringements caused by: (i) Your and any other third party's modifications of Covered Software, or (ii) the combination of its Contributions with other software (except as part of its Contributor Version); or
         (c) under Patent Claims infringed by Covered Software in the absence of its Contributions.
      This License does not grant any rights in the trademarks, service marks, or logos of any Contributor (except as may be necessary to comply with the notice requirements in Section 3.4).
      2.4. Subsequent Licenses
      No Contributor makes additional grants as a result of Your choice to distribute the Covered Software under a subsequent version of this License (see Section 10.2) or under the terms of a Secondary License (if permitted under the terms of Section 3.3).
      2.5. Representation
      Each Contributor represents that the Contributor believes its Contributions are its original creation(s) or it has sufficient rights to grant the rights to its Contributions conveyed by this License.
      2.6. Fair Use
      This License is not intended to limit any rights You have under applicable copyright doctrines of fair use, fair dealing, or other equivalents.
      2.7. Conditions
      Sections 3.1, 3.2, 3.3, and 3.4 are conditions of the licenses granted in Section 2.1.
   3. Responsibilities
      3.1. Distribution of Source Form
      All distribution of Covered Software in Source Code Form, including any Modifications that You create or to which You contribute, must be under the terms of this License. You must inform recipients that the Source Code Form of the Covered Software is governed by the terms of this License, and how they can obtain a copy of this License. You may not attempt to alter or restrict the recipients' rights in the Source Code Form.
      3.2. Distribution of Executable Form
      If You distribute Covered Software in Executable Form then:
         (a) such Covered Software must also be made available in Source Code Form, as described in Section 3.1, and You must inform recipients of the Executable Form how they can obtain a copy of such Source Code Form by reasonable means in a timely manner, at a charge no more than the cost of distribution to the recipient; and
         (b) You may distribute such Executable Form under the terms of this License, or sublicense it under different terms, provided that the license for the Executable Form does not attempt to limit or alter the recipients' rights in the Source Code Form under this License.
      3.3. Distribution of a Larger Work
      You may create and distribute a Larger Work under terms of Your choice, provided that You also comply with the requirements of this License for the Covered Software. If the Larger Work is a combination of Covered Software with a work governed by one or more Secondary Licenses, and the Covered Software is not Incompatible With Secondary Licenses, this License permits You to additionally distribute such Covered Software under the terms of such Secondary License(s), so that the recipient of the Larger Work may, at their option, further distribute the Covered Software under the terms of either this License or such Secondary License(s).
      3.4. Notices
      You may not remove or alter the substance of any license notices (including copyright notices, patent notices, disclaimers of warranty, or limitations of liability) contained within the Source Code Form of the Covered Software, except that You may alter any license notices to the extent required to remedy known factual inaccuracies.
      3.5. Application of Additional Terms
      You may choose to offer, and to charge a fee for, warranty, support, indemnity or liability obligations to one or more recipients of Covered Software. However, You may do so only on Your own behalf, and not on behalf of any Contributor. You must make it absolutely clear that any such warranty, support, indemnity, or liability obligation is offered by You alone, and You hereby agree to indemnify every Contributor for any liability incurred by such Contributor as a result of warranty, support, indemnity or liability terms You offer. You may include additional disclaimers of warranty and limitations of liability specific to any jurisdiction.
   4. Inability to Comply Due to Statute or Regulation
   If it is impossible for You to comply with any of the terms of this License with respect to some or all of the Covered Software due to statute, judicial order, or regulation then You must: (a) comply with the terms of this License to the maximum extent possible; and (b) describe the limitations and the code they affect. Such description must be placed in a text file included with all distributions of the Covered Software under this License. Except to the extent prohibited by statute or regulation, such description must be sufficiently detailed for a recipient of ordinary skill to be able to understand it.
   5. Termination
      5.1. The rights granted under this License will terminate automatically if You fail to comply with any of its terms. However, if You become compliant, then the rights granted under this License from a particular Contributor are reinstated (a) provisionally, unless and until such Contributor explicitly and finally terminates Your grants, and (b) on an ongoing basis, if such Contributor fails to notify You of the non-compliance by some reasonable means prior to 60 days after You have come back into compliance. Moreover, Your grants from a particular Contributor are reinstated on an ongoing basis if such Contributor notifies You of the non-compliance by some reasonable means, this is the first time You have received notice of non-compliance with this License from such Contributor, and You become compliant prior to 30 days after Your receipt of the notice.
      5.2. If You initiate litigation against any entity by asserting a patent infringement claim (excluding declaratory judgment actions, counter-claims, and cross-claims) alleging that a Contributor Version directly or indirectly infringes any patent, then the rights granted to You by any and all Contributors for the Covered Software under Section 2.1 of this License shall terminate.
      5.3. In the event of termination under Sections 5.1 or 5.2 above, all end user license agreements (excluding distributors and resellers) which have been validly granted by You or Your distributors under this License prior to termination shall survive termination.
   6. Disclaimer of Warranty
   Covered Software is provided under this License on an "as is" basis, without warranty of any kind, either expressed, implied, or statutory, including, without limitation, warranties that the Covered Software is free of defects, merchantable, fit for a particular purpose or non-infringing. The entire risk as to the quality and performance of the Covered Software is with You. Should any Covered Software prove defective in any respect, You (not any Contributor) assume the cost of any necessary servicing, repair, or correction. This disclaimer of warranty constitutes an essential part of this License. No use of any Covered Software is authorized under this License except under this disclaimer.
   7. Limitation of Liability
   Under no circumstances and under no legal theory, whether tort (including negligence), contract, or otherwise, shall any Contributor, or anyone who distributes Covered Software as permitted above, be liable to You for any direct, indirect, special, incidental, or consequential damages of any character including, without limitation, damages for lost profits, loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses, even if such party shall have been informed of the possibility of such damages. This limitation of liability shall not apply to liability for death or personal injury resulting from such party's negligence to the extent applicable law prohibits such limitation. Some jurisdictions do not allow the exclusion or limitation of incidental or consequential damages, so this exclusion and limitation may not apply to You.
   8. Litigation
   Any litigation relating to this License may be brought only in the courts of a jurisdiction where the defendant maintains its principal place of business and such litigation shall be governed by laws of that jurisdiction, without reference to its conflict-of-law provisions. Nothing in this Section shall prevent a party's ability to bring cross-claims or counter-claims.
   9. Miscellaneous
   This License represents the complete agreement concerning the subject matter hereof. If any provision of this License is held to be unenforceable, such provision shall be reformed only to the extent necessary to make it enforceable. Any law or regulation which provides that the language of a contract shall be construed against the drafter shall not be used to construe this License against a Contributor.
   10. Versions of the License
      10.1. New Versions
      Mozilla Foundation is the license steward. Except as provided in Section 10.3, no one other than the license steward has the right to modify or publish new versions of this License. Each version will be given a distinguishing version number.
      10.2. Effect of New Versions
      You may distribute the Covered Software under the terms of the version of the License under which You originally received the Covered Software, or under the terms of any subsequent version published by the license steward.
      10.3. Modified Versions
      If you create software not governed by this License, and you want to create a new license for such software, you may create and use a modified version of this License if you rename the license and remove any references to the name of the license steward (except to note that such modified license differs from this License).
      10.4. Distributing Source Code Form that is Incompatible With Secondary Licenses
      If You choose to distribute Source Code Form that is Incompatible With Secondary Licenses under the terms of this version of the License, the notice described in Exhibit B of this License must be attached.
```

















---

### [zipp (3.21.0)](https://pypi.org/project/zipp/)


#### Declared Licenses
MIT


```
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE.

```






#### Other Licenses














---




---

## Licenses


### Apache-2.0

```

                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      &quot;License&quot; shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      &quot;Legal Entity&quot; shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      &quot;control&quot; means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      &quot;Source&quot; form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      &quot;Object&quot; form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      &quot;Work&quot; shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      &quot;Contribution&quot; shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, &quot;submitted&quot;
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;

      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

```


### Apache-2.0

```

                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      &quot;License&quot; shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      &quot;Legal Entity&quot; shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      &quot;control&quot; means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      &quot;Source&quot; form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      &quot;Object&quot; form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      &quot;Work&quot; shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      &quot;Contribution&quot; shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, &quot;submitted&quot;
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;

      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets &quot;[]&quot;
      replaced with your own identifying information. (Don&#39;t include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same &quot;printed page&quot; as the copyright notice for easier
      identification within third-party archives.

   Copyright [yyyy] [name of copyright owner]

   Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```


### Apache-2.0

```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      &quot;License&quot; shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      &quot;Legal Entity&quot; shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      &quot;control&quot; means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      &quot;Source&quot; form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      &quot;Object&quot; form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      &quot;Work&quot; shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      &quot;Contribution&quot; shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, &quot;submitted&quot;
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;

      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets &quot;[]&quot;
      replaced with your own identifying information. (Don&#39;t include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same &quot;printed page&quot; as the copyright notice for easier
      identification within third-party archives.

   Copyright 2013-2023 Snowplow Analytics Ltd.

   Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```


### Apache-2.0

```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      &quot;License&quot; shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      &quot;Legal Entity&quot; shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      &quot;control&quot; means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      &quot;Source&quot; form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      &quot;Object&quot; form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      &quot;Work&quot; shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      &quot;Contribution&quot; shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, &quot;submitted&quot;
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;

      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets &quot;[]&quot;
      replaced with your own identifying information. (Don&#39;t include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same &quot;printed page&quot; as the copyright notice for easier
      identification within third-party archives.

   Copyright 2021 dbt Labs, Inc.

   Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```


### Apache-2.0

```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      &quot;License&quot; shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      &quot;Legal Entity&quot; shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      &quot;control&quot; means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      &quot;Source&quot; form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      &quot;Object&quot; form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      &quot;Work&quot; shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      &quot;Contribution&quot; shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, &quot;submitted&quot;
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;

      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets &quot;[]&quot;
      replaced with your own identifying information. (Don&#39;t include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same &quot;printed page&quot; as the copyright notice for easier
      identification within third-party archives.

   Copyright 2024 dbt Labs, Inc.

   Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```


### Apache-2.0

```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      &quot;License&quot; shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      &quot;Legal Entity&quot; shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      &quot;control&quot; means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      &quot;Source&quot; form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      &quot;Object&quot; form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      &quot;Work&quot; shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      &quot;Contribution&quot; shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, &quot;submitted&quot;
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;

      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets &quot;[]&quot;
      replaced with your own identifying information. (Don&#39;t include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same &quot;printed page&quot; as the copyright notice for easier
      identification within third-party archives.

   Copyright [yyyy] [name of copyright owner]

   Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```


### Apache-2.0

```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      &quot;License&quot; shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      &quot;Legal Entity&quot; shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      &quot;control&quot; means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      &quot;Source&quot; form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      &quot;Object&quot; form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      &quot;Work&quot; shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      &quot;Contribution&quot; shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, &quot;submitted&quot;
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;

      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets &quot;{}&quot;
      replaced with your own identifying information. (Don&#39;t include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same &quot;printed page&quot; as the copyright notice for easier
      identification within third-party archives.

   Copyright 2021 Starburst Data, Inc.

   Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```


### Apache-2.0

```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      &quot;License&quot; shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      &quot;Legal Entity&quot; shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      &quot;control&quot; means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      &quot;Source&quot; form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      &quot;Object&quot; form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      &quot;Work&quot; shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      &quot;Contribution&quot; shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, &quot;submitted&quot;
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;

      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets &quot;{}&quot;
      replaced with your own identifying information. (Don&#39;t include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same &quot;printed page&quot; as the copyright notice for easier
      identification within third-party archives.

   Copyright 2021 dbt Labs, Inc.

   Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```


### Apache-2.0

```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      &quot;License&quot; shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      &quot;Legal Entity&quot; shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      &quot;control&quot; means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      &quot;Source&quot; form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      &quot;Object&quot; form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      &quot;Work&quot; shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      &quot;Contribution&quot; shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, &quot;submitted&quot;
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as &quot;Not a Contribution.&quot;

      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   Copyright 2017 Alexander Tikhonov

   Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

```


### Apache-2.0

```
                               Apache License
                          Version 2.0, January 2004
                       http://www.apache.org/licenses/

TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

1. Definitions.

   &quot;License&quot; shall mean the terms and conditions for use, reproduction, and
   distribution as defined by Sections 1 through 9 of this document.

   &quot;Licensor&quot; shall mean the copyright owner or entity authorized by the
   copyright owner that is granting the License.

   &quot;Legal Entity&quot; shall mean the union of the acting entity and all other
   entities that control, are controlled by, or are under common control with
   that entity. For the purposes of this definition, &quot;control&quot; means (i) the
   power, direct or indirect, to cause the direction or management of such
   entity, whether by contract or otherwise, or (ii) ownership of fifty percent
   (50%) or more of the outstanding shares, or (iii) beneficial ownership of
   such entity.

   &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity exercising
   permissions granted by this License.

   &quot;Source&quot; form shall mean the preferred form for making modifications,
   including but not limited to software source code, documentation source,
   and configuration files.

   &quot;Object&quot; form shall mean any form resulting from mechanical
   transformation or translation of a Source form, including but not limited
   to compiled object code, generated documentation, and conversions to
   other media types.

   &quot;Work&quot; shall mean the work of authorship, whether in Source or Object
   form, made available under the License, as indicated by a copyright
   notice that is included in or attached to the work (an example is
   provided in the Appendix below).

   &quot;Derivative Works&quot; shall mean any work, whether in Source or Object form,
   that is based on (or derived from) the Work and for which the editorial
   revisions, annotations, elaborations, or other modifications represent,
   as a whole, an original work of authorship. For the purposes of this
   License, Derivative Works shall not include works that remain separable
   from, or merely link (or bind by name) to the interfaces of, the Work and
   Derivative Works thereof.

   &quot;Contribution&quot; shall mean any work of authorship, including the original
   version of the Work and any modifications or additions to that Work or
   Derivative Works thereof, that is intentionally submitted to Licensor for
   inclusion in the Work by the copyright owner or by an individual or Legal
   Entity authorized to submit on behalf of the copyright owner. For the
   purposes of this definition, &quot;submitted&quot; means any form of electronic,
   verbal, or written communication sent to the Licensor or its
   representatives, including but not limited to communication on electronic
   mailing lists, source code control systems, and issue tracking systems
   that are managed by, or on behalf of, the Licensor for the purpose of
   discussing and improving the Work, but excluding communication that is
   conspicuously marked or otherwise designated in writing by the copyright
   owner as &quot;Not a Contribution.&quot;

   &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity on
   behalf of whom a Contribution has been received by Licensor and
   subsequently incorporated within the Work.

2. Grant of Copyright License. Subject to the terms and conditions of this
   License, each Contributor hereby grants to You a perpetual, worldwide,
   non-exclusive, no-charge, royalty-free, irrevocable copyright license to
   reproduce, prepare Derivative Works of, publicly display, publicly
   perform, sublicense, and distribute the Work and such Derivative Works in
   Source or Object form.

3. Grant of Patent License. Subject to the terms and conditions of this
   License, each Contributor hereby grants to You a perpetual, worldwide,
   non-exclusive, no-charge, royalty-free, irrevocable (except as stated in
   this section) patent license to make, have made, use, offer to sell,
   sell, import, and otherwise transfer the Work, where such license applies
   only to those patent claims licensable by such Contributor that are
   necessarily infringed by their Contribution(s) alone or by combination of
   their Contribution(s) with the Work to which such Contribution(s) was
   submitted. If You institute patent litigation against any entity
   (including a cross-claim or counterclaim in a lawsuit) alleging that the
   Work or a Contribution incorporated within the Work constitutes direct or
   contributory patent infringement, then any patent licenses granted to You
   under this License for that Work shall terminate as of the date such
   litigation is filed.

4. Redistribution. You may reproduce and distribute copies of the Work or
   Derivative Works thereof in any medium, with or without modifications,
   and in Source or Object form, provided that You meet the following
   conditions:

   1. You must give any other recipients of the Work or Derivative Works a
      copy of this License; and

   2. You must cause any modified files to carry prominent notices stating
      that You changed the files; and

   3. You must retain, in the Source form of any Derivative Works that You
      distribute, all copyright, patent, trademark, and attribution notices
      from the Source form of the Work, excluding those notices that do not
      pertain to any part of the Derivative Works; and

   4. If the Work includes a &quot;NOTICE&quot; text file as part of its distribution,
      then any Derivative Works that You distribute must include a readable
      copy of the attribution notices contained within such NOTICE file,
      excluding those notices that do not pertain to any part of the
      Derivative Works, in at least one of the following places: within a
      NOTICE text file distributed as part of the Derivative Works; within
      the Source form or documentation, if provided along with the
      Derivative Works; or, within a display generated by the Derivative
      Works, if and wherever such third-party notices normally appear. The
      contents of the NOTICE file are for informational purposes only and do
      not modify the License. You may add Your own attribution notices
      within Derivative Works that You distribute, alongside or as an
      addendum to the NOTICE text from the Work, provided that such
      additional attribution notices cannot be construed as modifying the
      License.

   You may add Your own copyright statement to Your modifications and may
   provide additional or different license terms and conditions for use,
   reproduction, or distribution of Your modifications, or for any such
   Derivative Works as a whole, provided Your use, reproduction, and
   distribution of the Work otherwise complies with the conditions stated in
   this License.

5. Submission of Contributions. Unless You explicitly state otherwise, any
   Contribution intentionally submitted for inclusion in the Work by You to
   the Licensor shall be under the terms and conditions of this License,
   without any additional terms or conditions. Notwithstanding the above,
   nothing herein shall supersede or modify the terms of any separate
   license agreement you may have executed with Licensor regarding such
   Contributions.

6. Trademarks. This License does not grant permission to use the trade
   names, trademarks, service marks, or product names of the Licensor,
   except as required for reasonable and customary use in describing the
   origin of the Work and reproducing the content of the NOTICE file.

7. Disclaimer of Warranty. Unless required by applicable law or agreed to in
   writing, Licensor provides the Work (and each Contributor provides its
   Contributions) on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
   ANY KIND, either express or implied, including, without limitation, any
   warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or
   FITNESS FOR A PARTICULAR PURPOSE. You are solely responsible for
   determining the appropriateness of using or redistributing the Work and
   assume any risks associated with Your exercise of permissions under this
   License.

8. Limitation of Liability. In no event and under no legal theory, whether
   in tort (including negligence), contract, or otherwise, unless required
   by applicable law (such as deliberate and grossly negligent acts) or
   agreed to in writing, shall any Contributor be liable to You for damages,
   including any direct, indirect, special, incidental, or consequential
   damages of any character arising as a result of this License or out of
   the use or inability to use the Work (including but not limited to
   damages for loss of goodwill, work stoppage, computer failure or
   malfunction, or any and all other commercial damages or losses), even if
   such Contributor has been advised of the possibility of such damages.

9. Accepting Warranty or Additional Liability. While redistributing the Work
   or Derivative Works thereof, You may choose to offer, and charge a fee
   for, acceptance of support, warranty, indemnity, or other liability
   obligations and/or rights consistent with this License. However, in
   accepting such obligations, You may act only on Your own behalf and on
   Your sole responsibility, not on behalf of any other Contributor, and
   only if You agree to indemnify, defend, and hold each Contributor
   harmless for any liability incurred by, or claims asserted against, such
   Contributor by reason of your accepting any such warranty or additional
   liability.

END OF TERMS AND CONDITIONS

```


### 0BSD

```
Copyright (C) 2006 by Rob Landley &lt;rob@landley.net&gt;
Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot; AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
```


### AAL

```
Attribution Assurance License
Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;
All Rights Reserved ATTRIBUTION ASSURANCE LICENSE (adapted from the original BSD license)
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the conditions below are met. These conditions require a modest attribution to &lt;AUTHOR&gt; (the &quot;Author&quot;), who hopes that its promotional value may help justify the thousands of dollars in otherwise billable time invested in writing this and other freely available, open-source software.
   1. Redistributions of source code, in whole or part and with or without modification (the &quot;Code&quot;), must prominently display this GPG-signed text in verifiable form.
   2. Redistributions of the Code in binary form must be accompanied by this GPG-signed text in any documentation and, each time the resulting executable program or a program dependent thereon is launched, a prominent display (e.g., splash screen or banner text) of the Author&#39;s attribution information, which includes:
      (a) Name (&quot;AUTHOR&quot;),
      (b) Professional identification (&quot;PROFESSIONAL IDENTIFICATION&quot;), and
      (c) URL (&quot;URL&quot;).
   3. Neither the name nor any trademark of the Author may be used to endorse or promote products derived from this software without specific prior written permission.
   4. Users are entirely responsible, to the exclusion of the Author and any other persons, for compliance with (1) regulations set by owners or administrators of employed equipment, (2) licensing terms of any other software, and (3) local regulations regarding use, including those regarding import, export, and use of encryption software.
THIS FREE SOFTWARE IS PROVIDED BY THE AUTHOR &quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR ANY CONTRIBUTOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, EFFECTS OF UNAUTHORIZED OR MALICIOUS NETWORK ACCESS; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```


### AGPL-3.0-or-later

```
GNU AFFERO GENERAL PUBLIC LICENSE
Version 3, 19 November 2007
Copyright (C) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The GNU Affero General Public License is a free, copyleft license for software and other kinds of works, specifically designed to ensure cooperation with the community in the case of network server software.
The licenses for most software and other practical works are designed to take away your freedom to share and change the works. By contrast, our General Public Licenses are intended to guarantee your freedom to share and change all versions of a program--to make sure it remains free software for all its users.
When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for them if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs, and that you know you can do these things.
Developers that use our General Public Licenses protect your rights with two steps: (1) assert copyright on the software, and (2) offer you this License which gives you legal permission to copy, distribute and/or modify the software.
A secondary benefit of defending all users&#39; freedom is that improvements made in alternate versions of the program, if they receive widespread use, become available for other developers to incorporate. Many developers of free software are heartened and encouraged by the resulting cooperation. However, in the case of software used on network servers, this result may fail to come about. The GNU General Public License permits making a modified version and letting the public access it on a server without ever releasing its source code to the public.
The GNU Affero General Public License is designed specifically to ensure that, in such cases, the modified source code becomes available to the community. It requires the operator of a network server to provide the source code of the modified version running there to the users of that server. Therefore, public use of a modified version, on a publicly accessible server, gives the public access to the source code of the modified version.
An older license, called the Affero General Public License and published by Affero, was designed to accomplish similar goals. This is a different license, not a version of the Affero GPL, but Affero has released a new version of the Affero GPL which permits relicensing under this license.
The precise terms and conditions for copying, distribution and modification follow.
TERMS AND CONDITIONS
   0. Definitions.
   &quot;This License&quot; refers to version 3 of the GNU Affero General Public License.
   &quot;Copyright&quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.
   &quot;The Program&quot; refers to any copyrightable work licensed under this License. Each licensee is addressed as &quot;you&quot;. &quot;Licensees&quot; and &quot;recipients&quot; may be individuals or organizations.
   To &quot;modify&quot; a work means to copy from or adapt all or part of the work in a fashion requiring copyright permission, other than the making of an exact copy. The resulting work is called a &quot;modified version&quot; of the earlier work or a work &quot;based on&quot; the earlier work.
   A &quot;covered work&quot; means either the unmodified Program or a work based on the Program.
   To &quot;propagate&quot; a work means to do anything with it that, without permission, would make you directly or secondarily liable for infringement under applicable copyright law, except executing it on a computer or modifying a private copy. Propagation includes copying, distribution (with or without modification), making available to the public, and in some countries other activities as well.
   To &quot;convey&quot; a work means any kind of propagation that enables other parties to make or receive copies. Mere interaction with a user through a computer network, with no transfer of a copy, is not conveying.
   An interactive user interface displays &quot;Appropriate Legal Notices&quot; to the extent that it includes a convenient and prominently visible feature that (1) displays an appropriate copyright notice, and (2) tells the user that there is no warranty for the work (except to the extent that warranties are provided), that licensees may convey the work under this License, and how to view a copy of this License. If the interface presents a list of user commands or options, such as a menu, a prominent item in the list meets this criterion.
   1. Source Code.
   The &quot;source code&quot; for a work means the preferred form of the work for making modifications to it. &quot;Object code&quot; means any non-source form of a work.
   A &quot;Standard Interface&quot; means an interface that either is an official standard defined by a recognized standards body, or, in the case of interfaces specified for a particular programming language, one that is widely used among developers working in that language.
   The &quot;System Libraries&quot; of an executable work include anything, other than the work as a whole, that (a) is included in the normal form of packaging a Major Component, but which is not part of that Major Component, and (b) serves only to enable use of the work with that Major Component, or to implement a Standard Interface for which an implementation is available to the public in source code form. A &quot;Major Component&quot;, in this context, means a major essential component (kernel, window system, and so on) of the specific operating system (if any) on which the executable work runs, or a compiler used to produce the work, or an object code interpreter used to run it.
   The &quot;Corresponding Source&quot; for a work in object code form means all the source code needed to generate, install, and (for an executable work) run the object code and to modify the work, including scripts to control those activities. However, it does not include the work&#39;s System Libraries, or general-purpose tools or generally available free programs which are used unmodified in performing those activities but which are not part of the work. For example, Corresponding Source includes interface definition files associated with source files for the work, and the source code for shared libraries and dynamically linked subprograms that the work is specifically designed to require, such as by intimate data communication or control flow between those
   subprograms and other parts of the work.
   The Corresponding Source need not include anything that users can regenerate automatically from other parts of the Corresponding Source.
   The Corresponding Source for a work in source code form is that same work.
   2. Basic Permissions.
   All rights granted under this License are granted for the term of copyright on the Program, and are irrevocable provided the stated conditions are met. This License explicitly affirms your unlimited permission to run the unmodified Program. The output from running a covered work is covered by this License only if the output, given its content, constitutes a covered work. This License acknowledges your rights of fair use or other equivalent, as provided by copyright law.
   You may make, run and propagate covered works that you do not convey, without conditions so long as your license otherwise remains in force. You may convey covered works to others for the sole purpose of having them make modifications exclusively for you, or provide you with facilities for running those works, provided that you comply with the terms of this License in conveying all material for which you do not control copyright. Those thus making or running the covered works for you must do so exclusively on your behalf, under your direction and control, on terms that prohibit them from making any copies of your copyrighted material outside their relationship with you.
   Conveying under any other circumstances is permitted solely under the conditions stated below. Sublicensing is not allowed; section 10 makes it unnecessary.
   3. Protecting Users&#39; Legal Rights From Anti-Circumvention Law.
   No covered work shall be deemed part of an effective technological measure under any applicable law fulfilling obligations under article 11 of the WIPO copyright treaty adopted on 20 December 1996, or similar laws prohibiting or restricting circumvention of such measures.
   When you convey a covered work, you waive any legal power to forbid circumvention of technological measures to the extent such circumvention is effected by exercising rights under this License with respect to the covered work, and you disclaim any intention to limit operation or modification of the work as a means of enforcing, against the work&#39;s users, your or third parties&#39; legal rights to forbid circumvention of technological measures.
   4. Conveying Verbatim Copies.
   You may convey verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice; keep intact all notices stating that this License and any non-permissive terms added in accord with section 7 apply to the code; keep intact all notices of the absence of any warranty; and give all recipients a copy of this License along with the Program.
   You may charge any price or no price for each copy that you convey, and you may offer support or warranty protection for a fee.
   5. Conveying Modified Source Versions.
   You may convey a work based on the Program, or the modifications to produce it from the Program, in the form of source code under the terms of section 4, provided that you also meet all of these conditions:
      a) The work must carry prominent notices stating that you modified it, and giving a relevant date.
      b) The work must carry prominent notices stating that it is released under this License and any conditions added under section 7. This requirement modifies the requirement in section 4 to &quot;keep intact all notices&quot;.
      c) You must license the entire work, as a whole, under this License to anyone who comes into possession of a copy. This License will therefore apply, along with any applicable section 7 additional terms, to the whole of the work, and all its parts, regardless of how they are packaged. This License gives no permission to license the work in any other way, but it does not invalidate such permission if you have separately received it.
      d) If the work has interactive user interfaces, each must display Appropriate Legal Notices; however, if the Program has interactive interfaces that do not display Appropriate Legal Notices, your work need not make them do so.
   A compilation of a covered work with other separate and independent works, which are not by their nature extensions of the covered work, and which are not combined with it such as to form a larger program, in or on a volume of a storage or distribution medium, is called an &quot;aggregate&quot; if the compilation and its resulting copyright are not used to limit the access or legal rights of the compilation&#39;s users beyond what the individual works permit. Inclusion of a covered work in an aggregate does not cause this License to apply to the other parts of the aggregate.
   6. Conveying Non-Source Forms.
   You may convey a covered work in object code form under the terms of sections 4 and 5, provided that you also convey the machine-readable Corresponding Source under the terms of this License, in one of these ways:
      a) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by the Corresponding Source fixed on a durable physical medium customarily used for software interchange.
      b) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by a written offer, valid for at least three years and valid for as long as you offer spare parts or customer support for that product model, to give anyone who possesses the object code either (1) a copy of the Corresponding Source for all the software in the product that is covered by this License, on a durable physical medium customarily used for software interchange, for a price no more than your reasonable cost of physically performing this conveying of source, or (2) access to copy the Corresponding Source from a network server at no charge.
      c) Convey individual copies of the object code with a copy of the written offer to provide the Corresponding Source. This alternative is allowed only occasionally and noncommercially, and only if you received the object code with such an offer, in accord with subsection 6b.
      d) Convey the object code by offering access from a designated place (gratis or for a charge), and offer equivalent access to the Corresponding Source in the same way through the same place at no further charge. You need not require recipients to copy the Corresponding Source along with the object code. If the place to copy the object code is a network server, the Corresponding Source may be on a different server (operated by you or a third party) that supports equivalent copying facilities, provided you maintain clear directions next to the object code saying where to find the Corresponding Source. Regardless of what server hosts the Corresponding Source, you remain obligated to ensure that it is available for as long as needed to satisfy these requirements.
      e) Convey the object code using peer-to-peer transmission, provided you inform other peers where the object code and Corresponding Source of the work are being offered to the general public at no charge under subsection 6d.
   A separable portion of the object code, whose source code is excluded from the Corresponding Source as a System Library, need not be included in conveying the object code work.
   A &quot;User Product&quot; is either (1) a &quot;consumer product&quot;, which means any tangible personal property which is normally used for personal, family, or household purposes, or (2) anything designed or sold for incorporation into a dwelling. In determining whether a product is a consumer product, doubtful cases shall be resolved in favor of coverage. For a particular product received by a particular user, &quot;normally used&quot; refers to a typical or common use of that class of product, regardless of the status of the particular user or of the way in which the particular user actually uses, or expects or is expected to use, the product. A product is a consumer product regardless of whether the product has substantial commercial, industrial or non-consumer uses, unless such uses represent the only significant mode of use of the product.
   &quot;Installation Information&quot; for a User Product means any methods, procedures, authorization keys, or other information required to install and execute modified versions of a covered work in that User Product from a modified version of its Corresponding Source. The information must suffice to ensure that the continued functioning of the modified object code is in no case prevented or interfered with solely because modification has been made.
   If you convey an object code work under this section in, or with, or specifically for use in, a User Product, and the conveying occurs as part of a transaction in which the right of possession and use of the User Product is transferred to the recipient in perpetuity or for a fixed term (regardless of how the transaction is characterized), the Corresponding Source conveyed under this section must be accompanied by the Installation Information. But this requirement does not apply if neither you nor any third party retains the ability to install modified object code on the User Product (for example, the work has been installed in ROM).
   The requirement to provide Installation Information does not include a requirement to continue to provide support service, warranty, or updates for a work that has been modified or installed by the recipient, or for the User Product in which it has been modified or installed. Access to a network may be denied when the modification itself materially and adversely affects the operation of the network or violates the rules and protocols for communication across the network.
   Corresponding Source conveyed, and Installation Information provided, in accord with this section must be in a format that is publicly documented (and with an implementation available to the public in source code form), and must require no special password or key for unpacking, reading or copying.
   7. Additional Terms.
   &quot;Additional permissions&quot; are terms that supplement the terms of this License by making exceptions from one or more of its conditions. Additional permissions that are applicable to the entire Program shall be treated as though they were included in this License, to the extent that they are valid under applicable law. If additional permissions apply only to part of the Program, that part may be used separately under those permissions, but the entire Program remains governed by this License without regard to the additional permissions.
   When you convey a copy of a covered work, you may at your option remove any additional permissions from that copy, or from any part of it. (Additional permissions may be written to require their own removal in certain cases when you modify the work.) You may place additional permissions on material, added by you to a covered work, for which you have or can give appropriate copyright permission.
   Notwithstanding any other provision of this License, for material you add to a covered work, you may (if authorized by the copyright holders of that material) supplement the terms of this License with terms:
      a) Disclaiming warranty or limiting liability differently from the terms of sections 15 and 16 of this License; or
      b) Requiring preservation of specified reasonable legal notices or author attributions in that material or in the Appropriate Legal Notices displayed by works containing it; or
      c) Prohibiting misrepresentation of the origin of that material, or requiring that modified versions of such material be marked in reasonable ways as different from the original version; or
      d) Limiting the use for publicity purposes of names of licensors or authors of the material; or
      e) Declining to grant rights under trademark law for use of some trade names, trademarks, or service marks; or
      f) Requiring indemnification of licensors and authors of that material by anyone who conveys the material (or modified versions of it) with contractual assumptions of liability to the recipient, for any liability that these contractual assumptions directly impose on those licensors and authors.
   All other non-permissive additional terms are considered &quot;further restrictions&quot; within the meaning of section 10. If the Program as you received it, or any part of it, contains a notice stating that it is governed by this License along with a term that is a further restriction, you may remove that term. If a license document contains a further restriction but permits relicensing or conveying under this License, you may add to a covered work material governed by the terms of that license document, provided that the further restriction does not survive such relicensing or conveying.
   If you add terms to a covered work in accord with this section, you must place, in the relevant source files, a statement of the additional terms that apply to those files, or a notice indicating where to find the applicable terms.
   Additional terms, permissive or non-permissive, may be stated in the form of a separately written license, or stated as exceptions; the above requirements apply either way.
   8. Termination.
   You may not propagate or modify a covered work except as expressly provided under this License. Any attempt otherwise to propagate or modify it is void, and will automatically terminate your rights under this License (including any patent licenses granted under the third paragraph of section 11).
   However, if you cease all violation of this License, then your license from a particular copyright holder is reinstated (a) provisionally, unless and until the copyright holder explicitly and finally terminates your license, and (b) permanently, if the copyright holder fails to notify you of the violation by some reasonable means prior to 60 days after the cessation.
   Moreover, your license from a particular copyright holder is reinstated permanently if the copyright holder notifies you of the violation by some reasonable means, this is the first time you have received notice of violation of this License (for any work) from that copyright holder, and you cure the violation prior to 30 days after your receipt of the notice.
   Termination of your rights under this section does not terminate the licenses of parties who have received copies or rights from you under this License. If your rights have been terminated and not permanently reinstated, you do not qualify to receive new licenses for the same material under section 10.
   9. Acceptance Not Required for Having Copies.
   You are not required to accept this License in order to receive or run a copy of the Program. Ancillary propagation of a covered work occurring solely as a consequence of using peer-to-peer transmission to receive a copy likewise does not require acceptance. However, nothing other than this License grants you permission to propagate or modify any covered work. These actions infringe copyright if you do not accept this License. Therefore, by modifying or propagating a covered work, you indicate your acceptance of this License to do so.
   10. Automatic Licensing of Downstream Recipients.
   Each time you convey a covered work, the recipient automatically receives a license from the original licensors, to run, modify and propagate that work, subject to this License. You are not responsible for enforcing compliance by third parties with this License.
   An &quot;entity transaction&quot; is a transaction transferring control of an organization, or substantially all assets of one, or subdividing an organization, or merging organizations. If propagation of a covered work results from an entity transaction, each party to that transaction who receives a copy of the work also receives whatever licenses to the work the party&#39;s predecessor in interest had or could give under the previous paragraph, plus a right to possession of the Corresponding Source of the work from the predecessor in interest, if the predecessor has it or can get it with reasonable efforts.
   You may not impose any further restrictions on the exercise of the rights granted or affirmed under this License. For example, you may not impose a license fee, royalty, or other charge for exercise of rights granted under this License, and you may not initiate litigation (including a cross-claim or counterclaim in a lawsuit) alleging that any patent claim is infringed by making, using, selling, offering for sale, or importing the Program or any portion of it.
   11. Patents.
   A &quot;contributor&quot; is a copyright holder who authorizes use under this License of the Program or a work on which the Program is based. The work thus licensed is called the contributor&#39;s &quot;contributor version&quot;.
   A contributor&#39;s &quot;essential patent claims&quot; are all patent claims owned or controlled by the contributor, whether already acquired or hereafter acquired, that would be infringed by some manner, permitted by this License, of making, using, or selling its contributor version, but do not include claims that would be infringed only as a consequence of further modification of the contributor version. For purposes of this definition, &quot;control&quot; includes the right to grant patent sublicenses in a manner consistent with the requirements of this License.
   Each contributor grants you a non-exclusive, worldwide, royalty-free patent license under the contributor&#39;s essential patent claims, to make, use, sell, offer for sale, import and otherwise run, modify and propagate the contents of its contributor version.
   In the following three paragraphs, a &quot;patent license&quot; is any express agreement or commitment, however denominated, not to enforce a patent (such as an express permission to practice a patent or covenant not to s ue for patent infringement). To &quot;grant&quot; such a patent license to a party means to make such an agreement or commitment not to enforce a patent against the party.
   If you convey a covered work, knowingly relying on a patent license, and the Corresponding Source of the work is not available for anyone to copy, free of charge and under the terms of this License, through a publicly available network server or other readily accessible means, then you must either (1) cause the Corresponding Source to be so available, or (2) arrange to deprive yourself of the benefit of the patent license for this particular work, or (3) arrange, in a manner consistent with the requirements of this License, to extend the patent
   license to downstream recipients. &quot;Knowingly relying&quot; means you have actual knowledge that, but for the patent license, your conveying the covered work in a country, or your recipient&#39;s use of the covered work in a country, would infringe one or more identifiable patents in that country that you have reason to believe are valid.
   If, pursuant to or in connection with a single transaction or arrangement, you convey, or propagate by procuring conveyance of, a covered work, and grant a patent license to some of the parties receiving the covered work authorizing them to use, propagate, modify or convey a specific copy of the covered work, then the patent license you grant is automatically extended to all recipients of the covered work and works based on it.
   A patent license is &quot;discriminatory&quot; if it does not include within the scope of its coverage, prohibits the exercise of, or is conditioned on the non-exercise of one or more of the rights that are specifically granted under this License. You may not convey a covered work if you are a party to an arrangement with a third party that is in the business of distributing software, under which you make payment to the third party based on the extent of your activity of conveying the work, and under which the third party grants, to any of the parties who would receive the covered work from you, a discriminatory patent license (a) in connection with copies of the covered work conveyed by you (or copies made from those copies), or (b) primarily for and in connection with specific products or compilations that contain the covered work, unless you entered into that arrangement, or that patent license was granted, prior to 28 March 2007.
   Nothing in this License shall be construed as excluding or limiting any implied license or other defenses to infringement that may otherwise be available to you under applicable patent law.
   12. No Surrender of Others&#39; Freedom.
   If conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot convey a covered work so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may
   not convey it at all. For example, if you agree to terms that obligate you to collect a royalty for further conveying from those to whom you convey the Program, the only way you could satisfy both those terms and this License would be to refrain entirely from conveying the Program.
   13. Remote Network Interaction; Use with the GNU General Public License.
   Notwithstanding any other provision of this License, if you modify the Program, your modified version must prominently offer all users interacting with it remotely through a computer network (if your version supports such interaction) an opportunity to receive the Corresponding Source of your version by providing access to the Corresponding Source from a network server at no charge, through some standard or customary means of facilitating copying of software. This Corresponding Source shall include the Corresponding Source for any work covered by version 3 of the GNU General Public License that is incorporated pursuant to the following paragraph.
   Notwithstanding any other provision of this License, you have permission to link or combine any covered work with a work licensed under version 3 of the GNU General Public License into a single combined work, and to convey the resulting work. The terms of this License will continue to apply to the part which is the covered work, but the work with which it is combined will remain governed by version 3 of the GNU General Public License.
   14. Revised Versions of this License.
   The Free Software Foundation may publish revised and/or new versions of the GNU Affero General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies that a certain numbered version of the GNU Affero General Public License &quot;or any later version&quot; applies to it, you have the option of following the terms and conditions either of that numbered version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of the GNU Affero General Public License, you may choose any version ever published by the Free Software Foundation.
   If the Program specifies that a proxy can decide which future versions of the GNU Affero General Public License can be used, that proxy&#39;s public statement of acceptance of a version permanently authorizes you to choose that version for the Program.
   Later license versions may give you additional or different permissions. However, no additional obligations are imposed on any author or copyright holder as a result of your choosing to follow a later version.
   15. Disclaimer of Warranty.
   THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   16. Limitation of Liability.
   IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   17. Interpretation of Sections 15 and 16.
   If the disclaimer of warranty and limitation of liability provided above cannot be given local legal effect according to their terms, reviewing courts shall apply local law that most closely approximates an absolute waiver of all civil liability in connection with the Program, unless a warranty or assumption of liability accompanies a copy of the Program in return for a fee. END OF TERMS AND CONDITIONS
How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively state the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt;one line to give the program&#39;s name and a brief idea of what it does.&gt;
Copyright (C) &lt;year&gt; &lt;name of author&gt;
This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
You should have received a copy of the GNU Affero General Public License along with this program. If not, see &lt;http s ://www.gnu.org/licenses/&gt;.
Also add information on how to contact you by electronic and paper mail.
If your software can interact with users remotely through a computer network, you should also make sure that it provides a way for users to get its source. For example, if your program is a web application, its interface could display a &quot;Source&quot; link that leads users to an archive of the code. There are many ways you could offer source, and different solutions will be better for different programs; see section 13 for the specific requirements.
You should also get your employer (if you work as a programmer) or school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. For more information on this, and how to apply and follow the GNU AGPL, see &lt;http s ://www.gnu.org/licenses/&gt;.
```


### Apache-2.0

```
Apache License
Version 2.0, January 2004
http://www.apache.org/licenses/ TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION
   1. Definitions.
      
      &quot;License&quot; shall mean the terms and conditions for use, reproduction, and distribution as defined by Sections 1 through 9 of this document.
      
      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by the copyright owner that is granting the License.
      
      &quot;Legal Entity&quot; shall mean the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, &quot;control&quot; means (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (ii) ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial ownership of such entity.
      
      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity exercising permissions granted by this License.
      
      &quot;Source&quot; form shall mean the preferred form for making modifications, including but not limited to software source code, documentation source, and configuration files.
      
      &quot;Object&quot; form shall mean any form resulting from mechanical transformation or translation of a Source form, including but not limited to compiled object code, generated documentation, and conversions to other media types.
      
      &quot;Work&quot; shall mean the work of authorship, whether in Source or Object form, made available under the License, as indicated by a copyright notice that is included in or attached to the work (an example is provided in the Appendix below).
      
      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object form, that is based on (or derived from) the Work and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this License, Derivative Works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the Work and Derivative Works thereof.
      
      &quot;Contribution&quot; shall mean any work of authorship, including the original version of the Work and any modifications or additions to that Work or Derivative Works thereof, that is intentionally submitted to Licensor for inclusion in the Work by the copyright owner or by an individual or Legal Entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, &quot;submitted&quot; means any form of electronic, verbal, or written communication sent to the Licensor or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, the Licensor for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by the copyright owner as &quot;Not a Contribution.&quot;
      
      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity on behalf of whom a Contribution has been received by Licensor and subsequently incorporated within the Work.
   2. Grant of Copyright License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare Derivative Works of, publicly display, publicly perform, sublicense, and distribute the Work and such Derivative Works in Source or Object form.
   3. Grant of Patent License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the Work to which such Contribution(s) was submitted. If You institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the Work or a Contribution incorporated within the Work constitutes direct or contributory patent infringement, then any patent licenses granted to You under this License for that Work shall terminate as of the date such litigation is filed.
   4. Redistribution. You may reproduce and distribute copies of the Work or Derivative Works thereof in any medium, with or without modifications, and in Source or Object form, provided that You meet the following conditions:
      (a) You must give any other recipients of the Work or Derivative Works a copy of this License; and
      (b) You must cause any modified files to carry prominent notices stating that You changed the files; and
      (c) You must retain, in the Source form of any Derivative Works that You distribute, all copyright, patent, trademark, and attribution notices from the Source form of the Work, excluding those notices that do not pertain to any part of the Derivative Works; and
      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its distribution, then any Derivative Works that You distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the Derivative Works, in at least one of the following places: within a NOTICE text file distributed as part of the Derivative Works; within the Source form or documentation, if provided along with the Derivative Works; or, within a display generated by the Derivative Works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify the License. You may add Your own attribution notices within Derivative Works that You distribute, alongside or as an addendum to the NOTICE text from the Work, provided that such additional attribution notices cannot be construed as modifying the License.
      You may add Your own copyright statement to Your modifications and may provide additional or different license terms and conditions for use, reproduction, or distribution of Your modifications, or for any such Derivative Works as a whole, provided Your use, reproduction, and distribution of the Work otherwise complies with the conditions stated in this License.
   5. Submission of Contributions. Unless You explicitly state otherwise, any Contribution intentionally submitted for inclusion in the Work by You to the Licensor shall be under the terms and conditions of this License, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate license agreement you may have executed with Licensor regarding such Contributions.
   6. Trademarks. This License does not grant permission to use the trade names, trademarks, service marks, or product names of the Licensor, except as required for reasonable and customary use in describing the origin of the Work and reproducing the content of the NOTICE file.
   7. Disclaimer of Warranty. Unless required by applicable law or agreed to in writing, Licensor provides the Work (and each Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are solely responsible for determining the appropriateness of using or redistributing the Work and assume any risks associated with Your exercise of permissions under this License.
   8. Limitation of Liability. In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any Contributor be liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this License or out of the use or inability to use the Work (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such Contributor has been advised of the possibility of such damages.
   9. Accepting Warranty or Additional Liability. While redistributing the Work or Derivative Works thereof, You may choose to offer, and charge a fee for, acceptance of support, warranty, indemnity, or other liability obligations and/or rights consistent with this License. However, in accepting such obligations, You may act only on Your own behalf and on Your sole responsibility, not on behalf of any other Contributor, and only if You agree to indemnify, defend, and hold each Contributor harmless for any liability incurred by, or claims asserted against, such Contributor by reason of your accepting any such warranty or additional liability. END OF TERMS AND CONDITIONS
APPENDIX: How to apply the Apache License to your work.
To apply the Apache License to your work, attach the following boilerplate notice, with the fields enclosed by brackets &quot;[]&quot; replaced with your own identifying information. (Don&#39;t include the brackets!) The text should be enclosed in the appropriate comment syntax for the file format. We also recommend that a file or class name and description of purpose be included on the same &quot;printed page&quot; as the copyright notice for easier identification within third-party archives.
Copyright [yyyy] [name of copyright owner]
Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```


### Artistic-1.0

```
The Artistic License
Preamble
The intent of this document is to state the conditions under which a Package may be copied, such that the Copyright Holder maintains some semblance of artistic control over the development of the package, while giving the users of the package the right to use and distribute the Package in a more-or-less customary fashion, plus the right to make reasonable modifications.
Definitions:
&quot;Package&quot; refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
&quot;Standard Version&quot; refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder.
&quot;Copyright Holder&quot; is whoever is named in the copyright or copyrights for the package.
&quot;You&quot; is you, if you&#39;re thinking about copying or distributing this Package.
&quot;Reasonable copying fee&quot; is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
&quot;Freely Available&quot; means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as ftp.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
      b) use the modified Package only within your corporation or organization.
      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
      b) accompany the distribution with the machine-readable source of the Package with your modifications.
      c) accompany any non-standard executables with their corresponding Standard Version executables, giving the non-standard executables non-standard names, and clearly documenting the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own.
   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.
   7. C or perl subroutines supplied by you and linked into this Package shall not be considered part of this Package.
   8. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
   9. THIS PACKAGE IS PROVIDED &quot;AS IS&quot; AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE. The End
```


### Artistic-1.0-Perl

```
The &quot;Artistic License&quot;
Preamble
The intent of this document is to state the conditions under which a Package may be copied, such that the Copyright Holder maintains some semblance of artistic control over the development of the package, while giving the users of the package the right to use and distribute the Package in a more-or-less customary fashion, plus the right to make reasonable modifications.
Definitions:
&quot;Package&quot; refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
&quot;Standard Version&quot; refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder as specified below.
&quot;Copyright Holder&quot; is whoever is named in the copyright or copyrights for the package.
&quot;You&quot; is you, if you&#39;re thinking about copying or distributing this Package.
&quot;Reasonable copying fee&quot; is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
&quot;Freely Available&quot; means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as uunet.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
      b) use the modified Package only within your corporation or organization.
      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
      b) accompany the distribution with the machine-readable source of the Package with your modifications.
      c) give non-standard executables non-standard names, and clearly document the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own. You may embed this Package&#39;s interpreter within an executable of yours (by linking); this shall be construed as a mere form of aggregation, provided that the complete Standard Version of the interpreter is so embedded.
   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.
   7. C subroutines (or comparably compiled subroutines in other languages) supplied by you and linked into this Package in order to emulate subroutines and variables of the language defined by this Package shall not be considered part of this Package, but are the equivalent of input as in Paragraph 6, provided these subroutines do not change the language in any way that would cause it to fail the regression tests for the language.
   8. Aggregation of this Package with a commercial distribution is always permitted provided that the use of this Package is embedded; that is, when no overt attempt is made to make this Package&#39;s interfaces visible to the end user of the commercial distribution. Such use shall not be construed as a distribution of this Package.
   9. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
   10. THIS PACKAGE IS PROVIDED &quot;AS IS&quot; AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE. The End
```


### BSD-3-Clause

```
BSD 3-Clause License

Copyright (c) 2013-2024, Kim Davies and contributors.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
&quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```


### BSD-2-Clause

```
Copyright (c) &lt;year&gt; &lt;owner&gt;
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice, this
      list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation

      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot;
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```


### BSD-3-Clause

```
Copyright (c) &lt;year&gt; &lt;owner&gt;
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

   3. Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot;
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```


### BSD-3-Clause-Clear

```
The Clear BSD License
Copyright (c) [xxxx]-[xxxx] [Owner Organization]
All rights reserved.
Redistribution and use in source and binary forms, with or without modification, are permitted (subject to the limitations in the disclaimer below) provided that the following conditions are met:
      * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
      * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
      * Neither the name of [Owner Organization] nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY&#39;S PATENT RIGHTS ARE GRANTED BY THIS LICENSE. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```


### BSL-1.0

```
Boost Software License - Version 1.0 - August 17th, 2003
Permission is hereby granted, free of charge, to any person or organization obtaining a copy of the software and accompanying documentation covered by this license (the &quot;Software&quot;) to use, reproduce, display, distribute, execute, and transmit the Software, and to prepare derivative works of the Software, and to permit third-parties to whom the Software is furnished to do so, all subject to the following:
The copyright notices in the Software and this entire statement, including the above license grant, this restriction and the following disclaimer, must be included in all copies of the Software, in whole or in part, and all derivative works of the Software, unless such copies or derivative works are solely in the form of machine-executable object code generated by a source language processor.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
```


### CC-BY-4.0

```
Creative Commons Attribution 4.0 International Creative Commons Corporation (&quot;Creative Commons&quot;) is not a law firm and does not provide legal services or legal advice. Distribution of Creative Commons public licenses does not create a lawyer-client or other relationship. Creative Commons makes its licenses and related information available on an &quot;as-is&quot; basis. Creative Commons gives no warranties regarding its licenses, any material licensed under their terms and conditions, or any related information. Creative Commons disclaims all liability for damages resulting from their use to the fullest extent possible.
Using Creative Commons Public Licenses
Creative Commons public licenses provide a standard set of terms and conditions that creators and other rights holders may use to share original works of authorship and other material subject to copyright and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.
Considerations for licensors: Our public licenses are intended for use by those authorized to give the public permission to use material in ways otherwise restricted by copyright and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors
Considerations for the public: By using one of our public licenses, a licensor grants the public permission to use the licensed material under specified terms and conditions. If the licensor&#39;s permission is not necessary for any reason–for example, because of any applicable exception or limitation to copyright–then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License
By exercising the Licensed Rights (defined below), You accept and agree to be bound by the terms and conditions of this Creative Commons Attribution 4.0 International Public License (&quot;Public License&quot;). To the extent this Public License may be interpreted as a contract, You are granted the Licensed Rights in consideration of Your acceptance of these terms and conditions, and the Licensor grants You such rights in consideration of benefits the Licensor receives from making the Licensed Material available under these terms and conditions.
Section 1 – Definitions.
   a. Adapted Material means material subject to Copyright and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.
   b. Adapter&#39;s License means the license You apply to Your Copyright and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.
   c. Copyright and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.
   d. Effective Technological Measures means those measures that, in the absence of proper authority, may not be circumvented under laws fulfilling obligations under Article 11 of the WIPO Copyright Treaty adopted on December 20, 1996, and/or similar international agreements.
   e. Exceptions and Limitations means fair use, fair dealing, and/or any other exception or limitation to Copyright and Similar Rights that applies to Your use of the Licensed Material.
   f. Licensed Material means the artistic or literary work, database, or other material to which the Licensor applied this Public License.
   g. Licensed Rights means the rights granted to You subject to the terms and conditions of this Public License, which are limited to all Copyright and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.
   h. Licensor means the individual(s) or entity(ies) granting rights under this Public License.
   i. Share means to provide material to the public by any means or process that requires permission under the Licensed Rights, such as reproduction, public display, public performance, distribution, dissemination, communication, or importation, and to make material available to the public including in ways that members of the public may access the material from a place and at a time individually chosen by them.
   j. Sui Generis Database Rights means rights other than copyright resulting from Directive 96/9/EC of the European Parliament and of the Council of 11 March 1996 on the legal protection of databases, as amended and/or succeeded, as well as other essentially equivalent rights anywhere in the world.
   k. You means the individual or entity exercising the Licensed Rights under this Public License. Your has a corresponding meaning.
Section 2 – Scope.
   a. License grant.
      1. Subject to the terms and conditions of this Public License, the Licensor hereby grants You a worldwide, royalty-free, non-sublicensable, non-exclusive, irrevocable license to exercise the Licensed Rights in the Licensed Material to:
         A. reproduce and Share the Licensed Material, in whole or in part; and
         B. produce, reproduce, and Share Adapted Material.
      2. Exceptions and Limitations. For the avoidance of doubt, where Exceptions and Limitations apply to Your use, this Public License does not apply, and You do not need to comply with its terms and conditions.
      3. Term. The term of this Public License is specified in Section 6(a).
      4. Media and formats; technical modifications allowed. The Licensor authorizes You to exercise the Licensed Rights in all media and formats whether now known or hereafter created, and to make technical modifications necessary to do so. The Licensor waives and/or agrees not to assert any right or authority to forbid You from making technical modifications necessary to exercise the Licensed Rights, including technical modifications necessary to circumvent Effective Technological Measures. For purposes of this Public License, simply making modifications authorized by this Section 2(a)(4) never produces Adapted Material.
      5. Downstream recipients.
         A. Offer from the Licensor – Licensed Material. Every recipient of the Licensed Material automatically receives an offer from the Licensor to exercise the Licensed Rights under the terms and conditions of this Public License.
         B. No downstream restrictions. You may not offer or impose any additional or different terms or conditions on, or apply any Effective Technological Measures to, the Licensed Material if doing so restricts exercise of the Licensed Rights by any recipient of the Licensed Material.
      6. No endorsement. Nothing in this Public License constitutes or may be construed as permission to assert or imply that You are, or that Your use of the Licensed Material is, connected with, or sponsored, endorsed, or granted official status by, the Licensor or others designated to receive attribution as provided in Section 3(a)(1)(A)(i).
   b. Other rights.
      1. Moral rights, such as the right of integrity, are not licensed under this Public License, nor are publicity, privacy, and/or other similar personality rights; however, to the extent possible, the Licensor waives and/or agrees not to assert any such rights held by the Licensor to the limited extent necessary to allow You to exercise the Licensed Rights, but not otherwise.
      2. Patent and trademark rights are not licensed under this Public License.
      3. To the extent possible, the Licensor waives any right to collect royalties from You for the exercise of the Licensed Rights, whether directly or through a collecting society under any voluntary or waivable statutory or compulsory licensing scheme. In all other cases the Licensor expressly reserves any right to collect such royalties.
Section 3 – License Conditions.
Your exercise of the Licensed Rights is expressly made subject to the following conditions.
   a. Attribution.
      1. If You Share the Licensed Material (including in modified form), You must:
         A. retain the following if it is supplied by the Licensor with the Licensed Material:
            i. identification of the creator(s) of the Licensed Material and any others designated to receive attribution, in any reasonable manner requested by the Licensor (including by pseudonym if designated);
            ii. a copyright notice;
            iii. a notice that refers to this Public License;
            iv. a notice that refers to the disclaimer of warranties;
            v. a URI or hyperlink to the Licensed Material to the extent reasonably practicable;
         B. indicate if You modified the Licensed Material and retain an indication of any previous modifications; and
         C. indicate the Licensed Material is licensed under this Public License, and include the text of, or the URI or hyperlink to, this Public License.
      2. You may satisfy the conditions in Section 3(a)(1) in any reasonable manner based on the medium, means, and context in which You Share the Licensed Material. For example, it may be reasonable to satisfy the conditions by providing a URI or hyperlink to a resource that includes the required information.
      3. If requested by the Licensor, You must remove any of the information required by Section 3(a)(1)(A) to the extent reasonably practicable.
      4. If You Share Adapted Material You produce, the Adapter&#39;s License You apply must not prevent recipients of the Adapted Material from complying with this Public License.
Section 4 – Sui Generis Database Rights.
Where the Licensed Rights include Sui Generis Database Rights that apply to Your use of the Licensed Material:
   a. for the avoidance of doubt, Section 2(a)(1) grants You the right to extract, reuse, reproduce, and Share all or a substantial portion of the contents of the database;
   b. if You include all or a substantial portion of the database contents in a database in which You have Sui Generis Database Rights, then the database in which You have Sui Generis Database Rights (but not its individual contents) is Adapted Material; and
   c. You must comply with the conditions in Section 3(a) if You Share all or a substantial portion of the contents of the database.
For the avoidance of doubt, this Section 4 supplements and does not replace Your obligations under this Public License where the Licensed Rights include other Copyright and Similar Rights.
Section 5 – Disclaimer of Warranties and Limitation of Liability.
   a. Unless otherwise separately undertaken by the Licensor, to the extent possible, the Licensor offers the Licensed Material as-is and as-available, and makes no representations or warranties of any kind concerning the Licensed Material, whether express, implied, statutory, or other. This includes, without limitation, warranties of title, merchantability, fitness for a particular purpose, non-infringement, absence of latent or other defects, accuracy, or the presence or absence of errors, whether or not known or discoverable. Where disclaimers of warranties are not allowed in full or in part, this disclaimer may not apply to You.
   b. To the extent possible, in no event will the Licensor be liable to You on any legal theory (including, without limitation, negligence) or otherwise for any direct, special, indirect, incidental, consequential, punitive, exemplary, or other losses, costs, expenses, or damages arising out of this Public License or use of the Licensed Material, even if the Licensor has been advised of the possibility of such losses, costs, expenses, or damages. Where a limitation of liability is not allowed in full or in part, this limitation may not apply to You.
   c. The disclaimer of warranties and limitation of liability provided above shall be interpreted in a manner that, to the extent possible, most closely approximates an absolute disclaimer and waiver of all liability.
Section 6 – Term and Termination.
   a. This Public License applies for the term of the Copyright and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.
   b. Where Your right to use the Licensed Material has terminated under Section 6(a), it reinstates:
      1. automatically as of the date the violation is cured, provided it is cured within 30 days of Your discovery of the violation; or
      2. upon express reinstatement by the Licensor.
   c. For the avoidance of doubt, this Section 6(b) does not affect any right the Licensor may have to seek remedies for Your violations of this Public License.
   d. For the avoidance of doubt, the Licensor may also offer the Licensed Material under separate terms or conditions or stop distributing the Licensed Material at any time; however, doing so will not terminate this Public License.
   e. Sections 1, 5, 6, 7, and 8 survive termination of this Public License.
Section 7 – Other Terms and Conditions.
   a. The Licensor shall not be bound by any additional or different terms or conditions communicated by You unless expressly agreed.
   b. Any arrangements, understandings, or agreements regarding the Licensed Material not stated herein are separate from and independent of the terms and conditions of this Public License.
Section 8 – Interpretation.
   a. For the avoidance of doubt, this Public License does not, and shall not be interpreted to, reduce, limit, restrict, or impose conditions on any use of the Licensed Material that could lawfully be made without permission under this Public License.
   b. To the extent possible, if any provision of this Public License is deemed unenforceable, it shall be automatically reformed to the minimum extent necessary to make it enforceable. If the provision cannot be reformed, it shall be severed from this Public License without affecting the enforceability of the remaining terms and conditions.
   c. No term or condition of this Public License will be waived and no failure to comply consented to unless expressly agreed to by the Licensor.
   d. Nothing in this Public License constitutes or may be interpreted as a limitation upon, or waiver of, any privileges and immunities that apply to the Licensor or You, including from the legal processes of any jurisdiction or authority.
Creative Commons is not a party to its public licenses. Notwithstanding, Creative Commons may elect to apply one of its public licenses to material it publishes and in those instances will be considered the &quot;Licensor.&quot; The text of the Creative Commons public licenses is dedicated to the public domain under the CC0 Public Domain Dedication. Except for the limited purpose of indicating that material is shared under a Creative Commons public license or as otherwise permitted by the Creative Commons policies published at creativecommons.org/policies, Creative Commons does not authorize the use of the trademark &quot;Creative Commons&quot; or any other trademark or logo of Creative Commons without its prior written consent including, without limitation, in connection with any unauthorized modifications to any of its public licenses or any other arrangements, understandings, or agreements concerning use of licensed material. For the avoidance of doubt, this paragraph does not form part of the public licenses.
Creative Commons may be contacted at creativecommons.org.
```


### CC-BY-SA-3.0

```
Creative Commons Attribution-ShareAlike 3.0 Unported CREATIVE COMMONS CORPORATION IS NOT A LAW FIRM AND DOES NOT PROVIDE LEGAL SERVICES. DISTRIBUTION OF THIS LICENSE DOES NOT CREATE AN ATTORNEY-CLIENT RELATIONSHIP. CREATIVE COMMONS PROVIDES THIS INFORMATION ON AN &quot;AS-IS&quot; BASIS. CREATIVE COMMONS MAKES NO WARRANTIES REGARDING THE INFORMATION PROVIDED, AND DISCLAIMS LIABILITY FOR DAMAGES RESULTING FROM ITS USE.
License
THE WORK (AS DEFINED BELOW) IS PROVIDED UNDER THE TERMS OF THIS CREATIVE COMMONS PUBLIC LICENSE (&quot;CCPL&quot; OR &quot;LICENSE&quot;). THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.
BY EXERCISING ANY RIGHTS TO THE WORK PROVIDED HERE, YOU ACCEPT AND AGREE TO BE BOUND BY THE TERMS OF THIS LICENSE. TO THE EXTENT THIS LICENSE MAY BE CONSIDERED TO BE A CONTRACT, THE LICENSOR GRANTS YOU THE RIGHTS CONTAINED HERE IN CONSIDERATION OF YOUR ACCEPTANCE OF SUCH TERMS AND CONDITIONS.
   1. Definitions
      a. &quot;Adaptation&quot; means a work based upon the Work, or upon the Work and other pre-existing works, such as a translation, adaptation, derivative work, arrangement of music or other alterations of a literary or artistic work, or phonogram or performance and includes cinematographic adaptations or any other form in which the Work may be recast, transformed, or adapted including in any form recognizably derived from the original, except that a work that constitutes a Collection will not be considered an Adaptation for the purpose of this License. For the avoidance of doubt, where the Work is a musical work, performance or phonogram, the synchronization of the Work in timed-relation with a moving image (&quot;synching&quot;) will be considered an Adaptation for the purpose of this License.
      b. &quot;Collection&quot; means a collection of literary or artistic works, such as encyclopedias and anthologies, or performances, phonograms or broadcasts, or other works or subject matter other than works listed in Section 1(f) below, which, by reason of the selection and arrangement of their contents, constitute intellectual creations, in which the Work is included in its entirety in unmodified form along with one or more other contributions, each constituting separate and independent works in themselves, which together are assembled into a collective whole. A work that constitutes a Collection will not be considered an Adaptation (as defined below) for the purposes of this License.
      c. &quot;Creative Commons Compatible License&quot; means a license that is listed at http://creativecommons.org/compatiblelicenses that has been approved by Creative Commons as being essentially equivalent to this License, including, at a minimum, because that license: (i) contains terms that have the same purpose, meaning and effect as the License Elements of this License; and, (ii) explicitly permits the relicensing of adaptations of works made available under that license under this License or a Creative Commons jurisdiction license with the same License Elements as this License.
      d. &quot;Distribute&quot; means to make available to the public the original and copies of the Work or Adaptation, as appropriate, through sale or other transfer of ownership.
      e. &quot;License Elements&quot; means the following high-level license attributes as selected by Licensor and indicated in the title of this License: Attribution, ShareAlike.
      f. &quot;Licensor&quot; means the individual, individuals, entity or entities that offer(s) the Work under the terms of this License.
      g. &quot;Original Author&quot; means, in the case of a literary or artistic work, the individual, individuals, entity or entities who created the Work or if no individual or entity can be identified, the publisher; and in addition (i) in the case of a performance the actors, singers, musicians, dancers, and other persons who act, sing, deliver, declaim, play in, interpret or otherwise perform literary or artistic works or expressions of folklore; (ii) in the case of a phonogram the producer being the person or legal entity who first fixes the sounds of a performance or other sounds; and, (iii) in the case of broadcasts, the organization that transmits the broadcast.
      h. &quot;Work&quot; means the literary and/or artistic work offered under the terms of this License including without limitation any production in the literary, scientific and artistic domain, whatever may be the mode or form of its expression including digital form, such as a book, pamphlet and other writing; a lecture, address, sermon or other work of the same nature; a dramatic or dramatico-musical work; a choreographic work or entertainment in dumb show; a musical composition with or without words; a cinematographic work to which are assimilated works expressed by a process analogous to cinematography; a work of drawing, painting, architecture, sculpture, engraving or lithography; a photographic work to which are assimilated works expressed by a process analogous to photography; a work of applied art; an illustration, map, plan, sketch or three-dimensional work relative to geography, topography, architecture or science; a performance; a broadcast; a phonogram; a compilation of data to the extent it is protected as a copyrightable work; or a work performed by a variety or circus performer to the extent it is not otherwise considered a literary or artistic work.
      i. &quot;You&quot; means an individual or entity exercising rights under this License who has not previously violated the terms of this License with respect to the Work, or who has received express permission from the Licensor to exercise rights under this License despite a previous violation.
      j. &quot;Publicly Perform&quot; means to perform public recitations of the Work and to communicate to the public those public recitations, by any means or process, including by wire or wireless means or public digital performances; to make available to the public Works in such a way that members of the public may access these Works from a place and at a place individually chosen by them; to perform the Work to the public by any means or process and the communication to the public of the performances of the Work, including by public digital performance; to broadcast and rebroadcast the Work by any means including signs, sounds or images.
      k. &quot;Reproduce&quot; means to make copies of the Work by any means including without limitation by sound or visual recordings and the right of fixation and reproducing fixations of the Work, including storage of a protected performance or phonogram in digital form or other electronic medium.
   2. Fair Dealing Rights. Nothing in this License is intended to reduce, limit, or restrict any uses free from copyright or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.
   3. License Grant. Subject to the terms and conditions of this License, Licensor hereby grants You a worldwide, royalty-free, non-exclusive, perpetual (for the duration of the applicable copyright) license to exercise the rights in the Work as stated below:
      a. to Reproduce the Work, to incorporate the Work into one or more Collections, and to Reproduce the Work as incorporated in the Collections;
      b. to create and Reproduce Adaptations provided that any such Adaptation, including any translation in any medium, takes reasonable steps to clearly label, demarcate or otherwise identify that changes were made to the original Work. For example, a translation could be marked &quot;The original work was translated from English to Spanish,&quot; or a modification could indicate &quot;The original work has been modified.&quot;;
      c. to Distribute and Publicly Perform the Work including as incorporated in Collections; and,
      d. to Distribute and Publicly Perform Adaptations.
      e. For the avoidance of doubt:
         i. Non-waivable Compulsory License Schemes. In those jurisdictions in which the right to collect royalties through any statutory or compulsory licensing scheme cannot be waived, the Licensor reserves the exclusive right to collect such royalties for any exercise by You of the rights granted under this License;
         ii. Waivable Compulsory License Schemes. In those jurisdictions in which the right to collect royalties through any statutory or compulsory licensing scheme can be waived, the Licensor waives the exclusive right to collect such royalties for any exercise by You of the rights granted under this License; and,
         iii. Voluntary License Schemes. The Licensor waives the right to collect royalties, whether individually or, in the event that the Licensor is a member of a collecting society that administers voluntary licensing schemes, via that society, from any exercise by You of the rights granted under this License.
   The above rights may be exercised in all media and formats whether now known or hereafter devised. The above rights include the right to make such modifications as are technically necessary to exercise the rights in other media and formats. Subject to Section 8(f), all rights not expressly granted by Licensor are hereby reserved.
   4. Restrictions. The license granted in Section 3 above is expressly made subject to and limited by the following restrictions:
      a. You may Distribute or Publicly Perform the Work only under the terms of this License. You must include a copy of, or the Uniform Resource Identifier (URI) for, this License with every copy of the Work You Distribute or Publicly Perform. You may not offer or impose any terms on the Work that restrict the terms of this License or the ability of the recipient of the Work to exercise the rights granted to that recipient under the terms of the License. You may not sublicense the Work. You must keep intact all notices that refer to this License and to the disclaimer of warranties with every copy of the Work You Distribute or Publicly Perform. When You Distribute or Publicly Perform the Work, You may not impose any effective technological measures on the Work that restrict the ability of a recipient of the Work from You to exercise the rights granted to that recipient under the terms of the License. This Section 4(a) applies to the Work as incorporated in a Collection, but this does not require the Collection apart from the Work itself to be made subject to the terms of this License. If You create a Collection, upon notice from any Licensor You must, to the extent practicable, remove from the Collection any credit as required by Section 4(c), as requested. If You create an Adaptation, upon notice from any Licensor You must, to the extent practicable, remove from the Adaptation any credit as required by Section 4(c), as requested.
      b. You may Distribute or Publicly Perform an Adaptation only under the terms of: (i) this License; (ii) a later version of this License with the same License Elements as this License; (iii) a Creative Commons jurisdiction license (either this or a later license version) that contains the same License Elements as this License (e.g., Attribution-ShareAlike 3.0 US)); (iv) a Creative Commons Compatible License. If you license the Adaptation under one of the licenses mentioned in (iv), you must comply with the terms of that license. If you license the Adaptation under the terms of any of the licenses mentioned in (i), (ii) or (iii) (the &quot;Applicable License&quot;), you must comply with the terms of the Applicable License generally and the following provisions: (I) You must include a copy of, or the URI for, the Applicable License with every copy of each Adaptation You Distribute or Publicly Perform; (II) You may not offer or impose any terms on the Adaptation that restrict the terms of the Applicable License or the ability of the recipient of the Adaptation to exercise the rights granted to that recipient under the terms of the Applicable License; (III) You must keep intact all notices that refer to the Applicable License and to the disclaimer of warranties with every copy of the Work as included in the Adaptation You Distribute or Publicly Perform; (IV) when You Distribute or Publicly Perform the Adaptation, You may not impose any effective technological measures on the Adaptation that restrict the ability of a recipient of the Adaptation from You to exercise the rights granted to that recipient under the terms of the Applicable License. This Section 4(b) applies to the Adaptation as incorporated in a Collection, but this does not require the Collection apart from the Adaptation itself to be made subject to the terms of the Applicable License.
      c. If You Distribute, or Publicly Perform the Work or any Adaptations or Collections, You must, unless a request has been made pursuant to Section 4(a), keep intact all copyright notices for the Work and provide, reasonable to the medium or means You are utilizing: (i) the name of the Original Author (or pseudonym, if applicable) if supplied, and/or if the Original Author and/or Licensor designate another party or parties (e.g., a sponsor institute, publishing entity, journal) for attribution (&quot;Attribution Parties&quot;) in Licensor&#39;s copyright notice, terms of service or by other reasonable means, the name of such party or parties; (ii) the title of the Work if supplied; (iii) to the extent reasonably practicable, the URI, if any, that Licensor specifies to be associated with the Work, unless such URI does not refer to the copyright notice or licensing information for the Work; and (iv), consistent with Section 3(b), in the case of an Adaptation, a credit identifying the use of the Work in the Adaptation (e.g., &quot;French translation of the Work by Original Author,&quot; or &quot;Screenplay based on original Work by Original Author&quot;). The credit required by this Section 4(c) may be implemented in any reasonable manner; provided, however, that in the case of a Adaptation or Collection, at a minimum such credit will appear, if a credit for all contributing authors of the Adaptation or Collection appears, then as part of these credits and in a manner at least as prominent as the credits for the other contributing authors. For the avoidance of doubt, You may only use the credit required by this Section for the purpose of attribution in the manner set out above and, by exercising Your rights under this License, You may not implicitly or explicitly assert or imply any connection with, sponsorship or endorsement by the Original Author, Licensor and/or Attribution Parties, as appropriate, of You or Your use of the Work, without the separate, express prior written permission of the Original Author, Licensor and/or Attribution Parties.
      d. Except as otherwise agreed in writing by the Licensor or as may be otherwise permitted by applicable law, if You Reproduce, Distribute or Publicly Perform the Work either by itself or as part of any Adaptations or Collections, You must not distort, mutilate, modify or take other derogatory action in relation to the Work which would be prejudicial to the Original Author&#39;s honor or reputation. Licensor agrees that in those jurisdictions (e.g. Japan), in which any exercise of the right granted in Section 3(b) of this License (the right to make Adaptations) would be deemed to be a distortion, mutilation, modification or other derogatory action prejudicial to the Original Author&#39;s honor and reputation, the Licensor will waive or not assert, as appropriate, this Section, to the fullest extent permitted by the applicable national law, to enable You to reasonably exercise Your right under Section 3(b) of this License (right to make Adaptations) but not otherwise.
   5. Representations, Warranties and Disclaimer
   UNLESS OTHERWISE MUTUALLY AGREED TO BY THE PARTIES IN WRITING, LICENSOR OFFERS THE WORK AS-IS AND MAKES NO REPRESENTATIONS OR WARRANTIES OF ANY KIND CONCERNING THE WORK, EXPRESS, IMPLIED, STATUTORY OR OTHERWISE, INCLUDING, WITHOUT LIMITATION, WARRANTIES OF TITLE, MERCHANTIBILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, ACCURACY, OR THE PRESENCE OF ABSENCE OF ERRORS, WHETHER OR NOT DISCOVERABLE. SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OF IMPLIED WARRANTIES, SO SUCH EXCLUSION MAY NOT APPLY TO YOU.
   6. Limitation on Liability. EXCEPT TO THE EXTENT REQUIRED BY APPLICABLE LAW, IN NO EVENT WILL LICENSOR BE LIABLE TO YOU ON ANY LEGAL THEORY FOR ANY SPECIAL, INCIDENTAL, CONSEQUENTIAL, PUNITIVE OR EXEMPLARY DAMAGES ARISING OUT OF THIS LICENSE OR THE USE OF THE WORK, EVEN IF LICENSOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   7. Termination
      a. This License and the rights granted hereunder will terminate automatically upon any breach by You of the terms of this License. Individuals or entities who have received Adaptations or Collections from You under this License, however, will not have their licenses terminated provided such individuals or entities remain in full compliance with those licenses. Sections 1, 2, 5, 6, 7, and 8 will survive any termination of this License.
      b. Subject to the above terms and conditions, the license granted here is perpetual (for the duration of the applicable copyright in the Work). Notwithstanding the above, Licensor reserves the right to release the Work under different license terms or to stop distributing the Work at any time; provided, however that any such election will not serve to withdraw this License (or any other license that has been, or is required to be, granted under the terms of this License), and this License will continue in full force and effect unless terminated as stated above.
   8. Miscellaneous
      a. Each time You Distribute or Publicly Perform the Work or a Collection, the Licensor offers to the recipient a license to the Work on the same terms and conditions as the license granted to You under this License.
      b. Each time You Distribute or Publicly Perform an Adaptation, Licensor offers to the recipient a license to the original Work on the same terms and conditions as the license granted to You under this License.
      c. If any provision of this License is invalid or unenforceable under applicable law, it shall not affect the validity or enforceability of the remainder of the terms of this License, and without further action by the parties to this agreement, such provision shall be reformed to the minimum extent necessary to make such provision valid and enforceable.
      d. No term or provision of this License shall be deemed waived and no breach consented to unless such waiver or consent shall be in writing and signed by the party to be charged with such waiver or consent.
      e. This License constitutes the entire agreement between the parties with respect to the Work licensed here. There are no understandings, agreements or representations with respect to the Work not specified here. Licensor shall not be bound by any additional provisions that may appear in any communication from You. This License may not be modified without the mutual written agreement of the Licensor and You.
      f. The rights granted under, and the subject matter referenced, in this License were drafted utilizing the terminology of the Berne Convention for the Protection of Literary and Artistic Works (as amended on September 28, 1979), the Rome Convention of 1961, the WIPO Copyright Treaty of 1996, the WIPO Performances and Phonograms Treaty of 1996 and the Universal Copyright Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.
Creative Commons Notice
Creative Commons is not a party to this License, and makes no warranty whatsoever in connection with the Work. Creative Commons will not be liable to You or any party on any legal theory for any damages whatsoever, including without limitation any general, special, incidental or consequential damages arising in connection to this license. Notwithstanding the foregoing two (2) sentences, if Creative Commons has expressly identified itself as the Licensor hereunder, it shall have all rights and obligations of Licensor.
Except for the limited purpose of indicating to the public that the Work is licensed under the CCPL, Creative Commons does not authorize the use by either party of the trademark &quot;Creative Commons&quot; or any related trademark or logo of Creative Commons without the prior written consent of Creative Commons. Any permitted use will be in compliance with Creative Commons&#39; then-current trademark usage guidelines, as may be published on its website or otherwise made available upon request from time to time. For the avoidance of doubt, this trademark restriction does not form part of the License.
Creative Commons may be contacted at http://creativecommons.org/.
```


### CC-BY-SA-4.0

```
Creative Commons Attribution-ShareAlike 4.0 International Creative Commons Corporation (&quot;Creative Commons&quot;) is not a law firm and does not provide legal services or legal advice. Distribution of Creative Commons public licenses does not create a lawyer-client or other relationship. Creative Commons makes its licenses and related information available on an &quot;as-is&quot; basis. Creative Commons gives no warranties regarding its licenses, any material licensed under their terms and conditions, or any related information. Creative Commons disclaims all liability for damages resulting from their use to the fullest extent possible.
Using Creative Commons Public Licenses
Creative Commons public licenses provide a standard set of terms and conditions that creators and other rights holders may use to share original works of authorship and other material subject to copyright and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.
Considerations for licensors: Our public licenses are intended for use by those authorized to give the public permission to use material in ways otherwise restricted by copyright and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors
Considerations for the public: By using one of our public licenses, a licensor grants the public permission to use the licensed material under specified terms and conditions. If the licensor&#39;s permission is not necessary for any reason–for example, because of any applicable exception or limitation to copyright–then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.
Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees
Creative Commons Attribution-ShareAlike 4.0 International Public License
By exercising the Licensed Rights (defined below), You accept and agree to be bound by the terms and conditions of this Creative Commons Attribution-ShareAlike 4.0 International Public License (&quot;Public License&quot;). To the extent this Public License may be interpreted as a contract, You are granted the Licensed Rights in consideration of Your acceptance of these terms and conditions, and the Licensor grants You such rights in consideration of benefits the Licensor receives from making the Licensed Material available under these terms and conditions.
Section 1 – Definitions.
   a. Adapted Material means material subject to Copyright and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.
   b. Adapter&#39;s License means the license You apply to Your Copyright and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.
   c. BY-SA Compatible License means a license listed at creativecommons.org/compatiblelicenses, approved by Creative Commons as essentially the equivalent of this Public License.
   d. Copyright and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.
   e. Effective Technological Measures means those measures that, in the absence of proper authority, may not be circumvented under laws fulfilling obligations under Article 11 of the WIPO Copyright Treaty adopted on December 20, 1996, and/or similar international agreements.
   f. Exceptions and Limitations means fair use, fair dealing, and/or any other exception or limitation to Copyright and Similar Rights that applies to Your use of the Licensed Material.
   g. License Elements means the license attributes listed in the name of a Creative Commons Public License. The License Elements of this Public License are Attribution and ShareAlike.
   h. Licensed Material means the artistic or literary work, database, or other material to which the Licensor applied this Public License.
   i. Licensed Rights means the rights granted to You subject to the terms and conditions of this Public License, which are limited to all Copyright and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.
   j. Licensor means the individual(s) or entity(ies) granting rights under this Public License.
   k. Share means to provide material to the public by any means or process that requires permission under the Licensed Rights, such as reproduction, public display, public performance, distribution, dissemination, communication, or importation, and to make material available to the public including in ways that members of the public may access the material from a place and at a time individually chosen by them.
   l. Sui Generis Database Rights means rights other than copyright resulting from Directive 96/9/EC of the European Parliament and of the Council of 11 March 1996 on the legal protection of databases, as amended and/or succeeded, as well as other essentially equivalent rights anywhere in the world.
   m. You means the individual or entity exercising the Licensed Rights under this Public License. Your has a corresponding meaning.
Section 2 – Scope.
   a. License grant.
      1. Subject to the terms and conditions of this Public License, the Licensor hereby grants You a worldwide, royalty-free, non-sublicensable, non-exclusive, irrevocable license to exercise the Licensed Rights in the Licensed Material to:
         A. reproduce and Share the Licensed Material, in whole or in part; and
         B. produce, reproduce, and Share Adapted Material.
      2. Exceptions and Limitations. For the avoidance of doubt, where Exceptions and Limitations apply to Your use, this Public License does not apply, and You do not need to comply with its terms and conditions.
      3. Term. The term of this Public License is specified in Section 6(a).
      4. Media and formats; technical modifications allowed. The Licensor authorizes You to exercise the Licensed Rights in all media and formats whether now known or hereafter created, and to make technical modifications necessary to do so. The Licensor waives and/or agrees not to assert any right or authority to forbid You from making technical modifications necessary to exercise the Licensed Rights, including technical modifications necessary to circumvent Effective Technological Measures. For purposes of this Public License, simply making modifications authorized by this Section 2(a)(4) never produces Adapted Material.
      5. Downstream recipients.
         A. Offer from the Licensor – Licensed Material. Every recipient of the Licensed Material automatically receives an offer from the Licensor to exercise the Licensed Rights under the terms and conditions of this Public License.
         B. Additional offer from the Licensor – Adapted Material. Every recipient of Adapted Material from You automatically receives an offer from the Licensor to exercise the Licensed Rights in the Adapted Material under the conditions of the Adapter&#39;s License You apply.
         C. No downstream restrictions. You may not offer or impose any additional or different terms or conditions on, or apply any Effective Technological Measures to, the Licensed Material if doing so restricts exercise of the Licensed Rights by any recipient of the Licensed Material.
      6. No endorsement. Nothing in this Public License constitutes or may be construed as permission to assert or imply that You are, or that Your use of the Licensed Material is, connected with, or sponsored, endorsed, or granted official status by, the Licensor or others designated to receive attribution as provided in Section 3(a)(1)(A)(i).
   b. Other rights.
      1. Moral rights, such as the right of integrity, are not licensed under this Public License, nor are publicity, privacy, and/or other similar personality rights; however, to the extent possible, the Licensor waives and/or agrees not to assert any such rights held by the Licensor to the limited extent necessary to allow You to exercise the Licensed Rights, but not otherwise.
      2. Patent and trademark rights are not licensed under this Public License.
      3. To the extent possible, the Licensor waives any right to collect royalties from You for the exercise of the Licensed Rights, whether directly or through a collecting society under any voluntary or waivable statutory or compulsory licensing scheme. In all other cases the Licensor expressly reserves any right to collect such royalties.
Section 3 – License Conditions.
Your exercise of the Licensed Rights is expressly made subject to the following conditions.
   a. Attribution.
      1. If You Share the Licensed Material (including in modified form), You must:
         A. retain the following if it is supplied by the Licensor with the Licensed Material:
            i. identification of the creator(s) of the Licensed Material and any others designated to receive attribution, in any reasonable manner requested by the Licensor (including by pseudonym if designated);
            ii. a copyright notice;
            iii. a notice that refers to this Public License;
            iv. a notice that refers to the disclaimer of warranties;
            v. a URI or hyperlink to the Licensed Material to the extent reasonably practicable;
         B. indicate if You modified the Licensed Material and retain an indication of any previous modifications; and
         C. indicate the Licensed Material is licensed under this Public License, and include the text of, or the URI or hyperlink to, this Public License.
      2. You may satisfy the conditions in Section 3(a)(1) in any reasonable manner based on the medium, means, and context in which You Share the Licensed Material. For example, it may be reasonable to satisfy the conditions by providing a URI or hyperlink to a resource that includes the required information.
      3. If requested by the Licensor, You must remove any of the information required by Section 3(a)(1)(A) to the extent reasonably practicable.
   b. ShareAlike.In addition to the conditions in Section 3(a), if You Share Adapted Material You produce, the following conditions also apply.
      1. The Adapter&#39;s License You apply must be a Creative Commons license with the same License Elements, this version or later, or a BY-SA Compatible License.
      2. You must include the text of, or the URI or hyperlink to, the Adapter&#39;s License You apply. You may satisfy this condition in any reasonable manner based on the medium, means, and context in which You Share Adapted Material.
      3. You may not offer or impose any additional or different terms or conditions on, or apply any Effective Technological Measures to, Adapted Material that restrict exercise of the rights granted under the Adapter&#39;s License You apply.
Section 4 – Sui Generis Database Rights.
Where the Licensed Rights include Sui Generis Database Rights that apply to Your use of the Licensed Material:
   a. for the avoidance of doubt, Section 2(a)(1) grants You the right to extract, reuse, reproduce, and Share all or a substantial portion of the contents of the database;
   b. if You include all or a substantial portion of the database contents in a database in which You have Sui Generis Database Rights, then the database in which You have Sui Generis Database Rights (but not its individual contents) is Adapted Material, including for purposes of Section 3(b); and
   c. You must comply with the conditions in Section 3(a) if You Share all or a substantial portion of the contents of the database.
   For the avoidance of doubt, this Section 4 supplements and does not replace Your obligations under this Public License where the Licensed Rights include other Copyright and Similar Rights.
Section 5 – Disclaimer of Warranties and Limitation of Liability.
   a. Unless otherwise separately undertaken by the Licensor, to the extent possible, the Licensor offers the Licensed Material as-is and as-available, and makes no representations or warranties of any kind concerning the Licensed Material, whether express, implied, statutory, or other. This includes, without limitation, warranties of title, merchantability, fitness for a particular purpose, non-infringement, absence of latent or other defects, accuracy, or the presence or absence of errors, whether or not known or discoverable. Where disclaimers of warranties are not allowed in full or in part, this disclaimer may not apply to You.
   b. To the extent possible, in no event will the Licensor be liable to You on any legal theory (including, without limitation, negligence) or otherwise for any direct, special, indirect, incidental, consequential, punitive, exemplary, or other losses, costs, expenses, or damages arising out of this Public License or use of the Licensed Material, even if the Licensor has been advised of the possibility of such losses, costs, expenses, or damages. Where a limitation of liability is not allowed in full or in part, this limitation may not apply to You.
   c. The disclaimer of warranties and limitation of liability provided above shall be interpreted in a manner that, to the extent possible, most closely approximates an absolute disclaimer and waiver of all liability.
Section 6 – Term and Termination.
   a. This Public License applies for the term of the Copyright and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.
   b. Where Your right to use the Licensed Material has terminated under Section 6(a), it reinstates:
      1. automatically as of the date the violation is cured, provided it is cured within 30 days of Your discovery of the violation; or
      2. upon express reinstatement by the Licensor.
   c. For the avoidance of doubt, this Section 6(b) does not affect any right the Licensor may have to seek remedies for Your violations of this Public License.
   d. For the avoidance of doubt, the Licensor may also offer the Licensed Material under separate terms or conditions or stop distributing the Licensed Material at any time; however, doing so will not terminate this Public License.
   e. Sections 1, 5, 6, 7, and 8 survive termination of this Public License.
Section 7 – Other Terms and Conditions.
   a. The Licensor shall not be bound by any additional or different terms or conditions communicated by You unless expressly agreed.
   b. Any arrangements, understandings, or agreements regarding the Licensed Material not stated herein are separate from and independent of the terms and conditions of this Public License.
Section 8 – Interpretation.
   a. For the avoidance of doubt, this Public License does not, and shall not be interpreted to, reduce, limit, restrict, or impose conditions on any use of the Licensed Material that could lawfully be made without permission under this Public License.
   b. To the extent possible, if any provision of this Public License is deemed unenforceable, it shall be automatically reformed to the minimum extent necessary to make it enforceable. If the provision cannot be reformed, it shall be severed from this Public License without affecting the enforceability of the remaining terms and conditions.
   c. No term or condition of this Public License will be waived and no failure to comply consented to unless expressly agreed to by the Licensor.
   d. Nothing in this Public License constitutes or may be interpreted as a limitation upon, or waiver of, any privileges and immunities that apply to the Licensor or You, including from the legal processes of any jurisdiction or authority.
Creative Commons is not a party to its public licenses. Notwithstanding, Creative Commons may elect to apply one of its public licenses to material it publishes and in those instances will be considered the &quot;Licensor.&quot; The text of the Creative Commons public licenses is dedicated to the public domain under the CC0 Public Domain Dedication. Except for the limited purpose of indicating that material is shared under a Creative Commons public license or as otherwise permitted by the Creative Commons policies published at creativecommons.org/policies, Creative Commons does not authorize the use of the trademark &quot;Creative Commons&quot; or any other trademark or logo of Creative Commons without its prior written consent including, without limitation, in connection with any unauthorized modifications to any of its public licenses or any other arrangements, understandings, or agreements concerning use of licensed material. For the avoidance of doubt, this paragraph does not form part of the public licenses.
Creative Commons may be contacted at creativecommons.org.
```


### CC0-1.0

```
Creative Commons Legal Code
CC0 1.0 Universal CREATIVE COMMONS CORPORATION IS NOT A LAW FIRM AND DOES NOT PROVIDE LEGAL SERVICES. DISTRIBUTION OF THIS DOCUMENT DOES NOT CREATE AN ATTORNEY-CLIENT RELATIONSHIP. CREATIVE COMMONS PROVIDES THIS INFORMATION ON AN &quot;AS-IS&quot; BASIS. CREATIVE COMMONS MAKES NO WARRANTIES REGARDING THE USE OF THIS DOCUMENT OR THE INFORMATION OR WORKS PROVIDED HEREUNDER, AND DISCLAIMS LIABILITY FOR DAMAGES RESULTING FROM THE USE OF THIS DOCUMENT OR THE INFORMATION OR WORKS PROVIDED HEREUNDER.
Statement of Purpose
The laws of most jurisdictions throughout the world automatically confer exclusive Copyright and Related Rights (defined below) upon the creator and subsequent owner(s) (each and all, an &quot;owner&quot;) of an original work of authorship and/or a database (each, a &quot;Work&quot;).
Certain owners wish to permanently relinquish those rights to a Work for the purpose of contributing to a commons of creative, cultural and scientific works (&quot;Commons&quot;) that the public can reliably and without fear of later claims of infringement build upon, modify, incorporate in other works, reuse and redistribute as freely as possible in any form whatsoever and for any purposes, including without limitation commercial purposes. These owners may contribute to the Commons to promote the ideal of a free culture and the further production of creative, cultural and scientific works, or to gain reputation or greater distribution for their Work in part through the use and efforts of others.
For these and/or other purposes and motivations, and without any expectation of additional consideration or compensation, the person associating CC0 with a Work (the &quot;Affirmer&quot;), to the extent that he or she is an owner of Copyright and Related Rights in the Work, voluntarily elects to apply CC0 to the Work and publicly distribute the Work under its terms, with knowledge of his or her Copyright and Related Rights in the Work and the meaning and intended legal effect of CC0 on those rights.
   1. Copyright and Related Rights. A Work made available under CC0 may be protected by copyright and related or neighboring rights (&quot;Copyright and Related Rights&quot;). Copyright and Related Rights include, but are not limited to, the following:
      i. the right to reproduce, adapt, distribute, perform, display, communicate, and translate a Work;
      ii. moral rights retained by the original author(s) and/or performer(s);
      iii. publicity and privacy rights pertaining to a person&#39;s image or likeness depicted in a Work;
      iv. rights protecting against unfair competition in regards to a Work, subject to the limitations in paragraph 4(a), below;
      v. rights protecting the extraction, dissemination, use and reuse of data in a Work;
      vi. database rights (such as those arising under Directive 96/9/EC of the European Parliament and of the Council of 11 March 1996 on the legal protection of databases, and under any national implementation thereof, including any amended or successor version of such directive); and
      vii. other similar, equivalent or corresponding rights throughout the world based on applicable law or treaty, and any national implementations thereof.
   2. Waiver. To the greatest extent permitted by, but not in contravention of, applicable law, Affirmer hereby overtly, fully, permanently, irrevocably and unconditionally waives, abandons, and surrenders all of Affirmer&#39;s Copyright and Related Rights and associated claims and causes of action, whether now known or unknown (including existing as well as future claims and causes of action), in the Work (i) in all territories worldwide, (ii) for the maximum duration provided by applicable law or treaty (including future time extensions), (iii) in any current or future medium and for any number of copies, and (iv) for any purpose whatsoever, including without limitation commercial, advertising or promotional purposes (the &quot;Waiver&quot;). Affirmer makes the Waiver for the benefit of each member of the public at large and to the detriment of Affirmer&#39;s heirs and successors, fully intending that such Waiver shall not be subject to revocation, rescission, cancellation, termination, or any other legal or equitable action to disrupt the quiet enjoyment of the Work by the public as contemplated by Affirmer&#39;s express Statement of Purpose.
   3. Public License Fallback. Should any part of the Waiver for any reason be judged legally invalid or ineffective under applicable law, then the Waiver shall be preserved to the maximum extent permitted taking into account Affirmer&#39;s express Statement of Purpose. In addition, to the extent the Waiver is so judged Affirmer hereby grants to each affected person a royalty-free, non transferable, non sublicensable, non exclusive, irrevocable and unconditional license to exercise Affirmer&#39;s Copyright and Related Rights in the Work (i) in all territories worldwide, (ii) for the maximum duration provided by applicable law or treaty (including future time extensions), (iii) in any current or future medium and for any number of copies, and (iv) for any purpose whatsoever, including without limitation commercial, advertising or promotional purposes (the &quot;License&quot;). The License shall be deemed effective as of the date CC0 was applied by Affirmer to the Work. Should any part of the License for any reason be judged legally invalid or ineffective under applicable law, such partial invalidity or ineffectiveness shall not invalidate the remainder of the License, and in such case Affirmer hereby affirms that he or she will not (i) exercise any of his or her remaining Copyright and Related Rights in the Work or (ii) assert any associated claims and causes of action with respect to the Work, in either case contrary to Affirmer&#39;s express Statement of Purpose.
   4. Limitations and Disclaimers.
      a. No trademark or patent rights held by Affirmer are waived, abandoned, surrendered, licensed or otherwise affected by this document.
      b. Affirmer offers the Work as-is and makes no representations or warranties of any kind concerning the Work, express, implied, statutory or otherwise, including without limitation warranties of title, merchantability, fitness for a particular purpose, non infringement, or the absence of latent or other defects, accuracy, or the present or absence of errors, whether or not discoverable, all to the greatest extent permissible under applicable law.
      c. Affirmer disclaims responsibility for clearing rights of other persons that may apply to the Work or any use thereof, including without limitation any person&#39;s Copyright and Related Rights in the Work. Further, Affirmer disclaims responsibility for obtaining any necessary consents, permissions or other rights required for any use of the Work.
      d. Affirmer understands and acknowledges that Creative Commons is not a party to this document and has no duty or obligation with respect to this CC0 or use of the Work.
```


### CNRI-Python

```
CNRI OPEN SOURCE LICENSE AGREEMENT
IMPORTANT: PLEASE READ THE FOLLOWING AGREEMENT CAREFULLY.
BY CLICKING ON &quot;ACCEPT&quot; WHERE INDICATED BELOW, OR BY COPYING, INSTALLING OR OTHERWISE USING PYTHON 1.6, beta 1 SOFTWARE, YOU ARE DEEMED TO HAVE AGREED TO THE TERMS AND CONDITIONS OF THIS LICENSE AGREEMENT.
   1. This LICENSE AGREEMENT is between the Corporation for National Research Initiatives, having an office at 1895 Preston White Drive, Reston, VA 20191 (&quot;CNRI&quot;), and the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using Python 1.6, beta 1 software in source or binary form and its associated documentation, as released at the www.python.org Internet site on August 4, 2000 (&quot;Python 1.6b1&quot;).
   2. Subject to the terms and conditions of this License Agreement, CNRI hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python 1.6b1 alone or in any derivative version, provided, however, that CNRIs License Agreement is retained in Python 1.6b1, alone or in any derivative version prepared by Licensee.
   Alternately, in lieu of CNRIs License Agreement, Licensee may substitute the following text (omitting the quotes): &quot;Python 1.6, beta 1, is made available subject to the terms and conditions in CNRIs License Agreement. This Agreement may be located on the Internet using the following unique, persistent identifier (known as a handle): 1895.22/1011. This Agreement may also be obtained from a proxy server on the Internet using the URL:http://hdl.handle.net/1895.22/1011&quot;.
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python 1.6b1 or any part thereof, and wants to make the derivative work available to the public as provided herein, then Licensee hereby agrees to indicate in any such work the nature of the modifications made to Python 1.6b1.
   4. CNRI is making Python 1.6b1 available to Licensee on an &quot;AS IS&quot; basis. CNRI MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, CNRI MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON 1.6b1 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. CNRI SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING PYTHON 1.6b1, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. This License Agreement shall be governed by and interpreted in all respects by the law of the State of Virginia, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between CNRI and Licensee. This License Agreement does not grant permission to use CNRI trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By clicking on the &quot;ACCEPT&quot; button where indicated, or by copying, installing or otherwise using Python 1.6b1, Licensee agrees to be bound by the terms and conditions of this License Agreement.
ACCEPT
```


### MIT

```
Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the &quot;Software&quot;),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.

```


### MIT

```
Copyright (c) 2008-2011 Volvox Development Team

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```


### BSD-3-Clause

```
Copyright (c) 2010 Jonathan Hartley
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

* Neither the name of the copyright holders, nor those of its contributors
  may be used to endorse or promote products derived from this software without
  specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot; AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```


### MIT

```
Copyright (c) 2010-2024 Benjamin Peterson

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the &quot;Software&quot;), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

```


### MIT

```
Copyright (c) 2011-2020 Sergey Astanin and contributors

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
&quot;Software&quot;), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

```


### MIT

```
Copyright (c) 2011-2020 Sergey Astanin and contributors

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
&quot;Software&quot;), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

```


### MIT

```
Copyright (c) 2012 Erik Rose

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the &quot;Software&quot;), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```


### BSD-2-Clause

```
Copyright (c) 2012, Bryce Boe
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot; AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```


### MIT

```
Copyright (c) 2013 Julian Berman

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```


### BSD-3-Clause

```
Copyright (c) 2016, Andi Albrecht &lt;albrecht.andi@gmail.com&gt;
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.
    * Neither the name of the authors nor the names of its contributors may be
      used to endorse or promote products derived from this software without
      specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot; AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```


### MIT

```
Copyright (c) 2022 Julian Berman

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```


### MIT

```
Copyright (c) 2023 Julian Berman

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```


### BSD-2-Clause

```
Copyright (c) Donald Stufft and individual contributors.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    1. Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.

    2. Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot; AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```


### BSD-3-Clause

```
Copyright 2007 Pallets

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1.  Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

2.  Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.

3.  Neither the name of the copyright holder nor the names of its
    contributors may be used to endorse or promote products derived from
    this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
&quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```


### Protobuf

```
Copyright 2008 Google Inc.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.
    * Neither the name of Google Inc. nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
&quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Code generated by the Protocol Buffer compiler is owned by the owner
of the input file used when generating it.  This code is not
standalone and requires a support library to be linked with it.  This
support library is itself covered by the above license.

```


### BSD-3-Clause

```
Copyright 2010 Pallets

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1.  Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

2.  Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.

3.  Neither the name of the copyright holder nor the names of its
    contributors may be used to endorse or promote products derived from
    this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
&quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```


### BSD-3-Clause

```
Copyright 2014 Pallets

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1.  Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

2.  Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.

3.  Neither the name of the copyright holder nor the names of its
    contributors may be used to endorse or promote products derived from
    this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
&quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```


### Apache-2.0

```
Copyright 2017- Paul Ganssle &lt;paul@ganssle.io&gt;
Copyright 2017- dateutil contributors (see AUTHORS file)

   Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

The above license applies to all contributions after 2017-12-01, as well as
all contributions that have been re-licensed (see AUTHORS file for the list of
contributors who have re-licensed their code).
--------------------------------------------------------------------------------
dateutil - Extensions to the standard Python datetime module.

Copyright (c) 2003-2011 - Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;
Copyright (c) 2012-2014 - Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;
Copyright (c) 2014-2016 - Yaron de Leeuw &lt;me@jarondl.net&gt;
Copyright (c) 2015-     - Paul Ganssle &lt;paul@ganssle.io&gt;
Copyright (c) 2015-     - dateutil contributors (see AUTHORS file)

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.
    * Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
&quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The above BSD License Applies to all code, even that also covered by Apache 2.0.
```


### MIT

```
Copyright © 2020-present Max Bachmann
Copyright © 2011 Adam Cohen

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
&quot;Software&quot;), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

```


### GPL-1.0-only

```
GNU GENERAL PUBLIC LICENSE
Version 1, February 1989
Copyright (C) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The license agreements of most software companies try to keep users at the mercy of those companies. By contrast, our General Public License is intended to guarantee your freedom to share and change free software--to make sure the software is free for all its users. The General Public License applies to the Free Software Foundation&#39;s software and to any other program whose authors commit to using it. You can use it for your programs, too.
When we speak of free software, we are referring to freedom, not price. Specifically, the General Public License is designed to make sure that you have the freedom to give away or sell copies of free software, that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs; and that you know you can do these things.
To protect your rights, we need to make restrictions that forbid anyone to deny you these rights or to ask you to surrender the rights. These restrictions translate to certain responsibilities for you if you distribute copies of the software, or if you modify it.
For example, if you distribute copies of a such a program, whether gratis or for a fee, you must give the recipients all the rights that you have. You must make sure that they, too, receive or can get the source code. And you must tell them their rights.
We protect your rights with two steps: (1) copyright the software, and (2) offer you this license which gives you legal permission to copy, distribute and/or modify the software.
Also, for each author&#39;s protection and ours, we want to make certain that everyone understands that there is no warranty for this free software. If the software is modified by someone else and passed on, we want its recipients to know that what they have is not the original, so that any problems introduced by others will not reflect on the original authors&#39; reputations.
The precise terms and conditions for copying, distribution and modification follow.
GNU GENERAL PUBLIC LICENSE TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
   
   0. This License Agreement applies to any program or other work which contains a notice placed by the copyright holder saying it may be distributed under the terms of this General Public License. The &quot;Program&quot;, below, refers to any such program or work, and a &quot;work based on the Program&quot; means either the Program or any work containing the Program or a portion of it, either verbatim or with modifications. Each licensee is addressed as &quot;you&quot;.
   
   1. You may copy and distribute verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice and disclaimer of warranty; keep intact all the notices that refer to this General Public License and to the absence of any warranty; and give any other recipients of the Program a copy of this General Public License along with the Program. You may charge a fee for the physical act of transferring a copy.
   
   2. You may modify your copy or copies of the Program or any portion of it, and copy and distribute such modifications under the terms of Paragraph 1 above, provided that you also do the following:
      a) cause the modified files to carry prominent notices stating that you changed the files and the date of any change; and
      b) cause the whole of any work that you distribute or publish, that in whole or in part contains the Program or any part thereof, either with or without modifications, to be licensed at no charge to all third parties under the terms of this General Public License (except that you may choose to grant warranty protection to some or all third parties, at your option).
      c) If the modified program normally reads commands interactively when run, you must cause it, when started running for such interactive use in the simplest and most usual way, to print or display an announcement including an appropriate copyright notice and a notice that there is no warranty (or else, saying that you provide a warranty) and that users may redistribute the program under these conditions, and telling the user how to view a copy of this General Public License.
      d) You may charge a fee for the physical act of transferring a copy, and you may at your option offer warranty protection in exchange for a fee.
   Mere aggregation of another independent work with the Program (or its derivative) on a volume of a storage or distribution medium does not bring the other work under the scope of these terms.
   
   3. You may copy and distribute the Program (or a portion or derivative of it, under Paragraph 2) in object code or executable form under the terms of Paragraphs 1 and 2 above provided that you also do one of the following:
      a) accompany it with the complete corresponding machine-readable source code, which must be distributed under the terms of Paragraphs 1 and 2 above; or,
      b) accompany it with a written offer, valid for at least three years, to give any third party free (except for a nominal charge for the cost of distribution) a complete machine-readable copy of the corresponding source code, to be distributed under the terms of Paragraphs 1 and 2 above; or,
      c) accompany it with the information you received as to where the corresponding source code may be obtained. (This alternative is allowed only for noncommercial distribution and only if you received the program in object code or executable form alone.)
   Source code for a work means the preferred form of the work for making modifications to it. For an executable file, complete source code means all the source code for all modules it contains; but, as a special exception, it need not include source code for modules which are standard libraries that accompany the operating system on which the executable file runs, or for standard header files or definitions files that accompany that operating system.
   
   4. You may not copy, modify, sublicense, distribute or transfer the Program except as expressly provided under this General Public License. Any attempt otherwise to copy, modify, sublicense, distribute or transfer the Program is void, and will automatically terminate your rights to use the Program under this License. However, parties who have received copies, or rights to use copies, from you under this General Public License will not have their licenses terminated so long as such parties remain in full compliance.
   
   5. By copying, distributing or modifying the Program (or any work based on the Program) you indicate your acceptance of this license to do so, and all its terms and conditions.
   
   6. Each time you redistribute the Program (or any work based on the Program), the recipient automatically receives a license from the original licensor to copy, distribute or modify the Program subject to these terms and conditions. You may not impose any further restrictions on the recipients&#39; exercise of the rights granted herein.
   
   7. The Free Software Foundation may publish revised and/or new versions of the General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies a version number of the license which applies to it and &quot;any later version&quot;, you have the option of following the terms and conditions either of that version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of the license, you may choose any version ever published by the Free Software Foundation.
   
   8. If you wish to incorporate parts of the Program into other free programs whose distribution conditions are different, write to the author to ask for permission. For software which is copyrighted by the Free Software Foundation, write to the Free Software Foundation; we sometimes make exceptions for this. Our decision will be guided by the two goals of preserving the free status of all derivatives of our free software and of promoting the sharing and reuse of software generally.
   
   NO WARRANTY
   9. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   
   10. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. END OF TERMS AND CONDITIONS
Appendix: How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to humanity, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively convey the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt;one line to give the program&#39;s name and a brief idea of what it does.&gt; Copyright (C) 19yy &lt;name of author&gt;
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 1, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
Also add information on how to contact you by electronic and paper mail.
If the program is interactive, make it output a short notice like this when it starts in an interactive mode:
Gnomovision version 69, Copyright (C) 19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, the commands you use may be called something other than `show w&#39; and `show c&#39;; they could even be mouse-clicks or menu items--whatever suits your program.
You should also get your employer (if you work as a programmer) or your school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. Here a sample; alter the names:
Yoyodyne, Inc., hereby disclaims all copyright interest in the program `Gnomovision&#39; (a program to direct compilers to make passes at assemblers) written by James Hacker.
&lt;signature of Ty Coon&gt;, 1 April 1989 Ty Coon, President of Vice
That&#39;s all there is to it!
```


### GPL-1.0-or-later

```
GNU GENERAL PUBLIC LICENSE
Version 1, February 1989
Copyright (C) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The license agreements of most software companies try to keep users at the mercy of those companies. By contrast, our General Public License is intended to guarantee your freedom to share and change free software--to make sure the software is free for all its users. The General Public License applies to the Free Software Foundation&#39;s software and to any other program whose authors commit to using it. You can use it for your programs, too.
When we speak of free software, we are referring to freedom, not price. Specifically, the General Public License is designed to make sure that you have the freedom to give away or sell copies of free software, that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs; and that you know you can do these things.
To protect your rights, we need to make restrictions that forbid anyone to deny you these rights or to ask you to surrender the rights. These restrictions translate to certain responsibilities for you if you distribute copies of the software, or if you modify it.
For example, if you distribute copies of a such a program, whether gratis or for a fee, you must give the recipients all the rights that you have. You must make sure that they, too, receive or can get the source code. And you must tell them their rights.
We protect your rights with two steps: (1) copyright the software, and (2) offer you this license which gives you legal permission to copy, distribute and/or modify the software.
Also, for each author&#39;s protection and ours, we want to make certain that everyone understands that there is no warranty for this free software. If the software is modified by someone else and passed on, we want its recipients to know that what they have is not the original, so that any problems introduced by others will not reflect on the original authors&#39; reputations.
The precise terms and conditions for copying, distribution and modification follow.
GNU GENERAL PUBLIC LICENSE TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
   0. This License Agreement applies to any program or other work which contains a notice placed by the copyright holder saying it may be distributed under the terms of this General Public License. The &quot;Program&quot;, below, refers to any such program or work, and a &quot;work based on the Program&quot; means either the Program or any work containing the Program or a portion of it, either verbatim or with modifications. Each licensee is addressed as &quot;you&quot;.
   1. You may copy and distribute verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice and disclaimer of warranty; keep intact all the notices that refer to this General Public License and to the absence of any warranty; and give any other recipients of the Program a copy of this General Public License along with the Program. You may charge a fee for the physical act of transferring a copy.
   2. You may modify your copy or copies of the Program or any portion of it, and copy and distribute such modifications under the terms of Paragraph 1 above, provided that you also do the following:
      a) cause the modified files to carry prominent notices stating that you changed the files and the date of any change; and
      b) cause the whole of any work that you distribute or publish, that in whole or in part contains the Program or any part thereof, either with or without modifications, to be licensed at no charge to all third parties under the terms of this General Public License (except that you may choose to grant warranty protection to some or all third parties, at your option).
      c) If the modified program normally reads commands interactively when run, you must cause it, when started running for such interactive use in the simplest and most usual way, to print or display an announcement including an appropriate copyright notice and a notice that there is no warranty (or else, saying that you provide a warranty) and that users may redistribute the program under these conditions, and telling the user how to view a copy of this General Public License.
      d) You may charge a fee for the physical act of transferring a copy, and you may at your option offer warranty protection in exchange for a fee.
   Mere aggregation of another independent work with the Program (or its derivative) on a volume of a storage or distribution medium does not bring the other work under the scope of these terms.
   3. You may copy and distribute the Program (or a portion or derivative of it, under Paragraph 2) in object code or executable form under the terms of Paragraphs 1 and 2 above provided that you also do one of the following:
      a) accompany it with the complete corresponding machine-readable source code, which must be distributed under the terms of Paragraphs 1 and 2 above; or,
      b) accompany it with a written offer, valid for at least three years, to give any third party free (except for a nominal charge for the cost of distribution) a complete machine-readable copy of the corresponding source code, to be distributed under the terms of Paragraphs 1 and 2 above; or,
      c) accompany it with the information you received as to where the corresponding source code may be obtained. (This alternative is allowed only for noncommercial distribution and only if you received the program in object code or executable form alone.)
   Source code for a work means the preferred form of the work for making modifications to it. For an executable file, complete source code means all the source code for all modules it contains; but, as a special exception, it need not include source code for modules which are standard libraries that accompany the operating system on which the executable file runs, or for standard header files or definitions files that accompany that operating system.
   4. You may not copy, modify, sublicense, distribute or transfer the Program except as expressly provided under this General Public License. Any attempt otherwise to copy, modify, sublicense, distribute or transfer the Program is void, and will automatically terminate your rights to use the Program under this License. However, parties who have received copies, or rights to use copies, from you under this General Public License will not have their licenses terminated so long as such parties remain in full compliance.
   5. By copying, distributing or modifying the Program (or any work based on the Program) you indicate your acceptance of this license to do so, and all its terms and conditions.
   6. Each time you redistribute the Program (or any work based on the Program), the recipient automatically receives a license from the original licensor to copy, distribute or modify the Program subject to these terms and conditions. You may not impose any further restrictions on the recipients&#39; exercise of the rights granted herein.
   7. The Free Software Foundation may publish revised and/or new versions of the General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies a version number of the license which applies to it and &quot;any later version&quot;, you have the option of following the terms and conditions either of that version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of the license, you may choose any version ever published by the Free Software Foundation.
   8. If you wish to incorporate parts of the Program into other free programs whose distribution conditions are different, write to the author to ask for permission. For software which is copyrighted by the Free Software Foundation, write to the Free Software Foundation; we sometimes make exceptions for this. Our decision will be guided by the two goals of preserving the free status of all derivatives of our free software and of promoting the sharing and reuse of software generally.
   
   NO WARRANTY 9.
   BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   10. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. END OF TERMS AND CONDITIONS
Appendix: How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to humanity, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively convey the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt;one line to give the program&#39;s name and a brief idea of what it does.&gt; Copyright (C) 19yy &lt;name of author&gt;
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 1, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
Also add information on how to contact you by electronic and paper mail.
If the program is interactive, make it output a short notice like this when it starts in an interactive mode:
Gnomovision version 69, Copyright (C) 19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, the commands you use may be called something other than `show w&#39; and `show c&#39;; they could even be mouse-clicks or menu items--whatever suits your program.
You should also get your employer (if you work as a programmer) or your school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. Here a sample; alter the names:
Yoyodyne, Inc., hereby disclaims all copyright interest in the program `Gnomovision&#39; (a program to direct compilers to make passes at assemblers) written by James Hacker.
&lt;signature of Ty Coon&gt;, 1 April 1989 Ty Coon, President of Vice
That&#39;s all there is to it!
```


### GPL-2.0-only

```
GNU GENERAL PUBLIC LICENSE
Version 2, June 1991
Copyright (C) 1989, 1991 Free Software Foundation, Inc.
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 , USA
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The licenses for most software are designed to take away your freedom to share and change it. By contrast, the GNU General Public License is intended to guarantee your freedom to share and change free software--to make sure the software is free for all its users. This General Public License applies to most of the Free Software Foundation&#39;s software and to any other program whose authors commit to using it. (Some other Free Software Foundation software is covered by the GNU Lesser General Public License instead.) You can apply it to your programs, too.
When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for this service if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs; and that you know you can do these things.
To protect your rights, we need to make restrictions that forbid anyone to deny you these rights or to ask you to surrender the rights. These restrictions translate to certain responsibilities for you if you distribute copies of the software, or if you modify it.
For example, if you distribute copies of such a program, whether gratis or for a fee, you must give the recipients all the rights that you have. You must make sure that they, too, receive or can get the source code. And you must show them these terms so they know their rights.
We protect your rights with two steps: (1) copyright the software, and (2) offer you this license which gives you legal permission to copy, distribute and/or modify the software.
Also, for each author&#39;s protection and ours, we want to make certain that everyone understands that there is no warranty for this free software. If the software is modified by someone else and passed on, we want its recipients to know that what they have is not the original, so that any problems introduced by others will not reflect on the original authors&#39; reputations.
Finally, any free program is threatened constantly by software patents. We wish to avoid the danger that redistributors of a free program will individually obtain patent licenses, in effect making the program proprietary. To prevent this, we have made it clear that any patent must be licensed for everyone&#39;s free use or not licensed at all.
The precise terms and conditions for copying, distribution and modification follow.
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
   0. This License applies to any program or other work which contains a notice placed by the copyright holder saying it may be distributed under the terms of this General Public License. The &quot;Program&quot;, below, refers to any such program or work, and a &quot;work based on the Program&quot; means either the Program or any derivative work under copyright law: that is to say, a work containing the Program or a portion of it, either verbatim or with modifications and/or translated into another language. (Hereinafter, translation is included without limitation in the term &quot;modification&quot;.) Each licensee is addressed as &quot;you&quot;.
   Activities other than copying, distribution and modification are not covered by this License; they are outside its scope. The act of running the Program is not restricted, and the output from the Program is covered only if its contents constitute a work based on the Program (independent of having been made by running the Program). Whether that is true depends on what the Program does.
   1. You may copy and distribute verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice and disclaimer of warranty; keep intact all the notices that refer to this License and to the absence of any warranty; and give any other recipients of the Program a copy of this License along with the Program.
   You may charge a fee for the physical act of transferring a copy, and you may at your option offer warranty protection in exchange for a fee.
   2. You may modify your copy or copies of the Program or any portion of it, thus forming a work based on the Program, and copy and distribute such modifications or work under the terms of Section 1 above, provided that you also meet all of these conditions:
      a) You must cause the modified files to carry prominent notices stating that you changed the files and the date of any change.
      b) You must cause any work that you distribute or publish, that in whole or in part contains or is derived from the Program or any part thereof, to be licensed as a whole at no charge to all third parties under the terms of this License.
      c) If the modified program normally reads commands interactively when run, you must cause it, when started running for such interactive use in the most ordinary way, to print or display an announcement including an appropriate copyright notice and a notice that there is no warranty (or else, saying that you provide a warranty) and that users may redistribute the program under these conditions, and telling the user how to view a copy of this License. (Exception: if the Program itself is interactive but does not normally print such an announcement, your work based on the Program is not required to print an announcement.)
   These requirements apply to the modified work as a whole. If identifiable sections of that work are not derived from the Program, and can be reasonably considered independent and separate works in themselves, then this License, and its terms, do not apply to those sections when you distribute them as separate works. But when you distribute the same sections as part of a whole which is a work based on the Program, the distribution of the whole must be on the terms of this License, whose permissions for other licensees extend to the entire whole, and thus to each and every part regardless of who wrote it.
   Thus, it is not the intent of this section to claim rights or contest your rights to work written entirely by you; rather, the intent is to exercise the right to control the distribution of derivative or collective works based on the Program.
   In addition, mere aggregation of another work not based on the Program with the Program (or with a work based on the Program) on a volume of a storage or distribution medium does not bring the other work under the scope of this License.
   3. You may copy and distribute the Program (or a work based on it, under Section 2) in object code or executable form under the terms of Sections 1 and 2 above provided that you also do one of the following:
      a) Accompany it with the complete corresponding machine-readable source code, which must be distributed under the terms of Sections 1 and 2 above on a medium customarily used for software interchange; or,
      b) Accompany it with a written offer, valid for at least three years, to give any third party, for a charge no more than your cost of physically performing source distribution, a complete machine-readable copy of the corresponding source code, to be distributed under the terms of Sections 1 and 2 above on a medium customarily used for software interchange; or,
      c) Accompany it with the information you received as to the offer to distribute corresponding source code. (This alternative is allowed only for noncommercial distribution and only if you received the program in object code or executable form with such an offer, in accord with Subsection b above.)
   The source code for a work means the preferred form of the work for making modifications to it. For an executable work, complete source code means all the source code for all modules it contains, plus any associated interface definition files, plus the scripts used to control compilation and installation of the executable. However, as a special exception, the source code distributed need not include anything that is normally distributed (in either source or binary form) with the major components (compiler, kernel, and so on) of the operating system on which the executable runs, unless that component itself accompanies the executable.
   If distribution of executable or object code is made by offering access to copy from a designated place, then offering equivalent access to copy the source code from the same place counts as distribution of the source code, even though third parties are not compelled to copy the source along with the object code.
   4. You may not copy, modify, sublicense, or distribute the Program except as expressly provided under this License. Any attempt otherwise to copy, modify, sublicense or distribute the Program is void, and will automatically terminate your rights under this License. However, parties who have received copies, or rights, from you under this License will not have their licenses terminated so long as such parties remain in full compliance.
   5. You are not required to accept this License, since you have not signed it. However, nothing else grants you permission to modify or distribute the Program or its derivative works. These actions are prohibited by law if you do not accept this License. Therefore, by modifying or distributing the Program (or any work based on the Program), you indicate your acceptance of this License to do so, and all its terms and conditions for copying, distributing or modifying the Program or works based on it.
   6. Each time you redistribute the Program (or any work based on the Program), the recipient automatically receives a license from the original licensor to copy, distribute or modify the Program subject to these terms and conditions. You may not impose any further restrictions on the recipients&#39; exercise of the rights granted herein. You are not responsible for enforcing compliance by third parties to this License.
   7. If, as a consequence of a court judgment or allegation of patent infringement or for any other reason (not limited to patent issues), conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot distribute so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may not distribute the Program at all. For example, if a patent license would not permit royalty-free redistribution of the Program by all those who receive copies directly or indirectly through you, then the only way you could satisfy both it and this License would be to refrain entirely from distribution of the Program.
   If any portion of this section is held invalid or unenforceable under any particular circumstance, the balance of the section is intended to apply and the section as a whole is intended to apply in other circumstances.
   It is not the purpose of this section to induce you to infringe any patents or other property right claims or to contest validity of any such claims; this section has the sole purpose of protecting the integrity of the free software distribution system, which is implemented by public license practices. Many people have made generous contributions to the wide range of software distributed through that system in reliance on consistent application of that system; it is up to the author/donor to decide if he or she is willing to distribute software through any other system and a licensee cannot impose that choice.
   This section is intended to make thoroughly clear what is believed to be a consequence of the rest of this License.
   8. If the distribution and/or use of the Program is restricted in certain countries either by patents or by copyrighted interfaces, the original copyright holder who places the Program under this License may add an explicit geographical distribution limitation excluding those countries, so that distribution is permitted only in or among countries not thus excluded. In such case, this License incorporates the limitation as if written in the body of this License.
   9. The Free Software Foundation may publish revised and/or new versions of the General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies a version number of this License which applies to it and &quot;any later version&quot;, you have the option of following the terms and conditions either of that version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of this License, you may choose any version ever published by the Free Software Foundation.
   10. If you wish to incorporate parts of the Program into other free programs whose distribution conditions are different, write to the author to ask for permission. For software which is copyrighted by the Free Software Foundation, write to the Free Software Foundation; we sometimes make exceptions for this. Our decision will be guided by the two goals of preserving the free status of all derivatives of our free software and of promoting the sharing and reuse of software generally.
   NO WARRANTY
   11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. END OF TERMS AND CONDITIONS
How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively convey the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt; one line to give the program&#39;s name and an idea of what it does. &gt;
Copyright (C) &lt; yyyy &gt; &lt; name of author &gt;
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 , USA. Also add information on how to contact you by electronic and paper mail.
If the program is interactive, make it output a short notice like this when it starts in an interactive mode:
Gnomovision version 69, Copyright (C) year name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, the commands you use may be called something other than `show w&#39; and `show c&#39;; they could even be mouse-clicks or menu items--whatever suits your program.
You should also get your employer (if you work as a programmer) or your school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. Here is a sample; alter the names:
Yoyodyne, Inc., hereby disclaims all copyright interest in the program `Gnomovision&#39; (which makes passes at compilers) written by James Hacker.
&lt; signature of Ty Coon &gt; , 1 April 1989 Ty Coon, President of Vice
```


### GPL-2.0-or-later

```
GNU GENERAL PUBLIC LICENSE
Version 2, June 1991
Copyright (C) 1989, 1991 Free Software Foundation, Inc.
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 , USA
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The licenses for most software are designed to take away your freedom to share and change it. By contrast, the GNU General Public License is intended to guarantee your freedom to share and change free software--to make sure the software is free for all its users. This General Public License applies to most of the Free Software Foundation&#39;s software and to any other program whose authors commit to using it. (Some other Free Software Foundation software is covered by the GNU Lesser General Public License instead.) You can apply it to your programs, too.
When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for this service if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs; and that you know you can do these things.
To protect your rights, we need to make restrictions that forbid anyone to deny you these rights or to ask you to surrender the rights. These restrictions translate to certain responsibilities for you if you distribute copies of the software, or if you modify it.
For example, if you distribute copies of such a program, whether gratis or for a fee, you must give the recipients all the rights that you have. You must make sure that they, too, receive or can get the source code. And you must show them these terms so they know their rights.
We protect your rights with two steps: (1) copyright the software, and (2) offer you this license which gives you legal permission to copy, distribute and/or modify the software.
Also, for each author&#39;s protection and ours, we want to make certain that everyone understands that there is no warranty for this free software. If the software is modified by someone else and passed on, we want its recipients to know that what they have is not the original, so that any problems introduced by others will not reflect on the original authors&#39; reputations.
Finally, any free program is threatened constantly by software patents. We wish to avoid the danger that redistributors of a free program will individually obtain patent licenses, in effect making the program proprietary. To prevent this, we have made it clear that any patent must be licensed for everyone&#39;s free use or not licensed at all.
The precise terms and conditions for copying, distribution and modification follow.
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
   0. This License applies to any program or other work which contains a notice placed by the copyright holder saying it may be distributed under the terms of this General Public License. The &quot;Program&quot;, below, refers to any such program or work, and a &quot;work based on the Program&quot; means either the Program or any derivative work under copyright law: that is to say, a work containing the Program or a portion of it, either verbatim or with modifications and/or translated into another language. (Hereinafter, translation is included without limitation in the term &quot;modification&quot;.) Each licensee is addressed as &quot;you&quot;.
   Activities other than copying, distribution and modification are not covered by this License; they are outside its scope. The act of running the Program is not restricted, and the output from the Program is covered only if its contents constitute a work based on the Program (independent of having been made by running the Program). Whether that is true depends on what the Program does.
   1. You may copy and distribute verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice and disclaimer of warranty; keep intact all the notices that refer to this License and to the absence of any warranty; and give any other recipients of the Program a copy of this License along with the Program.
   You may charge a fee for the physical act of transferring a copy, and you may at your option offer warranty protection in exchange for a fee.
   2. You may modify your copy or copies of the Program or any portion of it, thus forming a work based on the Program, and copy and distribute such modifications or work under the terms of Section 1 above, provided that you also meet all of these conditions:
      a) You must cause the modified files to carry prominent notices stating that you changed the files and the date of any change.
      b) You must cause any work that you distribute or publish, that in whole or in part contains or is derived from the Program or any part thereof, to be licensed as a whole at no charge to all third parties under the terms of this License.
      c) If the modified program normally reads commands interactively when run, you must cause it, when started running for such interactive use in the most ordinary way, to print or display an announcement including an appropriate copyright notice and a notice that there is no warranty (or else, saying that you provide a warranty) and that users may redistribute the program under these conditions, and telling the user how to view a copy of this License. (Exception: if the Program itself is interactive but does not normally print such an announcement, your work based on the Program is not required to print an announcement.)
   These requirements apply to the modified work as a whole. If identifiable sections of that work are not derived from the Program, and can be reasonably considered independent and separate works in themselves, then this License, and its terms, do not apply to those sections when you distribute them as separate works. But when you distribute the same sections as part of a whole which is a work based on the Program, the distribution of the whole must be on the terms of this License, whose permissions for other licensees extend to the entire whole, and thus to each and every part regardless of who wrote it.
   Thus, it is not the intent of this section to claim rights or contest your rights to work written entirely by you; rather, the intent is to exercise the right to control the distribution of derivative or collective works based on the Program.
   In addition, mere aggregation of another work not based on the Program with the Program (or with a work based on the Program) on a volume of a storage or distribution medium does not bring the other work under the scope of this License.
   3. You may copy and distribute the Program (or a work based on it, under Section 2) in object code or executable form under the terms of Sections 1 and 2 above provided that you also do one of the following:
      a) Accompany it with the complete corresponding machine-readable source code, which must be distributed under the terms of Sections 1 and 2 above on a medium customarily used for software interchange; or,
      b) Accompany it with a written offer, valid for at least three years, to give any third party, for a charge no more than your cost of physically performing source distribution, a complete machine-readable copy of the corresponding source code, to be distributed under the terms of Sections 1 and 2 above on a medium customarily used for software interchange; or,
      c) Accompany it with the information you received as to the offer to distribute corresponding source code. (This alternative is allowed only for noncommercial distribution and only if you received the program in object code or executable form with such an offer, in accord with Subsection b above.)
   The source code for a work means the preferred form of the work for making modifications to it. For an executable work, complete source code means all the source code for all modules it contains, plus any associated interface definition files, plus the scripts used to control compilation and installation of the executable. However, as a special exception, the source code distributed need not include anything that is normally distributed (in either source or binary form) with the major components (compiler, kernel, and so on) of the operating system on which the executable runs, unless that component itself accompanies the executable.
   If distribution of executable or object code is made by offering access to copy from a designated place, then offering equivalent access to copy the source code from the same place counts as distribution of the source code, even though third parties are not compelled to copy the source along with the object code.
   4. You may not copy, modify, sublicense, or distribute the Program except as expressly provided under this License. Any attempt otherwise to copy, modify, sublicense or distribute the Program is void, and will automatically terminate your rights under this License. However, parties who have received copies, or rights, from you under this License will not have their licenses terminated so long as such parties remain in full compliance.
   5. You are not required to accept this License, since you have not signed it. However, nothing else grants you permission to modify or distribute the Program or its derivative works. These actions are prohibited by law if you do not accept this License. Therefore, by modifying or distributing the Program (or any work based on the Program), you indicate your acceptance of this License to do so, and all its terms and conditions for copying, distributing or modifying the Program or works based on it.
   6. Each time you redistribute the Program (or any work based on the Program), the recipient automatically receives a license from the original licensor to copy, distribute or modify the Program subject to these terms and conditions. You may not impose any further restrictions on the recipients&#39; exercise of the rights granted herein. You are not responsible for enforcing compliance by third parties to this License.
   7. If, as a consequence of a court judgment or allegation of patent infringement or for any other reason (not limited to patent issues), conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot distribute so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may not distribute the Program at all. For example, if a patent license would not permit royalty-free redistribution of the Program by all those who receive copies directly or indirectly through you, then the only way you could satisfy both it and this License would be to refrain entirely from distribution of the Program.
   If any portion of this section is held invalid or unenforceable under any particular circumstance, the balance of the section is intended to apply and the section as a whole is intended to apply in other circumstances.
   It is not the purpose of this section to induce you to infringe any patents or other property right claims or to contest validity of any such claims; this section has the sole purpose of protecting the integrity of the free software distribution system, which is implemented by public license practices. Many people have made generous contributions to the wide range of software distributed through that system in reliance on consistent application of that system; it is up to the author/donor to decide if he or she is willing to distribute software through any other system and a licensee cannot impose that choice.
   This section is intended to make thoroughly clear what is believed to be a consequence of the rest of this License.
   8. If the distribution and/or use of the Program is restricted in certain countries either by patents or by copyrighted interfaces, the original copyright holder who places the Program under this License may add an explicit geographical distribution limitation excluding those countries, so that distribution is permitted only in or among countries not thus excluded. In such case, this License incorporates the limitation as if written in the body of this License.
   9. The Free Software Foundation may publish revised and/or new versions of the General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies a version number of this License which applies to it and &quot;any later version&quot;, you have the option of following the terms and conditions either of that version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of this License, you may choose any version ever published by the Free Software Foundation.
   10. If you wish to incorporate parts of the Program into other free programs whose distribution conditions are different, write to the author to ask for permission. For software which is copyrighted by the Free Software Foundation, write to the Free Software Foundation; we sometimes make exceptions for this. Our decision will be guided by the two goals of preserving the free status of all derivatives of our free software and of promoting the sharing and reuse of software generally.
   NO WARRANTY
   11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. END OF TERMS AND CONDITIONS
How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively convey the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt; one line to give the program&#39;s name and an idea of what it does. &gt;
Copyright (C) &lt; yyyy &gt; &lt; name of author &gt;
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 , USA. Also add information on how to contact you by electronic and paper mail.
If the program is interactive, make it output a short notice like this when it starts in an interactive mode:
Gnomovision version 69, Copyright (C) year name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, the commands you use may be called something other than `show w&#39; and `show c&#39;; they could even be mouse-clicks or menu items--whatever suits your program.
You should also get your employer (if you work as a programmer) or your school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. Here is a sample; alter the names:
Yoyodyne, Inc., hereby disclaims all copyright interest in the program `Gnomovision&#39; (which makes passes at compilers) written by James Hacker.
&lt; signature of Ty Coon &gt; , 1 April 1989 Ty Coon, President of Vice
```


### GPL-2.0-with-bison-exception

```
Bison Exception
As a special exception, you may create a larger work that contains part or all of the Bison parser skeleton and distribute that work under terms of your choice, so long as that work isn&#39;t itself a parser generator using the skeleton or a modified version thereof as a parser skeleton. Alternatively, if you modify or redistribute the parser skeleton itself, you may (at your option) remove this special exception, which will cause the skeleton and the resulting Bison output files to be licensed under the GNU General Public License without this special exception.
This special exception was added by the Free Software Foundation in version 2.2 of Bison.
```


### GPL-3.0-only

```
GNU GENERAL PUBLIC LICENSE
Version 3, 29 June 2007
Copyright © 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The GNU General Public License is a free, copyleft license for software and other kinds of works.
The licenses for most software and other practical works are designed to take away your freedom to share and change the works. By contrast, the GNU General Public License is intended to guarantee your freedom to share and change all versions of a program--to make sure it remains free software for all its users. We, the Free Software Foundation, use the GNU General Public License for most of our software; it applies also to any other work released this way by its authors. You can apply it to your programs, too.
When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for them if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs, and that you know you can do these things.
To protect your rights, we need to prevent others from denying you these rights or asking you to surrender the rights. Therefore, you have certain responsibilities if you distribute copies of the software, or if you modify it: responsibilities to respect the freedom of others.
For example, if you distribute copies of such a program, whether gratis or for a fee, you must pass on to the recipients the same freedoms that you received. You must make sure that they, too, receive or can get the source code. And you must show them these terms so they know their rights.
Developers that use the GNU GPL protect your rights with two steps: (1) assert copyright on the software, and (2) offer you this License giving you legal permission to copy, distribute and/or modify it.
For the developers&#39; and authors&#39; protection, the GPL clearly explains that there is no warranty for this free software. For both users&#39; and authors&#39; sake, the GPL requires that modified versions be marked as changed, so that their problems will not be attributed erroneously to authors of previous versions.
Some devices are designed to deny users access to install or run modified versions of the software inside them, although the manufacturer can do so. This is fundamentally incompatible with the aim of protecting users&#39; freedom to change the software. The systematic pattern of such abuse occurs in the area of products for individuals to use, which is precisely where it is most unacceptable. Therefore, we have designed this version of the GPL to prohibit the practice for those products. If such problems arise substantially in other domains, we stand ready to extend this provision to those domains in future versions of the GPL, as needed to protect the freedom of users.
Finally, every program is threatened constantly by software patents. States should not allow patents to restrict development and use of software on general-purpose computers, but in those that do, we wish to avoid the special danger that patents applied to a free program could make it effectively proprietary. To prevent this, the GPL assures that patents cannot be used to render the program non-free.
The precise terms and conditions for copying, distribution and modification follow.
TERMS AND CONDITIONS
   0. Definitions.
   &quot;This License&quot; refers to version 3 of the GNU General Public License.
   &quot;Copyright&quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.
   &quot;The Program&quot; refers to any copyrightable work licensed under this License. Each licensee is addressed as &quot;you&quot;. &quot;Licensees&quot; and &quot;recipients&quot; may be individuals or organizations.
   To &quot;modify&quot; a work means to copy from or adapt all or part of the work in a fashion requiring copyright permission, other than the making of an exact copy. The resulting work is called a &quot;modified version&quot; of the earlier work or a work &quot;based on&quot; the earlier work.
   A &quot;covered work&quot; means either the unmodified Program or a work based on the Program.
   To &quot;propagate&quot; a work means to do anything with it that, without permission, would make you directly or secondarily liable for infringement under applicable copyright law, except executing it on a computer or modifying a private copy. Propagation includes copying, distribution (with or without modification), making available to the public, and in some countries other activities as well.
   To &quot;convey&quot; a work means any kind of propagation that enables other parties to make or receive copies. Mere interaction with a user through a computer network, with no transfer of a copy, is not conveying.
   An interactive user interface displays &quot;Appropriate Legal Notices&quot; to the extent that it includes a convenient and prominently visible feature that (1) displays an appropriate copyright notice, and (2) tells the user that there is no warranty for the work (except to the extent that warranties are provided), that licensees may convey the work under this License, and how to view a copy of this License. If the interface presents a list of user commands or options, such as a menu, a prominent item in the list meets this criterion.
   1. Source Code.
   The &quot;source code&quot; for a work means the preferred form of the work for making modifications to it. &quot;Object code&quot; means any non-source form of a work.
   A &quot;Standard Interface&quot; means an interface that either is an official standard defined by a recognized standards body, or, in the case of interfaces specified for a particular programming language, one that is widely used among developers working in that language.
   The &quot;System Libraries&quot; of an executable work include anything, other than the work as a whole, that (a) is included in the normal form of packaging a Major Component, but which is not part of that Major Component, and (b) serves only to enable use of the work with that Major Component, or to implement a Standard Interface for which an implementation is available to the public in source code form. A &quot;Major Component&quot;, in this context, means a major essential component (kernel, window system, and so on) of the specific operating system (if any) on which the executable work runs, or a compiler used to produce the work, or an object code interpreter used to run it.
   The &quot;Corresponding Source&quot; for a work in object code form means all the source code needed to generate, install, and (for an executable work) run the object code and to modify the work, including scripts to control those activities. However, it does not include the work&#39;s System Libraries, or general-purpose tools or generally available free programs which are used unmodified in performing those activities but which are not part of the work. For example, Corresponding Source includes interface definition files associated with source files for the work, and the source code for shared libraries and dynamically linked subprograms that the work is specifically designed to require, such as by intimate data communication or control flow between those subprograms and other parts of the work.
   The Corresponding Source need not include anything that users can regenerate automatically from other parts of the Corresponding Source.
   The Corresponding Source for a work in source code form is that same work.
   2. Basic Permissions.
   All rights granted under this License are granted for the term of copyright on the Program, and are irrevocable provided the stated conditions are met. This License explicitly affirms your unlimited permission to run the unmodified Program. The output from running a covered work is covered by this License only if the output, given its content, constitutes a covered work. This License acknowledges your rights of fair use or other equivalent, as provided by copyright law.
   You may make, run and propagate covered works that you do not convey, without conditions so long as your license otherwise remains in force. You may convey covered works to others for the sole purpose of having them make modifications exclusively for you, or provide you with facilities for running those works, provided that you comply with the terms of this License in conveying all material for which you do not control copyright. Those thus making or running the covered works for you must do so exclusively on your behalf, under your direction and control, on terms that prohibit them from making any copies of your copyrighted material outside their relationship with you.
   Conveying under any other circumstances is permitted solely under the conditions stated below. Sublicensing is not allowed; section 10 makes it unnecessary.
   3. Protecting Users&#39; Legal Rights From Anti-Circumvention Law.
   No covered work shall be deemed part of an effective technological measure under any applicable law fulfilling obligations under article 11 of the WIPO copyright treaty adopted on 20 December 1996, or similar laws prohibiting or restricting circumvention of such measures.
   When you convey a covered work, you waive any legal power to forbid circumvention of technological measures to the extent such circumvention is effected by exercising rights under this License with respect to the covered work, and you disclaim any intention to limit operation or modification of the work as a means of enforcing, against the work&#39;s users, your or third parties&#39; legal rights to forbid circumvention of technological measures.
   4. Conveying Verbatim Copies.
   You may convey verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice; keep intact all notices stating that this License and any non-permissive terms added in accord with section 7 apply to the code; keep intact all notices of the absence of any warranty; and give all recipients a copy of this License along with the Program.
   You may charge any price or no price for each copy that you convey, and you may offer support or warranty protection for a fee.
   5. Conveying Modified Source Versions.
   You may convey a work based on the Program, or the modifications to produce it from the Program, in the form of source code under the terms of section 4, provided that you also meet all of these conditions:
      a) The work must carry prominent notices stating that you modified it, and giving a relevant date.
      b) The work must carry prominent notices stating that it is released under this License and any conditions added under section 7. This requirement modifies the requirement in section 4 to &quot;keep intact all notices&quot;.
      c) You must license the entire work, as a whole, under this License to anyone who comes into possession of a copy. This License will therefore apply, along with any applicable section 7 additional terms, to the whole of the work, and all its parts, regardless of how they are packaged. This License gives no permission to license the work in any other way, but it does not invalidate such permission if you have separately received it.
      d) If the work has interactive user interfaces, each must display Appropriate Legal Notices; however, if the Program has interactive interfaces that do not display Appropriate Legal Notices, your work need not make them do so.
   A compilation of a covered work with other separate and independent works, which are not by their nature extensions of the covered work, and which are not combined with it such as to form a larger program, in or on a volume of a storage or distribution medium, is called an &quot;aggregate&quot; if the compilation and its resulting copyright are not used to limit the access or legal rights of the compilation&#39;s users beyond what the individual works permit. Inclusion of a covered work in an aggregate does not cause this License to apply to the other parts of the aggregate.
   6. Conveying Non-Source Forms.
   You may convey a covered work in object code form under the terms of sections 4 and 5, provided that you also convey the machine-readable Corresponding Source under the terms of this License, in one of these ways:
      a) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by the Corresponding Source fixed on a durable physical medium customarily used for software interchange.
      b) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by a written offer, valid for at least three years and valid for as long as you offer spare parts or customer support for that product model, to give anyone who possesses the object code either (1) a copy of the Corresponding Source for all the software in the product that is covered by this License, on a durable physical medium customarily used for software interchange, for a price no more than your reasonable cost of physically performing this conveying of source, or (2) access to copy the Corresponding Source from a network server at no charge.
      c) Convey individual copies of the object code with a copy of the written offer to provide the Corresponding Source. This alternative is allowed only occasionally and noncommercially, and only if you received the object code with such an offer, in accord with subsection 6b.
      d) Convey the object code by offering access from a designated place (gratis or for a charge), and offer equivalent access to the Corresponding Source in the same way through the same place at no further charge. You need not require recipients to copy the Corresponding Source along with the object code. If the place to copy the object code is a network server, the Corresponding Source may be on a different server (operated by you or a third party) that supports equivalent copying facilities, provided you maintain clear directions next to the object code saying where to find the Corresponding Source. Regardless of what server hosts the Corresponding Source, you remain obligated to ensure that it is available for as long as needed to satisfy these requirements.
      e) Convey the object code using peer-to-peer transmission, provided you inform other peers where the object code and Corresponding Source of the work are being offered to the general public at no charge under subsection 6d.
   A separable portion of the object code, whose source code is excluded from the Corresponding Source as a System Library, need not be included in conveying the object code work.
   A &quot;User Product&quot; is either (1) a &quot;consumer product&quot;, which means any tangible personal property which is normally used for personal, family, or household purposes, or (2) anything designed or sold for incorporation into a dwelling. In determining whether a product is a consumer product, doubtful cases shall be resolved in favor of coverage. For a particular product received by a particular user, &quot;normally used&quot; refers to a typical or common use of that class of product, regardless of the status of the particular user or of the way in which the particular user actually uses, or expects or is expected to use, the product. A product is a consumer product regardless of whether the product has substantial commercial, industrial or non-consumer uses, unless such uses represent the only significant mode of use of the product.
   &quot;Installation Information&quot; for a User Product means any methods, procedures, authorization keys, or other information required to install and execute modified versions of a covered work in that User Product from a modified version of its Corresponding Source. The information must suffice to ensure that the continued functioning of the modified object code is in no case prevented or interfered with solely because modification has been made.
   If you convey an object code work under this section in, or with, or specifically for use in, a User Product, and the conveying occurs as part of a transaction in which the right of possession and use of the User Product is transferred to the recipient in perpetuity or for a fixed term (regardless of how the transaction is characterized), the Corresponding Source conveyed under this section must be accompanied by the Installation Information. But this requirement does not apply if neither you nor any third party retains the ability to install modified object code on the User Product (for example, the work has been installed in ROM).
   The requirement to provide Installation Information does not include a requirement to continue to provide support service, warranty, or updates for a work that has been modified or installed by the recipient, or for the User Product in which it has been modified or installed. Access to a network may be denied when the modification itself materially and adversely affects the operation of the network or violates the rules and protocols for communication across the network.
   Corresponding Source conveyed, and Installation Information provided, in accord with this section must be in a format that is publicly documented (and with an implementation available to the public in source code form), and must require no special password or key for unpacking, reading or copying.
   7. Additional Terms.
   &quot;Additional permissions&quot; are terms that supplement the terms of this License by making exceptions from one or more of its conditions. Additional permissions that are applicable to the entire Program shall be treated as though they were included in this License, to the extent that they are valid under applicable law. If additional permissions apply only to part of the Program, that part may be used separately under those permissions, but the entire Program remains governed by this License without regard to the additional permissions.
   When you convey a copy of a covered work, you may at your option remove any additional permissions from that copy, or from any part of it. (Additional permissions may be written to require their own removal in certain cases when you modify the work.) You may place additional permissions on material, added by you to a covered work, for which you have or can give appropriate copyright permission.
   Notwithstanding any other provision of this License, for material you add to a covered work, you may (if authorized by the copyright holders of that material) supplement the terms of this License with terms:
      a) Disclaiming warranty or limiting liability differently from the terms of sections 15 and 16 of this License; or
      b) Requiring preservation of specified reasonable legal notices or author attributions in that material or in the Appropriate Legal Notices displayed by works containing it; or
      c) Prohibiting misrepresentation of the origin of that material, or requiring that modified versions of such material be marked in reasonable ways as different from the original version; or
      d) Limiting the use for publicity purposes of names of licensors or authors of the material; or
      e) Declining to grant rights under trademark law for use of some trade names, trademarks, or service marks; or
      f) Requiring indemnification of licensors and authors of that material by anyone who conveys the material (or modified versions of it) with contractual assumptions of liability to the recipient, for any liability that these contractual assumptions directly impose on those licensors and authors.
   All other non-permissive additional terms are considered &quot;further restrictions&quot; within the meaning of section 10. If the Program as you received it, or any part of it, contains a notice stating that it is governed by this License along with a term that is a further restriction, you may remove that term. If a license document contains a further restriction but permits relicensing or conveying under this License, you may add to a covered work material governed by the terms of that license document, provided that the further restriction does not survive such relicensing or conveying.
   If you add terms to a covered work in accord with this section, you must place, in the relevant source files, a statement of the additional terms that apply to those files, or a notice indicating where to find the applicable terms.
   Additional terms, permissive or non-permissive, may be stated in the form of a separately written license, or stated as exceptions; the above requirements apply either way.
   8. Termination.
   You may not propagate or modify a covered work except as expressly provided under this License. Any attempt otherwise to propagate or modify it is void, and will automatically terminate your rights under this License (including any patent licenses granted under the third paragraph of section 11).
   However, if you cease all violation of this License, then your license from a particular copyright holder is reinstated (a) provisionally, unless and until the copyright holder explicitly and finally terminates your license, and (b) permanently, if the copyright holder fails to notify you of the violation by some reasonable means prior to 60 days after the cessation.
   Moreover, your license from a particular copyright holder is reinstated permanently if the copyright holder notifies you of the violation by some reasonable means, this is the first time you have received notice of violation of this License (for any work) from that copyright holder, and you cure the violation prior to 30 days after your receipt of the notice.
   Termination of your rights under this section does not terminate the licenses of parties who have received copies or rights from you under this License. If your rights have been terminated and not permanently reinstated, you do not qualify to receive new licenses for the same material under section 10.
   9. Acceptance Not Required for Having Copies.
   You are not required to accept this License in order to receive or run a copy of the Program. Ancillary propagation of a covered work occurring solely as a consequence of using peer-to-peer transmission to receive a copy likewise does not require acceptance. However, nothing other than this License grants you permission to propagate or modify any covered work. These actions infringe copyright if you do not accept this License. Therefore, by modifying or propagating a covered work, you indicate your acceptance of this License to do so.
   10. Automatic Licensing of Downstream Recipients.
   Each time you convey a covered work, the recipient automatically receives a license from the original licensors, to run, modify and propagate that work, subject to this License. You are not responsible for enforcing compliance by third parties with this License.
   An &quot;entity transaction&quot; is a transaction transferring control of an organization, or substantially all assets of one, or subdividing an organization, or merging organizations. If propagation of a covered work results from an entity transaction, each party to that transaction who receives a copy of the work also receives whatever licenses to the work the party&#39;s predecessor in interest had or could give under the previous paragraph, plus a right to possession of the Corresponding Source of the work from the predecessor in interest, if the predecessor has it or can get it with reasonable efforts.
   You may not impose any further restrictions on the exercise of the rights granted or affirmed under this License. For example, you may not impose a license fee, royalty, or other charge for exercise of rights granted under this License, and you may not initiate litigation (including a cross-claim or counterclaim in a lawsuit) alleging that any patent claim is infringed by making, using, selling, offering for sale, or importing the Program or any portion of it.
   11. Patents.
   A &quot;contributor&quot; is a copyright holder who authorizes use under this License of the Program or a work on which the Program is based. The work thus licensed is called the contributor&#39;s &quot;contributor version&quot;.
   A contributor&#39;s &quot;essential patent claims&quot; are all patent claims owned or controlled by the contributor, whether already acquired or hereafter acquired, that would be infringed by some manner, permitted by this License, of making, using, or selling its contributor version, but do not include claims that would be infringed only as a consequence of further modification of the contributor version. For purposes of this definition, &quot;control&quot; includes the right to grant patent sublicenses in a manner consistent with the requirements of this License.
   Each contributor grants you a non-exclusive, worldwide, royalty-free patent license under the contributor&#39;s essential patent claims, to make, use, sell, offer for sale, import and otherwise run, modify and propagate the contents of its contributor version.
   In the following three paragraphs, a &quot;patent license&quot; is any express agreement or commitment, however denominated, not to enforce a patent (such as an express permission to practice a patent or covenant not to sue for patent infringement). To &quot;grant&quot; such a patent license to a party means to make such an agreement or commitment not to enforce a patent against the party.
   If you convey a covered work, knowingly relying on a patent license, and the Corresponding Source of the work is not available for anyone to copy, free of charge and under the terms of this License, through a publicly available network server or other readily accessible means, then you must either (1) cause the Corresponding Source to be so available, or (2) arrange to deprive yourself of the benefit of the patent license for this particular work, or (3) arrange, in a manner consistent with the requirements of this License, to extend the patent license to downstream recipients. &quot;Knowingly relying&quot; means you have actual knowledge that, but for the patent license, your conveying the covered work in a country, or your recipient&#39;s use of the covered work in a country, would infringe one or more identifiable patents in that country that you have reason to believe are valid.
   If, pursuant to or in connection with a single transaction or arrangement, you convey, or propagate by procuring conveyance of, a covered work, and grant a patent license to some of the parties receiving the covered work authorizing them to use, propagate, modify or convey a specific copy of the covered work, then the patent license you grant is automatically extended to all recipients of the covered work and works based on it.
   A patent license is &quot;discriminatory&quot; if it does not include within the scope of its coverage, prohibits the exercise of, or is conditioned on the non-exercise of one or more of the rights that are specifically granted under this License. You may not convey a covered work if you are a party to an arrangement with a third party that is in the business of distributing software, under which you make payment to the third party based on the extent of your activity of conveying the work, and under which the third party grants, to any of the parties who would receive the covered work from you, a discriminatory patent license (a) in connection with copies of the covered work conveyed by you (or copies made from those copies), or (b) primarily for and in connection with specific products or compilations that contain the covered work, unless you entered into that arrangement, or that patent license was granted, prior to 28 March 2007.
   Nothing in this License shall be construed as excluding or limiting any implied license or other defenses to infringement that may otherwise be available to you under applicable patent law.
   12. No Surrender of Others&#39; Freedom.
   If conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot convey a covered work so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may not convey it at all. For example, if you agree to terms that obligate you to collect a royalty for further conveying from those to whom you convey the Program, the only way you could satisfy both those terms and this License would be to refrain entirely from conveying the Program.
   13. Use with the GNU Affero General Public License.
   Notwithstanding any other provision of this License, you have permission to link or combine any covered work with a work licensed under version 3 of the GNU Affero General Public License into a single combined work, and to convey the resulting work. The terms of this License will continue to apply to the part which is the covered work, but the special requirements of the GNU Affero General Public License, section 13, concerning interaction through a network will apply to the combination as such.
   14. Revised Versions of this License.
   The Free Software Foundation may publish revised and/or new versions of the GNU General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies that a certain numbered version of the GNU General Public License &quot;or any later version&quot; applies to it, you have the option of following the terms and conditions either of that numbered version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of the GNU General Public License, you may choose any version ever published by the Free Software Foundation.
   If the Program specifies that a proxy can decide which future versions of the GNU General Public License can be used, that proxy&#39;s public statement of acceptance of a version permanently authorizes you to choose that version for the Program.
   Later license versions may give you additional or different permissions. However, no additional obligations are imposed on any author or copyright holder as a result of your choosing to follow a later version.
   15. Disclaimer of Warranty.
   THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   16. Limitation of Liability.
   IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   17. Interpretation of Sections 15 and 16.
   If the disclaimer of warranty and limitation of liability provided above cannot be given local legal effect according to their terms, reviewing courts shall apply local law that most closely approximates an absolute waiver of all civil liability in connection with the Program, unless a warranty or assumption of liability accompanies a copy of the Program in return for a fee. END OF TERMS AND CONDITIONS
How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively state the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt;one line to give the program&#39;s name and a brief idea of what it does.&gt;
Copyright (C) &lt;year&gt; &lt;name of author&gt;
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see &lt;http s ://www.gnu.org/licenses/&gt;.
Also add information on how to contact you by electronic and paper mail.
If the program does terminal interaction, make it output a short notice like this when it starts in an interactive mode:
&lt;program&gt; Copyright (C) &lt;year&gt; &lt;name of author&gt;
This program comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;.
This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, your program&#39;s commands might be different; for a GUI interface, you would use an &quot;about box&quot;.
You should also get your employer (if you work as a programmer) or school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. For more information on this, and how to apply and follow the GNU GPL, see &lt;http s ://www.gnu.org/licenses/&gt;.
The GNU General Public License does not permit incorporating your program into proprietary programs. If your program is a subroutine library, you may consider it more useful to permit linking proprietary applications with the library. If this is what you want to do, use the GNU Lesser General Public License instead of this License. But first, please read &lt;http s ://www.gnu.org/philosophy/why-not-lgpl.html&gt;.
```


### GPL-3.0-or-later

```
GNU GENERAL PUBLIC LICENSE
Version 3, 29 June 2007
Copyright © 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The GNU General Public License is a free, copyleft license for software and other kinds of works.
The licenses for most software and other practical works are designed to take away your freedom to share and change the works. By contrast, the GNU General Public License is intended to guarantee your freedom to share and change all versions of a program--to make sure it remains free software for all its users. We, the Free Software Foundation, use the GNU General Public License for most of our software; it applies also to any other work released this way by its authors. You can apply it to your programs, too.
When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for them if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs, and that you know you can do these things.
To protect your rights, we need to prevent others from denying you these rights or asking you to surrender the rights. Therefore, you have certain responsibilities if you distribute copies of the software, or if you modify it: responsibilities to respect the freedom of others.
For example, if you distribute copies of such a program, whether gratis or for a fee, you must pass on to the recipients the same freedoms that you received. You must make sure that they, too, receive or can get the source code. And you must show them these terms so they know their rights.
Developers that use the GNU GPL protect your rights with two steps: (1) assert copyright on the software, and (2) offer you this License giving you legal permission to copy, distribute and/or modify it.
For the developers&#39; and authors&#39; protection, the GPL clearly explains that there is no warranty for this free software. For both users&#39; and authors&#39; sake, the GPL requires that modified versions be marked as changed, so that their problems will not be attributed erroneously to authors of previous versions.
Some devices are designed to deny users access to install or run modified versions of the software inside them, although the manufacturer can do so. This is fundamentally incompatible with the aim of protecting users&#39; freedom to change the software. The systematic pattern of such abuse occurs in the area of products for individuals to use, which is precisely where it is most unacceptable. Therefore, we have designed this version of the GPL to prohibit the practice for those products. If such problems arise substantially in other domains, we stand ready to extend this provision to those domains in future versions of the GPL, as needed to protect the freedom of users.
Finally, every program is threatened constantly by software patents. States should not allow patents to restrict development and use of software on general-purpose computers, but in those that do, we wish to avoid the special danger that patents applied to a free program could make it effectively proprietary. To prevent this, the GPL assures that patents cannot be used to render the program non-free.
The precise terms and conditions for copying, distribution and modification follow.
TERMS AND CONDITIONS
   0. Definitions.
   &quot;This License&quot; refers to version 3 of the GNU General Public License.
   &quot;Copyright&quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.
   &quot;The Program&quot; refers to any copyrightable work licensed under this License. Each licensee is addressed as &quot;you&quot;. &quot;Licensees&quot; and &quot;recipients&quot; may be individuals or organizations.
   To &quot;modify&quot; a work means to copy from or adapt all or part of the work in a fashion requiring copyright permission, other than the making of an exact copy. The resulting work is called a &quot;modified version&quot; of the earlier work or a work &quot;based on&quot; the earlier work.
   A &quot;covered work&quot; means either the unmodified Program or a work based on the Program.
   To &quot;propagate&quot; a work means to do anything with it that, without permission, would make you directly or secondarily liable for infringement under applicable copyright law, except executing it on a computer or modifying a private copy. Propagation includes copying, distribution (with or without modification), making available to the public, and in some countries other activities as well.
   To &quot;convey&quot; a work means any kind of propagation that enables other parties to make or receive copies. Mere interaction with a user through a computer network, with no transfer of a copy, is not conveying.
   An interactive user interface displays &quot;Appropriate Legal Notices&quot; to the extent that it includes a convenient and prominently visible feature that (1) displays an appropriate copyright notice, and (2) tells the user that there is no warranty for the work (except to the extent that warranties are provided), that licensees may convey the work under this License, and how to view a copy of this License. If the interface presents a list of user commands or options, such as a menu, a prominent item in the list meets this criterion.
   1. Source Code.
   The &quot;source code&quot; for a work means the preferred form of the work for making modifications to it. &quot;Object code&quot; means any non-source form of a work.
   A &quot;Standard Interface&quot; means an interface that either is an official standard defined by a recognized standards body, or, in the case of interfaces specified for a particular programming language, one that is widely used among developers working in that language.
   The &quot;System Libraries&quot; of an executable work include anything, other than the work as a whole, that (a) is included in the normal form of packaging a Major Component, but which is not part of that Major Component, and (b) serves only to enable use of the work with that Major Component, or to implement a Standard Interface for which an implementation is available to the public in source code form. A &quot;Major Component&quot;, in this context, means a major essential component (kernel, window system, and so on) of the specific operating system (if any) on which the executable work runs, or a compiler used to produce the work, or an object code interpreter used to run it.
   The &quot;Corresponding Source&quot; for a work in object code form means all the source code needed to generate, install, and (for an executable work) run the object code and to modify the work, including scripts to control those activities. However, it does not include the work&#39;s System Libraries, or general-purpose tools or generally available free programs which are used unmodified in performing those activities but which are not part of the work. For example, Corresponding Source includes interface definition files associated with source files for the work, and the source code for shared libraries and dynamically linked subprograms that the work is specifically designed to require, such as by intimate data communication or control flow between those subprograms and other parts of the work.
   The Corresponding Source need not include anything that users can regenerate automatically from other parts of the Corresponding Source.
   The Corresponding Source for a work in source code form is that same work.
   2. Basic Permissions.
   All rights granted under this License are granted for the term of copyright on the Program, and are irrevocable provided the stated conditions are met. This License explicitly affirms your unlimited permission to run the unmodified Program. The output from running a covered work is covered by this License only if the output, given its content, constitutes a covered work. This License acknowledges your rights of fair use or other equivalent, as provided by copyright law.
   You may make, run and propagate covered works that you do not convey, without conditions so long as your license otherwise remains in force. You may convey covered works to others for the sole purpose of having them make modifications exclusively for you, or provide you with facilities for running those works, provided that you comply with the terms of this License in conveying all material for which you do not control copyright. Those thus making or running the covered works for you must do so exclusively on your behalf, under your direction and control, on terms that prohibit them from making any copies of your copyrighted material outside their relationship with you.
   Conveying under any other circumstances is permitted solely under the conditions stated below. Sublicensing is not allowed; section 10 makes it unnecessary.
   3. Protecting Users&#39; Legal Rights From Anti-Circumvention Law.
   No covered work shall be deemed part of an effective technological measure under any applicable law fulfilling obligations under article 11 of the WIPO copyright treaty adopted on 20 December 1996, or similar laws prohibiting or restricting circumvention of such measures.
   When you convey a covered work, you waive any legal power to forbid circumvention of technological measures to the extent such circumvention is effected by exercising rights under this License with respect to the covered work, and you disclaim any intention to limit operation or modification of the work as a means of enforcing, against the work&#39;s users, your or third parties&#39; legal rights to forbid circumvention of technological measures.
   4. Conveying Verbatim Copies.
   You may convey verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice; keep intact all notices stating that this License and any non-permissive terms added in accord with section 7 apply to the code; keep intact all notices of the absence of any warranty; and give all recipients a copy of this License along with the Program.
   You may charge any price or no price for each copy that you convey, and you may offer support or warranty protection for a fee.
   5. Conveying Modified Source Versions.
   You may convey a work based on the Program, or the modifications to produce it from the Program, in the form of source code under the terms of section 4, provided that you also meet all of these conditions:
      a) The work must carry prominent notices stating that you modified it, and giving a relevant date.
      b) The work must carry prominent notices stating that it is released under this License and any conditions added under section 7. This requirement modifies the requirement in section 4 to &quot;keep intact all notices&quot;.
      c) You must license the entire work, as a whole, under this License to anyone who comes into possession of a copy. This License will therefore apply, along with any applicable section 7 additional terms, to the whole of the work, and all its parts, regardless of how they are packaged. This License gives no permission to license the work in any other way, but it does not invalidate such permission if you have separately received it.
      d) If the work has interactive user interfaces, each must display Appropriate Legal Notices; however, if the Program has interactive interfaces that do not display Appropriate Legal Notices, your work need not make them do so.
   A compilation of a covered work with other separate and independent works, which are not by their nature extensions of the covered work, and which are not combined with it such as to form a larger program, in or on a volume of a storage or distribution medium, is called an &quot;aggregate&quot; if the compilation and its resulting copyright are not used to limit the access or legal rights of the compilation&#39;s users beyond what the individual works permit. Inclusion of a covered work in an aggregate does not cause this License to apply to the other parts of the aggregate.
   6. Conveying Non-Source Forms.
   You may convey a covered work in object code form under the terms of sections 4 and 5, provided that you also convey the machine-readable Corresponding Source under the terms of this License, in one of these ways:
      a) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by the Corresponding Source fixed on a durable physical medium customarily used for software interchange.
      b) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by a written offer, valid for at least three years and valid for as long as you offer spare parts or customer support for that product model, to give anyone who possesses the object code either (1) a copy of the Corresponding Source for all the software in the product that is covered by this License, on a durable physical medium customarily used for software interchange, for a price no more than your reasonable cost of physically performing this conveying of source, or (2) access to copy the Corresponding Source from a network server at no charge.
      c) Convey individual copies of the object code with a copy of the written offer to provide the Corresponding Source. This alternative is allowed only occasionally and noncommercially, and only if you received the object code with such an offer, in accord with subsection 6b.
      d) Convey the object code by offering access from a designated place (gratis or for a charge), and offer equivalent access to the Corresponding Source in the same way through the same place at no further charge. You need not require recipients to copy the Corresponding Source along with the object code. If the place to copy the object code is a network server, the Corresponding Source may be on a different server (operated by you or a third party) that supports equivalent copying facilities, provided you maintain clear directions next to the object code saying where to find the Corresponding Source. Regardless of what server hosts the Corresponding Source, you remain obligated to ensure that it is available for as long as needed to satisfy these requirements.
      e) Convey the object code using peer-to-peer transmission, provided you inform other peers where the object code and Corresponding Source of the work are being offered to the general public at no charge under subsection 6d.
   A separable portion of the object code, whose source code is excluded from the Corresponding Source as a System Library, need not be included in conveying the object code work.
   A &quot;User Product&quot; is either (1) a &quot;consumer product&quot;, which means any tangible personal property which is normally used for personal, family, or household purposes, or (2) anything designed or sold for incorporation into a dwelling. In determining whether a product is a consumer product, doubtful cases shall be resolved in favor of coverage. For a particular product received by a particular user, &quot;normally used&quot; refers to a typical or common use of that class of product, regardless of the status of the particular user or of the way in which the particular user actually uses, or expects or is expected to use, the product. A product is a consumer product regardless of whether the product has substantial commercial, industrial or non-consumer uses, unless such uses represent the only significant mode of use of the product.
   &quot;Installation Information&quot; for a User Product means any methods, procedures, authorization keys, or other information required to install and execute modified versions of a covered work in that User Product from a modified version of its Corresponding Source. The information must suffice to ensure that the continued functioning of the modified object code is in no case prevented or interfered with solely because modification has been made.
   If you convey an object code work under this section in, or with, or specifically for use in, a User Product, and the conveying occurs as part of a transaction in which the right of possession and use of the User Product is transferred to the recipient in perpetuity or for a fixed term (regardless of how the transaction is characterized), the Corresponding Source conveyed under this section must be accompanied by the Installation Information. But this requirement does not apply if neither you nor any third party retains the ability to install modified object code on the User Product (for example, the work has been installed in ROM).
   The requirement to provide Installation Information does not include a requirement to continue to provide support service, warranty, or updates for a work that has been modified or installed by the recipient, or for the User Product in which it has been modified or installed. Access to a network may be denied when the modification itself materially and adversely affects the operation of the network or violates the rules and protocols for communication across the network.
   Corresponding Source conveyed, and Installation Information provided, in accord with this section must be in a format that is publicly documented (and with an implementation available to the public in source code form), and must require no special password or key for unpacking, reading or copying.
   7. Additional Terms.
   &quot;Additional permissions&quot; are terms that supplement the terms of this License by making exceptions from one or more of its conditions. Additional permissions that are applicable to the entire Program shall be treated as though they were included in this License, to the extent that they are valid under applicable law. If additional permissions apply only to part of the Program, that part may be used separately under those permissions, but the entire Program remains governed by this License without regard to the additional permissions.
   When you convey a copy of a covered work, you may at your option remove any additional permissions from that copy, or from any part of it. (Additional permissions may be written to require their own removal in certain cases when you modify the work.) You may place additional permissions on material, added by you to a covered work, for which you have or can give appropriate copyright permission.
   Notwithstanding any other provision of this License, for material you add to a covered work, you may (if authorized by the copyright holders of that material) supplement the terms of this License with terms:
      a) Disclaiming warranty or limiting liability differently from the terms of sections 15 and 16 of this License; or
      b) Requiring preservation of specified reasonable legal notices or author attributions in that material or in the Appropriate Legal Notices displayed by works containing it; or
      c) Prohibiting misrepresentation of the origin of that material, or requiring that modified versions of such material be marked in reasonable ways as different from the original version; or
      d) Limiting the use for publicity purposes of names of licensors or authors of the material; or
      e) Declining to grant rights under trademark law for use of some trade names, trademarks, or service marks; or
      f) Requiring indemnification of licensors and authors of that material by anyone who conveys the material (or modified versions of it) with contractual assumptions of liability to the recipient, for any liability that these contractual assumptions directly impose on those licensors and authors.
   All other non-permissive additional terms are considered &quot;further restrictions&quot; within the meaning of section 10. If the Program as you received it, or any part of it, contains a notice stating that it is governed by this License along with a term that is a further restriction, you may remove that term. If a license document contains a further restriction but permits relicensing or conveying under this License, you may add to a covered work material governed by the terms of that license document, provided that the further restriction does not survive such relicensing or conveying.
   If you add terms to a covered work in accord with this section, you must place, in the relevant source files, a statement of the additional terms that apply to those files, or a notice indicating where to find the applicable terms.
   Additional terms, permissive or non-permissive, may be stated in the form of a separately written license, or stated as exceptions; the above requirements apply either way.
   8. Termination.
   You may not propagate or modify a covered work except as expressly provided under this License. Any attempt otherwise to propagate or modify it is void, and will automatically terminate your rights under this License (including any patent licenses granted under the third paragraph of section 11).
   However, if you cease all violation of this License, then your license from a particular copyright holder is reinstated (a) provisionally, unless and until the copyright holder explicitly and finally terminates your license, and (b) permanently, if the copyright holder fails to notify you of the violation by some reasonable means prior to 60 days after the cessation.
   Moreover, your license from a particular copyright holder is reinstated permanently if the copyright holder notifies you of the violation by some reasonable means, this is the first time you have received notice of violation of this License (for any work) from that copyright holder, and you cure the violation prior to 30 days after your receipt of the notice.
   Termination of your rights under this section does not terminate the licenses of parties who have received copies or rights from you under this License. If your rights have been terminated and not permanently reinstated, you do not qualify to receive new licenses for the same material under section 10.
   9. Acceptance Not Required for Having Copies.
   You are not required to accept this License in order to receive or run a copy of the Program. Ancillary propagation of a covered work occurring solely as a consequence of using peer-to-peer transmission to receive a copy likewise does not require acceptance. However, nothing other than this License grants you permission to propagate or modify any covered work. These actions infringe copyright if you do not accept this License. Therefore, by modifying or propagating a covered work, you indicate your acceptance of this License to do so.
   10. Automatic Licensing of Downstream Recipients.
   Each time you convey a covered work, the recipient automatically receives a license from the original licensors, to run, modify and propagate that work, subject to this License. You are not responsible for enforcing compliance by third parties with this License.
   An &quot;entity transaction&quot; is a transaction transferring control of an organization, or substantially all assets of one, or subdividing an organization, or merging organizations. If propagation of a covered work results from an entity transaction, each party to that transaction who receives a copy of the work also receives whatever licenses to the work the party&#39;s predecessor in interest had or could give under the previous paragraph, plus a right to possession of the Corresponding Source of the work from the predecessor in interest, if the predecessor has it or can get it with reasonable efforts.
   You may not impose any further restrictions on the exercise of the rights granted or affirmed under this License. For example, you may not impose a license fee, royalty, or other charge for exercise of rights granted under this License, and you may not initiate litigation (including a cross-claim or counterclaim in a lawsuit) alleging that any patent claim is infringed by making, using, selling, offering for sale, or importing the Program or any portion of it.
   11. Patents.
   A &quot;contributor&quot; is a copyright holder who authorizes use under this License of the Program or a work on which the Program is based. The work thus licensed is called the contributor&#39;s &quot;contributor version&quot;.
   A contributor&#39;s &quot;essential patent claims&quot; are all patent claims owned or controlled by the contributor, whether already acquired or hereafter acquired, that would be infringed by some manner, permitted by this License, of making, using, or selling its contributor version, but do not include claims that would be infringed only as a consequence of further modification of the contributor version. For purposes of this definition, &quot;control&quot; includes the right to grant patent sublicenses in a manner consistent with the requirements of this License.
   Each contributor grants you a non-exclusive, worldwide, royalty-free patent license under the contributor&#39;s essential patent claims, to make, use, sell, offer for sale, import and otherwise run, modify and propagate the contents of its contributor version.
   In the following three paragraphs, a &quot;patent license&quot; is any express agreement or commitment, however denominated, not to enforce a patent (such as an express permission to practice a patent or covenant not to sue for patent infringement). To &quot;grant&quot; such a patent license to a party means to make such an agreement or commitment not to enforce a patent against the party.
   If you convey a covered work, knowingly relying on a patent license, and the Corresponding Source of the work is not available for anyone to copy, free of charge and under the terms of this License, through a publicly available network server or other readily accessible means, then you must either (1) cause the Corresponding Source to be so available, or (2) arrange to deprive yourself of the benefit of the patent license for this particular work, or (3) arrange, in a manner consistent with the requirements of this License, to extend the patent license to downstream recipients. &quot;Knowingly relying&quot; means you have actual knowledge that, but for the patent license, your conveying the covered work in a country, or your recipient&#39;s use of the covered work in a country, would infringe one or more identifiable patents in that country that you have reason to believe are valid.
   If, pursuant to or in connection with a single transaction or arrangement, you convey, or propagate by procuring conveyance of, a covered work, and grant a patent license to some of the parties receiving the covered work authorizing them to use, propagate, modify or convey a specific copy of the covered work, then the patent license you grant is automatically extended to all recipients of the covered work and works based on it.
   A patent license is &quot;discriminatory&quot; if it does not include within the scope of its coverage, prohibits the exercise of, or is conditioned on the non-exercise of one or more of the rights that are specifically granted under this License. You may not convey a covered work if you are a party to an arrangement with a third party that is in the business of distributing software, under which you make payment to the third party based on the extent of your activity of conveying the work, and under which the third party grants, to any of the parties who would receive the covered work from you, a discriminatory patent license (a) in connection with copies of the covered work conveyed by you (or copies made from those copies), or (b) primarily for and in connection with specific products or compilations that contain the covered work, unless you entered into that arrangement, or that patent license was granted, prior to 28 March 2007.
   Nothing in this License shall be construed as excluding or limiting any implied license or other defenses to infringement that may otherwise be available to you under applicable patent law.
   12. No Surrender of Others&#39; Freedom.
   If conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot convey a covered work so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may not convey it at all. For example, if you agree to terms that obligate you to collect a royalty for further conveying from those to whom you convey the Program, the only way you could satisfy both those terms and this License would be to refrain entirely from conveying the Program.
   13. Use with the GNU Affero General Public License.
   Notwithstanding any other provision of this License, you have permission to link or combine any covered work with a work licensed under version 3 of the GNU Affero General Public License into a single combined work, and to convey the resulting work. The terms of this License will continue to apply to the part which is the covered work, but the special requirements of the GNU Affero General Public License, section 13, concerning interaction through a network will apply to the combination as such.
   14. Revised Versions of this License.
   The Free Software Foundation may publish revised and/or new versions of the GNU General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies that a certain numbered version of the GNU General Public License &quot;or any later version&quot; applies to it, you have the option of following the terms and conditions either of that numbered version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of the GNU General Public License, you may choose any version ever published by the Free Software Foundation.
   If the Program specifies that a proxy can decide which future versions of the GNU General Public License can be used, that proxy&#39;s public statement of acceptance of a version permanently authorizes you to choose that version for the Program.
   Later license versions may give you additional or different permissions. However, no additional obligations are imposed on any author or copyright holder as a result of your choosing to follow a later version.
   15. Disclaimer of Warranty.
   THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   16. Limitation of Liability.
   IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   17. Interpretation of Sections 15 and 16.
   If the disclaimer of warranty and limitation of liability provided above cannot be given local legal effect according to their terms, reviewing courts shall apply local law that most closely approximates an absolute waiver of all civil liability in connection with the Program, unless a warranty or assumption of liability accompanies a copy of the Program in return for a fee. END OF TERMS AND CONDITIONS
How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively state the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt;one line to give the program&#39;s name and a brief idea of what it does.&gt;
Copyright (C) &lt;year&gt; &lt;name of author&gt;
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see &lt;http s ://www.gnu.org/licenses/&gt;.
Also add information on how to contact you by electronic and paper mail.
If the program does terminal interaction, make it output a short notice like this when it starts in an interactive mode:
&lt;program&gt; Copyright (C) &lt;year&gt; &lt;name of author&gt;
This program comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;.
This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, your program&#39;s commands might be different; for a GUI interface, you would use an &quot;about box&quot;.
You should also get your employer (if you work as a programmer) or school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. For more information on this, and how to apply and follow the GNU GPL, see &lt;http s ://www.gnu.org/licenses/&gt;.
The GNU General Public License does not permit incorporating your program into proprietary programs. If your program is a subroutine library, you may consider it more useful to permit linking proprietary applications with the library. If this is what you want to do, use the GNU Lesser General Public License instead of this License. But first, please read &lt;http s ://www.gnu.org/philosophy/why-not-lgpl.html&gt;.
```


### GPL-3.0-with-GCC-exception

```
﻿insert GPL v3 text here GCC RUNTIME LIBRARY EXCEPTION
Version 3.1, 31 March 2009
General information: http://www.gnu.org/licenses/gcc-exception.html
Copyright (C) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
This GCC Runtime Library Exception (&quot;Exception&quot;) is an additional permission under section 7 of the GNU General Public License, version 3 (&quot;GPLv3&quot;). It applies to a given file (the &quot;Runtime Library&quot;) that bears a notice placed by the copyright holder of the file stating that the file is governed by GPLv3 along with this Exception.
When you use GCC to compile a program, GCC may combine portions of certain GCC header files and runtime libraries with the compiled program. The purpose of this Exception is to allow compilation of non-GPL (including proprietary) programs to use, in this way, the header files and runtime libraries covered by this Exception.
   0. Definitions.
   A file is an &quot;Independent Module&quot; if it either requires the Runtime Library for execution after a Compilation Process, or makes use of an interface provided by the Runtime Library, but is not otherwise based on the Runtime Library.
   &quot;GCC&quot; means a version of the GNU Compiler Collection, with or without modifications, governed by version 3 (or a specified later version) of the GNU General Public License (GPL) with the option of using any subsequent versions published by the FSF.
   &quot;GPL-compatible Software&quot; is software whose conditions of propagation, modification and use would permit combination with GCC in accord with the license of GCC.
   &quot;Target Code&quot; refers to output from any compiler for a real or virtual target processor architecture, in executable form or suitable for input to an assembler, loader, linker and/or execution phase. Notwithstanding that, Target Code does not include data in any format that is used as a compiler intermediate representation, or used for producing a compiler intermediate representation.
   The &quot;Compilation Process&quot; transforms code entirely represented in non-intermediate languages designed for human-written code, and/or in Java Virtual Machine byte code, into Target Code. Thus, for example, use of source code generators and preprocessors need not be considered part of the Compilation Process, since the Compilation Process can be understood as starting with the output of the generators or preprocessors.
   A Compilation Process is &quot;Eligible&quot; if it is done using GCC, alone or with other GPL-compatible software, or if it is done without using any work based on GCC. For example, using non-GPL-compatible Software to optimize any GCC intermediate representations would not qualify as an Eligible Compilation Process.
   1. Grant of Additional Permission.
   You have permission to propagate a work of Target Code formed by combining the Runtime Library with Independent Modules, even if such propagation would otherwise violate the terms of GPLv3, provided that all Target Code was generated by Eligible Compilation Processes. You may then convey such a combination under terms of your choice, consistent with the licensing of the Independent Modules.
   2. No Weakening of GCC Copyleft.
The availability of this Exception does not imply any general presumption that third-party software is unaffected by the copyleft requirements of the license of GCC.
```


### IPA

```
IPA Font License Agreement v1.0
The Licensor provides the Licensed Program (as defined in Article 1 below) under the terms of this license agreement (&quot;Agreement&quot;). Any use, reproduction or distribution of the Licensed Program, or any exercise of rights under this Agreement by a Recipient (as defined in Article 1 below) constitutes the Recipient&#39;s acceptance of this Agreement.
Article 1 (Definitions)
   1. &quot;Digital Font Program&quot; shall mean a computer program containing, or used to render or display fonts.
   2. &quot;Licensed Program&quot; shall mean a Digital Font Program licensed by the Licensor under this Agreement.
   3. &quot;Derived Program&quot; shall mean a Digital Font Program created as a result of a modification, addition, deletion, replacement or any other adaptation to or of a part or all of the Licensed Program, and includes a case where a Digital Font Program newly created by retrieving font information from a part or all of the Licensed Program or Embedded Fonts from a Digital Document File with or without modification of the retrieved font information.
   4. &quot;Digital Content&quot; shall mean products provided to end users in the form of digital data, including video content, motion and/or still pictures, TV programs or other broadcasting content and products consisting of character text, pictures, photographic images, graphic symbols and/or the like.
   5. &quot;Digital Document File&quot; shall mean a PDF file or other Digital Content created by various software programs in which a part or all of the Licensed Program becomes embedded or contained in the file for the display of the font (&quot;Embedded Fonts&quot;). Embedded Fonts are used only in the display of characters in the particular Digital Document File within which they are embedded, and shall be distinguished from those in any Digital Font Program, which may be used for display of characters outside that particular Digital Document File.
   6. &quot;Computer&quot; shall include a server in this Agreement.
   7. &quot;Reproduction and Other Exploitation&quot; shall mean reproduction, transfer, distribution, lease, public transmission, presentation, exhibition, adaptation and any other exploitation.
   8. &quot;Recipient&quot; shall mean anyone who receives the Licensed Program under this Agreement, including one that receives the Licensed Program from a Recipient.
Article 2 (Grant of License)
The Licensor grants to the Recipient a license to use the Licensed Program in any and all countries in accordance with each of the provisions set forth in this Agreement. However, any and all rights underlying in the Licensed Program shall be held by the Licensor. In no sense is this Agreement intended to transfer any right relating to the Licensed Program held by the Licensor except as specifically set forth herein or any right relating to any trademark, trade name, or service mark to the Recipient.
   1. The Recipient may install the Licensed Program on any number of Computers and use the same in accordance with the provisions set forth in this Agreement.
   2. The Recipient may use the Licensed Program, with or without modification in printed materials or in Digital Content as an expression of character texts or the like.
   3. The Recipient may conduct Reproduction and Other Exploitation of the printed materials and Digital Content created in accordance with the preceding Paragraph, for commercial or non-commercial purposes and in any form of media including but not limited to broadcasting, communication and various recording media.
   4. If any Recipient extracts Embedded Fonts from a Digital Document File to create a Derived Program, such Derived Program shall be subject to the terms of this agreement.
   5. If any Recipient performs Reproduction or Other Exploitation of a Digital Document File in which Embedded Fonts of the Licensed Program are used only for rendering the Digital Content within such Digital Document File then such Recipient shall have no further obligations under this Agreement in relation to such actions.
   6. The Recipient may reproduce the Licensed Program as is without modification and transfer such copies, publicly transmit or otherwise redistribute the Licensed Program to a third party for commercial or non-commercial purposes (&quot;Redistribute&quot;), in accordance with the provisions set forth in Article 3 Paragraph 2.
   7. The Recipient may create, use, reproduce and/or Redistribute a Derived Program under the terms stated above for the Licensed Program: provided, that the Recipient shall follow the provisions set forth in Article 3 Paragraph 1 when Redistributing the Derived Program.
Article 3 (Restriction)
The license granted in the preceding Article shall be subject to the following restrictions:
   1. If a Derived Program is Redistributed pursuant to Paragraph 4 and 7 of the preceding Article, the following conditions must be met :
      (1) The following must be also Redistributed together with the Derived Program, or be made available online or by means of mailing mechanisms in exchange for a cost which does not exceed the total costs of postage, storage medium and handling fees:
         (a) a copy of the Derived Program; and
         (b) any additional file created by the font developing program in the course of creating the Derived Program that can be used for further modification of the Derived Program, if any.
      (2) It is required to also Redistribute means to enable recipients of the Derived Program to replace the Derived Program with the Licensed Program first released under this License (the &quot;Original Program&quot;). Such means may be to provide a difference file from the Original Program, or instructions setting out a method to replace the Derived Program with the Original Program.
      (3) The Recipient must license the Derived Program under the terms and conditions of this Agreement.
      (4) No one may use or include the name of the Licensed Program as a program name, font name or file name of the Derived Program.
      (5) Any material to be made available online or by means of mailing a medium to satisfy the requirements of this paragraph may be provided, verbatim, by any party wishing to do so.
   2. If the Recipient Redistributes the Licensed Program pursuant to Paragraph 6 of the preceding Article, the Recipient shall meet all of the following conditions:
      (1) The Recipient may not change the name of the Licensed Program.
      (2) The Recipient may not alter or otherwise modify the Licensed Program.
      (3) The Recipient must attach a copy of this Agreement to the Licensed Program.
   3. THIS LICENSED PROGRAM IS PROVIDED BY THE LICENSOR &quot;AS IS&quot; AND ANY EXPRESSED OR IMPLIED WARRANTY AS TO THE LICENSED PROGRAM OR ANY DERIVED PROGRAM, INCLUDING, BUT NOT LIMITED TO, WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY, OR FITNESS FOR A PARTICULAR PURPOSE, ARE DISCLAIMED. IN NO EVENT SHALL THE LICENSOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXTENDED, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO; PROCUREMENT OF SUBSTITUTED GOODS OR SERVICE; DAMAGES ARISING FROM SYSTEM FAILURE; LOSS OR CORRUPTION OF EXISTING DATA OR PROGRAM; LOST PROFITS), HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE INSTALLATION, USE, THE REPRODUCTION OR OTHER EXPLOITATION OF THE LICENSED PROGRAM OR ANY DERIVED PROGRAM OR THE EXERCISE OF ANY RIGHTS GRANTED HEREUNDER, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   4. The Licensor is under no obligation to respond to any technical questions or inquiries, or provide any other user support in connection with the installation, use or the Reproduction and Other Exploitation of the Licensed Program or Derived Programs thereof.
Article 4 (Termination of Agreement)
   1. The term of this Agreement shall begin from the time of receipt of the Licensed Program by the Recipient and shall continue as long as the Recipient retains any such Licensed Program in any way.
   2. Notwithstanding the provision set forth in the preceding Paragraph, in the event of the breach of any of the provisions set forth in this Agreement by the Recipient, this Agreement shall automatically terminate without any notice. In the case of such termination, the Recipient may not use or conduct Reproduction and Other Exploitation of the Licensed Program or a Derived Program: provided that such termination shall not affect any rights of any other Recipient receiving the Licensed Program or the Derived Program from such Recipient who breached this Agreement.
Article 5 (Governing Law)
   1. IPA may publish revised and/or new versions of this License. In such an event, the Recipient may select either this Agreement or any subsequent version of the Agreement in using, conducting the Reproduction and Other Exploitation of, or Redistributing the Licensed Program or a Derived Program. Other matters not specified above shall be subject to the Copyright Law of Japan and other related laws and regulations of Japan.
   2. This Agreement shall be construed under the laws of Japan.
```


### ISC

```
ISC License
Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)
Copyright (c) 1995-2003 by Internet Software Consortium
Permission to use, copy, modify, and /or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot; AND ISC DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
```


### Info-ZIP

```
Info-ZIP License
Copyright (c) 1990-2009 Info-ZIP. All rights reserved.
For the purposes of this copyright and license, &quot;Info-ZIP&quot; is defined as the following set of individuals:
Mark Adler, John Bush, Karl Davis, Harald Denker, Jean-Michel Dubois, Jean-loup Gailly, Hunter Goatley, Ed Gordon, Ian Gorman, Chris Herborth, Dirk Haase, Greg Hartwig, Robert Heath, Jonathan Hudson, Paul Kienitz, David Kirschbaum, Johnny Lee, Onno van der Linden, Igor Mandrichenko, Steve P. Miller, Sergio Monesi, Keith Owens, George Petrov, Greg Roelofs, Kai Uwe Rommel, Steve Salisbury, Dave Smith, Steven M. Schweda, Christian Spieler, Cosmin Truta, Antoine Verheijen, Paul von Behren, Rich Wales, Mike White.
This software is provided &quot;as is,&quot; without warranty of any kind, express or implied. In no event shall Info-ZIP or its contributors be held liable for any direct, indirect, incidental, special or consequential damages arising out of the use of or inability to use this software.
Permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the above disclaimer and the following restrictions:
   * Redistributions of source code (in whole or in part) must retain the above copyright notice, definition, disclaimer, and this list of conditions.
   * Redistributions in binary form (compiled executables and libraries) must reproduce the above copyright notice, definition, disclaimer, and this list of conditions in documentation and/or other materials provided with the distribution. Additional documentation is not needed for executables where a command line license option provides these and a note regarding this option is in the executable&#39;s startup banner. The sole exception to this condition is redistribution of a standard UnZipSFX binary (including SFXWiz) as part of a self-extracting archive; that is permitted without inclusion of this license, as long as the normal SFX banner has not been removed from the binary or disabled.
   * Altered versions--including, but not limited to, ports to new operating systems, existing ports with new graphical interfaces, versions with modified or added functionality, and dynamic, shared, or static library versions not from Info-ZIP--must be plainly marked as such and must not be misrepresented as being the original source or, if binaries, compiled from the original source. Such altered versions also must not be misrepresented as being Info-ZIP releases--including, but not limited to, labeling of the altered versions with the names &quot;Info-ZIP&quot; (or any variation thereof, including, but not limited to, different capitalizations), &quot;Pocket UnZip,&quot; &quot;WiZ&quot; or &quot;MacZip&quot; without the explicit permission of Info-ZIP. Such altered versions are further prohibited from misrepresentative use of the Zip-Bugs or Info-ZIP e-mail addresses or the Info-ZIP URL(s), such as to imply Info-ZIP will provide support for the altered versions.
   * Info-ZIP retains the right to use the names &quot;Info-ZIP,&quot; &quot;Zip,&quot; &quot;UnZip,&quot; &quot;UnZipSFX,&quot; &quot;WiZ,&quot; &quot;Pocket UnZip,&quot; &quot;Pocket Zip,&quot; and &quot;MacZip&quot; for its own source and binary releases.
```


### LGPL-3.0-or-later

```
GNU LESSER GENERAL PUBLIC LICENSE
Version 3, 29 June 2007
Copyright (C) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
This version of the GNU Lesser General Public License incorporates the terms and conditions of version 3 of the GNU General Public License, supplemented by the additional permissions listed below.
   0. Additional Definitions.
      
      As used herein, &quot;this License&quot; refers to version 3 of the GNU Lesser General Public License, and the &quot;GNU GPL&quot; refers to version 3 of the GNU General Public License.
      
      &quot;The Library&quot; refers to a covered work governed by this License, other than an Application or a Combined Work as defined below.
      
      An &quot;Application&quot; is any work that makes use of an interface provided by the Library, but which is not otherwise based on the Library. Defining a subclass of a class defined by the Library is deemed a mode of using an interface provided by the Library.
      
      A &quot;Combined Work&quot; is a work produced by combining or linking an Application with the Library. The particular version of the Library with which the Combined Work was made is also called the &quot;Linked Version&quot;.
      
      The &quot;Minimal Corresponding Source&quot; for a Combined Work means the Corresponding Source for the Combined Work, excluding any source code for portions of the Combined Work that, considered in isolation, are based on the Application, and not on the Linked Version.
      
      The &quot;Corresponding Application Code&quot; for a Combined Work means the object code and/or source code for the Application, including any data and utility programs needed for reproducing the Combined Work from the Application, but excluding the System Libraries of the Combined Work.
   1. Exception to Section 3 of the GNU GPL.
   You may convey a covered work under sections 3 and 4 of this License without being bound by section 3 of the GNU GPL.
   2. Conveying Modified Versions.
   If you modify a copy of the Library, and, in your modifications, a facility refers to a function or data to be supplied by an Application that uses the facility (other than as an argument passed when the facility is invoked), then you may convey a copy of the modified version:
      a) under this License, provided that you make a good faith effort to ensure that, in the event an Application does not supply the function or data, the facility still operates, and performs whatever part of its purpose remains meaningful, or
      b) under the GNU GPL, with none of the additional permissions of this License applicable to that copy.
   3. Object Code Incorporating Material from Library Header Files.
   The object code form of an Application may incorporate material from a header file that is part of the Library. You may convey such object code under terms of your choice, provided that, if the incorporated material is not limited to numerical parameters, data structure layouts and accessors, or small macros, inline functions and templates (ten or fewer lines in length), you do both of the following:
      a) Give prominent notice with each copy of the object code that the Library is used in it and that the Library and its use are covered by this License.
      b) Accompany the object code with a copy of the GNU GPL and this license document.
   4. Combined Works.
   You may convey a Combined Work under terms of your choice that, taken together, effectively do not restrict modification of the portions of the Library contained in the Combined Work and reverse engineering for debugging such modifications, if you also do each of the following:
      a) Give prominent notice with each copy of the Combined Work that the Library is used in it and that the Library and its use are covered by this License.
      b) Accompany the Combined Work with a copy of the GNU GPL and this license document.
      c) For a Combined Work that displays copyright notices during execution, include the copyright notice for the Library among these notices, as well as a reference directing the user to the copies of the GNU GPL and this license document.
      d) Do one of the following:
         0) Convey the Minimal Corresponding Source under the terms of this License, and the Corresponding Application Code in a form suitable for, and under terms that permit, the user to recombine or relink the Application with a modified version of the Linked Version to produce a modified Combined Work, in the manner specified by section 6 of the GNU GPL for conveying Corresponding Source.
         1) Use a suitable shared library mechanism for linking with the Library. A suitable mechanism is one that (a) uses at run time a copy of the Library already present on the user&#39;s computer system, and (b) will operate properly with a modified version of the Library that is interface-compatible with the Linked Version.
      e) Provide Installation Information, but only if you would otherwise be required to provide such information under section 6 of the GNU GPL, and only to the extent that such information is necessary to install and execute a modified version of the Combined Work produced by recombining or relinking the Application with a modified version of the Linked Version. (If you use option 4d0, the Installation Information must accompany the Minimal Corresponding Source and Corresponding Application Code. If you use option 4d1, you must provide the Installation Information in the manner specified by section 6 of the GNU GPL for conveying Corresponding Source.)
   5. Combined Libraries.
   You may place library facilities that are a work based on the Library side by side in a single library together with other library facilities that are not Applications and are not covered by this License, and convey such a combined library under terms of your choice, if you do both of the following:
      a) Accompany the combined library with a copy of the same work based on the Library, uncombined with any other library facilities, conveyed under the terms of this License.
      b) Give prominent notice with the combined library that part of it is a work based on the Library, and explaining where to find the accompanying uncombined form of the same work.
   6. Revised Versions of the GNU Lesser General Public License.
   The Free Software Foundation may publish revised and/or new versions of the GNU Lesser General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Library as you received it specifies that a certain numbered version of the GNU Lesser General Public License &quot;or any later version&quot; applies to it, you have the option of following the terms and conditions either of that published version or of any later version published by the Free Software Foundation. If the Library as you received it does not specify a version number of the GNU Lesser General Public License, you may choose any version of the GNU Lesser General Public License ever published by the Free Software Foundation.
   If the Library as you received it specifies that a proxy can decide whether future versions of the GNU Lesser General Public License shall apply, that proxy&#39;s public statement of acceptance of any version is permanent authorization for you to choose that version for the Library.
```


### Apache-2.0

```
License text copyright © 2017 MariaDB Corporation Ab, All Rights Reserved.
“Business Source License” is a trademark of MariaDB Corporation Ab.

Licensed Work: MetricFlow

Change Date: The change date for each release of the Licensed Work will
be the 3rd anniversary of the initial release date of that
release of the Licensed Work.

Change License: Apache 2.0 https://www.apache.org/licenses/LICENSE-2.0

Additional Use Grant: The Licensor hereby grants you the right to use the
Licensed Work for production purposes that consist of
your internal business purposes, but not for the purpose
of providing managed services or software-as-a-service
to others.

Terms

The Licensor hereby grants you the right to copy, modify, create derivative
works, redistribute, and make non-production use of the Licensed Work. The
Licensor may make an Additional Use Grant, above, permitting limited production
use.

Effective on the Change Date, or the fourth anniversary of the first publicly
available distribution of a specific version of the Licensed Work under this
License, whichever comes first, the Licensor hereby grants you rights under the
terms of the Change License, and the rights granted in the paragraph above
terminate.

If your use of the Licensed Work does not comply with the requirements currently
in effect as described in this License, you must purchase a commercial license
from the Licensor, its affiliated entities, or authorized resellers, or you must
refrain from using the Licensed Work.

All copies of the original and modified Licensed Work, and derivative works of
the Licensed Work, are subject to this License. This License applies separately
for each version of the Licensed Work and the Change Date may vary for each
version of the Licensed Work released by Licensor.

You must conspicuously display this License on each original or modified copy of
the Licensed Work. If you receive the Licensed Work in original or modified form
from a third party, the terms and conditions set forth in this License apply to
your use of that work.

Any use of the Licensed Work in violation of this License will automatically
terminate your rights under this License for the current and all other versions
of the Licensed Work.

This License does not grant you any right in any trademark or logo of Licensor
or its affiliates (provided that you may use a trademark or logo of Licensor as
expressly required by this License).TO THE EXTENT PERMITTED BY APPLICABLE LAW,
THE LICENSED WORK IS PROVIDED ON AN “AS IS” BASIS. LICENSOR HEREBY DISCLAIMS ALL
WARRANTIES AND CONDITIONS, EXPRESS OR IMPLIED, INCLUDING (WITHOUT LIMITATION)
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE,
NON-INFRINGEMENT, AND TITLE.MariaDB hereby grants you permission to use this
License’s text to license your works, and to refer to it using the trademark
“Business Source License”, as long as you comply with the Covenants of Licensor
below.

Covenants of Licensor

In consideration of the right to use this License’s text and the “Business
Source License” name and trademark, Licensor covenants to MariaDB, and to all
other recipients of the licensed work to be provided by Licensor:

To specify as the Change License the GPL Version 2.0 or any later version, or a
license that is compatible with GPL Version 2.0 or a later version, where
“compatible” means that software provided under the Change License can be
included in a program with software provided under GPL Version 2.0 or a later
version. Licensor may specify additional Change Licenses without limitation.

To either: (a) specify an additional grant of rights to use that does not impose
any additional restriction on the right granted in this License, as the
Additional Use Grant; or (b) insert the text “None”.

To specify a Change Date.

Not to modify this License in any other way.

Notice

The Business Source License (this document, or the “License”) is not an Open
Source license. However, the Licensed Work will eventually be made available
under an Open Source License, as stated in this License.

For more information on the use of the Business Source License for MariaDB
products, please visit the MariaDB Business Source License FAQ. For more
information on the use of the Business Source License generally, please visit
the Adopting and Developing Business Source License FAQ.

```


### MIT

```
MIT License
Copyright (c) &lt;year&gt; &lt;copyright holders&gt;

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```


### MIT

```
MIT License

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```


### MIT

```
MIT License

Copyright (c) 2017 Manraj Singh

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```


### MIT

```
MIT License

Copyright (c) 2025 TAHRI Ahmed R.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```


### MPL-2.0

```
Mozilla Public License Version 2.0
   1. Definitions
      1.1. &quot;Contributor&quot; means each individual or legal entity that creates, contributes to the creation of, or owns Covered Software.
      1.2. &quot;Contributor Version&quot; means the combination of the Contributions of others (if any) used by a Contributor and that particular Contributor&#39;s Contribution.
      1.3. &quot;Contribution&quot; means Covered Software of a particular Contributor.
      1.4. &quot;Covered Software&quot; means Source Code Form to which the initial Contributor has attached the notice in Exhibit A, the Executable Form of such Source Code Form, and Modifications of such Source Code Form, in each case including portions thereof.
      1.5. &quot;Incompatible With Secondary Licenses&quot; means
         (a) that the initial Contributor has attached the notice described in Exhibit B to the Covered Software; or
         (b) that the Covered Software was made available under the terms of version 1.1 or earlier of the License, but not also under the terms of a Secondary License.
      1.6. &quot;Executable Form&quot; means any form of the work other than Source Code Form.
      1.7. &quot;Larger Work&quot; means a work that combines Covered Software with other material, in a separate file or files, that is not Covered Software.
      1.8. &quot;License&quot; means this document.
      1.9. &quot;Licensable&quot; means having the right to grant, to the maximum extent possible, whether at the time of the initial grant or subsequently, any and all of the rights conveyed by this License.
      1.10. &quot;Modifications&quot; means any of the following:
         (a) any file in Source Code Form that results from an addition to, deletion from, or modification of the contents of Covered Software; or
         (b) any new file in Source Code Form that contains any Covered Software.
      1.11. &quot;Patent Claims&quot; of a Contributor means any patent claim(s), including without limitation, method, process, and apparatus claims, in any patent Licensable by such Contributor that would be infringed, but for the grant of the License, by the making, using, selling, offering for sale, having made, import, or transfer of either its Contributions or its Contributor Version.
      1.12. &quot;Secondary License&quot; means either the GNU General Public License, Version 2.0, the GNU Lesser General Public License, Version 2.1, the GNU Affero General Public License, Version 3.0, or any later versions of those licenses.
      1.13. &quot;Source Code Form&quot; means the form of the work preferred for making modifications.
      1.14. &quot;You&quot; (or &quot;Your&quot;) means an individual or a legal entity exercising rights under this License. For legal entities, &quot;You&quot; includes any entity that controls, is controlled by, or is under common control with You. For purposes of this definition, &quot;control&quot; means (a) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (b) ownership of more than fifty percent (50%) of the outstanding shares or beneficial ownership of such entity.
   2. License Grants and Conditions
      2.1. Grants
      Each Contributor hereby grants You a world-wide, royalty-free, non-exclusive license:
         (a) under intellectual property rights (other than patent or trademark) Licensable by such Contributor to use, reproduce, make available, modify, display, perform, distribute, and otherwise exploit its Contributions, either on an unmodified basis, with Modifications, or as part of a Larger Work; and
         (b) under Patent Claims of such Contributor to make, use, sell, offer for sale, have made, import, and otherwise transfer either its Contributions or its Contributor Version.
      2.2. Effective Date
      The licenses granted in Section 2.1 with respect to any Contribution become effective for each Contribution on the date the Contributor first distributes such Contribution.
      2.3. Limitations on Grant Scope
      The licenses granted in this Section 2 are the only rights granted under this License. No additional rights or licenses will be implied from the distribution or licensing of Covered Software under this License. Notwithstanding Section 2.1(b) above, no patent license is granted by a Contributor:
         (a) for any code that a Contributor has removed from Covered Software; or
         (b) for infringements caused by: (i) Your and any other third party&#39;s modifications of Covered Software, or (ii) the combination of its Contributions with other software (except as part of its Contributor Version); or
         (c) under Patent Claims infringed by Covered Software in the absence of its Contributions.
      This License does not grant any rights in the trademarks, service marks, or logos of any Contributor (except as may be necessary to comply with the notice requirements in Section 3.4).
      2.4. Subsequent Licenses
      No Contributor makes additional grants as a result of Your choice to distribute the Covered Software under a subsequent version of this License (see Section 10.2) or under the terms of a Secondary License (if permitted under the terms of Section 3.3).
      2.5. Representation
      Each Contributor represents that the Contributor believes its Contributions are its original creation(s) or it has sufficient rights to grant the rights to its Contributions conveyed by this License.
      2.6. Fair Use
      This License is not intended to limit any rights You have under applicable copyright doctrines of fair use, fair dealing, or other equivalents.
      2.7. Conditions
      Sections 3.1, 3.2, 3.3, and 3.4 are conditions of the licenses granted in Section 2.1.
   3. Responsibilities
      3.1. Distribution of Source Form
      All distribution of Covered Software in Source Code Form, including any Modifications that You create or to which You contribute, must be under the terms of this License. You must inform recipients that the Source Code Form of the Covered Software is governed by the terms of this License, and how they can obtain a copy of this License. You may not attempt to alter or restrict the recipients&#39; rights in the Source Code Form.
      3.2. Distribution of Executable Form
      If You distribute Covered Software in Executable Form then:
         (a) such Covered Software must also be made available in Source Code Form, as described in Section 3.1, and You must inform recipients of the Executable Form how they can obtain a copy of such Source Code Form by reasonable means in a timely manner, at a charge no more than the cost of distribution to the recipient; and
         (b) You may distribute such Executable Form under the terms of this License, or sublicense it under different terms, provided that the license for the Executable Form does not attempt to limit or alter the recipients&#39; rights in the Source Code Form under this License.
      3.3. Distribution of a Larger Work
      You may create and distribute a Larger Work under terms of Your choice, provided that You also comply with the requirements of this License for the Covered Software. If the Larger Work is a combination of Covered Software with a work governed by one or more Secondary Licenses, and the Covered Software is not Incompatible With Secondary Licenses, this License permits You to additionally distribute such Covered Software under the terms of such Secondary License(s), so that the recipient of the Larger Work may, at their option, further distribute the Covered Software under the terms of either this License or such Secondary License(s).
      3.4. Notices
      You may not remove or alter the substance of any license notices (including copyright notices, patent notices, disclaimers of warranty, or limitations of liability) contained within the Source Code Form of the Covered Software, except that You may alter any license notices to the extent required to remedy known factual inaccuracies.
      3.5. Application of Additional Terms
      You may choose to offer, and to charge a fee for, warranty, support, indemnity or liability obligations to one or more recipients of Covered Software. However, You may do so only on Your own behalf, and not on behalf of any Contributor. You must make it absolutely clear that any such warranty, support, indemnity, or liability obligation is offered by You alone, and You hereby agree to indemnify every Contributor for any liability incurred by such Contributor as a result of warranty, support, indemnity or liability terms You offer. You may include additional disclaimers of warranty and limitations of liability specific to any jurisdiction.
   4. Inability to Comply Due to Statute or Regulation
   If it is impossible for You to comply with any of the terms of this License with respect to some or all of the Covered Software due to statute, judicial order, or regulation then You must: (a) comply with the terms of this License to the maximum extent possible; and (b) describe the limitations and the code they affect. Such description must be placed in a text file included with all distributions of the Covered Software under this License. Except to the extent prohibited by statute or regulation, such description must be sufficiently detailed for a recipient of ordinary skill to be able to understand it.
   5. Termination
      5.1. The rights granted under this License will terminate automatically if You fail to comply with any of its terms. However, if You become compliant, then the rights granted under this License from a particular Contributor are reinstated (a) provisionally, unless and until such Contributor explicitly and finally terminates Your grants, and (b) on an ongoing basis, if such Contributor fails to notify You of the non-compliance by some reasonable means prior to 60 days after You have come back into compliance. Moreover, Your grants from a particular Contributor are reinstated on an ongoing basis if such Contributor notifies You of the non-compliance by some reasonable means, this is the first time You have received notice of non-compliance with this License from such Contributor, and You become compliant prior to 30 days after Your receipt of the notice.
      5.2. If You initiate litigation against any entity by asserting a patent infringement claim (excluding declaratory judgment actions, counter-claims, and cross-claims) alleging that a Contributor Version directly or indirectly infringes any patent, then the rights granted to You by any and all Contributors for the Covered Software under Section 2.1 of this License shall terminate.
      5.3. In the event of termination under Sections 5.1 or 5.2 above, all end user license agreements (excluding distributors and resellers) which have been validly granted by You or Your distributors under this License prior to termination shall survive termination.
   6. Disclaimer of Warranty
   Covered Software is provided under this License on an &quot;as is&quot; basis, without warranty of any kind, either expressed, implied, or statutory, including, without limitation, warranties that the Covered Software is free of defects, merchantable, fit for a particular purpose or non-infringing. The entire risk as to the quality and performance of the Covered Software is with You. Should any Covered Software prove defective in any respect, You (not any Contributor) assume the cost of any necessary servicing, repair, or correction. This disclaimer of warranty constitutes an essential part of this License. No use of any Covered Software is authorized under this License except under this disclaimer.
   7. Limitation of Liability
   Under no circumstances and under no legal theory, whether tort (including negligence), contract, or otherwise, shall any Contributor, or anyone who distributes Covered Software as permitted above, be liable to You for any direct, indirect, special, incidental, or consequential damages of any character including, without limitation, damages for lost profits, loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses, even if such party shall have been informed of the possibility of such damages. This limitation of liability shall not apply to liability for death or personal injury resulting from such party&#39;s negligence to the extent applicable law prohibits such limitation. Some jurisdictions do not allow the exclusion or limitation of incidental or consequential damages, so this exclusion and limitation may not apply to You.
   8. Litigation
   Any litigation relating to this License may be brought only in the courts of a jurisdiction where the defendant maintains its principal place of business and such litigation shall be governed by laws of that jurisdiction, without reference to its conflict-of-law provisions. Nothing in this Section shall prevent a party&#39;s ability to bring cross-claims or counter-claims.
   9. Miscellaneous
   This License represents the complete agreement concerning the subject matter hereof. If any provision of this License is held to be unenforceable, such provision shall be reformed only to the extent necessary to make it enforceable. Any law or regulation which provides that the language of a contract shall be construed against the drafter shall not be used to construe this License against a Contributor.
   10. Versions of the License
      10.1. New Versions
      Mozilla Foundation is the license steward. Except as provided in Section 10.3, no one other than the license steward has the right to modify or publish new versions of this License. Each version will be given a distinguishing version number.
      10.2. Effect of New Versions
      You may distribute the Covered Software under the terms of the version of the License under which You originally received the Covered Software, or under the terms of any subsequent version published by the license steward.
      10.3. Modified Versions
      If you create software not governed by this License, and you want to create a new license for such software, you may create and use a modified version of this License if you rename the license and remove any references to the name of the license steward (except to note that such modified license differs from this License).
      10.4. Distributing Source Code Form that is Incompatible With Secondary Licenses
      If You choose to distribute Source Code Form that is Incompatible With Secondary Licenses under the terms of this version of the License, the notice described in Exhibit B of this License must be attached. Exhibit A - Source Code Form License Notice
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
If it is not possible or desirable to put the notice in a particular file, then You may include the notice in a location (such as a LICENSE file in a relevant directory) where a recipient would be likely to look for such a notice.
You may add additional accurate notices of copyright ownership.
Exhibit B - &quot;Incompatible With Secondary Licenses&quot; Notice
This Source Code Form is &quot;Incompatible With Secondary Licenses&quot;, as defined by the Mozilla Public License, v. 2.0.
```


### MPL-2.0

```
Mozilla Public License Version 2.0
==================================

1. Definitions
--------------

1.1. &quot;Contributor&quot;
    means each individual or legal entity that creates, contributes to
    the creation of, or owns Covered Software.

1.2. &quot;Contributor Version&quot;
    means the combination of the Contributions of others (if any) used
    by a Contributor and that particular Contributor&#39;s Contribution.

1.3. &quot;Contribution&quot;
    means Covered Software of a particular Contributor.

1.4. &quot;Covered Software&quot;
    means Source Code Form to which the initial Contributor has attached
    the notice in Exhibit A, the Executable Form of such Source Code
    Form, and Modifications of such Source Code Form, in each case
    including portions thereof.

1.5. &quot;Incompatible With Secondary Licenses&quot;
    means

    (a) that the initial Contributor has attached the notice described
        in Exhibit B to the Covered Software; or

    (b) that the Covered Software was made available under the terms of
        version 1.1 or earlier of the License, but not also under the
        terms of a Secondary License.

1.6. &quot;Executable Form&quot;
    means any form of the work other than Source Code Form.

1.7. &quot;Larger Work&quot;
    means a work that combines Covered Software with other material, in 
    a separate file or files, that is not Covered Software.

1.8. &quot;License&quot;
    means this document.

1.9. &quot;Licensable&quot;
    means having the right to grant, to the maximum extent possible,
    whether at the time of the initial grant or subsequently, any and
    all of the rights conveyed by this License.

1.10. &quot;Modifications&quot;
    means any of the following:

    (a) any file in Source Code Form that results from an addition to,
        deletion from, or modification of the contents of Covered
        Software; or

    (b) any new file in Source Code Form that contains any Covered
        Software.

1.11. &quot;Patent Claims&quot; of a Contributor
    means any patent claim(s), including without limitation, method,
    process, and apparatus claims, in any patent Licensable by such
    Contributor that would be infringed, but for the grant of the
    License, by the making, using, selling, offering for sale, having
    made, import, or transfer of either its Contributions or its
    Contributor Version.

1.12. &quot;Secondary License&quot;
    means either the GNU General Public License, Version 2.0, the GNU
    Lesser General Public License, Version 2.1, the GNU Affero General
    Public License, Version 3.0, or any later versions of those
    licenses.

1.13. &quot;Source Code Form&quot;
    means the form of the work preferred for making modifications.

1.14. &quot;You&quot; (or &quot;Your&quot;)
    means an individual or a legal entity exercising rights under this
    License. For legal entities, &quot;You&quot; includes any entity that
    controls, is controlled by, or is under common control with You. For
    purposes of this definition, &quot;control&quot; means (a) the power, direct
    or indirect, to cause the direction or management of such entity,
    whether by contract or otherwise, or (b) ownership of more than
    fifty percent (50%) of the outstanding shares or beneficial
    ownership of such entity.

2. License Grants and Conditions
--------------------------------

2.1. Grants

Each Contributor hereby grants You a world-wide, royalty-free,
non-exclusive license:

(a) under intellectual property rights (other than patent or trademark)
    Licensable by such Contributor to use, reproduce, make available,
    modify, display, perform, distribute, and otherwise exploit its
    Contributions, either on an unmodified basis, with Modifications, or
    as part of a Larger Work; and

(b) under Patent Claims of such Contributor to make, use, sell, offer
    for sale, have made, import, and otherwise transfer either its
    Contributions or its Contributor Version.

2.2. Effective Date

The licenses granted in Section 2.1 with respect to any Contribution
become effective for each Contribution on the date the Contributor first
distributes such Contribution.

2.3. Limitations on Grant Scope

The licenses granted in this Section 2 are the only rights granted under
this License. No additional rights or licenses will be implied from the
distribution or licensing of Covered Software under this License.
Notwithstanding Section 2.1(b) above, no patent license is granted by a
Contributor:

(a) for any code that a Contributor has removed from Covered Software;
    or

(b) for infringements caused by: (i) Your and any other third party&#39;s
    modifications of Covered Software, or (ii) the combination of its
    Contributions with other software (except as part of its Contributor
    Version); or

(c) under Patent Claims infringed by Covered Software in the absence of
    its Contributions.

This License does not grant any rights in the trademarks, service marks,
or logos of any Contributor (except as may be necessary to comply with
the notice requirements in Section 3.4).

2.4. Subsequent Licenses

No Contributor makes additional grants as a result of Your choice to
distribute the Covered Software under a subsequent version of this
License (see Section 10.2) or under the terms of a Secondary License (if
permitted under the terms of Section 3.3).

2.5. Representation

Each Contributor represents that the Contributor believes its
Contributions are its original creation(s) or it has sufficient rights
to grant the rights to its Contributions conveyed by this License.

2.6. Fair Use

This License is not intended to limit any rights You have under
applicable copyright doctrines of fair use, fair dealing, or other
equivalents.

2.7. Conditions

Sections 3.1, 3.2, 3.3, and 3.4 are conditions of the licenses granted
in Section 2.1.

3. Responsibilities
-------------------

3.1. Distribution of Source Form

All distribution of Covered Software in Source Code Form, including any
Modifications that You create or to which You contribute, must be under
the terms of this License. You must inform recipients that the Source
Code Form of the Covered Software is governed by the terms of this
License, and how they can obtain a copy of this License. You may not
attempt to alter or restrict the recipients&#39; rights in the Source Code
Form.

3.2. Distribution of Executable Form

If You distribute Covered Software in Executable Form then:

(a) such Covered Software must also be made available in Source Code
    Form, as described in Section 3.1, and You must inform recipients of
    the Executable Form how they can obtain a copy of such Source Code
    Form by reasonable means in a timely manner, at a charge no more
    than the cost of distribution to the recipient; and

(b) You may distribute such Executable Form under the terms of this
    License, or sublicense it under different terms, provided that the
    license for the Executable Form does not attempt to limit or alter
    the recipients&#39; rights in the Source Code Form under this License.

3.3. Distribution of a Larger Work

You may create and distribute a Larger Work under terms of Your choice,
provided that You also comply with the requirements of this License for
the Covered Software. If the Larger Work is a combination of Covered
Software with a work governed by one or more Secondary Licenses, and the
Covered Software is not Incompatible With Secondary Licenses, this
License permits You to additionally distribute such Covered Software
under the terms of such Secondary License(s), so that the recipient of
the Larger Work may, at their option, further distribute the Covered
Software under the terms of either this License or such Secondary
License(s).

3.4. Notices

You may not remove or alter the substance of any license notices
(including copyright notices, patent notices, disclaimers of warranty,
or limitations of liability) contained within the Source Code Form of
the Covered Software, except that You may alter any license notices to
the extent required to remedy known factual inaccuracies.

3.5. Application of Additional Terms

You may choose to offer, and to charge a fee for, warranty, support,
indemnity or liability obligations to one or more recipients of Covered
Software. However, You may do so only on Your own behalf, and not on
behalf of any Contributor. You must make it absolutely clear that any
such warranty, support, indemnity, or liability obligation is offered by
You alone, and You hereby agree to indemnify every Contributor for any
liability incurred by such Contributor as a result of warranty, support,
indemnity or liability terms You offer. You may include additional
disclaimers of warranty and limitations of liability specific to any
jurisdiction.

4. Inability to Comply Due to Statute or Regulation
---------------------------------------------------

If it is impossible for You to comply with any of the terms of this
License with respect to some or all of the Covered Software due to
statute, judicial order, or regulation then You must: (a) comply with
the terms of this License to the maximum extent possible; and (b)
describe the limitations and the code they affect. Such description must
be placed in a text file included with all distributions of the Covered
Software under this License. Except to the extent prohibited by statute
or regulation, such description must be sufficiently detailed for a
recipient of ordinary skill to be able to understand it.

5. Termination
--------------

5.1. The rights granted under this License will terminate automatically
if You fail to comply with any of its terms. However, if You become
compliant, then the rights granted under this License from a particular
Contributor are reinstated (a) provisionally, unless and until such
Contributor explicitly and finally terminates Your grants, and (b) on an
ongoing basis, if such Contributor fails to notify You of the
non-compliance by some reasonable means prior to 60 days after You have
come back into compliance. Moreover, Your grants from a particular
Contributor are reinstated on an ongoing basis if such Contributor
notifies You of the non-compliance by some reasonable means, this is the
first time You have received notice of non-compliance with this License
from such Contributor, and You become compliant prior to 30 days after
Your receipt of the notice.

5.2. If You initiate litigation against any entity by asserting a patent
infringement claim (excluding declaratory judgment actions,
counter-claims, and cross-claims) alleging that a Contributor Version
directly or indirectly infringes any patent, then the rights granted to
You by any and all Contributors for the Covered Software under Section
2.1 of this License shall terminate.

5.3. In the event of termination under Sections 5.1 or 5.2 above, all
end user license agreements (excluding distributors and resellers) which
have been validly granted by You or Your distributors under this License
prior to termination shall survive termination.

************************************************************************
*                                                                      *
*  6. Disclaimer of Warranty                                           *
*  -------------------------                                           *
*                                                                      *
*  Covered Software is provided under this License on an &quot;as is&quot;       *
*  basis, without warranty of any kind, either expressed, implied, or  *
*  statutory, including, without limitation, warranties that the       *
*  Covered Software is free of defects, merchantable, fit for a        *
*  particular purpose or non-infringing. The entire risk as to the     *
*  quality and performance of the Covered Software is with You.        *
*  Should any Covered Software prove defective in any respect, You     *
*  (not any Contributor) assume the cost of any necessary servicing,   *
*  repair, or correction. This disclaimer of warranty constitutes an   *
*  essential part of this License. No use of any Covered Software is   *
*  authorized under this License except under this disclaimer.         *
*                                                                      *
************************************************************************

************************************************************************
*                                                                      *
*  7. Limitation of Liability                                          *
*  --------------------------                                          *
*                                                                      *
*  Under no circumstances and under no legal theory, whether tort      *
*  (including negligence), contract, or otherwise, shall any           *
*  Contributor, or anyone who distributes Covered Software as          *
*  permitted above, be liable to You for any direct, indirect,         *
*  special, incidental, or consequential damages of any character      *
*  including, without limitation, damages for lost profits, loss of    *
*  goodwill, work stoppage, computer failure or malfunction, or any    *
*  and all other commercial damages or losses, even if such party      *
*  shall have been informed of the possibility of such damages. This   *
*  limitation of liability shall not apply to liability for death or   *
*  personal injury resulting from such party&#39;s negligence to the       *
*  extent applicable law prohibits such limitation. Some               *
*  jurisdictions do not allow the exclusion or limitation of           *
*  incidental or consequential damages, so this exclusion and          *
*  limitation may not apply to You.                                    *
*                                                                      *
************************************************************************

8. Litigation
-------------

Any litigation relating to this License may be brought only in the
courts of a jurisdiction where the defendant maintains its principal
place of business and such litigation shall be governed by laws of that
jurisdiction, without reference to its conflict-of-law provisions.
Nothing in this Section shall prevent a party&#39;s ability to bring
cross-claims or counter-claims.

9. Miscellaneous
----------------

This License represents the complete agreement concerning the subject
matter hereof. If any provision of this License is held to be
unenforceable, such provision shall be reformed only to the extent
necessary to make it enforceable. Any law or regulation which provides
that the language of a contract shall be construed against the drafter
shall not be used to construe this License against a Contributor.

10. Versions of the License
---------------------------

10.1. New Versions

Mozilla Foundation is the license steward. Except as provided in Section
10.3, no one other than the license steward has the right to modify or
publish new versions of this License. Each version will be given a
distinguishing version number.

10.2. Effect of New Versions

You may distribute the Covered Software under the terms of the version
of the License under which You originally received the Covered Software,
or under the terms of any subsequent version published by the license
steward.

10.3. Modified Versions

If you create software not governed by this License, and you want to
create a new license for such software, you may create and use a
modified version of this License if you rename the license and remove
any references to the name of the license steward (except to note that
such modified license differs from this License).

10.4. Distributing Source Code Form that is Incompatible With Secondary
Licenses

If You choose to distribute Source Code Form that is Incompatible With
Secondary Licenses under the terms of this version of the License, the
notice described in Exhibit B of this License must be attached.

Exhibit A - Source Code Form License Notice
-------------------------------------------

  This Source Code Form is subject to the terms of the Mozilla Public
  License, v. 2.0. If a copy of the MPL was not distributed with this
  file, You can obtain one at http://mozilla.org/MPL/2.0/.

If it is not possible or desirable to put the notice in a particular
file, then You may include the notice in a location (such as a LICENSE
file in a relevant directory) where a recipient would be likely to look
for such a notice.

You may add additional accurate notices of copyright ownership.

Exhibit B - &quot;Incompatible With Secondary Licenses&quot; Notice
---------------------------------------------------------

  This Source Code Form is &quot;Incompatible With Secondary Licenses&quot;, as
  defined by the Mozilla Public License, v. 2.0.

```


### NCSA

```
University of Illinois/NCSA Open Source License
Copyright (c) &lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.
Developed by: 
&lt;Name of Development Group&gt;
&lt;Name of Institution&gt;
&lt;URL for Development Group/Institution&gt;
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal with the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
   * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimers.
   * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimers in the documentation and/or other materials provided with the distribution.
   * Neither the names of &lt;Name of Development Group, Name of Institution&gt; , nor the names of its contributors may be used to endorse or promote products derived from this Software without specific prior written permission.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
```


### BSD-3-Clause

```
NetworkX is distributed with the 3-clause BSD license.

::

   Copyright (C) 2004-2024, NetworkX Developers
   Aric Hagberg &lt;hagberg@lanl.gov&gt;
   Dan Schult &lt;dschult@colgate.edu&gt;
   Pieter Swart &lt;swart@lanl.gov&gt;
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are
   met:

     * Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.

     * Redistributions in binary form must reproduce the above
       copyright notice, this list of conditions and the following
       disclaimer in the documentation and/or other materials provided
       with the distribution.

     * Neither the name of the NetworkX Developers nor the names of its
       contributors may be used to endorse or promote products derived
       from this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   &quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

```


### OLDAP-1.1

```
The OpenLDAP Public License
Version 1.1, 25 August 1998
Copyright 1998, The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;
PREAMBLE
The intent of this document is to state the conditions under which a Package may be copied, such that the Copyright Holder maintains some semblance of artistic control over the development of the package, while giving the users of the package the right to use and distribute the Package in a more-or-less customary fashion, plus the right to make reasonable modifications.
Definitions:
&quot;Package&quot; refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
&quot;Standard Version&quot; refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder.
&quot;Copyright Holder&quot; is whoever is named in the copyright or copyrights for the package.
&quot;You&quot; is you, if you&#39;re thinking about copying or distributing this Package.
&quot;Reasonable copying fee&quot; is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
&quot;Freely Available&quot; means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as uunet.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
      b) use the modified Package only within your corporation or organization.
      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
      b) accompany the distribution with the machine-readable source of the Package with your modifications.
      c) accompany any non-standard executables with their corresponding Standard Version executables, giving the non-standard executables non-standard names, and clearly documenting the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own.
   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.
   7. C subroutines supplied by you and linked into this Package in order to emulate subroutines and variables of the language defined by this Package shall not be considered part of this Package, but are the equivalent of input as in Paragraph 6, provided these subroutines do not change the language in any way that would cause it to fail the regression tests for the language.
   8. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
   9. THIS PACKAGE IS PROVIDED &quot;AS IS&quot; AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE. The End
```


### OPL-1.0

```
OPEN PUBLIC LICENSE
Version 1.0
   1. Definitions.
      1.1. &quot;Contributor&quot; means each entity that creates or contributes to the creation of Modifications.
      1.2. &quot;Contributor Version&quot; means the combination of the Original Code, prior Modifications used by a Contributor, and the Modifications made by that particular Contributor.
      1.3. &quot;Covered Code&quot; means the Original Code or Modifications or the combination of the Original Code and Modifications, in each case including portions thereof.
      1.4. &quot;Electronic Distribution Mechanism&quot; means a mechanism generally accepted in the software development community for the electronic transfer of data.
      1.5. &quot;Executable&quot; means Covered Code in any form other than Source Code.
      1.6. &quot;Initial Developer&quot; means the individual or entity identified as the Initial Developer in the Source Code notice required by Exhibit A.
      1.7. &quot;Larger Work&quot; means a work, which combines Covered Code or portions thereof with code not governed by the terms of this License.
      1.8. &quot;License&quot; means this document and the corresponding addendum described in section 6.4 below.
      1.9. &quot;Modifications&quot; means any addition to or deletion from the substance or structure of either the Original Code or any previous Modifications. When Covered Code is released as a series of files, a Modification is:
         A. Any addition to or deletion from the contents of a file containing Original Code or previous Modifications.
         B. Any new file that contains any part of the Original Code or previous Modifications.
      1.10. &quot;Original Code&quot; means Source Code of computer software code which is described in the Source Code notice required by Exhibit A as Original Code, and which, at the time of its release under this License is not already Covered Code governed by this License.
      1.11. &quot;Source Code&quot; means the preferred form of the Covered Code for making modifications to it, including all modules it contains, plus any associated interface definition files, scripts used to control compilation and installation of an Executable, or a list of source code differential comparisons against either the Original Code or another well known, available Covered Code of the Contributor&#39;s choice. The Source Code can be in a compressed or archival form, provided the appropriate decompression or de-archiving software is widely available for no charge.
      1.12. &quot;You&quot; means an individual or a legal entity exercising rights under, and complying with all of the terms of, this License or a future version of this License issued under Section 6.1. For legal entities, &quot;You&#39;&#39; includes any entity which controls, is controlled by, or is under common control with You. For purposes of this definition, &quot;control&#39;&#39; means (a) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (b) ownership of fifty percent (50%) or more of the outstanding shares or beneficial ownership of such entity.
      1.13 &quot;License Author&quot; means Lutris Technologies, Inc.
   2. Source Code License.
      2.1. The Initial Developer Grant. The Initial Developer hereby grants You a worldwide, royalty-free, non-exclusive license, subject to third party intellectual property claims:
         (a) under intellectual property rights (other than patent or trademark) to use, reproduce, modify, display, perform, sublicense and distribute the Original Code (or portions thereof) with or without Modifications, or as part of a Larger Work; and
         (b) under patents now or hereafter owned or controlled by Initial Developer, to make, have made, use and sell (``offer to sell and import&#39;&#39;) the Original Code (or portions thereof), but solely to the extent that any such patent is reasonably necessary to enable You to Utilize the Original Code (or portions thereof) and not to any greater extent that may be necessary to Utilize further Modifications or combinations.
      2.2. Contributor Grant. Each Contributor hereby grants You a worldwide, royalty-free, non-exclusive license, subject to third party intellectual property claims:
         (a) under intellectual property rights (other than patent or trademark) to use, reproduce, modify, display, perform, sublicense and distribute the Modifications created by such Contributor (or portions thereof) either on an unmodified basis, with other Modifications, as Covered Code or as part of a Larger Work; and
         (b) under patents now or hereafter owned or controlled by Contributor, to to make, have made, use and sell (``offer to sell and import&#39;&#39;) the Contributor Version (or portions thereof), but solely to the extent that any such patent is reasonably necessary to enable You to Utilize the Contributor Version (or portions thereof), and not to any greater extent that may be necessary to Utilize further Modifications or combinations
   3. Distribution Obligations.
      3.1. Application of License. The Modifications which You create or to which You contribute are governed by the terms of this License, including without limitation Section 2.2. The Source Code version of Covered Code may be distributed only under the terms of this License or a future version of this License released under Section 6.1, and You must include a copy of this License with every copy of the Source Code You distribute. You may not offer or impose any terms on any Source Code version that alters or restricts the applicable version of this License or the recipients&#39; rights hereunder. However, You may include an additional document offering the additional rights described in Section 3.5.
      3.2. Availability of Source Code. Any Modification which You create or to which You contribute must be made available, prior to any use, except for internal development and practice, in Source Code form under the terms of this License either on the same media as an Executable version or via an accepted Electronic Distribution Mechanism to anyone to whom you made an Executable version available; and if made available via Electronic Distribution Mechanism, must remain available for at least twelve (12) months after the date it initially became available, or at least six (6) months after a subsequent version of that particular Modification has been made available to such recipients. You shall notify the Initial Developer of the Modification and the location of the Source Code via the contact means provided for in the Developer Specific license. Initial Developer will be acting as maintainer of the Source Code and may provide an Electronic Distribution mechanism for the Modification to be made available.
      3.3. Description of Modifications. You must cause all Covered Code to which you contribute to contain a file documenting the changes You made to create that Covered Code and the date of any change. You must include a prominent statement that the Modification is derived, directly or indirectly, from Original Code provided by the Initial Developer and including the name of the Initial Developer in (a) the Source Code, and (b) in any notice in an Executable version or related documentation in which You describe the origin or ownership of the Covered Code.
      3.4. Intellectual Property Matters
         (a) Third Party Claims. If You have knowledge that a party claims an intellectual property right in particular functionality or code (or its utilization under this License), you must include a text file with the source code distribution titled &quot;LEGAL&quot; which describes the claim and the party making the claim in sufficient detail that a recipient will know whom to contact. If you obtain such knowledge after You make Your Modification available as described in Section 3.2, You shall promptly modify the LEGAL file in all copies You make available thereafter and shall take other steps (such as notifying appropriate mailing lists or newsgroups) reasonably calculated to inform those who received the Covered Code that new knowledge has been obtained.
         (b) Representations. Contributor represents that, except as disclosed pursuant to Section 3.4(a) above, Contributor believes that Contributor&#39;s Modifications are Contributor&#39;s original creation(s) and/or Contributor has sufficient rights to grant the rights conveyed by this License.
      3.5. Required Notices. You must duplicate the notice in Exhibit A in each file of the Source Code, and this License in any documentation for the Source Code, where You describe recipients&#39; rights relating to Covered Code. If You created one or more Modification(s), You may add your name as a Contributor to the notice described in Exhibit A. If it is not possible to put such notice in a particular Source Code file due to its structure, then you must include such notice in a location (such as a relevant directory file) where a user would be likely to look for such a notice. You may choose to offer, and to charge a fee for, warranty, support, indemnity or liability obligations to one or more recipients of Covered Code. However, You may do so only on Your own behalf, and not on behalf of the Initial Developer or any Contributor. You must make it absolutely clear that any such warranty, support, indemnity or liability obligation is offered by You alone, and You hereby agree to indemnify the Initial Developer and every Contributor for any liability incurred by the Initial Developer or such Contributor as a result of warranty, support, indemnity or liability terms You offer.
      3.6. Distribution of Executable Versions. You may distribute Covered Code in Executable form only if the requirements of Section 3.1-3.5 have been met for that Covered Code, and if You include a notice stating that the Source Code version of the Covered Code is available under the terms of this License, including a description of how and where You have fulfilled the obligations of Section 3.2. The notice must be conspicuously included in any notice in an Executable version, related documentation or collateral in which You describe recipients&#39; rights relating to the Covered Code. You may distribute the Executable version of Covered Code under a license of Your choice, which may contain terms different from this License, provided that You are in compliance with the terms of this License and that the license for the Executable version does not attempt to limit or alter the recipient&#39;s rights in the Source Code version from the rights set forth in this License. If You distribute the Executable version under a different license You must make it absolutely clear that any terms which differ from this License are offered by You alone, not by the Initial Developer or any Contributor. You hereby agree to indemnify the Initial Developer and every Contributor for any liability incurred by the Initial Developer or such Contributor as a result of any such terms You offer. If you distribute executable versions containing Covered Code, you must reproduce the notice in Exhibit B in the documentation and/or other materials provided with the product.
      3.7. Larger Works. You may create a Larger Work by combining Covered Code with other code not governed by the terms of this License and distribute the Larger Work as a single product. In such a case, You must make sure the requirements of this License are fulfilled for the Covered Code.
   4. Inability to Comply Due to Statute or Regulation.
   If it is impossible for You to comply with any of the terms of this License with respect to some or all of the Covered Code due to statute or regulation then You must: (a) comply with the terms of this License to the maximum extent possible; and (b) Cite all of the statutes or regulations that prohibit you from complying fully with this license. (c) describe the limitations and the code they affect. Such description must be included in the LEGAL file described in Section 3.4 and must be included with all distributions of the Source Code. Except to the extent prohibited by statute or regulation, such description must be sufficiently detailed for a recipient of ordinary skill to be able to understand it.
   5. Application of this License.
   This License applies to code to which the Initial Developer has attached the notice in Exhibit A, and to related Covered Code.
   6. Versions of the License.
      6.1. New Versions. License Author may publish revised and/or new versions of the License from time to time. Each version will be given a distinguishing version number and shall be submitted to opensource.org for certification.
      6.2. Effect of New Versions. Once Covered Code has been published under a particular version of the License, You may always continue to use it under the terms of that version. You may also choose to use such Covered Code under the terms of any subsequent version of the License published by Initial Developer. No one other than Initial Developer has the right to modify the terms applicable to Covered Code created under this License.
      6.3. Derivative Works. If you create or use a modified version of this License, except in association with the required Developer Specific License described in section 6.4, (which you may only do in order to apply it to code which is not already Covered Code governed by this License), you must (a) rename Your license so that the phrases ``Open&#39;&#39;, ``OpenPL&#39;&#39;, ``OPL&#39;&#39; or any confusingly similar phrase do not appear anywhere in your license and (b) otherwise make it clear that your version of the license contains terms which differ from the Open Public License. (Filling in the name of the Initial Developer, Original Code or Contributor in the notice described in Exhibit A shall not of themselves be deemed to be modifications of this License.)
      6.4. Required Additional Developer Specific License
      This license is a union of the following two parts that should be found as text files in the same place (directory), in the order of preeminence:
         [1] A Developer specific license.
         [2] The contents of this file OPL_1_0.TXT, stating the general licensing policy of the software.
      In case of conflicting dispositions in the parts of this license, the terms of the lower-numbered part will always be superseded by the terms of the higher numbered part.
   7. DISCLAIMER OF WARRANTY.
   COVERED CODE IS PROVIDED UNDER THIS LICENSE ON AN &quot;AS IS&quot; BASIS, WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES THAT THE COVERED CODE IS FREE OF DEFECTS, MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE OR NON-INFRINGING. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE COVERED CODE IS WITH YOU. SHOULD ANY COVERED CODE PROVE DEFECTIVE IN ANY RESPECT, YOU (NOT THE INITIAL DEVELOPER OR ANY OTHER CONTRIBUTOR) ASSUME THE COST OF ANY NECESSARY SERVICING, REPAIR OR CORRECTION. THIS DISCLAIMER OF WARRANTY CONSTITUTES AN ESSENTIAL PART OF THIS LICENSE. NO USE OF ANY COVERED CODE IS AUTHORIZED HEREUNDER EXCEPT UNDER THIS DISCLAIMER.
   8. TERMINATION.
      8.1 Termination upon Breach
      This License and the rights granted hereunder will terminate automatically if You fail to comply with terms herein and fail to cure such breach within 30 days of becoming aware of the breach. All sublicenses to the Covered Code, which are properly granted, shall survive any termination of this License. Provisions that, by their nature, must remain in effect beyond the termination of this License shall survive.
      8.2. Termination Upon Litigation. If You initiate litigation by asserting a patent infringement claim (excluding declatory judgment actions) against Initial Developer or a Contributor (the Initial Developer or Contributor against whom You file such action is referred to as &quot;Participant&quot;) alleging that:
         (a) such Participant&#39;s Contributor Version directly or indirectly infringes any patent, then any and all rights granted by such Participant to You under Sections 2.1 and/or 2.2 of this License shall, upon 60 days notice from Participant terminate prospectively, unless if within 60 days after receipt of notice You either: (i) agree in writing to pay Participant a mutually agreeable reasonable royalty for Your past and future use of Modifications made by such Participant, or (ii) withdraw Your litigation claim with respect to the Contributor Version against such Participant. If within 60 days of notice, a reasonable royalty and payment arrangement are not mutually agreed upon in writing by the parties or the litigation claim is not withdrawn, the rights granted by Participant to You under Sections 2.1 and/or 2.2 automatically terminate at the expiration of the 60 day notice period specified above.
         (b) any software, hardware, or device, other than such Participant&#39;s Contributor Version, directly or indirectly infringes any patent, then any rights granted to You by such Participant under Sections 2.1(b) and 2.2(b) are revoked effective as of the date You first made, used, sold, distributed, or had made, Modifications made by that Participant.
      8.3. If You assert a patent infringement claim against Participant alleging that such Participant&#39;s Contributor Version directly or indirectly infringes any patent where such claim is resolved (such as by license or settlement) prior to the initiation of patent infringement litigation, then the reasonable value of the licenses granted by such Participant under Sections 2.1 or 2.2 shall be taken into account in determining the amount or value of any payment or license.
      8.4. In the event of termination under Sections 8.1 or 8.2 above, all end user license agreements (excluding distributors and resellers) which have been validly granted by You or any distributor hereunder prior to termination shall survive termination.
   9. LIMITATION OF LIABILITY.
   UNDER NO CIRCUMSTANCES AND UNDER NO LEGAL THEORY, WHETHER TORT (INCLUDING NEGLIGENCE), CONTRACT, OR OTHERWISE, SHALL THE INITIAL DEVELOPER, ANY OTHER CONTRIBUTOR, OR ANY DISTRIBUTOR OF COVERED CODE, OR ANY SUPPLIER OF ANY OF SUCH PARTIES, BE LIABLE TO YOU OR ANY OTHER PERSON FOR ANY INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES OF ANY CHARACTER INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF GOODWILL, WORK STOPPAGE, COMPUTER FAILURE OR MALFUNCTION, OR ANY AND ALL OTHER COMMERCIAL DAMAGES OR LOSSES, EVEN IF SUCH PARTY SHALL HAVE BEEN INFORMED OF THE POSSIBILITY OF SUCH DAMAGES. THIS LIMITATION OF LIABILITY SHALL NOT APPLY TO LIABILITY FOR DEATH OR PERSONAL INJURY RESULTING FROM SUCH PARTY&#39;S NEGLIGENCE TO THE EXTENT APPLICABLE LAW PROHIBITS SUCH LIMITATION. SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OR LIMITATION OF INCIDENTAL OR CONSEQUENTIAL DAMAGES, SO THAT EXCLUSION AND LIMITATION MAY NOT APPLY TO YOU.
   10. U.S. GOVERNMENT END USERS.
   The Covered Code is a ``commercial item,&#39;&#39; as that term is defined in 48 C.F.R. 2.101 (Oct. 1995), consisting of ``commercial computer software&#39;&#39; and ``commercial computer software documentation,&#39;&#39; as such terms are used in 48 C.F.R. 12.212 (Sept. 1995). Consistent with 48 C.F.R. 12.212 and 48 C.F.R. 227.7202-1 through 227.7202-4 (June 1995), all U.S. Government End Users acquire Covered Code with only those rights set forth herein.
   11. MISCELLANEOUS.
   his section was intentionally left blank. The contents of this section are found in the corresponding addendum described above.
   12. RESPONSIBILITY FOR CLAIMS.
Except in cases where another Contributor has failed to comply with Section 3.4, You are responsible for damages arising, directly or indirectly, out of Your utilization of rights under this License, based on the number of copies of Covered Code you made available, the revenues you received from utilizing such rights, and other relevant factors. You agree to work with affected parties to distribute with Initial Developer responsibility on an equitable basis. EXHIBIT A.
Text for this Exhibit A is found in the corresponding addendum, described in section 6.4 above, text file provided by the Initial Developer. This license is not valid or complete with out that file.
EXHIBIT B.
Text for this Exhibit B is found in the corresponding addendum, described in section 6.4 above, text file provided by the Initial Developer. This license is not valid or complete with out that file.
```


### PSF-2.0

```
PYTHON SOFTWARE FOUNDATION LICENSE VERSION 2

  1. This LICENSE AGREEMENT is between the Python Software Foundation (&quot;PSF&quot;), and the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using this software (&quot;Python&quot;) in source or binary form and its associated documentation.
  2. Subject to the terms and conditions of this License Agreement, PSF hereby grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python alone or in any derivative version, provided, however, that PSF&#39;s License Agreement and PSF&#39;s notice of copyright, i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.
  3. In the event Licensee prepares a derivative work that is based on or incorporates Python or any part thereof, and wants to make the derivative work available to others as provided herein, then Licensee hereby agrees to include in any such work a brief summary of the changes made to Python.
  4. PSF is making Python available to Licensee on an &quot;AS IS&quot; basis. PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
  5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
  6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
  7. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between PSF and Licensee. This License Agreement does not grant permission to use PSF trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
  8. By copying, installing or otherwise using Python, Licensee agrees to be bound by the terms and conditions of this License Agreement.
```


### MIT

```
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE.

```


### Protobuf

```
Copyright 2008 Google Inc.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.
    * Neither the name of Google Inc. nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
&quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Code generated by the Protocol Buffer compiler is owned by the owner
of the input file used when generating it.  This code is not
standalone and requires a support library to be linked with it.  This
support library is itself covered by the above license.
```


### Python-2.0

```
PYTHON SOFTWARE FOUNDATION LICENSE VERSION 2
   1. This LICENSE AGREEMENT is between the Python Software Foundation (&quot;PSF&quot;), and the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using this software (&quot;Python&quot;) in source or binary form and its associated documentation.
   2. Subject to the terms and conditions of this License Agreement, PSF hereby grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python alone or in any derivative version, provided, however, that PSF&#39;s License Agreement and PSF&#39;s notice of copyright, i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python or any part thereof, and wants to make the derivative work available to others as provided herein, then Licensee hereby agrees to include in any such work a brief summary of the changes made to Python.
   4. PSF is making Python available to Licensee on an &quot;AS IS&quot; basis. PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between PSF and Licensee. This License Agreement does not grant permission to use PSF trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By copying, installing or otherwise using Python, Licensee agrees to be bound by the terms and conditions of this License Agreement. BEOPEN.COM LICENSE AGREEMENT FOR PYTHON 2.0
BEOPEN PYTHON OPEN SOURCE LICENSE AGREEMENT VERSION 1
   1. This LICENSE AGREEMENT is between BeOpen.com (&quot;BeOpen&quot;), having an office at 160 Saratoga Avenue, Santa Clara, CA 95051, and the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using this software in source or binary form and its associated documentation (&quot;the Software&quot;).
   2. Subject to the terms and conditions of this BeOpen Python License Agreement, BeOpen hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use the Software alone or in any derivative version, provided, however, that the BeOpen Python License is retained in the Software, alone or in any derivative version prepared by Licensee.
   3. BeOpen is making the Software available to Licensee on an &quot;AS IS&quot; basis. BEOPEN MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, BEOPEN MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF THE SOFTWARE WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   4. BEOPEN SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THE SOFTWARE, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   5. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   6. This License Agreement shall be governed by and interpreted in all respects by the law of the State of California, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between BeOpen and Licensee. This License Agreement does not grant permission to use BeOpen trademarks or trade names in a trademark sense to endorse or promote products or services of Licensee, or any third party. As an exception, the &quot;BeOpen Python&quot; logos available at http://www.pythonlabs.com/logos.html may be used according to the permissions granted on that web page.
   7. By copying, installing or otherwise using the software, Licensee agrees to be bound by the terms and conditions of this License Agreement. CNRI OPEN SOURCE LICENSE AGREEMENT (for Python 1.6b1) IMPORTANT: PLEASE READ THE FOLLOWING AGREEMENT CAREFULLY.
BY CLICKING ON &quot;ACCEPT&quot; WHERE INDICATED BELOW, OR BY COPYING, INSTALLING OR OTHERWISE USING PYTHON 1.6, beta 1 SOFTWARE, YOU ARE DEEMED TO HAVE AGREED TO THE TERMS AND CONDITIONS OF THIS LICENSE AGREEMENT.
   1. This LICENSE AGREEMENT is between the Corporation for National Research Initiatives, having an office at 1895 Preston White Drive, Reston, VA 20191 (&quot;CNRI&quot;), and the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using Python 1.6, beta 1 software in source or binary form and its associated documentation, as released at the www.python.org Internet site on August 4, 2000 (&quot;Python 1.6b1&quot;).
   2. Subject to the terms and conditions of this License Agreement, CNRI hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python 1.6b1 alone or in any derivative version, provided, however, that CNRIs License Agreement is retained in Python 1.6b1, alone or in any derivative version prepared by Licensee.
   Alternately, in lieu of CNRIs License Agreement, Licensee may substitute the following text (omitting the quotes): &quot;Python 1.6, beta 1, is made available subject to the terms and conditions in CNRIs License Agreement. This Agreement may be located on the Internet using the following unique, persistent identifier (known as a handle): 1895.22/1011. This Agreement may also be obtained from a proxy server on the Internet using the URL:http://hdl.handle.net/1895.22/1011&quot;.
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python 1.6b1 or any part thereof, and wants to make the derivative work available to the public as provided herein, then Licensee hereby agrees to indicate in any such work the nature of the modifications made to Python 1.6b1.
   4. CNRI is making Python 1.6b1 available to Licensee on an &quot;AS IS&quot; basis. CNRI MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, CNRI MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON 1.6b1 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. CNRI SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING PYTHON 1.6b1, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. This License Agreement shall be governed by and interpreted in all respects by the law of the State of Virginia, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between CNRI and Licensee. This License Agreement does not grant permission to use CNRI trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By clicking on the &quot;ACCEPT&quot; button where indicated, or by copying, installing or otherwise using Python 1.6b1, Licensee agrees to be bound by the terms and conditions of this License Agreement. ACCEPT CWI LICENSE AGREEMENT FOR PYTHON 0.9.0 THROUGH 1.2
Copyright (c) 1991 - 1995, Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.
Permission to use, copy, modify, and distribute this software and its documentation for any purpose and without fee is hereby granted, provided that the above copyright notice appear in all copies and that both that copyright notice and this permission notice appear in supporting documentation, and that the name of Stichting Mathematisch Centrum or CWI not be used in advertising or publicity pertaining to distribution of the software without specific, written prior permission.
STICHTING MATHEMATISCH CENTRUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL STICHTING MATHEMATISCH CENTRUM BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
```


### SunPro

```
Copyright (C) 1993 by Sun Microsystems, Inc. All rights reserved.
Developed at SunPro, a Sun Microsystems, Inc. business.

Permission to use, copy, modify, and distribute this
software is freely granted, provided that this notice
is preserved.
```


### MIT

```
The MIT License

Copyright (c) 2016 Christopher Groskopf and contributors 

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```


### MIT

```
The MIT License

Copyright (c) 2017 Christopher Groskopf and contributors 

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```


### MIT

```
The MIT License

Copyright (c) Val Neekman @ Neekware Inc. http://neekware.com

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```


### MIT

```
The MIT License (MIT)

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors
www.zepworks.com

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.


```


### MIT

```
The MIT License (MIT)

Copyright (c) 2014 Will Roberts

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
&quot;Software&quot;), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

```


### MIT

```
The MIT License (MIT)

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```


### MIT

```
The MIT License (MIT)

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```


### MIT

```
The MIT License (MIT)

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```


### MIT

```
The MIT License (MIT)

Copyright (c) 2022 the contributors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```


### MIT

```
The MIT License (MIT)

Copyright (c) 2013-2021 Sebastian Bank

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```


### MIT

```
The MIT License (MIT)

Copyright (c) 2013-2024 Sebastian Bank

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

```


### MPL-2.0

```
This package contains a modified version of ca-bundle.crt:

ca-bundle.crt -- Bundle of CA Root Certificates

This is a bundle of X.509 certificates of public Certificate Authorities
(CA). These were automatically extracted from Mozilla&#39;s root certificates
file (certdata.txt).  This file can be found in the mozilla source tree:
https://hg.mozilla.org/mozilla-central/file/tip/security/nss/lib/ckfw/builtins/certdata.txt
It contains the certificates in PEM format and therefore
can be directly used with curl / libcurl / php_curl, or with
an Apache+mod_ssl webserver for SSL client authentication.
Just configure this file as the SSLCACertificateFile.#

***** BEGIN LICENSE BLOCK *****
This Source Code Form is subject to the terms of the Mozilla Public License,
v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain
one at http://mozilla.org/MPL/2.0/.

***** END LICENSE BLOCK *****
@(#) $RCSfile: certdata.txt,v $ $Revision: 1.80 $ $Date: 2011/11/03 15:11:58 $

```


### Apache-2.0

```
This software is made available under the terms of *either* of the licenses
found in LICENSE.APACHE or LICENSE.BSD. Contributions to this software is made
under the terms of *both* these licenses.

```


### Unlicense

```
This is free and unencumbered software released into the public domain.
Anyone is free to copy, modify, publish, use, compile, sell, or distribute this software, either in source code form or as a compiled binary, for any purpose, commercial or non-commercial, and by any means.
In jurisdictions that recognize copyright laws, the author or authors of this software dedicate any and all copyright interest in the software to the public domain. We make this dedication for the benefit of the public at large and to the detriment of our heirs and
successors. We intend this dedication to be an overt act of relinquishment in perpetuity of all present and future rights to this software under copyright law.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
For more information, please refer to &lt;http://unlicense.org/&gt;
```


### X11

```
X11 License
Copyright (C) 1996 X Consortium
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
Except as contained in this notice, the name of the X Consortium shall not be used in advertising or otherwise to promote the sale, use or other dealings in this Software without prior written authorization from the X Consortium.
X Window System is a trademark of X Consortium, Inc.
```


### Zlib

```
zlib License Copyright (c) &lt;year&gt; &lt;copyright holders&gt;
This software is provided &#39;as-is&#39;, without any express or implied warranty. In no event will the authors be held liable for any damages arising from the use of this software.
Permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the following restrictions:
   1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
   2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.
```


### bsd-2-clause-views

```
Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS&#39;&#39; AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those
of the authors and should not be interpreted as representing official policies,
either expressed or implied, of the FreeBSD Project.
```


### bsd-3-clause-open-mpi

```
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
  notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
  notice, this list of conditions and the following disclaimer listed
  in this license in the documentation and/or other materials
  provided with the distribution.

- Neither the name of the copyright holders nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

The copyright holders provide no reassurances that the source code
provided does not infringe any patent, copyright, or any other
intellectual property rights of third parties.  The copyright holders
disclaim any liability to any recipient for claims brought against
recipient by any third party for infringement of that parties
intellectual property rights.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
&quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```


### business-source-license-1.1

```
Terms

The Licensor hereby grants you the right to copy, modify, create derivative works, redistribute, and make non-production use of the Licensed Work. The Licensor may make an Additional Use Grant, above, permitting limited production use.

Effective on the Change Date, or the fourth anniversary of the first publicly available distribution of a specific version of the Licensed Work under this License, whichever comes first, the Licensor hereby grants you rights under the terms of the Change License, and the rights granted in the paragraph above terminate.

If your use of the Licensed Work does not comply with the requirements currently in effect as described in this License, you must purchase a commercial license from the Licensor, its affiliated entities, or authorized resellers, or you must refrain from using the Licensed Work.

All copies of the original and modified Licensed Work, and derivative works of the Licensed Work, are subject to this License. This License applies separately for each version of the Licensed Work and the Change Date may vary for each version of the Licensed Work released by Licensor.

You must conspicuously display this License on each original or modified copy of the Licensed Work. If you receive the Licensed Work in original or modified form from a third party, the terms and conditions set forth in this License apply to your use of that work.

Any use of the Licensed Work in violation of this License will automatically terminate your rights under this License for the current and all other versions of the Licensed Work.

This License does not grant you any right in any trademark or logo of Licensor or its affiliates (provided that you may use a trademark or logo of Licensor as expressly required by this License).TO THE EXTENT PERMITTED BY APPLICABLE LAW, THE LICENSED WORK IS PROVIDED ON AN “AS IS” BASIS. LICENSOR HEREBY DISCLAIMS ALL WARRANTIES AND CONDITIONS, EXPRESS OR IMPLIED, INCLUDING (WITHOUT LIMITATION) WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NON-INFRINGEMENT, AND TITLE.MariaDB hereby grants you permission to use this License’s text to license your works, and to refer to it using the trademark “Business Source License”, as long as you comply with the Covenants of Licensor below.
Covenants of Licensor

In consideration of the right to use this License’s text and the “Business Source License” name and trademark, Licensor covenants to MariaDB, and to all other recipients of the licensed work to be provided by Licensor:

To specify as the Change License the GPL Version 2.0 or any later version, or a license that is compatible with GPL Version 2.0 or a later version, where “compatible” means that software provided under the Change License can be included in a program with software provided under GPL Version 2.0 or a later version. Licensor may specify additional Change Licenses without limitation.
To either: (a) specify an additional grant of rights to use that does not impose any additional restriction on the right granted in this License, as the Additional Use Grant; or (b) insert the text “None”.
To specify a Change Date.
Not to modify this License in any other way.
Notice

The Business Source License (this document, or the “License”) is not an Open Source license. However, the Licensed Work will eventually be made available under an Open Source License, as stated in this License.

For more information on the use of the Business Source License for MariaDB products, please visit the MariaDB Business Source License FAQ. For more information on the use of the Business Source License generally, please visit the Adopting and Developing Business Source License FAQ.
```


### gpl-2.0 WITH bison-exception-2.2

```
﻿insert GPL v2 text here

Bison Exception

As a special exception, you may create a larger work that contains part or all of the Bison parser skeleton and distribute that work under terms of your choice, so long as that work isn&#39;t itself a parser generator using the skeleton or a modified version thereof as a parser skeleton. Alternatively, if you modify or redistribute the parser skeleton itself, you may (at your option) remove this special exception, which will cause the skeleton and the resulting Bison output files to be licensed under the GNU General Public License without this special exception.

This special exception was added by the Free Software Foundation in version 2.2 of Bison.
```


### mit-0

```
Permission is hereby granted, free of charge, to any person obtaining a copy of this
software and associated documentation files (the &quot;Software&quot;), to deal in the Software
without restriction, including without limitation the rights to use, copy, modify,
merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
```


### mit-nagy

```
Permission to use, copy, modify, and/or distribute this code
for any purpose with or without fee is hereby granted.
There is no warranty.
```


### mit-old-style-no-advert

```
Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and
that both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the authors not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission. The authors
makes no representations about the suitability of this software for any
purpose. It is provided &quot;as is&quot; without express or implied warranty.
```


### mit-taylor-variant

```
Permission to use, copy, modify, and/or distribute this software for any purpose
with or without fee is hereby granted, provided that the above copyright notice
and this permission notice appear in all copies.

The software is  provided &quot;as is&quot;, without warranty of any kind, including all
implied warranties of merchantability and fitness. In no event shall the authors
or copyright holders be liable for any claim, damages, or other liability,
whether in an action of contract, tort, or otherwise, arising from, out of, or
in connection with the software or the use or other dealings in the software.
```


### openpub

```
Open Publication License
v1.0, 8 June 1999

I. REQUIREMENTS ON BOTH UNMODIFIED AND MODIFIED VERSIONS

The Open Publication works may be reproduced and distributed in whole or in part, in any medium physical or electronic, provided that the terms of this license are adhered to, and that this license or an incorporation of it by reference (with any options elected by the author(s) and/or publisher) is displayed in the reproduction.

Proper form for an incorporation by reference is as follows:

    Copyright (c) &lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

The reference must be immediately followed with any options elected by the author(s) and/or publisher of the document (see section VI).

Commercial redistribution of Open Publication-licensed material is permitted.

Any publication in standard (paper) book form shall require the citation of the original publisher and author. The publisher and author&#39;s names shall appear on all outer surfaces of the book. On all outer surfaces of the book the original publisher&#39;s name shall be as large as the title of the work and cited as possessive with respect to the title.


II. COPYRIGHT

The copyright to each Open Publication is owned by its author(s) or designee.


III. SCOPE OF LICENSE

The following license terms apply to all Open Publication works, unless otherwise explicitly stated in the document.

Mere aggregation of Open Publication works or a portion of an Open Publication work with other works or programs on the same media shall not cause this license to apply to those other works. The aggregate work shall contain a notice specifying the inclusion of the Open Publication material and appropriate copyright notice.

SEVERABILITY. If any part of this license is found to be unenforceable in any jurisdiction, the remaining portions of the license remain in force.

NO WARRANTY. Open Publication works are licensed and provided &quot;as is&quot; without warranty of any kind, express or implied, including, but not limited to, the implied warranties of merchantability and fitness for a particular purpose or a warranty of non-infringement.


IV. REQUIREMENTS ON MODIFIED WORKS

All modified versions of documents covered by this license, including translations, anthologies, compilations and partial documents, must meet the following requirements:

   1. The modified version must be labeled as such.
   2. The person making the modifications must be identified and the modifications dated.
   3. Acknowledgement of the original author and publisher if applicable must be retained according to normal academic citation practices.
   4. The location of the original unmodified document must be identified.
   5. The original author&#39;s (or authors&#39;) name(s) may not be used to assert or imply endorsement of the resulting document without the original author&#39;s (or authors&#39;) permission. 


V. GOOD-PRACTICE RECOMMENDATIONS

In addition to the requirements of this license, it is requested from and strongly recommended of redistributors that:

   1. If you are distributing Open Publication works on hardcopy or CD-ROM, you provide email notification to the authors of your intent to redistribute at least thirty days before your manuscript or media freeze, to give the authors time to provide updated documents. This notification should describe modifications, if any, made to the document.
   2. All substantive modifications (including deletions) be either clearly marked up in the document or else described in an attachment to the document.
   3. Finally, while it is not mandatory under this license, it is considered good form to offer a free copy of any hardcopy and CD-ROM expression of an Open Publication-licensed work to its author(s). 


VI. LICENSE OPTIONS

The author(s) and/or publisher of an Open Publication-licensed document may elect certain options by appending language to the reference to or copy of the license. These options are considered part of the license instance and must be included with the license (or its incorporation by reference) in derived works.

A. To prohibit distribution of substantively modified versions without the explicit permission of the author(s). &quot;Substantive modification&quot; is defined as a change to the semantic content of the document, and excludes mere changes in format or typographical corrections.

To accomplish this, add the phrase `Distribution of substantively modified versions of this document is prohibited without the explicit permission of the copyright holder.&#39; to the license reference or copy.

B. To prohibit any publication of this work or derivative works in whole or in part in standard (paper) book form for commercial purposes unless prior permission is obtained from the copyright holder.

To accomplish this, add the phrase &#39;Distribution of the work or derivative of the work in any standard (paper) book form is prohibited unless prior permission is obtained from the copyright holder.&#39; to the license reference or copy.


OPEN PUBLICATION POLICY APPENDIX:

(This is not considered part of the license.)

Open Publication works are available in source format via the Open Publication home page at http://works.opencontent.org/.

Open Publication authors who want to include their own license on Open Publication works may do so, as long as their terms are not more restrictive than the Open Publication license.

If you have questions about the Open Publication License, please contact David Wiley, and/or the Open Publication Authors&#39; List at opal@opencontent.org, via email.

To subscribe to the Open Publication Authors&#39; List:
Send E-mail to opal-request@opencontent.org with the word &quot;subscribe&quot; in the body.

To post to the Open Publication Authors&#39; List:
Send E-mail to opal@opencontent.org or simply reply to a previous post.

To unsubscribe from the Open Publication Authors&#39; List:
Send E-mail to opal-request@opencontent.org with the word &quot;unsubscribe&quot; in the body.
```


### openssl-ssleay

```
LICENSE ISSUES
  ==============

  The OpenSSL toolkit stays under a dual license, i.e. both the conditions of
  the OpenSSL License and the original SSLeay license apply to the toolkit.
  See below for the actual license texts. Actually both licenses are BSD-style
  Open Source licenses. In case of any license issues related to OpenSSL
  please contact openssl-core@openssl.org.

  OpenSSL License
  ---------------

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer. 

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. All advertising materials mentioning features or use of this
   software must display the following acknowledgment:
   &quot;This product includes software developed by the OpenSSL Project
   for use in the OpenSSL Toolkit. (http://www.openssl.org/)&quot;

4. The names &quot;OpenSSL Toolkit&quot; and &quot;OpenSSL Project&quot; must not be used to
   endorse or promote products derived from this software without
   prior written permission. For written permission, please contact
   openssl-core@openssl.org.

5. Products derived from this software may not be called &quot;OpenSSL&quot;
   nor may &quot;OpenSSL&quot; appear in their names without prior written
   permission of the OpenSSL Project.

6. Redistributions of any form whatsoever must retain the following
   acknowledgment:
   &quot;This product includes software developed by the OpenSSL Project
   for use in the OpenSSL Toolkit (http://www.openssl.org/)&quot;

THIS SOFTWARE IS PROVIDED BY THE OpenSSL PROJECT ``AS IS&#39;&#39; AND ANY
EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE OpenSSL PROJECT OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
OF THE POSSIBILITY OF SUCH DAMAGE.


This product includes cryptographic software written by Eric Young
(eay@cryptsoft.com).  This product includes software written by Tim
Hudson (tjh@cryptsoft.com).


 Original SSLeay License
 -----------------------

Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
All rights reserved.

This package is an SSL implementation written
by Eric Young (eay@cryptsoft.com).
The implementation was written so as to conform with Netscapes SSL.

This library is free for commercial and non-commercial use as long as
the following conditions are aheared to.  The following conditions
apply to all code found in this distribution, be it the RC4, RSA,
lhash, DES, etc., code; not just the SSL code.  The SSL documentation
included with this distribution is covered by the same copyright terms
except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright remains Eric Young&#39;s, and as such any Copyright notices in
the code are not to be removed.
If this package is used in a product, Eric Young should be given attribution
as the author of the parts of the library used.
This can be in the form of a textual message at program startup or
in documentation (online or textual) provided with the package.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. All advertising materials mentioning features or use of this software
   must display the following acknowledgement:
   &quot;This product includes cryptographic software written by
    Eric Young (eay@cryptsoft.com)&quot;
   The word &#39;cryptographic&#39; can be left out if the rouines from the library
   being used are not cryptographic related :-).
4. If you include any Windows specific code (or a derivative thereof) from 
   the apps directory (application code) you must include an acknowledgement:
   &quot;This product includes software written by Tim Hudson (tjh@cryptsoft.com)&quot;

THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS&#39;&#39; AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.

The licence and distribution terms for any publically available version or
derivative of this code cannot be changed.  i.e. this code cannot simply be
copied and put under another distribution licence
[including the GNU Public Licence.]
```


### proprietary-license

```
This is a catch-all license used when we find many different proprietary licenses.
```


### psf-3.7.2

```
PSF LICENSE AGREEMENT FOR PYTHON 3.7.2

1. This LICENSE AGREEMENT is between the Python Software Foundation (&quot;PSF&quot;), and
   the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using Python
   3.7.2 software in source or binary form and its associated documentation.

2. Subject to the terms and conditions of this License Agreement, PSF hereby
   grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce,
   analyze, test, perform and/or display publicly, prepare derivative works,
   distribute, and otherwise use Python 3.7.2 alone or in any derivative
   version, provided, however, that PSF&#39;s License Agreement and PSF&#39;s notice of
   copyright, i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights
   Reserved&quot; are retained in Python 3.7.2 alone or in any derivative version
   prepared by Licensee.

3. In the event Licensee prepares a derivative work that is based on or
   incorporates Python 3.7.2 or any part thereof, and wants to make the
   derivative work available to others as provided herein, then Licensee hereby
   agrees to include in any such work a brief summary of the changes made to Python
   3.7.2.

4. PSF is making Python 3.7.2 available to Licensee on an &quot;AS IS&quot; basis.
   PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.  BY WAY OF
   EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR
   WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE
   USE OF PYTHON 3.7.2 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.

5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON 3.7.2
   FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF
   MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON 3.7.2, OR ANY DERIVATIVE
   THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.

6. This License Agreement will automatically terminate upon a material breach of
   its terms and conditions.

7. Nothing in this License Agreement shall be deemed to create any relationship
   of agency, partnership, or joint venture between PSF and Licensee.  This License
   Agreement does not grant permission to use PSF trademarks or trade name in a
   trademark sense to endorse or promote products or services of Licensee, or any
   third party.

8. By copying, installing or otherwise using Python 3.7.2, Licensee agrees
   to be bound by the terms and conditions of this License Agreement.
```


### public-domain

```

```


### Artistic-1.0

```
text-unidecode is a free software; you can redistribute
it and/or modify it under the terms of either:

* GPL or GPLv2+ (see https://www.gnu.org/licenses/license-list.html#GNUGPL), or
* Artistic License - see below:


                         The &quot;Artistic License&quot;

                                Preamble

The intent of this document is to state the conditions under which a
Package may be copied, such that the Copyright Holder maintains some
semblance of artistic control over the development of the package,
while giving the users of the package the right to use and distribute
the Package in a more-or-less customary fashion, plus the right to make
reasonable modifications.

Definitions:

        &quot;Package&quot; refers to the collection of files distributed by the
        Copyright Holder, and derivatives of that collection of files
        created through textual modification.

        &quot;Standard Version&quot; refers to such a Package if it has not been
        modified, or has been modified in accordance with the wishes
        of the Copyright Holder as specified below.

        &quot;Copyright Holder&quot; is whoever is named in the copyright or
        copyrights for the package.

        &quot;You&quot; is you, if you&#39;re thinking about copying or distributing
        this Package.

        &quot;Reasonable copying fee&quot; is whatever you can justify on the
        basis of media cost, duplication charges, time of people involved,
        and so on.  (You will not be required to justify it to the
        Copyright Holder, but only to the computing community at large
        as a market that must bear the fee.)

        &quot;Freely Available&quot; means that no fee is charged for the item
        itself, though there may be fees involved in handling the item.
        It also means that recipients of the item may redistribute it
        under the same conditions they received it.

1. You may make and give away verbatim copies of the source form of the
Standard Version of this Package without restriction, provided that you
duplicate all of the original copyright notices and associated disclaimers.

2. You may apply bug fixes, portability fixes and other modifications
derived from the Public Domain or from the Copyright Holder.  A Package
modified in such a way shall still be considered the Standard Version.

3. You may otherwise modify your copy of this Package in any way, provided
that you insert a prominent notice in each changed file stating how and
when you changed that file, and provided that you do at least ONE of the
following:

    a) place your modifications in the Public Domain or otherwise make them
    Freely Available, such as by posting said modifications to Usenet or
    an equivalent medium, or placing the modifications on a major archive
    site such as uunet.uu.net, or by allowing the Copyright Holder to include
    your modifications in the Standard Version of the Package.

    b) use the modified Package only within your corporation or organization.

    c) rename any non-standard executables so the names do not conflict
    with standard executables, which must also be provided, and provide
    a separate manual page for each non-standard executable that clearly
    documents how it differs from the Standard Version.

    d) make other distribution arrangements with the Copyright Holder.

4. You may distribute the programs of this Package in object code or
executable form, provided that you do at least ONE of the following:

    a) distribute a Standard Version of the executables and library files,
    together with instructions (in the manual page or equivalent) on where
    to get the Standard Version.

    b) accompany the distribution with the machine-readable source of
    the Package with your modifications.

    c) give non-standard executables non-standard names, and clearly
    document the differences in manual pages (or equivalent), together
    with instructions on where to get the Standard Version.

    d) make other distribution arrangements with the Copyright Holder.

5. You may charge a reasonable copying fee for any distribution of this
Package.  You may charge any fee you choose for support of this
Package.  You may not charge a fee for this Package itself.  However,
you may distribute this Package in aggregate with other (possibly
commercial) programs as part of a larger (possibly commercial) software
distribution provided that you do not advertise this Package as a
product of your own.  You may embed this Package&#39;s interpreter within
an executable of yours (by linking); this shall be construed as a mere
form of aggregation, provided that the complete Standard Version of the
interpreter is so embedded.

6. The scripts and library files supplied as input to or produced as
output from the programs of this Package do not automatically fall
under the copyright of this Package, but belong to whoever generated
them, and may be sold commercially, and may be aggregated with this
Package.  If such scripts or library files are aggregated with this
Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a
binary executable image, then distribution of such an image shall
neither be construed as a distribution of this Package nor shall it
fall under the restrictions of Paragraphs 3 and 4, provided that you do
not represent such an executable image as a Standard Version of this
Package.

7. C subroutines (or comparably compiled subroutines in other
languages) supplied by you and linked into this Package in order to
emulate subroutines and variables of the language defined by this
Package shall not be considered part of this Package, but are the
equivalent of input as in Paragraph 6, provided these subroutines do
not change the language in any way that would cause it to fail the
regression tests for the language.

8. Aggregation of this Package with a commercial distribution is always
permitted provided that the use of this Package is embedded; that is,
when no overt attempt is made to make this Package&#39;s interfaces visible
to the end user of the commercial distribution.  Such use shall not be
construed as a distribution of this Package.

9. The name of the Copyright Holder may not be used to endorse or promote
products derived from this software without specific prior written permission.

10. THIS PACKAGE IS PROVIDED &quot;AS IS&quot; AND WITHOUT ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

                                The End

```






## Copyrights

### BSD Zero Clause License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Copyright (C) 2006 by Rob Landley &lt;rob@landley.net&gt;
Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot; AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
```


### Attribution Assurance License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Attribution Assurance License
Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;
All Rights Reserved ATTRIBUTION ASSURANCE LICENSE (adapted from the original BSD license)
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the conditions below are met. These conditions require a modest attribution to &lt;AUTHOR&gt; (the &quot;Author&quot;), who hopes that its promotional value may help justify the thousands of dollars in otherwise billable time invested in writing this and other freely available, open-source software.
   1. Redistributions of source code, in whole or part and with or without modification (the &quot;Code&quot;), must prominently display this GPG-signed text in verifiable form.
   2. Redistributions of the Code in binary form must be accompanied by this GPG-signed text in any documentation and, each time the resulting executable program or a program dependent thereon is launched, a prominent display (e.g., splash screen or banner text) of the Author&#39;s attribution information, which includes:
      (a) Name (&quot;AUTHOR&quot;),
      (b) Professional identification (&quot;PROFESSIONAL IDENTIFICATION&quot;), and
      (c) URL (&quot;URL&quot;).
   3. Neither the name nor any trademark of the Author may be used to endorse or promote products derived from this software without specific prior written permission.
   4. Users are entirely responsible, to the exclusion of the Author and any other persons, for compliance with (1) regulations set by owners or administrators of employed equipment, (2) licensing terms of any other software, and (3) local regulations regarding use, including those regarding import, export, and use of encryption software.
THIS FREE SOFTWARE IS PROVIDED BY THE AUTHOR &quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR ANY CONTRIBUTOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, EFFECTS OF UNAUTHORIZED OR MALICIOUS NETWORK ACCESS; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```


### GNU Affero General Public License v3.0 or later

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
GNU AFFERO GENERAL PUBLIC LICENSE
Version 3, 19 November 2007
Copyright (C) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The GNU Affero General Public License is a free, copyleft license for software and other kinds of works, specifically designed to ensure cooperation with the community in the case of network server software.
The licenses for most software and other practical works are designed to take away your freedom to share and change the works. By contrast, our General Public Licenses are intended to guarantee your freedom to share and change all versions of a program--to make sure it remains free software for all its users.
When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for them if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs, and that you know you can do these things.
Developers that use our General Public Licenses protect your rights with two steps: (1) assert copyright on the software, and (2) offer you this License which gives you legal permission to copy, distribute and/or modify the software.
A secondary benefit of defending all users&#39; freedom is that improvements made in alternate versions of the program, if they receive widespread use, become available for other developers to incorporate. Many developers of free software are heartened and encouraged by the resulting cooperation. However, in the case of software used on network servers, this result may fail to come about. The GNU General Public License permits making a modified version and letting the public access it on a server without ever releasing its source code to the public.
The GNU Affero General Public License is designed specifically to ensure that, in such cases, the modified source code becomes available to the community. It requires the operator of a network server to provide the source code of the modified version running there to the users of that server. Therefore, public use of a modified version, on a publicly accessible server, gives the public access to the source code of the modified version.
An older license, called the Affero General Public License and published by Affero, was designed to accomplish similar goals. This is a different license, not a version of the Affero GPL, but Affero has released a new version of the Affero GPL which permits relicensing under this license.
The precise terms and conditions for copying, distribution and modification follow.
TERMS AND CONDITIONS
   0. Definitions.
   &quot;This License&quot; refers to version 3 of the GNU Affero General Public License.
   &quot;Copyright&quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.
   &quot;The Program&quot; refers to any copyrightable work licensed under this License. Each licensee is addressed as &quot;you&quot;. &quot;Licensees&quot; and &quot;recipients&quot; may be individuals or organizations.
   To &quot;modify&quot; a work means to copy from or adapt all or part of the work in a fashion requiring copyright permission, other than the making of an exact copy. The resulting work is called a &quot;modified version&quot; of the earlier work or a work &quot;based on&quot; the earlier work.
   A &quot;covered work&quot; means either the unmodified Program or a work based on the Program.
   To &quot;propagate&quot; a work means to do anything with it that, without permission, would make you directly or secondarily liable for infringement under applicable copyright law, except executing it on a computer or modifying a private copy. Propagation includes copying, distribution (with or without modification), making available to the public, and in some countries other activities as well.
   To &quot;convey&quot; a work means any kind of propagation that enables other parties to make or receive copies. Mere interaction with a user through a computer network, with no transfer of a copy, is not conveying.
   An interactive user interface displays &quot;Appropriate Legal Notices&quot; to the extent that it includes a convenient and prominently visible feature that (1) displays an appropriate copyright notice, and (2) tells the user that there is no warranty for the work (except to the extent that warranties are provided), that licensees may convey the work under this License, and how to view a copy of this License. If the interface presents a list of user commands or options, such as a menu, a prominent item in the list meets this criterion.
   1. Source Code.
   The &quot;source code&quot; for a work means the preferred form of the work for making modifications to it. &quot;Object code&quot; means any non-source form of a work.
   A &quot;Standard Interface&quot; means an interface that either is an official standard defined by a recognized standards body, or, in the case of interfaces specified for a particular programming language, one that is widely used among developers working in that language.
   The &quot;System Libraries&quot; of an executable work include anything, other than the work as a whole, that (a) is included in the normal form of packaging a Major Component, but which is not part of that Major Component, and (b) serves only to enable use of the work with that Major Component, or to implement a Standard Interface for which an implementation is available to the public in source code form. A &quot;Major Component&quot;, in this context, means a major essential component (kernel, window system, and so on) of the specific operating system (if any) on which the executable work runs, or a compiler used to produce the work, or an object code interpreter used to run it.
   The &quot;Corresponding Source&quot; for a work in object code form means all the source code needed to generate, install, and (for an executable work) run the object code and to modify the work, including scripts to control those activities. However, it does not include the work&#39;s System Libraries, or general-purpose tools or generally available free programs which are used unmodified in performing those activities but which are not part of the work. For example, Corresponding Source includes interface definition files associated with source files for the work, and the source code for shared libraries and dynamically linked subprograms that the work is specifically designed to require, such as by intimate data communication or control flow between those
   subprograms and other parts of the work.
   The Corresponding Source need not include anything that users can regenerate automatically from other parts of the Corresponding Source.
   The Corresponding Source for a work in source code form is that same work.
   2. Basic Permissions.
   All rights granted under this License are granted for the term of copyright on the Program, and are irrevocable provided the stated conditions are met. This License explicitly affirms your unlimited permission to run the unmodified Program. The output from running a covered work is covered by this License only if the output, given its content, constitutes a covered work. This License acknowledges your rights of fair use or other equivalent, as provided by copyright law.
   You may make, run and propagate covered works that you do not convey, without conditions so long as your license otherwise remains in force. You may convey covered works to others for the sole purpose of having them make modifications exclusively for you, or provide you with facilities for running those works, provided that you comply with the terms of this License in conveying all material for which you do not control copyright. Those thus making or running the covered works for you must do so exclusively on your behalf, under your direction and control, on terms that prohibit them from making any copies of your copyrighted material outside their relationship with you.
   Conveying under any other circumstances is permitted solely under the conditions stated below. Sublicensing is not allowed; section 10 makes it unnecessary.
   3. Protecting Users&#39; Legal Rights From Anti-Circumvention Law.
   No covered work shall be deemed part of an effective technological measure under any applicable law fulfilling obligations under article 11 of the WIPO copyright treaty adopted on 20 December 1996, or similar laws prohibiting or restricting circumvention of such measures.
   When you convey a covered work, you waive any legal power to forbid circumvention of technological measures to the extent such circumvention is effected by exercising rights under this License with respect to the covered work, and you disclaim any intention to limit operation or modification of the work as a means of enforcing, against the work&#39;s users, your or third parties&#39; legal rights to forbid circumvention of technological measures.
   4. Conveying Verbatim Copies.
   You may convey verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice; keep intact all notices stating that this License and any non-permissive terms added in accord with section 7 apply to the code; keep intact all notices of the absence of any warranty; and give all recipients a copy of this License along with the Program.
   You may charge any price or no price for each copy that you convey, and you may offer support or warranty protection for a fee.
   5. Conveying Modified Source Versions.
   You may convey a work based on the Program, or the modifications to produce it from the Program, in the form of source code under the terms of section 4, provided that you also meet all of these conditions:
      a) The work must carry prominent notices stating that you modified it, and giving a relevant date.
      b) The work must carry prominent notices stating that it is released under this License and any conditions added under section 7. This requirement modifies the requirement in section 4 to &quot;keep intact all notices&quot;.
      c) You must license the entire work, as a whole, under this License to anyone who comes into possession of a copy. This License will therefore apply, along with any applicable section 7 additional terms, to the whole of the work, and all its parts, regardless of how they are packaged. This License gives no permission to license the work in any other way, but it does not invalidate such permission if you have separately received it.
      d) If the work has interactive user interfaces, each must display Appropriate Legal Notices; however, if the Program has interactive interfaces that do not display Appropriate Legal Notices, your work need not make them do so.
   A compilation of a covered work with other separate and independent works, which are not by their nature extensions of the covered work, and which are not combined with it such as to form a larger program, in or on a volume of a storage or distribution medium, is called an &quot;aggregate&quot; if the compilation and its resulting copyright are not used to limit the access or legal rights of the compilation&#39;s users beyond what the individual works permit. Inclusion of a covered work in an aggregate does not cause this License to apply to the other parts of the aggregate.
   6. Conveying Non-Source Forms.
   You may convey a covered work in object code form under the terms of sections 4 and 5, provided that you also convey the machine-readable Corresponding Source under the terms of this License, in one of these ways:
      a) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by the Corresponding Source fixed on a durable physical medium customarily used for software interchange.
      b) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by a written offer, valid for at least three years and valid for as long as you offer spare parts or customer support for that product model, to give anyone who possesses the object code either (1) a copy of the Corresponding Source for all the software in the product that is covered by this License, on a durable physical medium customarily used for software interchange, for a price no more than your reasonable cost of physically performing this conveying of source, or (2) access to copy the Corresponding Source from a network server at no charge.
      c) Convey individual copies of the object code with a copy of the written offer to provide the Corresponding Source. This alternative is allowed only occasionally and noncommercially, and only if you received the object code with such an offer, in accord with subsection 6b.
      d) Convey the object code by offering access from a designated place (gratis or for a charge), and offer equivalent access to the Corresponding Source in the same way through the same place at no further charge. You need not require recipients to copy the Corresponding Source along with the object code. If the place to copy the object code is a network server, the Corresponding Source may be on a different server (operated by you or a third party) that supports equivalent copying facilities, provided you maintain clear directions next to the object code saying where to find the Corresponding Source. Regardless of what server hosts the Corresponding Source, you remain obligated to ensure that it is available for as long as needed to satisfy these requirements.
      e) Convey the object code using peer-to-peer transmission, provided you inform other peers where the object code and Corresponding Source of the work are being offered to the general public at no charge under subsection 6d.
   A separable portion of the object code, whose source code is excluded from the Corresponding Source as a System Library, need not be included in conveying the object code work.
   A &quot;User Product&quot; is either (1) a &quot;consumer product&quot;, which means any tangible personal property which is normally used for personal, family, or household purposes, or (2) anything designed or sold for incorporation into a dwelling. In determining whether a product is a consumer product, doubtful cases shall be resolved in favor of coverage. For a particular product received by a particular user, &quot;normally used&quot; refers to a typical or common use of that class of product, regardless of the status of the particular user or of the way in which the particular user actually uses, or expects or is expected to use, the product. A product is a consumer product regardless of whether the product has substantial commercial, industrial or non-consumer uses, unless such uses represent the only significant mode of use of the product.
   &quot;Installation Information&quot; for a User Product means any methods, procedures, authorization keys, or other information required to install and execute modified versions of a covered work in that User Product from a modified version of its Corresponding Source. The information must suffice to ensure that the continued functioning of the modified object code is in no case prevented or interfered with solely because modification has been made.
   If you convey an object code work under this section in, or with, or specifically for use in, a User Product, and the conveying occurs as part of a transaction in which the right of possession and use of the User Product is transferred to the recipient in perpetuity or for a fixed term (regardless of how the transaction is characterized), the Corresponding Source conveyed under this section must be accompanied by the Installation Information. But this requirement does not apply if neither you nor any third party retains the ability to install modified object code on the User Product (for example, the work has been installed in ROM).
   The requirement to provide Installation Information does not include a requirement to continue to provide support service, warranty, or updates for a work that has been modified or installed by the recipient, or for the User Product in which it has been modified or installed. Access to a network may be denied when the modification itself materially and adversely affects the operation of the network or violates the rules and protocols for communication across the network.
   Corresponding Source conveyed, and Installation Information provided, in accord with this section must be in a format that is publicly documented (and with an implementation available to the public in source code form), and must require no special password or key for unpacking, reading or copying.
   7. Additional Terms.
   &quot;Additional permissions&quot; are terms that supplement the terms of this License by making exceptions from one or more of its conditions. Additional permissions that are applicable to the entire Program shall be treated as though they were included in this License, to the extent that they are valid under applicable law. If additional permissions apply only to part of the Program, that part may be used separately under those permissions, but the entire Program remains governed by this License without regard to the additional permissions.
   When you convey a copy of a covered work, you may at your option remove any additional permissions from that copy, or from any part of it. (Additional permissions may be written to require their own removal in certain cases when you modify the work.) You may place additional permissions on material, added by you to a covered work, for which you have or can give appropriate copyright permission.
   Notwithstanding any other provision of this License, for material you add to a covered work, you may (if authorized by the copyright holders of that material) supplement the terms of this License with terms:
      a) Disclaiming warranty or limiting liability differently from the terms of sections 15 and 16 of this License; or
      b) Requiring preservation of specified reasonable legal notices or author attributions in that material or in the Appropriate Legal Notices displayed by works containing it; or
      c) Prohibiting misrepresentation of the origin of that material, or requiring that modified versions of such material be marked in reasonable ways as different from the original version; or
      d) Limiting the use for publicity purposes of names of licensors or authors of the material; or
      e) Declining to grant rights under trademark law for use of some trade names, trademarks, or service marks; or
      f) Requiring indemnification of licensors and authors of that material by anyone who conveys the material (or modified versions of it) with contractual assumptions of liability to the recipient, for any liability that these contractual assumptions directly impose on those licensors and authors.
   All other non-permissive additional terms are considered &quot;further restrictions&quot; within the meaning of section 10. If the Program as you received it, or any part of it, contains a notice stating that it is governed by this License along with a term that is a further restriction, you may remove that term. If a license document contains a further restriction but permits relicensing or conveying under this License, you may add to a covered work material governed by the terms of that license document, provided that the further restriction does not survive such relicensing or conveying.
   If you add terms to a covered work in accord with this section, you must place, in the relevant source files, a statement of the additional terms that apply to those files, or a notice indicating where to find the applicable terms.
   Additional terms, permissive or non-permissive, may be stated in the form of a separately written license, or stated as exceptions; the above requirements apply either way.
   8. Termination.
   You may not propagate or modify a covered work except as expressly provided under this License. Any attempt otherwise to propagate or modify it is void, and will automatically terminate your rights under this License (including any patent licenses granted under the third paragraph of section 11).
   However, if you cease all violation of this License, then your license from a particular copyright holder is reinstated (a) provisionally, unless and until the copyright holder explicitly and finally terminates your license, and (b) permanently, if the copyright holder fails to notify you of the violation by some reasonable means prior to 60 days after the cessation.
   Moreover, your license from a particular copyright holder is reinstated permanently if the copyright holder notifies you of the violation by some reasonable means, this is the first time you have received notice of violation of this License (for any work) from that copyright holder, and you cure the violation prior to 30 days after your receipt of the notice.
   Termination of your rights under this section does not terminate the licenses of parties who have received copies or rights from you under this License. If your rights have been terminated and not permanently reinstated, you do not qualify to receive new licenses for the same material under section 10.
   9. Acceptance Not Required for Having Copies.
   You are not required to accept this License in order to receive or run a copy of the Program. Ancillary propagation of a covered work occurring solely as a consequence of using peer-to-peer transmission to receive a copy likewise does not require acceptance. However, nothing other than this License grants you permission to propagate or modify any covered work. These actions infringe copyright if you do not accept this License. Therefore, by modifying or propagating a covered work, you indicate your acceptance of this License to do so.
   10. Automatic Licensing of Downstream Recipients.
   Each time you convey a covered work, the recipient automatically receives a license from the original licensors, to run, modify and propagate that work, subject to this License. You are not responsible for enforcing compliance by third parties with this License.
   An &quot;entity transaction&quot; is a transaction transferring control of an organization, or substantially all assets of one, or subdividing an organization, or merging organizations. If propagation of a covered work results from an entity transaction, each party to that transaction who receives a copy of the work also receives whatever licenses to the work the party&#39;s predecessor in interest had or could give under the previous paragraph, plus a right to possession of the Corresponding Source of the work from the predecessor in interest, if the predecessor has it or can get it with reasonable efforts.
   You may not impose any further restrictions on the exercise of the rights granted or affirmed under this License. For example, you may not impose a license fee, royalty, or other charge for exercise of rights granted under this License, and you may not initiate litigation (including a cross-claim or counterclaim in a lawsuit) alleging that any patent claim is infringed by making, using, selling, offering for sale, or importing the Program or any portion of it.
   11. Patents.
   A &quot;contributor&quot; is a copyright holder who authorizes use under this License of the Program or a work on which the Program is based. The work thus licensed is called the contributor&#39;s &quot;contributor version&quot;.
   A contributor&#39;s &quot;essential patent claims&quot; are all patent claims owned or controlled by the contributor, whether already acquired or hereafter acquired, that would be infringed by some manner, permitted by this License, of making, using, or selling its contributor version, but do not include claims that would be infringed only as a consequence of further modification of the contributor version. For purposes of this definition, &quot;control&quot; includes the right to grant patent sublicenses in a manner consistent with the requirements of this License.
   Each contributor grants you a non-exclusive, worldwide, royalty-free patent license under the contributor&#39;s essential patent claims, to make, use, sell, offer for sale, import and otherwise run, modify and propagate the contents of its contributor version.
   In the following three paragraphs, a &quot;patent license&quot; is any express agreement or commitment, however denominated, not to enforce a patent (such as an express permission to practice a patent or covenant not to s ue for patent infringement). To &quot;grant&quot; such a patent license to a party means to make such an agreement or commitment not to enforce a patent against the party.
   If you convey a covered work, knowingly relying on a patent license, and the Corresponding Source of the work is not available for anyone to copy, free of charge and under the terms of this License, through a publicly available network server or other readily accessible means, then you must either (1) cause the Corresponding Source to be so available, or (2) arrange to deprive yourself of the benefit of the patent license for this particular work, or (3) arrange, in a manner consistent with the requirements of this License, to extend the patent
   license to downstream recipients. &quot;Knowingly relying&quot; means you have actual knowledge that, but for the patent license, your conveying the covered work in a country, or your recipient&#39;s use of the covered work in a country, would infringe one or more identifiable patents in that country that you have reason to believe are valid.
   If, pursuant to or in connection with a single transaction or arrangement, you convey, or propagate by procuring conveyance of, a covered work, and grant a patent license to some of the parties receiving the covered work authorizing them to use, propagate, modify or convey a specific copy of the covered work, then the patent license you grant is automatically extended to all recipients of the covered work and works based on it.
   A patent license is &quot;discriminatory&quot; if it does not include within the scope of its coverage, prohibits the exercise of, or is conditioned on the non-exercise of one or more of the rights that are specifically granted under this License. You may not convey a covered work if you are a party to an arrangement with a third party that is in the business of distributing software, under which you make payment to the third party based on the extent of your activity of conveying the work, and under which the third party grants, to any of the parties who would receive the covered work from you, a discriminatory patent license (a) in connection with copies of the covered work conveyed by you (or copies made from those copies), or (b) primarily for and in connection with specific products or compilations that contain the covered work, unless you entered into that arrangement, or that patent license was granted, prior to 28 March 2007.
   Nothing in this License shall be construed as excluding or limiting any implied license or other defenses to infringement that may otherwise be available to you under applicable patent law.
   12. No Surrender of Others&#39; Freedom.
   If conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot convey a covered work so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may
   not convey it at all. For example, if you agree to terms that obligate you to collect a royalty for further conveying from those to whom you convey the Program, the only way you could satisfy both those terms and this License would be to refrain entirely from conveying the Program.
   13. Remote Network Interaction; Use with the GNU General Public License.
   Notwithstanding any other provision of this License, if you modify the Program, your modified version must prominently offer all users interacting with it remotely through a computer network (if your version supports such interaction) an opportunity to receive the Corresponding Source of your version by providing access to the Corresponding Source from a network server at no charge, through some standard or customary means of facilitating copying of software. This Corresponding Source shall include the Corresponding Source for any work covered by version 3 of the GNU General Public License that is incorporated pursuant to the following paragraph.
   Notwithstanding any other provision of this License, you have permission to link or combine any covered work with a work licensed under version 3 of the GNU General Public License into a single combined work, and to convey the resulting work. The terms of this License will continue to apply to the part which is the covered work, but the work with which it is combined will remain governed by version 3 of the GNU General Public License.
   14. Revised Versions of this License.
   The Free Software Foundation may publish revised and/or new versions of the GNU Affero General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies that a certain numbered version of the GNU Affero General Public License &quot;or any later version&quot; applies to it, you have the option of following the terms and conditions either of that numbered version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of the GNU Affero General Public License, you may choose any version ever published by the Free Software Foundation.
   If the Program specifies that a proxy can decide which future versions of the GNU Affero General Public License can be used, that proxy&#39;s public statement of acceptance of a version permanently authorizes you to choose that version for the Program.
   Later license versions may give you additional or different permissions. However, no additional obligations are imposed on any author or copyright holder as a result of your choosing to follow a later version.
   15. Disclaimer of Warranty.
   THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   16. Limitation of Liability.
   IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   17. Interpretation of Sections 15 and 16.
   If the disclaimer of warranty and limitation of liability provided above cannot be given local legal effect according to their terms, reviewing courts shall apply local law that most closely approximates an absolute waiver of all civil liability in connection with the Program, unless a warranty or assumption of liability accompanies a copy of the Program in return for a fee. END OF TERMS AND CONDITIONS
How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively state the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt;one line to give the program&#39;s name and a brief idea of what it does.&gt;
Copyright (C) &lt;year&gt; &lt;name of author&gt;
This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
You should have received a copy of the GNU Affero General Public License along with this program. If not, see &lt;http s ://www.gnu.org/licenses/&gt;.
Also add information on how to contact you by electronic and paper mail.
If your software can interact with users remotely through a computer network, you should also make sure that it provides a way for users to get its source. For example, if your program is a web application, its interface could display a &quot;Source&quot; link that leads users to an archive of the code. There are many ways you could offer source, and different solutions will be better for different programs; see section 13 for the specific requirements.
You should also get your employer (if you work as a programmer) or school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. For more information on this, and how to apply and follow the GNU AGPL, see &lt;http s ://www.gnu.org/licenses/&gt;.
```


### Apache License 2.0

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Apache License
Version 2.0, January 2004
http://www.apache.org/licenses/ TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION
   1. Definitions.
      
      &quot;License&quot; shall mean the terms and conditions for use, reproduction, and distribution as defined by Sections 1 through 9 of this document.
      
      &quot;Licensor&quot; shall mean the copyright owner or entity authorized by the copyright owner that is granting the License.
      
      &quot;Legal Entity&quot; shall mean the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, &quot;control&quot; means (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (ii) ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial ownership of such entity.
      
      &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity exercising permissions granted by this License.
      
      &quot;Source&quot; form shall mean the preferred form for making modifications, including but not limited to software source code, documentation source, and configuration files.
      
      &quot;Object&quot; form shall mean any form resulting from mechanical transformation or translation of a Source form, including but not limited to compiled object code, generated documentation, and conversions to other media types.
      
      &quot;Work&quot; shall mean the work of authorship, whether in Source or Object form, made available under the License, as indicated by a copyright notice that is included in or attached to the work (an example is provided in the Appendix below).
      
      &quot;Derivative Works&quot; shall mean any work, whether in Source or Object form, that is based on (or derived from) the Work and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this License, Derivative Works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the Work and Derivative Works thereof.
      
      &quot;Contribution&quot; shall mean any work of authorship, including the original version of the Work and any modifications or additions to that Work or Derivative Works thereof, that is intentionally submitted to Licensor for inclusion in the Work by the copyright owner or by an individual or Legal Entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, &quot;submitted&quot; means any form of electronic, verbal, or written communication sent to the Licensor or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, the Licensor for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by the copyright owner as &quot;Not a Contribution.&quot;
      
      &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity on behalf of whom a Contribution has been received by Licensor and subsequently incorporated within the Work.
   2. Grant of Copyright License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare Derivative Works of, publicly display, publicly perform, sublicense, and distribute the Work and such Derivative Works in Source or Object form.
   3. Grant of Patent License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the Work to which such Contribution(s) was submitted. If You institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the Work or a Contribution incorporated within the Work constitutes direct or contributory patent infringement, then any patent licenses granted to You under this License for that Work shall terminate as of the date such litigation is filed.
   4. Redistribution. You may reproduce and distribute copies of the Work or Derivative Works thereof in any medium, with or without modifications, and in Source or Object form, provided that You meet the following conditions:
      (a) You must give any other recipients of the Work or Derivative Works a copy of this License; and
      (b) You must cause any modified files to carry prominent notices stating that You changed the files; and
      (c) You must retain, in the Source form of any Derivative Works that You distribute, all copyright, patent, trademark, and attribution notices from the Source form of the Work, excluding those notices that do not pertain to any part of the Derivative Works; and
      (d) If the Work includes a &quot;NOTICE&quot; text file as part of its distribution, then any Derivative Works that You distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the Derivative Works, in at least one of the following places: within a NOTICE text file distributed as part of the Derivative Works; within the Source form or documentation, if provided along with the Derivative Works; or, within a display generated by the Derivative Works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify the License. You may add Your own attribution notices within Derivative Works that You distribute, alongside or as an addendum to the NOTICE text from the Work, provided that such additional attribution notices cannot be construed as modifying the License.
      You may add Your own copyright statement to Your modifications and may provide additional or different license terms and conditions for use, reproduction, or distribution of Your modifications, or for any such Derivative Works as a whole, provided Your use, reproduction, and distribution of the Work otherwise complies with the conditions stated in this License.
   5. Submission of Contributions. Unless You explicitly state otherwise, any Contribution intentionally submitted for inclusion in the Work by You to the Licensor shall be under the terms and conditions of this License, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate license agreement you may have executed with Licensor regarding such Contributions.
   6. Trademarks. This License does not grant permission to use the trade names, trademarks, service marks, or product names of the Licensor, except as required for reasonable and customary use in describing the origin of the Work and reproducing the content of the NOTICE file.
   7. Disclaimer of Warranty. Unless required by applicable law or agreed to in writing, Licensor provides the Work (and each Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are solely responsible for determining the appropriateness of using or redistributing the Work and assume any risks associated with Your exercise of permissions under this License.
   8. Limitation of Liability. In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any Contributor be liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this License or out of the use or inability to use the Work (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such Contributor has been advised of the possibility of such damages.
   9. Accepting Warranty or Additional Liability. While redistributing the Work or Derivative Works thereof, You may choose to offer, and charge a fee for, acceptance of support, warranty, indemnity, or other liability obligations and/or rights consistent with this License. However, in accepting such obligations, You may act only on Your own behalf and on Your sole responsibility, not on behalf of any other Contributor, and only if You agree to indemnify, defend, and hold each Contributor harmless for any liability incurred by, or claims asserted against, such Contributor by reason of your accepting any such warranty or additional liability. END OF TERMS AND CONDITIONS
APPENDIX: How to apply the Apache License to your work.
To apply the Apache License to your work, attach the following boilerplate notice, with the fields enclosed by brackets &quot;[]&quot; replaced with your own identifying information. (Don&#39;t include the brackets!) The text should be enclosed in the appropriate comment syntax for the file format. We also recommend that a file or class name and description of purpose be included on the same &quot;printed page&quot; as the copyright notice for easier identification within third-party archives.
Copyright [yyyy] [name of copyright owner]
Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```


### Artistic License 1.0

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.

Copyright (c) or


```
The Artistic License
Preamble
The intent of this document is to state the conditions under which a Package may be copied, such that the Copyright Holder maintains some semblance of artistic control over the development of the package, while giving the users of the package the right to use and distribute the Package in a more-or-less customary fashion, plus the right to make reasonable modifications.
Definitions:
&quot;Package&quot; refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
&quot;Standard Version&quot; refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder.
&quot;Copyright Holder&quot; is whoever is named in the copyright or copyrights for the package.
&quot;You&quot; is you, if you&#39;re thinking about copying or distributing this Package.
&quot;Reasonable copying fee&quot; is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
&quot;Freely Available&quot; means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as ftp.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
      b) use the modified Package only within your corporation or organization.
      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
      b) accompany the distribution with the machine-readable source of the Package with your modifications.
      c) accompany any non-standard executables with their corresponding Standard Version executables, giving the non-standard executables non-standard names, and clearly documenting the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own.
   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.
   7. C or perl subroutines supplied by you and linked into this Package shall not be considered part of this Package.
   8. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
   9. THIS PACKAGE IS PROVIDED &quot;AS IS&quot; AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE. The End
```


### Artistic License 1.0 (Perl)

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) or

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
The &quot;Artistic License&quot;
Preamble
The intent of this document is to state the conditions under which a Package may be copied, such that the Copyright Holder maintains some semblance of artistic control over the development of the package, while giving the users of the package the right to use and distribute the Package in a more-or-less customary fashion, plus the right to make reasonable modifications.
Definitions:
&quot;Package&quot; refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
&quot;Standard Version&quot; refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder as specified below.
&quot;Copyright Holder&quot; is whoever is named in the copyright or copyrights for the package.
&quot;You&quot; is you, if you&#39;re thinking about copying or distributing this Package.
&quot;Reasonable copying fee&quot; is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
&quot;Freely Available&quot; means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as uunet.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
      b) use the modified Package only within your corporation or organization.
      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
      b) accompany the distribution with the machine-readable source of the Package with your modifications.
      c) give non-standard executables non-standard names, and clearly document the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own. You may embed this Package&#39;s interpreter within an executable of yours (by linking); this shall be construed as a mere form of aggregation, provided that the complete Standard Version of the interpreter is so embedded.
   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.
   7. C subroutines (or comparably compiled subroutines in other languages) supplied by you and linked into this Package in order to emulate subroutines and variables of the language defined by this Package shall not be considered part of this Package, but are the equivalent of input as in Paragraph 6, provided these subroutines do not change the language in any way that would cause it to fail the regression tests for the language.
   8. Aggregation of this Package with a commercial distribution is always permitted provided that the use of this Package is embedded; that is, when no overt attempt is made to make this Package&#39;s interfaces visible to the end user of the commercial distribution. Such use shall not be construed as a distribution of this Package.
   9. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
   10. THIS PACKAGE IS PROVIDED &quot;AS IS&quot; AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE. The End
```


### BSD 2-Clause &quot;Simplified&quot; License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.

Copyright (c) Donald Stufft and individual contributors.


```
Copyright (c) &lt;year&gt; &lt;owner&gt;
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice, this
      list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation

      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot;
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```


### BSD 3-Clause &quot;New&quot; or &quot;Revised&quot; License

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Copyright (c) &lt;year&gt; &lt;owner&gt;
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

   3. Neither the name of the copyright holder nor the names of its
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot;
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```


### BSD 3-Clause Clear License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
The Clear BSD License
Copyright (c) [xxxx]-[xxxx] [Owner Organization]
All rights reserved.
Redistribution and use in source and binary forms, with or without modification, are permitted (subject to the limitations in the disclaimer below) provided that the following conditions are met:
      * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
      * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
      * Neither the name of [Owner Organization] nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY&#39;S PATENT RIGHTS ARE GRANTED BY THIS LICENSE. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```


### Boost Software License 1.0

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Boost Software License - Version 1.0 - August 17th, 2003
Permission is hereby granted, free of charge, to any person or organization obtaining a copy of the software and accompanying documentation covered by this license (the &quot;Software&quot;) to use, reproduce, display, distribute, execute, and transmit the Software, and to prepare derivative works of the Software, and to permit third-parties to whom the Software is furnished to do so, all subject to the following:
The copyright notices in the Software and this entire statement, including the above license grant, this restriction and the following disclaimer, must be included in all copies of the Software, in whole or in part, and all derivative works of the Software, unless such copies or derivative works are solely in the form of machine-executable object code generated by a source language processor.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
```


### Creative Commons Attribution 4.0

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Creative Commons Attribution 4.0 International Creative Commons Corporation (&quot;Creative Commons&quot;) is not a law firm and does not provide legal services or legal advice. Distribution of Creative Commons public licenses does not create a lawyer-client or other relationship. Creative Commons makes its licenses and related information available on an &quot;as-is&quot; basis. Creative Commons gives no warranties regarding its licenses, any material licensed under their terms and conditions, or any related information. Creative Commons disclaims all liability for damages resulting from their use to the fullest extent possible.
Using Creative Commons Public Licenses
Creative Commons public licenses provide a standard set of terms and conditions that creators and other rights holders may use to share original works of authorship and other material subject to copyright and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.
Considerations for licensors: Our public licenses are intended for use by those authorized to give the public permission to use material in ways otherwise restricted by copyright and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors
Considerations for the public: By using one of our public licenses, a licensor grants the public permission to use the licensed material under specified terms and conditions. If the licensor&#39;s permission is not necessary for any reason–for example, because of any applicable exception or limitation to copyright–then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License
By exercising the Licensed Rights (defined below), You accept and agree to be bound by the terms and conditions of this Creative Commons Attribution 4.0 International Public License (&quot;Public License&quot;). To the extent this Public License may be interpreted as a contract, You are granted the Licensed Rights in consideration of Your acceptance of these terms and conditions, and the Licensor grants You such rights in consideration of benefits the Licensor receives from making the Licensed Material available under these terms and conditions.
Section 1 – Definitions.
   a. Adapted Material means material subject to Copyright and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.
   b. Adapter&#39;s License means the license You apply to Your Copyright and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.
   c. Copyright and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.
   d. Effective Technological Measures means those measures that, in the absence of proper authority, may not be circumvented under laws fulfilling obligations under Article 11 of the WIPO Copyright Treaty adopted on December 20, 1996, and/or similar international agreements.
   e. Exceptions and Limitations means fair use, fair dealing, and/or any other exception or limitation to Copyright and Similar Rights that applies to Your use of the Licensed Material.
   f. Licensed Material means the artistic or literary work, database, or other material to which the Licensor applied this Public License.
   g. Licensed Rights means the rights granted to You subject to the terms and conditions of this Public License, which are limited to all Copyright and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.
   h. Licensor means the individual(s) or entity(ies) granting rights under this Public License.
   i. Share means to provide material to the public by any means or process that requires permission under the Licensed Rights, such as reproduction, public display, public performance, distribution, dissemination, communication, or importation, and to make material available to the public including in ways that members of the public may access the material from a place and at a time individually chosen by them.
   j. Sui Generis Database Rights means rights other than copyright resulting from Directive 96/9/EC of the European Parliament and of the Council of 11 March 1996 on the legal protection of databases, as amended and/or succeeded, as well as other essentially equivalent rights anywhere in the world.
   k. You means the individual or entity exercising the Licensed Rights under this Public License. Your has a corresponding meaning.
Section 2 – Scope.
   a. License grant.
      1. Subject to the terms and conditions of this Public License, the Licensor hereby grants You a worldwide, royalty-free, non-sublicensable, non-exclusive, irrevocable license to exercise the Licensed Rights in the Licensed Material to:
         A. reproduce and Share the Licensed Material, in whole or in part; and
         B. produce, reproduce, and Share Adapted Material.
      2. Exceptions and Limitations. For the avoidance of doubt, where Exceptions and Limitations apply to Your use, this Public License does not apply, and You do not need to comply with its terms and conditions.
      3. Term. The term of this Public License is specified in Section 6(a).
      4. Media and formats; technical modifications allowed. The Licensor authorizes You to exercise the Licensed Rights in all media and formats whether now known or hereafter created, and to make technical modifications necessary to do so. The Licensor waives and/or agrees not to assert any right or authority to forbid You from making technical modifications necessary to exercise the Licensed Rights, including technical modifications necessary to circumvent Effective Technological Measures. For purposes of this Public License, simply making modifications authorized by this Section 2(a)(4) never produces Adapted Material.
      5. Downstream recipients.
         A. Offer from the Licensor – Licensed Material. Every recipient of the Licensed Material automatically receives an offer from the Licensor to exercise the Licensed Rights under the terms and conditions of this Public License.
         B. No downstream restrictions. You may not offer or impose any additional or different terms or conditions on, or apply any Effective Technological Measures to, the Licensed Material if doing so restricts exercise of the Licensed Rights by any recipient of the Licensed Material.
      6. No endorsement. Nothing in this Public License constitutes or may be construed as permission to assert or imply that You are, or that Your use of the Licensed Material is, connected with, or sponsored, endorsed, or granted official status by, the Licensor or others designated to receive attribution as provided in Section 3(a)(1)(A)(i).
   b. Other rights.
      1. Moral rights, such as the right of integrity, are not licensed under this Public License, nor are publicity, privacy, and/or other similar personality rights; however, to the extent possible, the Licensor waives and/or agrees not to assert any such rights held by the Licensor to the limited extent necessary to allow You to exercise the Licensed Rights, but not otherwise.
      2. Patent and trademark rights are not licensed under this Public License.
      3. To the extent possible, the Licensor waives any right to collect royalties from You for the exercise of the Licensed Rights, whether directly or through a collecting society under any voluntary or waivable statutory or compulsory licensing scheme. In all other cases the Licensor expressly reserves any right to collect such royalties.
Section 3 – License Conditions.
Your exercise of the Licensed Rights is expressly made subject to the following conditions.
   a. Attribution.
      1. If You Share the Licensed Material (including in modified form), You must:
         A. retain the following if it is supplied by the Licensor with the Licensed Material:
            i. identification of the creator(s) of the Licensed Material and any others designated to receive attribution, in any reasonable manner requested by the Licensor (including by pseudonym if designated);
            ii. a copyright notice;
            iii. a notice that refers to this Public License;
            iv. a notice that refers to the disclaimer of warranties;
            v. a URI or hyperlink to the Licensed Material to the extent reasonably practicable;
         B. indicate if You modified the Licensed Material and retain an indication of any previous modifications; and
         C. indicate the Licensed Material is licensed under this Public License, and include the text of, or the URI or hyperlink to, this Public License.
      2. You may satisfy the conditions in Section 3(a)(1) in any reasonable manner based on the medium, means, and context in which You Share the Licensed Material. For example, it may be reasonable to satisfy the conditions by providing a URI or hyperlink to a resource that includes the required information.
      3. If requested by the Licensor, You must remove any of the information required by Section 3(a)(1)(A) to the extent reasonably practicable.
      4. If You Share Adapted Material You produce, the Adapter&#39;s License You apply must not prevent recipients of the Adapted Material from complying with this Public License.
Section 4 – Sui Generis Database Rights.
Where the Licensed Rights include Sui Generis Database Rights that apply to Your use of the Licensed Material:
   a. for the avoidance of doubt, Section 2(a)(1) grants You the right to extract, reuse, reproduce, and Share all or a substantial portion of the contents of the database;
   b. if You include all or a substantial portion of the database contents in a database in which You have Sui Generis Database Rights, then the database in which You have Sui Generis Database Rights (but not its individual contents) is Adapted Material; and
   c. You must comply with the conditions in Section 3(a) if You Share all or a substantial portion of the contents of the database.
For the avoidance of doubt, this Section 4 supplements and does not replace Your obligations under this Public License where the Licensed Rights include other Copyright and Similar Rights.
Section 5 – Disclaimer of Warranties and Limitation of Liability.
   a. Unless otherwise separately undertaken by the Licensor, to the extent possible, the Licensor offers the Licensed Material as-is and as-available, and makes no representations or warranties of any kind concerning the Licensed Material, whether express, implied, statutory, or other. This includes, without limitation, warranties of title, merchantability, fitness for a particular purpose, non-infringement, absence of latent or other defects, accuracy, or the presence or absence of errors, whether or not known or discoverable. Where disclaimers of warranties are not allowed in full or in part, this disclaimer may not apply to You.
   b. To the extent possible, in no event will the Licensor be liable to You on any legal theory (including, without limitation, negligence) or otherwise for any direct, special, indirect, incidental, consequential, punitive, exemplary, or other losses, costs, expenses, or damages arising out of this Public License or use of the Licensed Material, even if the Licensor has been advised of the possibility of such losses, costs, expenses, or damages. Where a limitation of liability is not allowed in full or in part, this limitation may not apply to You.
   c. The disclaimer of warranties and limitation of liability provided above shall be interpreted in a manner that, to the extent possible, most closely approximates an absolute disclaimer and waiver of all liability.
Section 6 – Term and Termination.
   a. This Public License applies for the term of the Copyright and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.
   b. Where Your right to use the Licensed Material has terminated under Section 6(a), it reinstates:
      1. automatically as of the date the violation is cured, provided it is cured within 30 days of Your discovery of the violation; or
      2. upon express reinstatement by the Licensor.
   c. For the avoidance of doubt, this Section 6(b) does not affect any right the Licensor may have to seek remedies for Your violations of this Public License.
   d. For the avoidance of doubt, the Licensor may also offer the Licensed Material under separate terms or conditions or stop distributing the Licensed Material at any time; however, doing so will not terminate this Public License.
   e. Sections 1, 5, 6, 7, and 8 survive termination of this Public License.
Section 7 – Other Terms and Conditions.
   a. The Licensor shall not be bound by any additional or different terms or conditions communicated by You unless expressly agreed.
   b. Any arrangements, understandings, or agreements regarding the Licensed Material not stated herein are separate from and independent of the terms and conditions of this Public License.
Section 8 – Interpretation.
   a. For the avoidance of doubt, this Public License does not, and shall not be interpreted to, reduce, limit, restrict, or impose conditions on any use of the Licensed Material that could lawfully be made without permission under this Public License.
   b. To the extent possible, if any provision of this Public License is deemed unenforceable, it shall be automatically reformed to the minimum extent necessary to make it enforceable. If the provision cannot be reformed, it shall be severed from this Public License without affecting the enforceability of the remaining terms and conditions.
   c. No term or condition of this Public License will be waived and no failure to comply consented to unless expressly agreed to by the Licensor.
   d. Nothing in this Public License constitutes or may be interpreted as a limitation upon, or waiver of, any privileges and immunities that apply to the Licensor or You, including from the legal processes of any jurisdiction or authority.
Creative Commons is not a party to its public licenses. Notwithstanding, Creative Commons may elect to apply one of its public licenses to material it publishes and in those instances will be considered the &quot;Licensor.&quot; The text of the Creative Commons public licenses is dedicated to the public domain under the CC0 Public Domain Dedication. Except for the limited purpose of indicating that material is shared under a Creative Commons public license or as otherwise permitted by the Creative Commons policies published at creativecommons.org/policies, Creative Commons does not authorize the use of the trademark &quot;Creative Commons&quot; or any other trademark or logo of Creative Commons without its prior written consent including, without limitation, in connection with any unauthorized modifications to any of its public licenses or any other arrangements, understandings, or agreements concerning use of licensed material. For the avoidance of doubt, this paragraph does not form part of the public licenses.
Creative Commons may be contacted at creativecommons.org.
```


### Creative Commons Attribution Share Alike 3.0

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Creative Commons Attribution-ShareAlike 3.0 Unported CREATIVE COMMONS CORPORATION IS NOT A LAW FIRM AND DOES NOT PROVIDE LEGAL SERVICES. DISTRIBUTION OF THIS LICENSE DOES NOT CREATE AN ATTORNEY-CLIENT RELATIONSHIP. CREATIVE COMMONS PROVIDES THIS INFORMATION ON AN &quot;AS-IS&quot; BASIS. CREATIVE COMMONS MAKES NO WARRANTIES REGARDING THE INFORMATION PROVIDED, AND DISCLAIMS LIABILITY FOR DAMAGES RESULTING FROM ITS USE.
License
THE WORK (AS DEFINED BELOW) IS PROVIDED UNDER THE TERMS OF THIS CREATIVE COMMONS PUBLIC LICENSE (&quot;CCPL&quot; OR &quot;LICENSE&quot;). THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.
BY EXERCISING ANY RIGHTS TO THE WORK PROVIDED HERE, YOU ACCEPT AND AGREE TO BE BOUND BY THE TERMS OF THIS LICENSE. TO THE EXTENT THIS LICENSE MAY BE CONSIDERED TO BE A CONTRACT, THE LICENSOR GRANTS YOU THE RIGHTS CONTAINED HERE IN CONSIDERATION OF YOUR ACCEPTANCE OF SUCH TERMS AND CONDITIONS.
   1. Definitions
      a. &quot;Adaptation&quot; means a work based upon the Work, or upon the Work and other pre-existing works, such as a translation, adaptation, derivative work, arrangement of music or other alterations of a literary or artistic work, or phonogram or performance and includes cinematographic adaptations or any other form in which the Work may be recast, transformed, or adapted including in any form recognizably derived from the original, except that a work that constitutes a Collection will not be considered an Adaptation for the purpose of this License. For the avoidance of doubt, where the Work is a musical work, performance or phonogram, the synchronization of the Work in timed-relation with a moving image (&quot;synching&quot;) will be considered an Adaptation for the purpose of this License.
      b. &quot;Collection&quot; means a collection of literary or artistic works, such as encyclopedias and anthologies, or performances, phonograms or broadcasts, or other works or subject matter other than works listed in Section 1(f) below, which, by reason of the selection and arrangement of their contents, constitute intellectual creations, in which the Work is included in its entirety in unmodified form along with one or more other contributions, each constituting separate and independent works in themselves, which together are assembled into a collective whole. A work that constitutes a Collection will not be considered an Adaptation (as defined below) for the purposes of this License.
      c. &quot;Creative Commons Compatible License&quot; means a license that is listed at http://creativecommons.org/compatiblelicenses that has been approved by Creative Commons as being essentially equivalent to this License, including, at a minimum, because that license: (i) contains terms that have the same purpose, meaning and effect as the License Elements of this License; and, (ii) explicitly permits the relicensing of adaptations of works made available under that license under this License or a Creative Commons jurisdiction license with the same License Elements as this License.
      d. &quot;Distribute&quot; means to make available to the public the original and copies of the Work or Adaptation, as appropriate, through sale or other transfer of ownership.
      e. &quot;License Elements&quot; means the following high-level license attributes as selected by Licensor and indicated in the title of this License: Attribution, ShareAlike.
      f. &quot;Licensor&quot; means the individual, individuals, entity or entities that offer(s) the Work under the terms of this License.
      g. &quot;Original Author&quot; means, in the case of a literary or artistic work, the individual, individuals, entity or entities who created the Work or if no individual or entity can be identified, the publisher; and in addition (i) in the case of a performance the actors, singers, musicians, dancers, and other persons who act, sing, deliver, declaim, play in, interpret or otherwise perform literary or artistic works or expressions of folklore; (ii) in the case of a phonogram the producer being the person or legal entity who first fixes the sounds of a performance or other sounds; and, (iii) in the case of broadcasts, the organization that transmits the broadcast.
      h. &quot;Work&quot; means the literary and/or artistic work offered under the terms of this License including without limitation any production in the literary, scientific and artistic domain, whatever may be the mode or form of its expression including digital form, such as a book, pamphlet and other writing; a lecture, address, sermon or other work of the same nature; a dramatic or dramatico-musical work; a choreographic work or entertainment in dumb show; a musical composition with or without words; a cinematographic work to which are assimilated works expressed by a process analogous to cinematography; a work of drawing, painting, architecture, sculpture, engraving or lithography; a photographic work to which are assimilated works expressed by a process analogous to photography; a work of applied art; an illustration, map, plan, sketch or three-dimensional work relative to geography, topography, architecture or science; a performance; a broadcast; a phonogram; a compilation of data to the extent it is protected as a copyrightable work; or a work performed by a variety or circus performer to the extent it is not otherwise considered a literary or artistic work.
      i. &quot;You&quot; means an individual or entity exercising rights under this License who has not previously violated the terms of this License with respect to the Work, or who has received express permission from the Licensor to exercise rights under this License despite a previous violation.
      j. &quot;Publicly Perform&quot; means to perform public recitations of the Work and to communicate to the public those public recitations, by any means or process, including by wire or wireless means or public digital performances; to make available to the public Works in such a way that members of the public may access these Works from a place and at a place individually chosen by them; to perform the Work to the public by any means or process and the communication to the public of the performances of the Work, including by public digital performance; to broadcast and rebroadcast the Work by any means including signs, sounds or images.
      k. &quot;Reproduce&quot; means to make copies of the Work by any means including without limitation by sound or visual recordings and the right of fixation and reproducing fixations of the Work, including storage of a protected performance or phonogram in digital form or other electronic medium.
   2. Fair Dealing Rights. Nothing in this License is intended to reduce, limit, or restrict any uses free from copyright or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.
   3. License Grant. Subject to the terms and conditions of this License, Licensor hereby grants You a worldwide, royalty-free, non-exclusive, perpetual (for the duration of the applicable copyright) license to exercise the rights in the Work as stated below:
      a. to Reproduce the Work, to incorporate the Work into one or more Collections, and to Reproduce the Work as incorporated in the Collections;
      b. to create and Reproduce Adaptations provided that any such Adaptation, including any translation in any medium, takes reasonable steps to clearly label, demarcate or otherwise identify that changes were made to the original Work. For example, a translation could be marked &quot;The original work was translated from English to Spanish,&quot; or a modification could indicate &quot;The original work has been modified.&quot;;
      c. to Distribute and Publicly Perform the Work including as incorporated in Collections; and,
      d. to Distribute and Publicly Perform Adaptations.
      e. For the avoidance of doubt:
         i. Non-waivable Compulsory License Schemes. In those jurisdictions in which the right to collect royalties through any statutory or compulsory licensing scheme cannot be waived, the Licensor reserves the exclusive right to collect such royalties for any exercise by You of the rights granted under this License;
         ii. Waivable Compulsory License Schemes. In those jurisdictions in which the right to collect royalties through any statutory or compulsory licensing scheme can be waived, the Licensor waives the exclusive right to collect such royalties for any exercise by You of the rights granted under this License; and,
         iii. Voluntary License Schemes. The Licensor waives the right to collect royalties, whether individually or, in the event that the Licensor is a member of a collecting society that administers voluntary licensing schemes, via that society, from any exercise by You of the rights granted under this License.
   The above rights may be exercised in all media and formats whether now known or hereafter devised. The above rights include the right to make such modifications as are technically necessary to exercise the rights in other media and formats. Subject to Section 8(f), all rights not expressly granted by Licensor are hereby reserved.
   4. Restrictions. The license granted in Section 3 above is expressly made subject to and limited by the following restrictions:
      a. You may Distribute or Publicly Perform the Work only under the terms of this License. You must include a copy of, or the Uniform Resource Identifier (URI) for, this License with every copy of the Work You Distribute or Publicly Perform. You may not offer or impose any terms on the Work that restrict the terms of this License or the ability of the recipient of the Work to exercise the rights granted to that recipient under the terms of the License. You may not sublicense the Work. You must keep intact all notices that refer to this License and to the disclaimer of warranties with every copy of the Work You Distribute or Publicly Perform. When You Distribute or Publicly Perform the Work, You may not impose any effective technological measures on the Work that restrict the ability of a recipient of the Work from You to exercise the rights granted to that recipient under the terms of the License. This Section 4(a) applies to the Work as incorporated in a Collection, but this does not require the Collection apart from the Work itself to be made subject to the terms of this License. If You create a Collection, upon notice from any Licensor You must, to the extent practicable, remove from the Collection any credit as required by Section 4(c), as requested. If You create an Adaptation, upon notice from any Licensor You must, to the extent practicable, remove from the Adaptation any credit as required by Section 4(c), as requested.
      b. You may Distribute or Publicly Perform an Adaptation only under the terms of: (i) this License; (ii) a later version of this License with the same License Elements as this License; (iii) a Creative Commons jurisdiction license (either this or a later license version) that contains the same License Elements as this License (e.g., Attribution-ShareAlike 3.0 US)); (iv) a Creative Commons Compatible License. If you license the Adaptation under one of the licenses mentioned in (iv), you must comply with the terms of that license. If you license the Adaptation under the terms of any of the licenses mentioned in (i), (ii) or (iii) (the &quot;Applicable License&quot;), you must comply with the terms of the Applicable License generally and the following provisions: (I) You must include a copy of, or the URI for, the Applicable License with every copy of each Adaptation You Distribute or Publicly Perform; (II) You may not offer or impose any terms on the Adaptation that restrict the terms of the Applicable License or the ability of the recipient of the Adaptation to exercise the rights granted to that recipient under the terms of the Applicable License; (III) You must keep intact all notices that refer to the Applicable License and to the disclaimer of warranties with every copy of the Work as included in the Adaptation You Distribute or Publicly Perform; (IV) when You Distribute or Publicly Perform the Adaptation, You may not impose any effective technological measures on the Adaptation that restrict the ability of a recipient of the Adaptation from You to exercise the rights granted to that recipient under the terms of the Applicable License. This Section 4(b) applies to the Adaptation as incorporated in a Collection, but this does not require the Collection apart from the Adaptation itself to be made subject to the terms of the Applicable License.
      c. If You Distribute, or Publicly Perform the Work or any Adaptations or Collections, You must, unless a request has been made pursuant to Section 4(a), keep intact all copyright notices for the Work and provide, reasonable to the medium or means You are utilizing: (i) the name of the Original Author (or pseudonym, if applicable) if supplied, and/or if the Original Author and/or Licensor designate another party or parties (e.g., a sponsor institute, publishing entity, journal) for attribution (&quot;Attribution Parties&quot;) in Licensor&#39;s copyright notice, terms of service or by other reasonable means, the name of such party or parties; (ii) the title of the Work if supplied; (iii) to the extent reasonably practicable, the URI, if any, that Licensor specifies to be associated with the Work, unless such URI does not refer to the copyright notice or licensing information for the Work; and (iv), consistent with Section 3(b), in the case of an Adaptation, a credit identifying the use of the Work in the Adaptation (e.g., &quot;French translation of the Work by Original Author,&quot; or &quot;Screenplay based on original Work by Original Author&quot;). The credit required by this Section 4(c) may be implemented in any reasonable manner; provided, however, that in the case of a Adaptation or Collection, at a minimum such credit will appear, if a credit for all contributing authors of the Adaptation or Collection appears, then as part of these credits and in a manner at least as prominent as the credits for the other contributing authors. For the avoidance of doubt, You may only use the credit required by this Section for the purpose of attribution in the manner set out above and, by exercising Your rights under this License, You may not implicitly or explicitly assert or imply any connection with, sponsorship or endorsement by the Original Author, Licensor and/or Attribution Parties, as appropriate, of You or Your use of the Work, without the separate, express prior written permission of the Original Author, Licensor and/or Attribution Parties.
      d. Except as otherwise agreed in writing by the Licensor or as may be otherwise permitted by applicable law, if You Reproduce, Distribute or Publicly Perform the Work either by itself or as part of any Adaptations or Collections, You must not distort, mutilate, modify or take other derogatory action in relation to the Work which would be prejudicial to the Original Author&#39;s honor or reputation. Licensor agrees that in those jurisdictions (e.g. Japan), in which any exercise of the right granted in Section 3(b) of this License (the right to make Adaptations) would be deemed to be a distortion, mutilation, modification or other derogatory action prejudicial to the Original Author&#39;s honor and reputation, the Licensor will waive or not assert, as appropriate, this Section, to the fullest extent permitted by the applicable national law, to enable You to reasonably exercise Your right under Section 3(b) of this License (right to make Adaptations) but not otherwise.
   5. Representations, Warranties and Disclaimer
   UNLESS OTHERWISE MUTUALLY AGREED TO BY THE PARTIES IN WRITING, LICENSOR OFFERS THE WORK AS-IS AND MAKES NO REPRESENTATIONS OR WARRANTIES OF ANY KIND CONCERNING THE WORK, EXPRESS, IMPLIED, STATUTORY OR OTHERWISE, INCLUDING, WITHOUT LIMITATION, WARRANTIES OF TITLE, MERCHANTIBILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, ACCURACY, OR THE PRESENCE OF ABSENCE OF ERRORS, WHETHER OR NOT DISCOVERABLE. SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OF IMPLIED WARRANTIES, SO SUCH EXCLUSION MAY NOT APPLY TO YOU.
   6. Limitation on Liability. EXCEPT TO THE EXTENT REQUIRED BY APPLICABLE LAW, IN NO EVENT WILL LICENSOR BE LIABLE TO YOU ON ANY LEGAL THEORY FOR ANY SPECIAL, INCIDENTAL, CONSEQUENTIAL, PUNITIVE OR EXEMPLARY DAMAGES ARISING OUT OF THIS LICENSE OR THE USE OF THE WORK, EVEN IF LICENSOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   7. Termination
      a. This License and the rights granted hereunder will terminate automatically upon any breach by You of the terms of this License. Individuals or entities who have received Adaptations or Collections from You under this License, however, will not have their licenses terminated provided such individuals or entities remain in full compliance with those licenses. Sections 1, 2, 5, 6, 7, and 8 will survive any termination of this License.
      b. Subject to the above terms and conditions, the license granted here is perpetual (for the duration of the applicable copyright in the Work). Notwithstanding the above, Licensor reserves the right to release the Work under different license terms or to stop distributing the Work at any time; provided, however that any such election will not serve to withdraw this License (or any other license that has been, or is required to be, granted under the terms of this License), and this License will continue in full force and effect unless terminated as stated above.
   8. Miscellaneous
      a. Each time You Distribute or Publicly Perform the Work or a Collection, the Licensor offers to the recipient a license to the Work on the same terms and conditions as the license granted to You under this License.
      b. Each time You Distribute or Publicly Perform an Adaptation, Licensor offers to the recipient a license to the original Work on the same terms and conditions as the license granted to You under this License.
      c. If any provision of this License is invalid or unenforceable under applicable law, it shall not affect the validity or enforceability of the remainder of the terms of this License, and without further action by the parties to this agreement, such provision shall be reformed to the minimum extent necessary to make such provision valid and enforceable.
      d. No term or provision of this License shall be deemed waived and no breach consented to unless such waiver or consent shall be in writing and signed by the party to be charged with such waiver or consent.
      e. This License constitutes the entire agreement between the parties with respect to the Work licensed here. There are no understandings, agreements or representations with respect to the Work not specified here. Licensor shall not be bound by any additional provisions that may appear in any communication from You. This License may not be modified without the mutual written agreement of the Licensor and You.
      f. The rights granted under, and the subject matter referenced, in this License were drafted utilizing the terminology of the Berne Convention for the Protection of Literary and Artistic Works (as amended on September 28, 1979), the Rome Convention of 1961, the WIPO Copyright Treaty of 1996, the WIPO Performances and Phonograms Treaty of 1996 and the Universal Copyright Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.
Creative Commons Notice
Creative Commons is not a party to this License, and makes no warranty whatsoever in connection with the Work. Creative Commons will not be liable to You or any party on any legal theory for any damages whatsoever, including without limitation any general, special, incidental or consequential damages arising in connection to this license. Notwithstanding the foregoing two (2) sentences, if Creative Commons has expressly identified itself as the Licensor hereunder, it shall have all rights and obligations of Licensor.
Except for the limited purpose of indicating to the public that the Work is licensed under the CCPL, Creative Commons does not authorize the use by either party of the trademark &quot;Creative Commons&quot; or any related trademark or logo of Creative Commons without the prior written consent of Creative Commons. Any permitted use will be in compliance with Creative Commons&#39; then-current trademark usage guidelines, as may be published on its website or otherwise made available upon request from time to time. For the avoidance of doubt, this trademark restriction does not form part of the License.
Creative Commons may be contacted at http://creativecommons.org/.
```


### Creative Commons Attribution Share Alike 4.0

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Creative Commons Attribution-ShareAlike 4.0 International Creative Commons Corporation (&quot;Creative Commons&quot;) is not a law firm and does not provide legal services or legal advice. Distribution of Creative Commons public licenses does not create a lawyer-client or other relationship. Creative Commons makes its licenses and related information available on an &quot;as-is&quot; basis. Creative Commons gives no warranties regarding its licenses, any material licensed under their terms and conditions, or any related information. Creative Commons disclaims all liability for damages resulting from their use to the fullest extent possible.
Using Creative Commons Public Licenses
Creative Commons public licenses provide a standard set of terms and conditions that creators and other rights holders may use to share original works of authorship and other material subject to copyright and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.
Considerations for licensors: Our public licenses are intended for use by those authorized to give the public permission to use material in ways otherwise restricted by copyright and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors
Considerations for the public: By using one of our public licenses, a licensor grants the public permission to use the licensed material under specified terms and conditions. If the licensor&#39;s permission is not necessary for any reason–for example, because of any applicable exception or limitation to copyright–then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.
Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees
Creative Commons Attribution-ShareAlike 4.0 International Public License
By exercising the Licensed Rights (defined below), You accept and agree to be bound by the terms and conditions of this Creative Commons Attribution-ShareAlike 4.0 International Public License (&quot;Public License&quot;). To the extent this Public License may be interpreted as a contract, You are granted the Licensed Rights in consideration of Your acceptance of these terms and conditions, and the Licensor grants You such rights in consideration of benefits the Licensor receives from making the Licensed Material available under these terms and conditions.
Section 1 – Definitions.
   a. Adapted Material means material subject to Copyright and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.
   b. Adapter&#39;s License means the license You apply to Your Copyright and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.
   c. BY-SA Compatible License means a license listed at creativecommons.org/compatiblelicenses, approved by Creative Commons as essentially the equivalent of this Public License.
   d. Copyright and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.
   e. Effective Technological Measures means those measures that, in the absence of proper authority, may not be circumvented under laws fulfilling obligations under Article 11 of the WIPO Copyright Treaty adopted on December 20, 1996, and/or similar international agreements.
   f. Exceptions and Limitations means fair use, fair dealing, and/or any other exception or limitation to Copyright and Similar Rights that applies to Your use of the Licensed Material.
   g. License Elements means the license attributes listed in the name of a Creative Commons Public License. The License Elements of this Public License are Attribution and ShareAlike.
   h. Licensed Material means the artistic or literary work, database, or other material to which the Licensor applied this Public License.
   i. Licensed Rights means the rights granted to You subject to the terms and conditions of this Public License, which are limited to all Copyright and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.
   j. Licensor means the individual(s) or entity(ies) granting rights under this Public License.
   k. Share means to provide material to the public by any means or process that requires permission under the Licensed Rights, such as reproduction, public display, public performance, distribution, dissemination, communication, or importation, and to make material available to the public including in ways that members of the public may access the material from a place and at a time individually chosen by them.
   l. Sui Generis Database Rights means rights other than copyright resulting from Directive 96/9/EC of the European Parliament and of the Council of 11 March 1996 on the legal protection of databases, as amended and/or succeeded, as well as other essentially equivalent rights anywhere in the world.
   m. You means the individual or entity exercising the Licensed Rights under this Public License. Your has a corresponding meaning.
Section 2 – Scope.
   a. License grant.
      1. Subject to the terms and conditions of this Public License, the Licensor hereby grants You a worldwide, royalty-free, non-sublicensable, non-exclusive, irrevocable license to exercise the Licensed Rights in the Licensed Material to:
         A. reproduce and Share the Licensed Material, in whole or in part; and
         B. produce, reproduce, and Share Adapted Material.
      2. Exceptions and Limitations. For the avoidance of doubt, where Exceptions and Limitations apply to Your use, this Public License does not apply, and You do not need to comply with its terms and conditions.
      3. Term. The term of this Public License is specified in Section 6(a).
      4. Media and formats; technical modifications allowed. The Licensor authorizes You to exercise the Licensed Rights in all media and formats whether now known or hereafter created, and to make technical modifications necessary to do so. The Licensor waives and/or agrees not to assert any right or authority to forbid You from making technical modifications necessary to exercise the Licensed Rights, including technical modifications necessary to circumvent Effective Technological Measures. For purposes of this Public License, simply making modifications authorized by this Section 2(a)(4) never produces Adapted Material.
      5. Downstream recipients.
         A. Offer from the Licensor – Licensed Material. Every recipient of the Licensed Material automatically receives an offer from the Licensor to exercise the Licensed Rights under the terms and conditions of this Public License.
         B. Additional offer from the Licensor – Adapted Material. Every recipient of Adapted Material from You automatically receives an offer from the Licensor to exercise the Licensed Rights in the Adapted Material under the conditions of the Adapter&#39;s License You apply.
         C. No downstream restrictions. You may not offer or impose any additional or different terms or conditions on, or apply any Effective Technological Measures to, the Licensed Material if doing so restricts exercise of the Licensed Rights by any recipient of the Licensed Material.
      6. No endorsement. Nothing in this Public License constitutes or may be construed as permission to assert or imply that You are, or that Your use of the Licensed Material is, connected with, or sponsored, endorsed, or granted official status by, the Licensor or others designated to receive attribution as provided in Section 3(a)(1)(A)(i).
   b. Other rights.
      1. Moral rights, such as the right of integrity, are not licensed under this Public License, nor are publicity, privacy, and/or other similar personality rights; however, to the extent possible, the Licensor waives and/or agrees not to assert any such rights held by the Licensor to the limited extent necessary to allow You to exercise the Licensed Rights, but not otherwise.
      2. Patent and trademark rights are not licensed under this Public License.
      3. To the extent possible, the Licensor waives any right to collect royalties from You for the exercise of the Licensed Rights, whether directly or through a collecting society under any voluntary or waivable statutory or compulsory licensing scheme. In all other cases the Licensor expressly reserves any right to collect such royalties.
Section 3 – License Conditions.
Your exercise of the Licensed Rights is expressly made subject to the following conditions.
   a. Attribution.
      1. If You Share the Licensed Material (including in modified form), You must:
         A. retain the following if it is supplied by the Licensor with the Licensed Material:
            i. identification of the creator(s) of the Licensed Material and any others designated to receive attribution, in any reasonable manner requested by the Licensor (including by pseudonym if designated);
            ii. a copyright notice;
            iii. a notice that refers to this Public License;
            iv. a notice that refers to the disclaimer of warranties;
            v. a URI or hyperlink to the Licensed Material to the extent reasonably practicable;
         B. indicate if You modified the Licensed Material and retain an indication of any previous modifications; and
         C. indicate the Licensed Material is licensed under this Public License, and include the text of, or the URI or hyperlink to, this Public License.
      2. You may satisfy the conditions in Section 3(a)(1) in any reasonable manner based on the medium, means, and context in which You Share the Licensed Material. For example, it may be reasonable to satisfy the conditions by providing a URI or hyperlink to a resource that includes the required information.
      3. If requested by the Licensor, You must remove any of the information required by Section 3(a)(1)(A) to the extent reasonably practicable.
   b. ShareAlike.In addition to the conditions in Section 3(a), if You Share Adapted Material You produce, the following conditions also apply.
      1. The Adapter&#39;s License You apply must be a Creative Commons license with the same License Elements, this version or later, or a BY-SA Compatible License.
      2. You must include the text of, or the URI or hyperlink to, the Adapter&#39;s License You apply. You may satisfy this condition in any reasonable manner based on the medium, means, and context in which You Share Adapted Material.
      3. You may not offer or impose any additional or different terms or conditions on, or apply any Effective Technological Measures to, Adapted Material that restrict exercise of the rights granted under the Adapter&#39;s License You apply.
Section 4 – Sui Generis Database Rights.
Where the Licensed Rights include Sui Generis Database Rights that apply to Your use of the Licensed Material:
   a. for the avoidance of doubt, Section 2(a)(1) grants You the right to extract, reuse, reproduce, and Share all or a substantial portion of the contents of the database;
   b. if You include all or a substantial portion of the database contents in a database in which You have Sui Generis Database Rights, then the database in which You have Sui Generis Database Rights (but not its individual contents) is Adapted Material, including for purposes of Section 3(b); and
   c. You must comply with the conditions in Section 3(a) if You Share all or a substantial portion of the contents of the database.
   For the avoidance of doubt, this Section 4 supplements and does not replace Your obligations under this Public License where the Licensed Rights include other Copyright and Similar Rights.
Section 5 – Disclaimer of Warranties and Limitation of Liability.
   a. Unless otherwise separately undertaken by the Licensor, to the extent possible, the Licensor offers the Licensed Material as-is and as-available, and makes no representations or warranties of any kind concerning the Licensed Material, whether express, implied, statutory, or other. This includes, without limitation, warranties of title, merchantability, fitness for a particular purpose, non-infringement, absence of latent or other defects, accuracy, or the presence or absence of errors, whether or not known or discoverable. Where disclaimers of warranties are not allowed in full or in part, this disclaimer may not apply to You.
   b. To the extent possible, in no event will the Licensor be liable to You on any legal theory (including, without limitation, negligence) or otherwise for any direct, special, indirect, incidental, consequential, punitive, exemplary, or other losses, costs, expenses, or damages arising out of this Public License or use of the Licensed Material, even if the Licensor has been advised of the possibility of such losses, costs, expenses, or damages. Where a limitation of liability is not allowed in full or in part, this limitation may not apply to You.
   c. The disclaimer of warranties and limitation of liability provided above shall be interpreted in a manner that, to the extent possible, most closely approximates an absolute disclaimer and waiver of all liability.
Section 6 – Term and Termination.
   a. This Public License applies for the term of the Copyright and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.
   b. Where Your right to use the Licensed Material has terminated under Section 6(a), it reinstates:
      1. automatically as of the date the violation is cured, provided it is cured within 30 days of Your discovery of the violation; or
      2. upon express reinstatement by the Licensor.
   c. For the avoidance of doubt, this Section 6(b) does not affect any right the Licensor may have to seek remedies for Your violations of this Public License.
   d. For the avoidance of doubt, the Licensor may also offer the Licensed Material under separate terms or conditions or stop distributing the Licensed Material at any time; however, doing so will not terminate this Public License.
   e. Sections 1, 5, 6, 7, and 8 survive termination of this Public License.
Section 7 – Other Terms and Conditions.
   a. The Licensor shall not be bound by any additional or different terms or conditions communicated by You unless expressly agreed.
   b. Any arrangements, understandings, or agreements regarding the Licensed Material not stated herein are separate from and independent of the terms and conditions of this Public License.
Section 8 – Interpretation.
   a. For the avoidance of doubt, this Public License does not, and shall not be interpreted to, reduce, limit, restrict, or impose conditions on any use of the Licensed Material that could lawfully be made without permission under this Public License.
   b. To the extent possible, if any provision of this Public License is deemed unenforceable, it shall be automatically reformed to the minimum extent necessary to make it enforceable. If the provision cannot be reformed, it shall be severed from this Public License without affecting the enforceability of the remaining terms and conditions.
   c. No term or condition of this Public License will be waived and no failure to comply consented to unless expressly agreed to by the Licensor.
   d. Nothing in this Public License constitutes or may be interpreted as a limitation upon, or waiver of, any privileges and immunities that apply to the Licensor or You, including from the legal processes of any jurisdiction or authority.
Creative Commons is not a party to its public licenses. Notwithstanding, Creative Commons may elect to apply one of its public licenses to material it publishes and in those instances will be considered the &quot;Licensor.&quot; The text of the Creative Commons public licenses is dedicated to the public domain under the CC0 Public Domain Dedication. Except for the limited purpose of indicating that material is shared under a Creative Commons public license or as otherwise permitted by the Creative Commons policies published at creativecommons.org/policies, Creative Commons does not authorize the use of the trademark &quot;Creative Commons&quot; or any other trademark or logo of Creative Commons without its prior written consent including, without limitation, in connection with any unauthorized modifications to any of its public licenses or any other arrangements, understandings, or agreements concerning use of licensed material. For the avoidance of doubt, this paragraph does not form part of the public licenses.
Creative Commons may be contacted at creativecommons.org.
```


### Creative Commons Zero v1.0 Universal

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Creative Commons Legal Code
CC0 1.0 Universal CREATIVE COMMONS CORPORATION IS NOT A LAW FIRM AND DOES NOT PROVIDE LEGAL SERVICES. DISTRIBUTION OF THIS DOCUMENT DOES NOT CREATE AN ATTORNEY-CLIENT RELATIONSHIP. CREATIVE COMMONS PROVIDES THIS INFORMATION ON AN &quot;AS-IS&quot; BASIS. CREATIVE COMMONS MAKES NO WARRANTIES REGARDING THE USE OF THIS DOCUMENT OR THE INFORMATION OR WORKS PROVIDED HEREUNDER, AND DISCLAIMS LIABILITY FOR DAMAGES RESULTING FROM THE USE OF THIS DOCUMENT OR THE INFORMATION OR WORKS PROVIDED HEREUNDER.
Statement of Purpose
The laws of most jurisdictions throughout the world automatically confer exclusive Copyright and Related Rights (defined below) upon the creator and subsequent owner(s) (each and all, an &quot;owner&quot;) of an original work of authorship and/or a database (each, a &quot;Work&quot;).
Certain owners wish to permanently relinquish those rights to a Work for the purpose of contributing to a commons of creative, cultural and scientific works (&quot;Commons&quot;) that the public can reliably and without fear of later claims of infringement build upon, modify, incorporate in other works, reuse and redistribute as freely as possible in any form whatsoever and for any purposes, including without limitation commercial purposes. These owners may contribute to the Commons to promote the ideal of a free culture and the further production of creative, cultural and scientific works, or to gain reputation or greater distribution for their Work in part through the use and efforts of others.
For these and/or other purposes and motivations, and without any expectation of additional consideration or compensation, the person associating CC0 with a Work (the &quot;Affirmer&quot;), to the extent that he or she is an owner of Copyright and Related Rights in the Work, voluntarily elects to apply CC0 to the Work and publicly distribute the Work under its terms, with knowledge of his or her Copyright and Related Rights in the Work and the meaning and intended legal effect of CC0 on those rights.
   1. Copyright and Related Rights. A Work made available under CC0 may be protected by copyright and related or neighboring rights (&quot;Copyright and Related Rights&quot;). Copyright and Related Rights include, but are not limited to, the following:
      i. the right to reproduce, adapt, distribute, perform, display, communicate, and translate a Work;
      ii. moral rights retained by the original author(s) and/or performer(s);
      iii. publicity and privacy rights pertaining to a person&#39;s image or likeness depicted in a Work;
      iv. rights protecting against unfair competition in regards to a Work, subject to the limitations in paragraph 4(a), below;
      v. rights protecting the extraction, dissemination, use and reuse of data in a Work;
      vi. database rights (such as those arising under Directive 96/9/EC of the European Parliament and of the Council of 11 March 1996 on the legal protection of databases, and under any national implementation thereof, including any amended or successor version of such directive); and
      vii. other similar, equivalent or corresponding rights throughout the world based on applicable law or treaty, and any national implementations thereof.
   2. Waiver. To the greatest extent permitted by, but not in contravention of, applicable law, Affirmer hereby overtly, fully, permanently, irrevocably and unconditionally waives, abandons, and surrenders all of Affirmer&#39;s Copyright and Related Rights and associated claims and causes of action, whether now known or unknown (including existing as well as future claims and causes of action), in the Work (i) in all territories worldwide, (ii) for the maximum duration provided by applicable law or treaty (including future time extensions), (iii) in any current or future medium and for any number of copies, and (iv) for any purpose whatsoever, including without limitation commercial, advertising or promotional purposes (the &quot;Waiver&quot;). Affirmer makes the Waiver for the benefit of each member of the public at large and to the detriment of Affirmer&#39;s heirs and successors, fully intending that such Waiver shall not be subject to revocation, rescission, cancellation, termination, or any other legal or equitable action to disrupt the quiet enjoyment of the Work by the public as contemplated by Affirmer&#39;s express Statement of Purpose.
   3. Public License Fallback. Should any part of the Waiver for any reason be judged legally invalid or ineffective under applicable law, then the Waiver shall be preserved to the maximum extent permitted taking into account Affirmer&#39;s express Statement of Purpose. In addition, to the extent the Waiver is so judged Affirmer hereby grants to each affected person a royalty-free, non transferable, non sublicensable, non exclusive, irrevocable and unconditional license to exercise Affirmer&#39;s Copyright and Related Rights in the Work (i) in all territories worldwide, (ii) for the maximum duration provided by applicable law or treaty (including future time extensions), (iii) in any current or future medium and for any number of copies, and (iv) for any purpose whatsoever, including without limitation commercial, advertising or promotional purposes (the &quot;License&quot;). The License shall be deemed effective as of the date CC0 was applied by Affirmer to the Work. Should any part of the License for any reason be judged legally invalid or ineffective under applicable law, such partial invalidity or ineffectiveness shall not invalidate the remainder of the License, and in such case Affirmer hereby affirms that he or she will not (i) exercise any of his or her remaining Copyright and Related Rights in the Work or (ii) assert any associated claims and causes of action with respect to the Work, in either case contrary to Affirmer&#39;s express Statement of Purpose.
   4. Limitations and Disclaimers.
      a. No trademark or patent rights held by Affirmer are waived, abandoned, surrendered, licensed or otherwise affected by this document.
      b. Affirmer offers the Work as-is and makes no representations or warranties of any kind concerning the Work, express, implied, statutory or otherwise, including without limitation warranties of title, merchantability, fitness for a particular purpose, non infringement, or the absence of latent or other defects, accuracy, or the present or absence of errors, whether or not discoverable, all to the greatest extent permissible under applicable law.
      c. Affirmer disclaims responsibility for clearing rights of other persons that may apply to the Work or any use thereof, including without limitation any person&#39;s Copyright and Related Rights in the Work. Further, Affirmer disclaims responsibility for obtaining any necessary consents, permissions or other rights required for any use of the Work.
      d. Affirmer understands and acknowledges that Creative Commons is not a party to this document and has no duty or obligation with respect to this CC0 or use of the Work.
```


### CNRI Python License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
CNRI OPEN SOURCE LICENSE AGREEMENT
IMPORTANT: PLEASE READ THE FOLLOWING AGREEMENT CAREFULLY.
BY CLICKING ON &quot;ACCEPT&quot; WHERE INDICATED BELOW, OR BY COPYING, INSTALLING OR OTHERWISE USING PYTHON 1.6, beta 1 SOFTWARE, YOU ARE DEEMED TO HAVE AGREED TO THE TERMS AND CONDITIONS OF THIS LICENSE AGREEMENT.
   1. This LICENSE AGREEMENT is between the Corporation for National Research Initiatives, having an office at 1895 Preston White Drive, Reston, VA 20191 (&quot;CNRI&quot;), and the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using Python 1.6, beta 1 software in source or binary form and its associated documentation, as released at the www.python.org Internet site on August 4, 2000 (&quot;Python 1.6b1&quot;).
   2. Subject to the terms and conditions of this License Agreement, CNRI hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python 1.6b1 alone or in any derivative version, provided, however, that CNRIs License Agreement is retained in Python 1.6b1, alone or in any derivative version prepared by Licensee.
   Alternately, in lieu of CNRIs License Agreement, Licensee may substitute the following text (omitting the quotes): &quot;Python 1.6, beta 1, is made available subject to the terms and conditions in CNRIs License Agreement. This Agreement may be located on the Internet using the following unique, persistent identifier (known as a handle): 1895.22/1011. This Agreement may also be obtained from a proxy server on the Internet using the URL:http://hdl.handle.net/1895.22/1011&quot;.
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python 1.6b1 or any part thereof, and wants to make the derivative work available to the public as provided herein, then Licensee hereby agrees to indicate in any such work the nature of the modifications made to Python 1.6b1.
   4. CNRI is making Python 1.6b1 available to Licensee on an &quot;AS IS&quot; basis. CNRI MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, CNRI MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON 1.6b1 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. CNRI SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING PYTHON 1.6b1, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. This License Agreement shall be governed by and interpreted in all respects by the law of the State of Virginia, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between CNRI and Licensee. This License Agreement does not grant permission to use CNRI trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By clicking on the &quot;ACCEPT&quot; button where indicated, or by copying, installing or otherwise using Python 1.6b1, Licensee agrees to be bound by the terms and conditions of this License Agreement.
ACCEPT
```


### GNU General Public License v1.0 only

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
GNU GENERAL PUBLIC LICENSE
Version 1, February 1989
Copyright (C) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The license agreements of most software companies try to keep users at the mercy of those companies. By contrast, our General Public License is intended to guarantee your freedom to share and change free software--to make sure the software is free for all its users. The General Public License applies to the Free Software Foundation&#39;s software and to any other program whose authors commit to using it. You can use it for your programs, too.
When we speak of free software, we are referring to freedom, not price. Specifically, the General Public License is designed to make sure that you have the freedom to give away or sell copies of free software, that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs; and that you know you can do these things.
To protect your rights, we need to make restrictions that forbid anyone to deny you these rights or to ask you to surrender the rights. These restrictions translate to certain responsibilities for you if you distribute copies of the software, or if you modify it.
For example, if you distribute copies of a such a program, whether gratis or for a fee, you must give the recipients all the rights that you have. You must make sure that they, too, receive or can get the source code. And you must tell them their rights.
We protect your rights with two steps: (1) copyright the software, and (2) offer you this license which gives you legal permission to copy, distribute and/or modify the software.
Also, for each author&#39;s protection and ours, we want to make certain that everyone understands that there is no warranty for this free software. If the software is modified by someone else and passed on, we want its recipients to know that what they have is not the original, so that any problems introduced by others will not reflect on the original authors&#39; reputations.
The precise terms and conditions for copying, distribution and modification follow.
GNU GENERAL PUBLIC LICENSE TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
   
   0. This License Agreement applies to any program or other work which contains a notice placed by the copyright holder saying it may be distributed under the terms of this General Public License. The &quot;Program&quot;, below, refers to any such program or work, and a &quot;work based on the Program&quot; means either the Program or any work containing the Program or a portion of it, either verbatim or with modifications. Each licensee is addressed as &quot;you&quot;.
   
   1. You may copy and distribute verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice and disclaimer of warranty; keep intact all the notices that refer to this General Public License and to the absence of any warranty; and give any other recipients of the Program a copy of this General Public License along with the Program. You may charge a fee for the physical act of transferring a copy.
   
   2. You may modify your copy or copies of the Program or any portion of it, and copy and distribute such modifications under the terms of Paragraph 1 above, provided that you also do the following:
      a) cause the modified files to carry prominent notices stating that you changed the files and the date of any change; and
      b) cause the whole of any work that you distribute or publish, that in whole or in part contains the Program or any part thereof, either with or without modifications, to be licensed at no charge to all third parties under the terms of this General Public License (except that you may choose to grant warranty protection to some or all third parties, at your option).
      c) If the modified program normally reads commands interactively when run, you must cause it, when started running for such interactive use in the simplest and most usual way, to print or display an announcement including an appropriate copyright notice and a notice that there is no warranty (or else, saying that you provide a warranty) and that users may redistribute the program under these conditions, and telling the user how to view a copy of this General Public License.
      d) You may charge a fee for the physical act of transferring a copy, and you may at your option offer warranty protection in exchange for a fee.
   Mere aggregation of another independent work with the Program (or its derivative) on a volume of a storage or distribution medium does not bring the other work under the scope of these terms.
   
   3. You may copy and distribute the Program (or a portion or derivative of it, under Paragraph 2) in object code or executable form under the terms of Paragraphs 1 and 2 above provided that you also do one of the following:
      a) accompany it with the complete corresponding machine-readable source code, which must be distributed under the terms of Paragraphs 1 and 2 above; or,
      b) accompany it with a written offer, valid for at least three years, to give any third party free (except for a nominal charge for the cost of distribution) a complete machine-readable copy of the corresponding source code, to be distributed under the terms of Paragraphs 1 and 2 above; or,
      c) accompany it with the information you received as to where the corresponding source code may be obtained. (This alternative is allowed only for noncommercial distribution and only if you received the program in object code or executable form alone.)
   Source code for a work means the preferred form of the work for making modifications to it. For an executable file, complete source code means all the source code for all modules it contains; but, as a special exception, it need not include source code for modules which are standard libraries that accompany the operating system on which the executable file runs, or for standard header files or definitions files that accompany that operating system.
   
   4. You may not copy, modify, sublicense, distribute or transfer the Program except as expressly provided under this General Public License. Any attempt otherwise to copy, modify, sublicense, distribute or transfer the Program is void, and will automatically terminate your rights to use the Program under this License. However, parties who have received copies, or rights to use copies, from you under this General Public License will not have their licenses terminated so long as such parties remain in full compliance.
   
   5. By copying, distributing or modifying the Program (or any work based on the Program) you indicate your acceptance of this license to do so, and all its terms and conditions.
   
   6. Each time you redistribute the Program (or any work based on the Program), the recipient automatically receives a license from the original licensor to copy, distribute or modify the Program subject to these terms and conditions. You may not impose any further restrictions on the recipients&#39; exercise of the rights granted herein.
   
   7. The Free Software Foundation may publish revised and/or new versions of the General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies a version number of the license which applies to it and &quot;any later version&quot;, you have the option of following the terms and conditions either of that version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of the license, you may choose any version ever published by the Free Software Foundation.
   
   8. If you wish to incorporate parts of the Program into other free programs whose distribution conditions are different, write to the author to ask for permission. For software which is copyrighted by the Free Software Foundation, write to the Free Software Foundation; we sometimes make exceptions for this. Our decision will be guided by the two goals of preserving the free status of all derivatives of our free software and of promoting the sharing and reuse of software generally.
   
   NO WARRANTY
   9. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   
   10. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. END OF TERMS AND CONDITIONS
Appendix: How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to humanity, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively convey the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt;one line to give the program&#39;s name and a brief idea of what it does.&gt; Copyright (C) 19yy &lt;name of author&gt;
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 1, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
Also add information on how to contact you by electronic and paper mail.
If the program is interactive, make it output a short notice like this when it starts in an interactive mode:
Gnomovision version 69, Copyright (C) 19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, the commands you use may be called something other than `show w&#39; and `show c&#39;; they could even be mouse-clicks or menu items--whatever suits your program.
You should also get your employer (if you work as a programmer) or your school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. Here a sample; alter the names:
Yoyodyne, Inc., hereby disclaims all copyright interest in the program `Gnomovision&#39; (a program to direct compilers to make passes at assemblers) written by James Hacker.
&lt;signature of Ty Coon&gt;, 1 April 1989 Ty Coon, President of Vice
That&#39;s all there is to it!
```


### GNU General Public License v1.0 or later

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) or

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
GNU GENERAL PUBLIC LICENSE
Version 1, February 1989
Copyright (C) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The license agreements of most software companies try to keep users at the mercy of those companies. By contrast, our General Public License is intended to guarantee your freedom to share and change free software--to make sure the software is free for all its users. The General Public License applies to the Free Software Foundation&#39;s software and to any other program whose authors commit to using it. You can use it for your programs, too.
When we speak of free software, we are referring to freedom, not price. Specifically, the General Public License is designed to make sure that you have the freedom to give away or sell copies of free software, that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs; and that you know you can do these things.
To protect your rights, we need to make restrictions that forbid anyone to deny you these rights or to ask you to surrender the rights. These restrictions translate to certain responsibilities for you if you distribute copies of the software, or if you modify it.
For example, if you distribute copies of a such a program, whether gratis or for a fee, you must give the recipients all the rights that you have. You must make sure that they, too, receive or can get the source code. And you must tell them their rights.
We protect your rights with two steps: (1) copyright the software, and (2) offer you this license which gives you legal permission to copy, distribute and/or modify the software.
Also, for each author&#39;s protection and ours, we want to make certain that everyone understands that there is no warranty for this free software. If the software is modified by someone else and passed on, we want its recipients to know that what they have is not the original, so that any problems introduced by others will not reflect on the original authors&#39; reputations.
The precise terms and conditions for copying, distribution and modification follow.
GNU GENERAL PUBLIC LICENSE TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
   0. This License Agreement applies to any program or other work which contains a notice placed by the copyright holder saying it may be distributed under the terms of this General Public License. The &quot;Program&quot;, below, refers to any such program or work, and a &quot;work based on the Program&quot; means either the Program or any work containing the Program or a portion of it, either verbatim or with modifications. Each licensee is addressed as &quot;you&quot;.
   1. You may copy and distribute verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice and disclaimer of warranty; keep intact all the notices that refer to this General Public License and to the absence of any warranty; and give any other recipients of the Program a copy of this General Public License along with the Program. You may charge a fee for the physical act of transferring a copy.
   2. You may modify your copy or copies of the Program or any portion of it, and copy and distribute such modifications under the terms of Paragraph 1 above, provided that you also do the following:
      a) cause the modified files to carry prominent notices stating that you changed the files and the date of any change; and
      b) cause the whole of any work that you distribute or publish, that in whole or in part contains the Program or any part thereof, either with or without modifications, to be licensed at no charge to all third parties under the terms of this General Public License (except that you may choose to grant warranty protection to some or all third parties, at your option).
      c) If the modified program normally reads commands interactively when run, you must cause it, when started running for such interactive use in the simplest and most usual way, to print or display an announcement including an appropriate copyright notice and a notice that there is no warranty (or else, saying that you provide a warranty) and that users may redistribute the program under these conditions, and telling the user how to view a copy of this General Public License.
      d) You may charge a fee for the physical act of transferring a copy, and you may at your option offer warranty protection in exchange for a fee.
   Mere aggregation of another independent work with the Program (or its derivative) on a volume of a storage or distribution medium does not bring the other work under the scope of these terms.
   3. You may copy and distribute the Program (or a portion or derivative of it, under Paragraph 2) in object code or executable form under the terms of Paragraphs 1 and 2 above provided that you also do one of the following:
      a) accompany it with the complete corresponding machine-readable source code, which must be distributed under the terms of Paragraphs 1 and 2 above; or,
      b) accompany it with a written offer, valid for at least three years, to give any third party free (except for a nominal charge for the cost of distribution) a complete machine-readable copy of the corresponding source code, to be distributed under the terms of Paragraphs 1 and 2 above; or,
      c) accompany it with the information you received as to where the corresponding source code may be obtained. (This alternative is allowed only for noncommercial distribution and only if you received the program in object code or executable form alone.)
   Source code for a work means the preferred form of the work for making modifications to it. For an executable file, complete source code means all the source code for all modules it contains; but, as a special exception, it need not include source code for modules which are standard libraries that accompany the operating system on which the executable file runs, or for standard header files or definitions files that accompany that operating system.
   4. You may not copy, modify, sublicense, distribute or transfer the Program except as expressly provided under this General Public License. Any attempt otherwise to copy, modify, sublicense, distribute or transfer the Program is void, and will automatically terminate your rights to use the Program under this License. However, parties who have received copies, or rights to use copies, from you under this General Public License will not have their licenses terminated so long as such parties remain in full compliance.
   5. By copying, distributing or modifying the Program (or any work based on the Program) you indicate your acceptance of this license to do so, and all its terms and conditions.
   6. Each time you redistribute the Program (or any work based on the Program), the recipient automatically receives a license from the original licensor to copy, distribute or modify the Program subject to these terms and conditions. You may not impose any further restrictions on the recipients&#39; exercise of the rights granted herein.
   7. The Free Software Foundation may publish revised and/or new versions of the General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies a version number of the license which applies to it and &quot;any later version&quot;, you have the option of following the terms and conditions either of that version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of the license, you may choose any version ever published by the Free Software Foundation.
   8. If you wish to incorporate parts of the Program into other free programs whose distribution conditions are different, write to the author to ask for permission. For software which is copyrighted by the Free Software Foundation, write to the Free Software Foundation; we sometimes make exceptions for this. Our decision will be guided by the two goals of preserving the free status of all derivatives of our free software and of promoting the sharing and reuse of software generally.
   
   NO WARRANTY 9.
   BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   10. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. END OF TERMS AND CONDITIONS
Appendix: How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to humanity, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively convey the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt;one line to give the program&#39;s name and a brief idea of what it does.&gt; Copyright (C) 19yy &lt;name of author&gt;
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 1, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
Also add information on how to contact you by electronic and paper mail.
If the program is interactive, make it output a short notice like this when it starts in an interactive mode:
Gnomovision version 69, Copyright (C) 19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, the commands you use may be called something other than `show w&#39; and `show c&#39;; they could even be mouse-clicks or menu items--whatever suits your program.
You should also get your employer (if you work as a programmer) or your school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. Here a sample; alter the names:
Yoyodyne, Inc., hereby disclaims all copyright interest in the program `Gnomovision&#39; (a program to direct compilers to make passes at assemblers) written by James Hacker.
&lt;signature of Ty Coon&gt;, 1 April 1989 Ty Coon, President of Vice
That&#39;s all there is to it!
```


### GNU General Public License v2.0 only

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
GNU GENERAL PUBLIC LICENSE
Version 2, June 1991
Copyright (C) 1989, 1991 Free Software Foundation, Inc.
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 , USA
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The licenses for most software are designed to take away your freedom to share and change it. By contrast, the GNU General Public License is intended to guarantee your freedom to share and change free software--to make sure the software is free for all its users. This General Public License applies to most of the Free Software Foundation&#39;s software and to any other program whose authors commit to using it. (Some other Free Software Foundation software is covered by the GNU Lesser General Public License instead.) You can apply it to your programs, too.
When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for this service if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs; and that you know you can do these things.
To protect your rights, we need to make restrictions that forbid anyone to deny you these rights or to ask you to surrender the rights. These restrictions translate to certain responsibilities for you if you distribute copies of the software, or if you modify it.
For example, if you distribute copies of such a program, whether gratis or for a fee, you must give the recipients all the rights that you have. You must make sure that they, too, receive or can get the source code. And you must show them these terms so they know their rights.
We protect your rights with two steps: (1) copyright the software, and (2) offer you this license which gives you legal permission to copy, distribute and/or modify the software.
Also, for each author&#39;s protection and ours, we want to make certain that everyone understands that there is no warranty for this free software. If the software is modified by someone else and passed on, we want its recipients to know that what they have is not the original, so that any problems introduced by others will not reflect on the original authors&#39; reputations.
Finally, any free program is threatened constantly by software patents. We wish to avoid the danger that redistributors of a free program will individually obtain patent licenses, in effect making the program proprietary. To prevent this, we have made it clear that any patent must be licensed for everyone&#39;s free use or not licensed at all.
The precise terms and conditions for copying, distribution and modification follow.
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
   0. This License applies to any program or other work which contains a notice placed by the copyright holder saying it may be distributed under the terms of this General Public License. The &quot;Program&quot;, below, refers to any such program or work, and a &quot;work based on the Program&quot; means either the Program or any derivative work under copyright law: that is to say, a work containing the Program or a portion of it, either verbatim or with modifications and/or translated into another language. (Hereinafter, translation is included without limitation in the term &quot;modification&quot;.) Each licensee is addressed as &quot;you&quot;.
   Activities other than copying, distribution and modification are not covered by this License; they are outside its scope. The act of running the Program is not restricted, and the output from the Program is covered only if its contents constitute a work based on the Program (independent of having been made by running the Program). Whether that is true depends on what the Program does.
   1. You may copy and distribute verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice and disclaimer of warranty; keep intact all the notices that refer to this License and to the absence of any warranty; and give any other recipients of the Program a copy of this License along with the Program.
   You may charge a fee for the physical act of transferring a copy, and you may at your option offer warranty protection in exchange for a fee.
   2. You may modify your copy or copies of the Program or any portion of it, thus forming a work based on the Program, and copy and distribute such modifications or work under the terms of Section 1 above, provided that you also meet all of these conditions:
      a) You must cause the modified files to carry prominent notices stating that you changed the files and the date of any change.
      b) You must cause any work that you distribute or publish, that in whole or in part contains or is derived from the Program or any part thereof, to be licensed as a whole at no charge to all third parties under the terms of this License.
      c) If the modified program normally reads commands interactively when run, you must cause it, when started running for such interactive use in the most ordinary way, to print or display an announcement including an appropriate copyright notice and a notice that there is no warranty (or else, saying that you provide a warranty) and that users may redistribute the program under these conditions, and telling the user how to view a copy of this License. (Exception: if the Program itself is interactive but does not normally print such an announcement, your work based on the Program is not required to print an announcement.)
   These requirements apply to the modified work as a whole. If identifiable sections of that work are not derived from the Program, and can be reasonably considered independent and separate works in themselves, then this License, and its terms, do not apply to those sections when you distribute them as separate works. But when you distribute the same sections as part of a whole which is a work based on the Program, the distribution of the whole must be on the terms of this License, whose permissions for other licensees extend to the entire whole, and thus to each and every part regardless of who wrote it.
   Thus, it is not the intent of this section to claim rights or contest your rights to work written entirely by you; rather, the intent is to exercise the right to control the distribution of derivative or collective works based on the Program.
   In addition, mere aggregation of another work not based on the Program with the Program (or with a work based on the Program) on a volume of a storage or distribution medium does not bring the other work under the scope of this License.
   3. You may copy and distribute the Program (or a work based on it, under Section 2) in object code or executable form under the terms of Sections 1 and 2 above provided that you also do one of the following:
      a) Accompany it with the complete corresponding machine-readable source code, which must be distributed under the terms of Sections 1 and 2 above on a medium customarily used for software interchange; or,
      b) Accompany it with a written offer, valid for at least three years, to give any third party, for a charge no more than your cost of physically performing source distribution, a complete machine-readable copy of the corresponding source code, to be distributed under the terms of Sections 1 and 2 above on a medium customarily used for software interchange; or,
      c) Accompany it with the information you received as to the offer to distribute corresponding source code. (This alternative is allowed only for noncommercial distribution and only if you received the program in object code or executable form with such an offer, in accord with Subsection b above.)
   The source code for a work means the preferred form of the work for making modifications to it. For an executable work, complete source code means all the source code for all modules it contains, plus any associated interface definition files, plus the scripts used to control compilation and installation of the executable. However, as a special exception, the source code distributed need not include anything that is normally distributed (in either source or binary form) with the major components (compiler, kernel, and so on) of the operating system on which the executable runs, unless that component itself accompanies the executable.
   If distribution of executable or object code is made by offering access to copy from a designated place, then offering equivalent access to copy the source code from the same place counts as distribution of the source code, even though third parties are not compelled to copy the source along with the object code.
   4. You may not copy, modify, sublicense, or distribute the Program except as expressly provided under this License. Any attempt otherwise to copy, modify, sublicense or distribute the Program is void, and will automatically terminate your rights under this License. However, parties who have received copies, or rights, from you under this License will not have their licenses terminated so long as such parties remain in full compliance.
   5. You are not required to accept this License, since you have not signed it. However, nothing else grants you permission to modify or distribute the Program or its derivative works. These actions are prohibited by law if you do not accept this License. Therefore, by modifying or distributing the Program (or any work based on the Program), you indicate your acceptance of this License to do so, and all its terms and conditions for copying, distributing or modifying the Program or works based on it.
   6. Each time you redistribute the Program (or any work based on the Program), the recipient automatically receives a license from the original licensor to copy, distribute or modify the Program subject to these terms and conditions. You may not impose any further restrictions on the recipients&#39; exercise of the rights granted herein. You are not responsible for enforcing compliance by third parties to this License.
   7. If, as a consequence of a court judgment or allegation of patent infringement or for any other reason (not limited to patent issues), conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot distribute so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may not distribute the Program at all. For example, if a patent license would not permit royalty-free redistribution of the Program by all those who receive copies directly or indirectly through you, then the only way you could satisfy both it and this License would be to refrain entirely from distribution of the Program.
   If any portion of this section is held invalid or unenforceable under any particular circumstance, the balance of the section is intended to apply and the section as a whole is intended to apply in other circumstances.
   It is not the purpose of this section to induce you to infringe any patents or other property right claims or to contest validity of any such claims; this section has the sole purpose of protecting the integrity of the free software distribution system, which is implemented by public license practices. Many people have made generous contributions to the wide range of software distributed through that system in reliance on consistent application of that system; it is up to the author/donor to decide if he or she is willing to distribute software through any other system and a licensee cannot impose that choice.
   This section is intended to make thoroughly clear what is believed to be a consequence of the rest of this License.
   8. If the distribution and/or use of the Program is restricted in certain countries either by patents or by copyrighted interfaces, the original copyright holder who places the Program under this License may add an explicit geographical distribution limitation excluding those countries, so that distribution is permitted only in or among countries not thus excluded. In such case, this License incorporates the limitation as if written in the body of this License.
   9. The Free Software Foundation may publish revised and/or new versions of the General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies a version number of this License which applies to it and &quot;any later version&quot;, you have the option of following the terms and conditions either of that version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of this License, you may choose any version ever published by the Free Software Foundation.
   10. If you wish to incorporate parts of the Program into other free programs whose distribution conditions are different, write to the author to ask for permission. For software which is copyrighted by the Free Software Foundation, write to the Free Software Foundation; we sometimes make exceptions for this. Our decision will be guided by the two goals of preserving the free status of all derivatives of our free software and of promoting the sharing and reuse of software generally.
   NO WARRANTY
   11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. END OF TERMS AND CONDITIONS
How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively convey the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt; one line to give the program&#39;s name and an idea of what it does. &gt;
Copyright (C) &lt; yyyy &gt; &lt; name of author &gt;
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 , USA. Also add information on how to contact you by electronic and paper mail.
If the program is interactive, make it output a short notice like this when it starts in an interactive mode:
Gnomovision version 69, Copyright (C) year name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, the commands you use may be called something other than `show w&#39; and `show c&#39;; they could even be mouse-clicks or menu items--whatever suits your program.
You should also get your employer (if you work as a programmer) or your school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. Here is a sample; alter the names:
Yoyodyne, Inc., hereby disclaims all copyright interest in the program `Gnomovision&#39; (which makes passes at compilers) written by James Hacker.
&lt; signature of Ty Coon &gt; , 1 April 1989 Ty Coon, President of Vice
```


### GNU General Public License v2.0 or later

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006

Copyright (c) or

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
GNU GENERAL PUBLIC LICENSE
Version 2, June 1991
Copyright (C) 1989, 1991 Free Software Foundation, Inc.
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 , USA
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The licenses for most software are designed to take away your freedom to share and change it. By contrast, the GNU General Public License is intended to guarantee your freedom to share and change free software--to make sure the software is free for all its users. This General Public License applies to most of the Free Software Foundation&#39;s software and to any other program whose authors commit to using it. (Some other Free Software Foundation software is covered by the GNU Lesser General Public License instead.) You can apply it to your programs, too.
When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for this service if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs; and that you know you can do these things.
To protect your rights, we need to make restrictions that forbid anyone to deny you these rights or to ask you to surrender the rights. These restrictions translate to certain responsibilities for you if you distribute copies of the software, or if you modify it.
For example, if you distribute copies of such a program, whether gratis or for a fee, you must give the recipients all the rights that you have. You must make sure that they, too, receive or can get the source code. And you must show them these terms so they know their rights.
We protect your rights with two steps: (1) copyright the software, and (2) offer you this license which gives you legal permission to copy, distribute and/or modify the software.
Also, for each author&#39;s protection and ours, we want to make certain that everyone understands that there is no warranty for this free software. If the software is modified by someone else and passed on, we want its recipients to know that what they have is not the original, so that any problems introduced by others will not reflect on the original authors&#39; reputations.
Finally, any free program is threatened constantly by software patents. We wish to avoid the danger that redistributors of a free program will individually obtain patent licenses, in effect making the program proprietary. To prevent this, we have made it clear that any patent must be licensed for everyone&#39;s free use or not licensed at all.
The precise terms and conditions for copying, distribution and modification follow.
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
   0. This License applies to any program or other work which contains a notice placed by the copyright holder saying it may be distributed under the terms of this General Public License. The &quot;Program&quot;, below, refers to any such program or work, and a &quot;work based on the Program&quot; means either the Program or any derivative work under copyright law: that is to say, a work containing the Program or a portion of it, either verbatim or with modifications and/or translated into another language. (Hereinafter, translation is included without limitation in the term &quot;modification&quot;.) Each licensee is addressed as &quot;you&quot;.
   Activities other than copying, distribution and modification are not covered by this License; they are outside its scope. The act of running the Program is not restricted, and the output from the Program is covered only if its contents constitute a work based on the Program (independent of having been made by running the Program). Whether that is true depends on what the Program does.
   1. You may copy and distribute verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice and disclaimer of warranty; keep intact all the notices that refer to this License and to the absence of any warranty; and give any other recipients of the Program a copy of this License along with the Program.
   You may charge a fee for the physical act of transferring a copy, and you may at your option offer warranty protection in exchange for a fee.
   2. You may modify your copy or copies of the Program or any portion of it, thus forming a work based on the Program, and copy and distribute such modifications or work under the terms of Section 1 above, provided that you also meet all of these conditions:
      a) You must cause the modified files to carry prominent notices stating that you changed the files and the date of any change.
      b) You must cause any work that you distribute or publish, that in whole or in part contains or is derived from the Program or any part thereof, to be licensed as a whole at no charge to all third parties under the terms of this License.
      c) If the modified program normally reads commands interactively when run, you must cause it, when started running for such interactive use in the most ordinary way, to print or display an announcement including an appropriate copyright notice and a notice that there is no warranty (or else, saying that you provide a warranty) and that users may redistribute the program under these conditions, and telling the user how to view a copy of this License. (Exception: if the Program itself is interactive but does not normally print such an announcement, your work based on the Program is not required to print an announcement.)
   These requirements apply to the modified work as a whole. If identifiable sections of that work are not derived from the Program, and can be reasonably considered independent and separate works in themselves, then this License, and its terms, do not apply to those sections when you distribute them as separate works. But when you distribute the same sections as part of a whole which is a work based on the Program, the distribution of the whole must be on the terms of this License, whose permissions for other licensees extend to the entire whole, and thus to each and every part regardless of who wrote it.
   Thus, it is not the intent of this section to claim rights or contest your rights to work written entirely by you; rather, the intent is to exercise the right to control the distribution of derivative or collective works based on the Program.
   In addition, mere aggregation of another work not based on the Program with the Program (or with a work based on the Program) on a volume of a storage or distribution medium does not bring the other work under the scope of this License.
   3. You may copy and distribute the Program (or a work based on it, under Section 2) in object code or executable form under the terms of Sections 1 and 2 above provided that you also do one of the following:
      a) Accompany it with the complete corresponding machine-readable source code, which must be distributed under the terms of Sections 1 and 2 above on a medium customarily used for software interchange; or,
      b) Accompany it with a written offer, valid for at least three years, to give any third party, for a charge no more than your cost of physically performing source distribution, a complete machine-readable copy of the corresponding source code, to be distributed under the terms of Sections 1 and 2 above on a medium customarily used for software interchange; or,
      c) Accompany it with the information you received as to the offer to distribute corresponding source code. (This alternative is allowed only for noncommercial distribution and only if you received the program in object code or executable form with such an offer, in accord with Subsection b above.)
   The source code for a work means the preferred form of the work for making modifications to it. For an executable work, complete source code means all the source code for all modules it contains, plus any associated interface definition files, plus the scripts used to control compilation and installation of the executable. However, as a special exception, the source code distributed need not include anything that is normally distributed (in either source or binary form) with the major components (compiler, kernel, and so on) of the operating system on which the executable runs, unless that component itself accompanies the executable.
   If distribution of executable or object code is made by offering access to copy from a designated place, then offering equivalent access to copy the source code from the same place counts as distribution of the source code, even though third parties are not compelled to copy the source along with the object code.
   4. You may not copy, modify, sublicense, or distribute the Program except as expressly provided under this License. Any attempt otherwise to copy, modify, sublicense or distribute the Program is void, and will automatically terminate your rights under this License. However, parties who have received copies, or rights, from you under this License will not have their licenses terminated so long as such parties remain in full compliance.
   5. You are not required to accept this License, since you have not signed it. However, nothing else grants you permission to modify or distribute the Program or its derivative works. These actions are prohibited by law if you do not accept this License. Therefore, by modifying or distributing the Program (or any work based on the Program), you indicate your acceptance of this License to do so, and all its terms and conditions for copying, distributing or modifying the Program or works based on it.
   6. Each time you redistribute the Program (or any work based on the Program), the recipient automatically receives a license from the original licensor to copy, distribute or modify the Program subject to these terms and conditions. You may not impose any further restrictions on the recipients&#39; exercise of the rights granted herein. You are not responsible for enforcing compliance by third parties to this License.
   7. If, as a consequence of a court judgment or allegation of patent infringement or for any other reason (not limited to patent issues), conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot distribute so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may not distribute the Program at all. For example, if a patent license would not permit royalty-free redistribution of the Program by all those who receive copies directly or indirectly through you, then the only way you could satisfy both it and this License would be to refrain entirely from distribution of the Program.
   If any portion of this section is held invalid or unenforceable under any particular circumstance, the balance of the section is intended to apply and the section as a whole is intended to apply in other circumstances.
   It is not the purpose of this section to induce you to infringe any patents or other property right claims or to contest validity of any such claims; this section has the sole purpose of protecting the integrity of the free software distribution system, which is implemented by public license practices. Many people have made generous contributions to the wide range of software distributed through that system in reliance on consistent application of that system; it is up to the author/donor to decide if he or she is willing to distribute software through any other system and a licensee cannot impose that choice.
   This section is intended to make thoroughly clear what is believed to be a consequence of the rest of this License.
   8. If the distribution and/or use of the Program is restricted in certain countries either by patents or by copyrighted interfaces, the original copyright holder who places the Program under this License may add an explicit geographical distribution limitation excluding those countries, so that distribution is permitted only in or among countries not thus excluded. In such case, this License incorporates the limitation as if written in the body of this License.
   9. The Free Software Foundation may publish revised and/or new versions of the General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies a version number of this License which applies to it and &quot;any later version&quot;, you have the option of following the terms and conditions either of that version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of this License, you may choose any version ever published by the Free Software Foundation.
   10. If you wish to incorporate parts of the Program into other free programs whose distribution conditions are different, write to the author to ask for permission. For software which is copyrighted by the Free Software Foundation, write to the Free Software Foundation; we sometimes make exceptions for this. Our decision will be guided by the two goals of preserving the free status of all derivatives of our free software and of promoting the sharing and reuse of software generally.
   NO WARRANTY
   11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. END OF TERMS AND CONDITIONS
How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively convey the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt; one line to give the program&#39;s name and an idea of what it does. &gt;
Copyright (C) &lt; yyyy &gt; &lt; name of author &gt;
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 , USA. Also add information on how to contact you by electronic and paper mail.
If the program is interactive, make it output a short notice like this when it starts in an interactive mode:
Gnomovision version 69, Copyright (C) year name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, the commands you use may be called something other than `show w&#39; and `show c&#39;; they could even be mouse-clicks or menu items--whatever suits your program.
You should also get your employer (if you work as a programmer) or your school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. Here is a sample; alter the names:
Yoyodyne, Inc., hereby disclaims all copyright interest in the program `Gnomovision&#39; (which makes passes at compilers) written by James Hacker.
&lt; signature of Ty Coon &gt; , 1 April 1989 Ty Coon, President of Vice
```


### GNU General Public License v2.0 w/Bison exception

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Bison Exception
As a special exception, you may create a larger work that contains part or all of the Bison parser skeleton and distribute that work under terms of your choice, so long as that work isn&#39;t itself a parser generator using the skeleton or a modified version thereof as a parser skeleton. Alternatively, if you modify or redistribute the parser skeleton itself, you may (at your option) remove this special exception, which will cause the skeleton and the resulting Bison output files to be licensed under the GNU General Public License without this special exception.
This special exception was added by the Free Software Foundation in version 2.2 of Bison.
```


### GNU General Public License v3.0 only

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
GNU GENERAL PUBLIC LICENSE
Version 3, 29 June 2007
Copyright © 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The GNU General Public License is a free, copyleft license for software and other kinds of works.
The licenses for most software and other practical works are designed to take away your freedom to share and change the works. By contrast, the GNU General Public License is intended to guarantee your freedom to share and change all versions of a program--to make sure it remains free software for all its users. We, the Free Software Foundation, use the GNU General Public License for most of our software; it applies also to any other work released this way by its authors. You can apply it to your programs, too.
When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for them if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs, and that you know you can do these things.
To protect your rights, we need to prevent others from denying you these rights or asking you to surrender the rights. Therefore, you have certain responsibilities if you distribute copies of the software, or if you modify it: responsibilities to respect the freedom of others.
For example, if you distribute copies of such a program, whether gratis or for a fee, you must pass on to the recipients the same freedoms that you received. You must make sure that they, too, receive or can get the source code. And you must show them these terms so they know their rights.
Developers that use the GNU GPL protect your rights with two steps: (1) assert copyright on the software, and (2) offer you this License giving you legal permission to copy, distribute and/or modify it.
For the developers&#39; and authors&#39; protection, the GPL clearly explains that there is no warranty for this free software. For both users&#39; and authors&#39; sake, the GPL requires that modified versions be marked as changed, so that their problems will not be attributed erroneously to authors of previous versions.
Some devices are designed to deny users access to install or run modified versions of the software inside them, although the manufacturer can do so. This is fundamentally incompatible with the aim of protecting users&#39; freedom to change the software. The systematic pattern of such abuse occurs in the area of products for individuals to use, which is precisely where it is most unacceptable. Therefore, we have designed this version of the GPL to prohibit the practice for those products. If such problems arise substantially in other domains, we stand ready to extend this provision to those domains in future versions of the GPL, as needed to protect the freedom of users.
Finally, every program is threatened constantly by software patents. States should not allow patents to restrict development and use of software on general-purpose computers, but in those that do, we wish to avoid the special danger that patents applied to a free program could make it effectively proprietary. To prevent this, the GPL assures that patents cannot be used to render the program non-free.
The precise terms and conditions for copying, distribution and modification follow.
TERMS AND CONDITIONS
   0. Definitions.
   &quot;This License&quot; refers to version 3 of the GNU General Public License.
   &quot;Copyright&quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.
   &quot;The Program&quot; refers to any copyrightable work licensed under this License. Each licensee is addressed as &quot;you&quot;. &quot;Licensees&quot; and &quot;recipients&quot; may be individuals or organizations.
   To &quot;modify&quot; a work means to copy from or adapt all or part of the work in a fashion requiring copyright permission, other than the making of an exact copy. The resulting work is called a &quot;modified version&quot; of the earlier work or a work &quot;based on&quot; the earlier work.
   A &quot;covered work&quot; means either the unmodified Program or a work based on the Program.
   To &quot;propagate&quot; a work means to do anything with it that, without permission, would make you directly or secondarily liable for infringement under applicable copyright law, except executing it on a computer or modifying a private copy. Propagation includes copying, distribution (with or without modification), making available to the public, and in some countries other activities as well.
   To &quot;convey&quot; a work means any kind of propagation that enables other parties to make or receive copies. Mere interaction with a user through a computer network, with no transfer of a copy, is not conveying.
   An interactive user interface displays &quot;Appropriate Legal Notices&quot; to the extent that it includes a convenient and prominently visible feature that (1) displays an appropriate copyright notice, and (2) tells the user that there is no warranty for the work (except to the extent that warranties are provided), that licensees may convey the work under this License, and how to view a copy of this License. If the interface presents a list of user commands or options, such as a menu, a prominent item in the list meets this criterion.
   1. Source Code.
   The &quot;source code&quot; for a work means the preferred form of the work for making modifications to it. &quot;Object code&quot; means any non-source form of a work.
   A &quot;Standard Interface&quot; means an interface that either is an official standard defined by a recognized standards body, or, in the case of interfaces specified for a particular programming language, one that is widely used among developers working in that language.
   The &quot;System Libraries&quot; of an executable work include anything, other than the work as a whole, that (a) is included in the normal form of packaging a Major Component, but which is not part of that Major Component, and (b) serves only to enable use of the work with that Major Component, or to implement a Standard Interface for which an implementation is available to the public in source code form. A &quot;Major Component&quot;, in this context, means a major essential component (kernel, window system, and so on) of the specific operating system (if any) on which the executable work runs, or a compiler used to produce the work, or an object code interpreter used to run it.
   The &quot;Corresponding Source&quot; for a work in object code form means all the source code needed to generate, install, and (for an executable work) run the object code and to modify the work, including scripts to control those activities. However, it does not include the work&#39;s System Libraries, or general-purpose tools or generally available free programs which are used unmodified in performing those activities but which are not part of the work. For example, Corresponding Source includes interface definition files associated with source files for the work, and the source code for shared libraries and dynamically linked subprograms that the work is specifically designed to require, such as by intimate data communication or control flow between those subprograms and other parts of the work.
   The Corresponding Source need not include anything that users can regenerate automatically from other parts of the Corresponding Source.
   The Corresponding Source for a work in source code form is that same work.
   2. Basic Permissions.
   All rights granted under this License are granted for the term of copyright on the Program, and are irrevocable provided the stated conditions are met. This License explicitly affirms your unlimited permission to run the unmodified Program. The output from running a covered work is covered by this License only if the output, given its content, constitutes a covered work. This License acknowledges your rights of fair use or other equivalent, as provided by copyright law.
   You may make, run and propagate covered works that you do not convey, without conditions so long as your license otherwise remains in force. You may convey covered works to others for the sole purpose of having them make modifications exclusively for you, or provide you with facilities for running those works, provided that you comply with the terms of this License in conveying all material for which you do not control copyright. Those thus making or running the covered works for you must do so exclusively on your behalf, under your direction and control, on terms that prohibit them from making any copies of your copyrighted material outside their relationship with you.
   Conveying under any other circumstances is permitted solely under the conditions stated below. Sublicensing is not allowed; section 10 makes it unnecessary.
   3. Protecting Users&#39; Legal Rights From Anti-Circumvention Law.
   No covered work shall be deemed part of an effective technological measure under any applicable law fulfilling obligations under article 11 of the WIPO copyright treaty adopted on 20 December 1996, or similar laws prohibiting or restricting circumvention of such measures.
   When you convey a covered work, you waive any legal power to forbid circumvention of technological measures to the extent such circumvention is effected by exercising rights under this License with respect to the covered work, and you disclaim any intention to limit operation or modification of the work as a means of enforcing, against the work&#39;s users, your or third parties&#39; legal rights to forbid circumvention of technological measures.
   4. Conveying Verbatim Copies.
   You may convey verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice; keep intact all notices stating that this License and any non-permissive terms added in accord with section 7 apply to the code; keep intact all notices of the absence of any warranty; and give all recipients a copy of this License along with the Program.
   You may charge any price or no price for each copy that you convey, and you may offer support or warranty protection for a fee.
   5. Conveying Modified Source Versions.
   You may convey a work based on the Program, or the modifications to produce it from the Program, in the form of source code under the terms of section 4, provided that you also meet all of these conditions:
      a) The work must carry prominent notices stating that you modified it, and giving a relevant date.
      b) The work must carry prominent notices stating that it is released under this License and any conditions added under section 7. This requirement modifies the requirement in section 4 to &quot;keep intact all notices&quot;.
      c) You must license the entire work, as a whole, under this License to anyone who comes into possession of a copy. This License will therefore apply, along with any applicable section 7 additional terms, to the whole of the work, and all its parts, regardless of how they are packaged. This License gives no permission to license the work in any other way, but it does not invalidate such permission if you have separately received it.
      d) If the work has interactive user interfaces, each must display Appropriate Legal Notices; however, if the Program has interactive interfaces that do not display Appropriate Legal Notices, your work need not make them do so.
   A compilation of a covered work with other separate and independent works, which are not by their nature extensions of the covered work, and which are not combined with it such as to form a larger program, in or on a volume of a storage or distribution medium, is called an &quot;aggregate&quot; if the compilation and its resulting copyright are not used to limit the access or legal rights of the compilation&#39;s users beyond what the individual works permit. Inclusion of a covered work in an aggregate does not cause this License to apply to the other parts of the aggregate.
   6. Conveying Non-Source Forms.
   You may convey a covered work in object code form under the terms of sections 4 and 5, provided that you also convey the machine-readable Corresponding Source under the terms of this License, in one of these ways:
      a) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by the Corresponding Source fixed on a durable physical medium customarily used for software interchange.
      b) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by a written offer, valid for at least three years and valid for as long as you offer spare parts or customer support for that product model, to give anyone who possesses the object code either (1) a copy of the Corresponding Source for all the software in the product that is covered by this License, on a durable physical medium customarily used for software interchange, for a price no more than your reasonable cost of physically performing this conveying of source, or (2) access to copy the Corresponding Source from a network server at no charge.
      c) Convey individual copies of the object code with a copy of the written offer to provide the Corresponding Source. This alternative is allowed only occasionally and noncommercially, and only if you received the object code with such an offer, in accord with subsection 6b.
      d) Convey the object code by offering access from a designated place (gratis or for a charge), and offer equivalent access to the Corresponding Source in the same way through the same place at no further charge. You need not require recipients to copy the Corresponding Source along with the object code. If the place to copy the object code is a network server, the Corresponding Source may be on a different server (operated by you or a third party) that supports equivalent copying facilities, provided you maintain clear directions next to the object code saying where to find the Corresponding Source. Regardless of what server hosts the Corresponding Source, you remain obligated to ensure that it is available for as long as needed to satisfy these requirements.
      e) Convey the object code using peer-to-peer transmission, provided you inform other peers where the object code and Corresponding Source of the work are being offered to the general public at no charge under subsection 6d.
   A separable portion of the object code, whose source code is excluded from the Corresponding Source as a System Library, need not be included in conveying the object code work.
   A &quot;User Product&quot; is either (1) a &quot;consumer product&quot;, which means any tangible personal property which is normally used for personal, family, or household purposes, or (2) anything designed or sold for incorporation into a dwelling. In determining whether a product is a consumer product, doubtful cases shall be resolved in favor of coverage. For a particular product received by a particular user, &quot;normally used&quot; refers to a typical or common use of that class of product, regardless of the status of the particular user or of the way in which the particular user actually uses, or expects or is expected to use, the product. A product is a consumer product regardless of whether the product has substantial commercial, industrial or non-consumer uses, unless such uses represent the only significant mode of use of the product.
   &quot;Installation Information&quot; for a User Product means any methods, procedures, authorization keys, or other information required to install and execute modified versions of a covered work in that User Product from a modified version of its Corresponding Source. The information must suffice to ensure that the continued functioning of the modified object code is in no case prevented or interfered with solely because modification has been made.
   If you convey an object code work under this section in, or with, or specifically for use in, a User Product, and the conveying occurs as part of a transaction in which the right of possession and use of the User Product is transferred to the recipient in perpetuity or for a fixed term (regardless of how the transaction is characterized), the Corresponding Source conveyed under this section must be accompanied by the Installation Information. But this requirement does not apply if neither you nor any third party retains the ability to install modified object code on the User Product (for example, the work has been installed in ROM).
   The requirement to provide Installation Information does not include a requirement to continue to provide support service, warranty, or updates for a work that has been modified or installed by the recipient, or for the User Product in which it has been modified or installed. Access to a network may be denied when the modification itself materially and adversely affects the operation of the network or violates the rules and protocols for communication across the network.
   Corresponding Source conveyed, and Installation Information provided, in accord with this section must be in a format that is publicly documented (and with an implementation available to the public in source code form), and must require no special password or key for unpacking, reading or copying.
   7. Additional Terms.
   &quot;Additional permissions&quot; are terms that supplement the terms of this License by making exceptions from one or more of its conditions. Additional permissions that are applicable to the entire Program shall be treated as though they were included in this License, to the extent that they are valid under applicable law. If additional permissions apply only to part of the Program, that part may be used separately under those permissions, but the entire Program remains governed by this License without regard to the additional permissions.
   When you convey a copy of a covered work, you may at your option remove any additional permissions from that copy, or from any part of it. (Additional permissions may be written to require their own removal in certain cases when you modify the work.) You may place additional permissions on material, added by you to a covered work, for which you have or can give appropriate copyright permission.
   Notwithstanding any other provision of this License, for material you add to a covered work, you may (if authorized by the copyright holders of that material) supplement the terms of this License with terms:
      a) Disclaiming warranty or limiting liability differently from the terms of sections 15 and 16 of this License; or
      b) Requiring preservation of specified reasonable legal notices or author attributions in that material or in the Appropriate Legal Notices displayed by works containing it; or
      c) Prohibiting misrepresentation of the origin of that material, or requiring that modified versions of such material be marked in reasonable ways as different from the original version; or
      d) Limiting the use for publicity purposes of names of licensors or authors of the material; or
      e) Declining to grant rights under trademark law for use of some trade names, trademarks, or service marks; or
      f) Requiring indemnification of licensors and authors of that material by anyone who conveys the material (or modified versions of it) with contractual assumptions of liability to the recipient, for any liability that these contractual assumptions directly impose on those licensors and authors.
   All other non-permissive additional terms are considered &quot;further restrictions&quot; within the meaning of section 10. If the Program as you received it, or any part of it, contains a notice stating that it is governed by this License along with a term that is a further restriction, you may remove that term. If a license document contains a further restriction but permits relicensing or conveying under this License, you may add to a covered work material governed by the terms of that license document, provided that the further restriction does not survive such relicensing or conveying.
   If you add terms to a covered work in accord with this section, you must place, in the relevant source files, a statement of the additional terms that apply to those files, or a notice indicating where to find the applicable terms.
   Additional terms, permissive or non-permissive, may be stated in the form of a separately written license, or stated as exceptions; the above requirements apply either way.
   8. Termination.
   You may not propagate or modify a covered work except as expressly provided under this License. Any attempt otherwise to propagate or modify it is void, and will automatically terminate your rights under this License (including any patent licenses granted under the third paragraph of section 11).
   However, if you cease all violation of this License, then your license from a particular copyright holder is reinstated (a) provisionally, unless and until the copyright holder explicitly and finally terminates your license, and (b) permanently, if the copyright holder fails to notify you of the violation by some reasonable means prior to 60 days after the cessation.
   Moreover, your license from a particular copyright holder is reinstated permanently if the copyright holder notifies you of the violation by some reasonable means, this is the first time you have received notice of violation of this License (for any work) from that copyright holder, and you cure the violation prior to 30 days after your receipt of the notice.
   Termination of your rights under this section does not terminate the licenses of parties who have received copies or rights from you under this License. If your rights have been terminated and not permanently reinstated, you do not qualify to receive new licenses for the same material under section 10.
   9. Acceptance Not Required for Having Copies.
   You are not required to accept this License in order to receive or run a copy of the Program. Ancillary propagation of a covered work occurring solely as a consequence of using peer-to-peer transmission to receive a copy likewise does not require acceptance. However, nothing other than this License grants you permission to propagate or modify any covered work. These actions infringe copyright if you do not accept this License. Therefore, by modifying or propagating a covered work, you indicate your acceptance of this License to do so.
   10. Automatic Licensing of Downstream Recipients.
   Each time you convey a covered work, the recipient automatically receives a license from the original licensors, to run, modify and propagate that work, subject to this License. You are not responsible for enforcing compliance by third parties with this License.
   An &quot;entity transaction&quot; is a transaction transferring control of an organization, or substantially all assets of one, or subdividing an organization, or merging organizations. If propagation of a covered work results from an entity transaction, each party to that transaction who receives a copy of the work also receives whatever licenses to the work the party&#39;s predecessor in interest had or could give under the previous paragraph, plus a right to possession of the Corresponding Source of the work from the predecessor in interest, if the predecessor has it or can get it with reasonable efforts.
   You may not impose any further restrictions on the exercise of the rights granted or affirmed under this License. For example, you may not impose a license fee, royalty, or other charge for exercise of rights granted under this License, and you may not initiate litigation (including a cross-claim or counterclaim in a lawsuit) alleging that any patent claim is infringed by making, using, selling, offering for sale, or importing the Program or any portion of it.
   11. Patents.
   A &quot;contributor&quot; is a copyright holder who authorizes use under this License of the Program or a work on which the Program is based. The work thus licensed is called the contributor&#39;s &quot;contributor version&quot;.
   A contributor&#39;s &quot;essential patent claims&quot; are all patent claims owned or controlled by the contributor, whether already acquired or hereafter acquired, that would be infringed by some manner, permitted by this License, of making, using, or selling its contributor version, but do not include claims that would be infringed only as a consequence of further modification of the contributor version. For purposes of this definition, &quot;control&quot; includes the right to grant patent sublicenses in a manner consistent with the requirements of this License.
   Each contributor grants you a non-exclusive, worldwide, royalty-free patent license under the contributor&#39;s essential patent claims, to make, use, sell, offer for sale, import and otherwise run, modify and propagate the contents of its contributor version.
   In the following three paragraphs, a &quot;patent license&quot; is any express agreement or commitment, however denominated, not to enforce a patent (such as an express permission to practice a patent or covenant not to sue for patent infringement). To &quot;grant&quot; such a patent license to a party means to make such an agreement or commitment not to enforce a patent against the party.
   If you convey a covered work, knowingly relying on a patent license, and the Corresponding Source of the work is not available for anyone to copy, free of charge and under the terms of this License, through a publicly available network server or other readily accessible means, then you must either (1) cause the Corresponding Source to be so available, or (2) arrange to deprive yourself of the benefit of the patent license for this particular work, or (3) arrange, in a manner consistent with the requirements of this License, to extend the patent license to downstream recipients. &quot;Knowingly relying&quot; means you have actual knowledge that, but for the patent license, your conveying the covered work in a country, or your recipient&#39;s use of the covered work in a country, would infringe one or more identifiable patents in that country that you have reason to believe are valid.
   If, pursuant to or in connection with a single transaction or arrangement, you convey, or propagate by procuring conveyance of, a covered work, and grant a patent license to some of the parties receiving the covered work authorizing them to use, propagate, modify or convey a specific copy of the covered work, then the patent license you grant is automatically extended to all recipients of the covered work and works based on it.
   A patent license is &quot;discriminatory&quot; if it does not include within the scope of its coverage, prohibits the exercise of, or is conditioned on the non-exercise of one or more of the rights that are specifically granted under this License. You may not convey a covered work if you are a party to an arrangement with a third party that is in the business of distributing software, under which you make payment to the third party based on the extent of your activity of conveying the work, and under which the third party grants, to any of the parties who would receive the covered work from you, a discriminatory patent license (a) in connection with copies of the covered work conveyed by you (or copies made from those copies), or (b) primarily for and in connection with specific products or compilations that contain the covered work, unless you entered into that arrangement, or that patent license was granted, prior to 28 March 2007.
   Nothing in this License shall be construed as excluding or limiting any implied license or other defenses to infringement that may otherwise be available to you under applicable patent law.
   12. No Surrender of Others&#39; Freedom.
   If conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot convey a covered work so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may not convey it at all. For example, if you agree to terms that obligate you to collect a royalty for further conveying from those to whom you convey the Program, the only way you could satisfy both those terms and this License would be to refrain entirely from conveying the Program.
   13. Use with the GNU Affero General Public License.
   Notwithstanding any other provision of this License, you have permission to link or combine any covered work with a work licensed under version 3 of the GNU Affero General Public License into a single combined work, and to convey the resulting work. The terms of this License will continue to apply to the part which is the covered work, but the special requirements of the GNU Affero General Public License, section 13, concerning interaction through a network will apply to the combination as such.
   14. Revised Versions of this License.
   The Free Software Foundation may publish revised and/or new versions of the GNU General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies that a certain numbered version of the GNU General Public License &quot;or any later version&quot; applies to it, you have the option of following the terms and conditions either of that numbered version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of the GNU General Public License, you may choose any version ever published by the Free Software Foundation.
   If the Program specifies that a proxy can decide which future versions of the GNU General Public License can be used, that proxy&#39;s public statement of acceptance of a version permanently authorizes you to choose that version for the Program.
   Later license versions may give you additional or different permissions. However, no additional obligations are imposed on any author or copyright holder as a result of your choosing to follow a later version.
   15. Disclaimer of Warranty.
   THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   16. Limitation of Liability.
   IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   17. Interpretation of Sections 15 and 16.
   If the disclaimer of warranty and limitation of liability provided above cannot be given local legal effect according to their terms, reviewing courts shall apply local law that most closely approximates an absolute waiver of all civil liability in connection with the Program, unless a warranty or assumption of liability accompanies a copy of the Program in return for a fee. END OF TERMS AND CONDITIONS
How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively state the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt;one line to give the program&#39;s name and a brief idea of what it does.&gt;
Copyright (C) &lt;year&gt; &lt;name of author&gt;
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see &lt;http s ://www.gnu.org/licenses/&gt;.
Also add information on how to contact you by electronic and paper mail.
If the program does terminal interaction, make it output a short notice like this when it starts in an interactive mode:
&lt;program&gt; Copyright (C) &lt;year&gt; &lt;name of author&gt;
This program comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;.
This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, your program&#39;s commands might be different; for a GUI interface, you would use an &quot;about box&quot;.
You should also get your employer (if you work as a programmer) or school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. For more information on this, and how to apply and follow the GNU GPL, see &lt;http s ://www.gnu.org/licenses/&gt;.
The GNU General Public License does not permit incorporating your program into proprietary programs. If your program is a subroutine library, you may consider it more useful to permit linking proprietary applications with the library. If this is what you want to do, use the GNU Lesser General Public License instead of this License. But first, please read &lt;http s ://www.gnu.org/philosophy/why-not-lgpl.html&gt;.
```


### GNU General Public License v3.0 or later

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
GNU GENERAL PUBLIC LICENSE
Version 3, 29 June 2007
Copyright © 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
Preamble
The GNU General Public License is a free, copyleft license for software and other kinds of works.
The licenses for most software and other practical works are designed to take away your freedom to share and change the works. By contrast, the GNU General Public License is intended to guarantee your freedom to share and change all versions of a program--to make sure it remains free software for all its users. We, the Free Software Foundation, use the GNU General Public License for most of our software; it applies also to any other work released this way by its authors. You can apply it to your programs, too.
When we speak of free software, we are referring to freedom, not price. Our General Public Licenses are designed to make sure that you have the freedom to distribute copies of free software (and charge for them if you wish), that you receive source code or can get it if you want it, that you can change the software or use pieces of it in new free programs, and that you know you can do these things.
To protect your rights, we need to prevent others from denying you these rights or asking you to surrender the rights. Therefore, you have certain responsibilities if you distribute copies of the software, or if you modify it: responsibilities to respect the freedom of others.
For example, if you distribute copies of such a program, whether gratis or for a fee, you must pass on to the recipients the same freedoms that you received. You must make sure that they, too, receive or can get the source code. And you must show them these terms so they know their rights.
Developers that use the GNU GPL protect your rights with two steps: (1) assert copyright on the software, and (2) offer you this License giving you legal permission to copy, distribute and/or modify it.
For the developers&#39; and authors&#39; protection, the GPL clearly explains that there is no warranty for this free software. For both users&#39; and authors&#39; sake, the GPL requires that modified versions be marked as changed, so that their problems will not be attributed erroneously to authors of previous versions.
Some devices are designed to deny users access to install or run modified versions of the software inside them, although the manufacturer can do so. This is fundamentally incompatible with the aim of protecting users&#39; freedom to change the software. The systematic pattern of such abuse occurs in the area of products for individuals to use, which is precisely where it is most unacceptable. Therefore, we have designed this version of the GPL to prohibit the practice for those products. If such problems arise substantially in other domains, we stand ready to extend this provision to those domains in future versions of the GPL, as needed to protect the freedom of users.
Finally, every program is threatened constantly by software patents. States should not allow patents to restrict development and use of software on general-purpose computers, but in those that do, we wish to avoid the special danger that patents applied to a free program could make it effectively proprietary. To prevent this, the GPL assures that patents cannot be used to render the program non-free.
The precise terms and conditions for copying, distribution and modification follow.
TERMS AND CONDITIONS
   0. Definitions.
   &quot;This License&quot; refers to version 3 of the GNU General Public License.
   &quot;Copyright&quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.
   &quot;The Program&quot; refers to any copyrightable work licensed under this License. Each licensee is addressed as &quot;you&quot;. &quot;Licensees&quot; and &quot;recipients&quot; may be individuals or organizations.
   To &quot;modify&quot; a work means to copy from or adapt all or part of the work in a fashion requiring copyright permission, other than the making of an exact copy. The resulting work is called a &quot;modified version&quot; of the earlier work or a work &quot;based on&quot; the earlier work.
   A &quot;covered work&quot; means either the unmodified Program or a work based on the Program.
   To &quot;propagate&quot; a work means to do anything with it that, without permission, would make you directly or secondarily liable for infringement under applicable copyright law, except executing it on a computer or modifying a private copy. Propagation includes copying, distribution (with or without modification), making available to the public, and in some countries other activities as well.
   To &quot;convey&quot; a work means any kind of propagation that enables other parties to make or receive copies. Mere interaction with a user through a computer network, with no transfer of a copy, is not conveying.
   An interactive user interface displays &quot;Appropriate Legal Notices&quot; to the extent that it includes a convenient and prominently visible feature that (1) displays an appropriate copyright notice, and (2) tells the user that there is no warranty for the work (except to the extent that warranties are provided), that licensees may convey the work under this License, and how to view a copy of this License. If the interface presents a list of user commands or options, such as a menu, a prominent item in the list meets this criterion.
   1. Source Code.
   The &quot;source code&quot; for a work means the preferred form of the work for making modifications to it. &quot;Object code&quot; means any non-source form of a work.
   A &quot;Standard Interface&quot; means an interface that either is an official standard defined by a recognized standards body, or, in the case of interfaces specified for a particular programming language, one that is widely used among developers working in that language.
   The &quot;System Libraries&quot; of an executable work include anything, other than the work as a whole, that (a) is included in the normal form of packaging a Major Component, but which is not part of that Major Component, and (b) serves only to enable use of the work with that Major Component, or to implement a Standard Interface for which an implementation is available to the public in source code form. A &quot;Major Component&quot;, in this context, means a major essential component (kernel, window system, and so on) of the specific operating system (if any) on which the executable work runs, or a compiler used to produce the work, or an object code interpreter used to run it.
   The &quot;Corresponding Source&quot; for a work in object code form means all the source code needed to generate, install, and (for an executable work) run the object code and to modify the work, including scripts to control those activities. However, it does not include the work&#39;s System Libraries, or general-purpose tools or generally available free programs which are used unmodified in performing those activities but which are not part of the work. For example, Corresponding Source includes interface definition files associated with source files for the work, and the source code for shared libraries and dynamically linked subprograms that the work is specifically designed to require, such as by intimate data communication or control flow between those subprograms and other parts of the work.
   The Corresponding Source need not include anything that users can regenerate automatically from other parts of the Corresponding Source.
   The Corresponding Source for a work in source code form is that same work.
   2. Basic Permissions.
   All rights granted under this License are granted for the term of copyright on the Program, and are irrevocable provided the stated conditions are met. This License explicitly affirms your unlimited permission to run the unmodified Program. The output from running a covered work is covered by this License only if the output, given its content, constitutes a covered work. This License acknowledges your rights of fair use or other equivalent, as provided by copyright law.
   You may make, run and propagate covered works that you do not convey, without conditions so long as your license otherwise remains in force. You may convey covered works to others for the sole purpose of having them make modifications exclusively for you, or provide you with facilities for running those works, provided that you comply with the terms of this License in conveying all material for which you do not control copyright. Those thus making or running the covered works for you must do so exclusively on your behalf, under your direction and control, on terms that prohibit them from making any copies of your copyrighted material outside their relationship with you.
   Conveying under any other circumstances is permitted solely under the conditions stated below. Sublicensing is not allowed; section 10 makes it unnecessary.
   3. Protecting Users&#39; Legal Rights From Anti-Circumvention Law.
   No covered work shall be deemed part of an effective technological measure under any applicable law fulfilling obligations under article 11 of the WIPO copyright treaty adopted on 20 December 1996, or similar laws prohibiting or restricting circumvention of such measures.
   When you convey a covered work, you waive any legal power to forbid circumvention of technological measures to the extent such circumvention is effected by exercising rights under this License with respect to the covered work, and you disclaim any intention to limit operation or modification of the work as a means of enforcing, against the work&#39;s users, your or third parties&#39; legal rights to forbid circumvention of technological measures.
   4. Conveying Verbatim Copies.
   You may convey verbatim copies of the Program&#39;s source code as you receive it, in any medium, provided that you conspicuously and appropriately publish on each copy an appropriate copyright notice; keep intact all notices stating that this License and any non-permissive terms added in accord with section 7 apply to the code; keep intact all notices of the absence of any warranty; and give all recipients a copy of this License along with the Program.
   You may charge any price or no price for each copy that you convey, and you may offer support or warranty protection for a fee.
   5. Conveying Modified Source Versions.
   You may convey a work based on the Program, or the modifications to produce it from the Program, in the form of source code under the terms of section 4, provided that you also meet all of these conditions:
      a) The work must carry prominent notices stating that you modified it, and giving a relevant date.
      b) The work must carry prominent notices stating that it is released under this License and any conditions added under section 7. This requirement modifies the requirement in section 4 to &quot;keep intact all notices&quot;.
      c) You must license the entire work, as a whole, under this License to anyone who comes into possession of a copy. This License will therefore apply, along with any applicable section 7 additional terms, to the whole of the work, and all its parts, regardless of how they are packaged. This License gives no permission to license the work in any other way, but it does not invalidate such permission if you have separately received it.
      d) If the work has interactive user interfaces, each must display Appropriate Legal Notices; however, if the Program has interactive interfaces that do not display Appropriate Legal Notices, your work need not make them do so.
   A compilation of a covered work with other separate and independent works, which are not by their nature extensions of the covered work, and which are not combined with it such as to form a larger program, in or on a volume of a storage or distribution medium, is called an &quot;aggregate&quot; if the compilation and its resulting copyright are not used to limit the access or legal rights of the compilation&#39;s users beyond what the individual works permit. Inclusion of a covered work in an aggregate does not cause this License to apply to the other parts of the aggregate.
   6. Conveying Non-Source Forms.
   You may convey a covered work in object code form under the terms of sections 4 and 5, provided that you also convey the machine-readable Corresponding Source under the terms of this License, in one of these ways:
      a) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by the Corresponding Source fixed on a durable physical medium customarily used for software interchange.
      b) Convey the object code in, or embodied in, a physical product (including a physical distribution medium), accompanied by a written offer, valid for at least three years and valid for as long as you offer spare parts or customer support for that product model, to give anyone who possesses the object code either (1) a copy of the Corresponding Source for all the software in the product that is covered by this License, on a durable physical medium customarily used for software interchange, for a price no more than your reasonable cost of physically performing this conveying of source, or (2) access to copy the Corresponding Source from a network server at no charge.
      c) Convey individual copies of the object code with a copy of the written offer to provide the Corresponding Source. This alternative is allowed only occasionally and noncommercially, and only if you received the object code with such an offer, in accord with subsection 6b.
      d) Convey the object code by offering access from a designated place (gratis or for a charge), and offer equivalent access to the Corresponding Source in the same way through the same place at no further charge. You need not require recipients to copy the Corresponding Source along with the object code. If the place to copy the object code is a network server, the Corresponding Source may be on a different server (operated by you or a third party) that supports equivalent copying facilities, provided you maintain clear directions next to the object code saying where to find the Corresponding Source. Regardless of what server hosts the Corresponding Source, you remain obligated to ensure that it is available for as long as needed to satisfy these requirements.
      e) Convey the object code using peer-to-peer transmission, provided you inform other peers where the object code and Corresponding Source of the work are being offered to the general public at no charge under subsection 6d.
   A separable portion of the object code, whose source code is excluded from the Corresponding Source as a System Library, need not be included in conveying the object code work.
   A &quot;User Product&quot; is either (1) a &quot;consumer product&quot;, which means any tangible personal property which is normally used for personal, family, or household purposes, or (2) anything designed or sold for incorporation into a dwelling. In determining whether a product is a consumer product, doubtful cases shall be resolved in favor of coverage. For a particular product received by a particular user, &quot;normally used&quot; refers to a typical or common use of that class of product, regardless of the status of the particular user or of the way in which the particular user actually uses, or expects or is expected to use, the product. A product is a consumer product regardless of whether the product has substantial commercial, industrial or non-consumer uses, unless such uses represent the only significant mode of use of the product.
   &quot;Installation Information&quot; for a User Product means any methods, procedures, authorization keys, or other information required to install and execute modified versions of a covered work in that User Product from a modified version of its Corresponding Source. The information must suffice to ensure that the continued functioning of the modified object code is in no case prevented or interfered with solely because modification has been made.
   If you convey an object code work under this section in, or with, or specifically for use in, a User Product, and the conveying occurs as part of a transaction in which the right of possession and use of the User Product is transferred to the recipient in perpetuity or for a fixed term (regardless of how the transaction is characterized), the Corresponding Source conveyed under this section must be accompanied by the Installation Information. But this requirement does not apply if neither you nor any third party retains the ability to install modified object code on the User Product (for example, the work has been installed in ROM).
   The requirement to provide Installation Information does not include a requirement to continue to provide support service, warranty, or updates for a work that has been modified or installed by the recipient, or for the User Product in which it has been modified or installed. Access to a network may be denied when the modification itself materially and adversely affects the operation of the network or violates the rules and protocols for communication across the network.
   Corresponding Source conveyed, and Installation Information provided, in accord with this section must be in a format that is publicly documented (and with an implementation available to the public in source code form), and must require no special password or key for unpacking, reading or copying.
   7. Additional Terms.
   &quot;Additional permissions&quot; are terms that supplement the terms of this License by making exceptions from one or more of its conditions. Additional permissions that are applicable to the entire Program shall be treated as though they were included in this License, to the extent that they are valid under applicable law. If additional permissions apply only to part of the Program, that part may be used separately under those permissions, but the entire Program remains governed by this License without regard to the additional permissions.
   When you convey a copy of a covered work, you may at your option remove any additional permissions from that copy, or from any part of it. (Additional permissions may be written to require their own removal in certain cases when you modify the work.) You may place additional permissions on material, added by you to a covered work, for which you have or can give appropriate copyright permission.
   Notwithstanding any other provision of this License, for material you add to a covered work, you may (if authorized by the copyright holders of that material) supplement the terms of this License with terms:
      a) Disclaiming warranty or limiting liability differently from the terms of sections 15 and 16 of this License; or
      b) Requiring preservation of specified reasonable legal notices or author attributions in that material or in the Appropriate Legal Notices displayed by works containing it; or
      c) Prohibiting misrepresentation of the origin of that material, or requiring that modified versions of such material be marked in reasonable ways as different from the original version; or
      d) Limiting the use for publicity purposes of names of licensors or authors of the material; or
      e) Declining to grant rights under trademark law for use of some trade names, trademarks, or service marks; or
      f) Requiring indemnification of licensors and authors of that material by anyone who conveys the material (or modified versions of it) with contractual assumptions of liability to the recipient, for any liability that these contractual assumptions directly impose on those licensors and authors.
   All other non-permissive additional terms are considered &quot;further restrictions&quot; within the meaning of section 10. If the Program as you received it, or any part of it, contains a notice stating that it is governed by this License along with a term that is a further restriction, you may remove that term. If a license document contains a further restriction but permits relicensing or conveying under this License, you may add to a covered work material governed by the terms of that license document, provided that the further restriction does not survive such relicensing or conveying.
   If you add terms to a covered work in accord with this section, you must place, in the relevant source files, a statement of the additional terms that apply to those files, or a notice indicating where to find the applicable terms.
   Additional terms, permissive or non-permissive, may be stated in the form of a separately written license, or stated as exceptions; the above requirements apply either way.
   8. Termination.
   You may not propagate or modify a covered work except as expressly provided under this License. Any attempt otherwise to propagate or modify it is void, and will automatically terminate your rights under this License (including any patent licenses granted under the third paragraph of section 11).
   However, if you cease all violation of this License, then your license from a particular copyright holder is reinstated (a) provisionally, unless and until the copyright holder explicitly and finally terminates your license, and (b) permanently, if the copyright holder fails to notify you of the violation by some reasonable means prior to 60 days after the cessation.
   Moreover, your license from a particular copyright holder is reinstated permanently if the copyright holder notifies you of the violation by some reasonable means, this is the first time you have received notice of violation of this License (for any work) from that copyright holder, and you cure the violation prior to 30 days after your receipt of the notice.
   Termination of your rights under this section does not terminate the licenses of parties who have received copies or rights from you under this License. If your rights have been terminated and not permanently reinstated, you do not qualify to receive new licenses for the same material under section 10.
   9. Acceptance Not Required for Having Copies.
   You are not required to accept this License in order to receive or run a copy of the Program. Ancillary propagation of a covered work occurring solely as a consequence of using peer-to-peer transmission to receive a copy likewise does not require acceptance. However, nothing other than this License grants you permission to propagate or modify any covered work. These actions infringe copyright if you do not accept this License. Therefore, by modifying or propagating a covered work, you indicate your acceptance of this License to do so.
   10. Automatic Licensing of Downstream Recipients.
   Each time you convey a covered work, the recipient automatically receives a license from the original licensors, to run, modify and propagate that work, subject to this License. You are not responsible for enforcing compliance by third parties with this License.
   An &quot;entity transaction&quot; is a transaction transferring control of an organization, or substantially all assets of one, or subdividing an organization, or merging organizations. If propagation of a covered work results from an entity transaction, each party to that transaction who receives a copy of the work also receives whatever licenses to the work the party&#39;s predecessor in interest had or could give under the previous paragraph, plus a right to possession of the Corresponding Source of the work from the predecessor in interest, if the predecessor has it or can get it with reasonable efforts.
   You may not impose any further restrictions on the exercise of the rights granted or affirmed under this License. For example, you may not impose a license fee, royalty, or other charge for exercise of rights granted under this License, and you may not initiate litigation (including a cross-claim or counterclaim in a lawsuit) alleging that any patent claim is infringed by making, using, selling, offering for sale, or importing the Program or any portion of it.
   11. Patents.
   A &quot;contributor&quot; is a copyright holder who authorizes use under this License of the Program or a work on which the Program is based. The work thus licensed is called the contributor&#39;s &quot;contributor version&quot;.
   A contributor&#39;s &quot;essential patent claims&quot; are all patent claims owned or controlled by the contributor, whether already acquired or hereafter acquired, that would be infringed by some manner, permitted by this License, of making, using, or selling its contributor version, but do not include claims that would be infringed only as a consequence of further modification of the contributor version. For purposes of this definition, &quot;control&quot; includes the right to grant patent sublicenses in a manner consistent with the requirements of this License.
   Each contributor grants you a non-exclusive, worldwide, royalty-free patent license under the contributor&#39;s essential patent claims, to make, use, sell, offer for sale, import and otherwise run, modify and propagate the contents of its contributor version.
   In the following three paragraphs, a &quot;patent license&quot; is any express agreement or commitment, however denominated, not to enforce a patent (such as an express permission to practice a patent or covenant not to sue for patent infringement). To &quot;grant&quot; such a patent license to a party means to make such an agreement or commitment not to enforce a patent against the party.
   If you convey a covered work, knowingly relying on a patent license, and the Corresponding Source of the work is not available for anyone to copy, free of charge and under the terms of this License, through a publicly available network server or other readily accessible means, then you must either (1) cause the Corresponding Source to be so available, or (2) arrange to deprive yourself of the benefit of the patent license for this particular work, or (3) arrange, in a manner consistent with the requirements of this License, to extend the patent license to downstream recipients. &quot;Knowingly relying&quot; means you have actual knowledge that, but for the patent license, your conveying the covered work in a country, or your recipient&#39;s use of the covered work in a country, would infringe one or more identifiable patents in that country that you have reason to believe are valid.
   If, pursuant to or in connection with a single transaction or arrangement, you convey, or propagate by procuring conveyance of, a covered work, and grant a patent license to some of the parties receiving the covered work authorizing them to use, propagate, modify or convey a specific copy of the covered work, then the patent license you grant is automatically extended to all recipients of the covered work and works based on it.
   A patent license is &quot;discriminatory&quot; if it does not include within the scope of its coverage, prohibits the exercise of, or is conditioned on the non-exercise of one or more of the rights that are specifically granted under this License. You may not convey a covered work if you are a party to an arrangement with a third party that is in the business of distributing software, under which you make payment to the third party based on the extent of your activity of conveying the work, and under which the third party grants, to any of the parties who would receive the covered work from you, a discriminatory patent license (a) in connection with copies of the covered work conveyed by you (or copies made from those copies), or (b) primarily for and in connection with specific products or compilations that contain the covered work, unless you entered into that arrangement, or that patent license was granted, prior to 28 March 2007.
   Nothing in this License shall be construed as excluding or limiting any implied license or other defenses to infringement that may otherwise be available to you under applicable patent law.
   12. No Surrender of Others&#39; Freedom.
   If conditions are imposed on you (whether by court order, agreement or otherwise) that contradict the conditions of this License, they do not excuse you from the conditions of this License. If you cannot convey a covered work so as to satisfy simultaneously your obligations under this License and any other pertinent obligations, then as a consequence you may not convey it at all. For example, if you agree to terms that obligate you to collect a royalty for further conveying from those to whom you convey the Program, the only way you could satisfy both those terms and this License would be to refrain entirely from conveying the Program.
   13. Use with the GNU Affero General Public License.
   Notwithstanding any other provision of this License, you have permission to link or combine any covered work with a work licensed under version 3 of the GNU Affero General Public License into a single combined work, and to convey the resulting work. The terms of this License will continue to apply to the part which is the covered work, but the special requirements of the GNU Affero General Public License, section 13, concerning interaction through a network will apply to the combination as such.
   14. Revised Versions of this License.
   The Free Software Foundation may publish revised and/or new versions of the GNU General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Program specifies that a certain numbered version of the GNU General Public License &quot;or any later version&quot; applies to it, you have the option of following the terms and conditions either of that numbered version or of any later version published by the Free Software Foundation. If the Program does not specify a version number of the GNU General Public License, you may choose any version ever published by the Free Software Foundation.
   If the Program specifies that a proxy can decide which future versions of the GNU General Public License can be used, that proxy&#39;s public statement of acceptance of a version permanently authorizes you to choose that version for the Program.
   Later license versions may give you additional or different permissions. However, no additional obligations are imposed on any author or copyright holder as a result of your choosing to follow a later version.
   15. Disclaimer of Warranty.
   THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
   16. Limitation of Liability.
   IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   17. Interpretation of Sections 15 and 16.
   If the disclaimer of warranty and limitation of liability provided above cannot be given local legal effect according to their terms, reviewing courts shall apply local law that most closely approximates an absolute waiver of all civil liability in connection with the Program, unless a warranty or assumption of liability accompanies a copy of the Program in return for a fee. END OF TERMS AND CONDITIONS
How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest possible use to the public, the best way to achieve this is to make it free software which everyone can redistribute and change under these terms.
To do so, attach the following notices to the program. It is safest to attach them to the start of each source file to most effectively state the exclusion of warranty; and each file should have at least the &quot;copyright&quot; line and a pointer to where the full notice is found.
&lt;one line to give the program&#39;s name and a brief idea of what it does.&gt;
Copyright (C) &lt;year&gt; &lt;name of author&gt;
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see &lt;http s ://www.gnu.org/licenses/&gt;.
Also add information on how to contact you by electronic and paper mail.
If the program does terminal interaction, make it output a short notice like this when it starts in an interactive mode:
&lt;program&gt; Copyright (C) &lt;year&gt; &lt;name of author&gt;
This program comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;.
This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.
The hypothetical commands `show w&#39; and `show c&#39; should show the appropriate parts of the General Public License. Of course, your program&#39;s commands might be different; for a GUI interface, you would use an &quot;about box&quot;.
You should also get your employer (if you work as a programmer) or school, if any, to sign a &quot;copyright disclaimer&quot; for the program, if necessary. For more information on this, and how to apply and follow the GNU GPL, see &lt;http s ://www.gnu.org/licenses/&gt;.
The GNU General Public License does not permit incorporating your program into proprietary programs. If your program is a subroutine library, you may consider it more useful to permit linking proprietary applications with the library. If this is what you want to do, use the GNU Lesser General Public License instead of this License. But first, please read &lt;http s ://www.gnu.org/philosophy/why-not-lgpl.html&gt;.
```


### GNU General Public License v3.0 w/GCC Runtime Library exception

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
﻿insert GPL v3 text here GCC RUNTIME LIBRARY EXCEPTION
Version 3.1, 31 March 2009
General information: http://www.gnu.org/licenses/gcc-exception.html
Copyright (C) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
This GCC Runtime Library Exception (&quot;Exception&quot;) is an additional permission under section 7 of the GNU General Public License, version 3 (&quot;GPLv3&quot;). It applies to a given file (the &quot;Runtime Library&quot;) that bears a notice placed by the copyright holder of the file stating that the file is governed by GPLv3 along with this Exception.
When you use GCC to compile a program, GCC may combine portions of certain GCC header files and runtime libraries with the compiled program. The purpose of this Exception is to allow compilation of non-GPL (including proprietary) programs to use, in this way, the header files and runtime libraries covered by this Exception.
   0. Definitions.
   A file is an &quot;Independent Module&quot; if it either requires the Runtime Library for execution after a Compilation Process, or makes use of an interface provided by the Runtime Library, but is not otherwise based on the Runtime Library.
   &quot;GCC&quot; means a version of the GNU Compiler Collection, with or without modifications, governed by version 3 (or a specified later version) of the GNU General Public License (GPL) with the option of using any subsequent versions published by the FSF.
   &quot;GPL-compatible Software&quot; is software whose conditions of propagation, modification and use would permit combination with GCC in accord with the license of GCC.
   &quot;Target Code&quot; refers to output from any compiler for a real or virtual target processor architecture, in executable form or suitable for input to an assembler, loader, linker and/or execution phase. Notwithstanding that, Target Code does not include data in any format that is used as a compiler intermediate representation, or used for producing a compiler intermediate representation.
   The &quot;Compilation Process&quot; transforms code entirely represented in non-intermediate languages designed for human-written code, and/or in Java Virtual Machine byte code, into Target Code. Thus, for example, use of source code generators and preprocessors need not be considered part of the Compilation Process, since the Compilation Process can be understood as starting with the output of the generators or preprocessors.
   A Compilation Process is &quot;Eligible&quot; if it is done using GCC, alone or with other GPL-compatible software, or if it is done without using any work based on GCC. For example, using non-GPL-compatible Software to optimize any GCC intermediate representations would not qualify as an Eligible Compilation Process.
   1. Grant of Additional Permission.
   You have permission to propagate a work of Target Code formed by combining the Runtime Library with Independent Modules, even if such propagation would otherwise violate the terms of GPLv3, provided that all Target Code was generated by Eligible Compilation Processes. You may then convey such a combination under terms of your choice, consistent with the licensing of the Independent Modules.
   2. No Weakening of GCC Copyleft.
The availability of this Exception does not imply any general presumption that third-party software is unaffected by the copyleft requirements of the license of GCC.
```


### IPA Font License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
IPA Font License Agreement v1.0
The Licensor provides the Licensed Program (as defined in Article 1 below) under the terms of this license agreement (&quot;Agreement&quot;). Any use, reproduction or distribution of the Licensed Program, or any exercise of rights under this Agreement by a Recipient (as defined in Article 1 below) constitutes the Recipient&#39;s acceptance of this Agreement.
Article 1 (Definitions)
   1. &quot;Digital Font Program&quot; shall mean a computer program containing, or used to render or display fonts.
   2. &quot;Licensed Program&quot; shall mean a Digital Font Program licensed by the Licensor under this Agreement.
   3. &quot;Derived Program&quot; shall mean a Digital Font Program created as a result of a modification, addition, deletion, replacement or any other adaptation to or of a part or all of the Licensed Program, and includes a case where a Digital Font Program newly created by retrieving font information from a part or all of the Licensed Program or Embedded Fonts from a Digital Document File with or without modification of the retrieved font information.
   4. &quot;Digital Content&quot; shall mean products provided to end users in the form of digital data, including video content, motion and/or still pictures, TV programs or other broadcasting content and products consisting of character text, pictures, photographic images, graphic symbols and/or the like.
   5. &quot;Digital Document File&quot; shall mean a PDF file or other Digital Content created by various software programs in which a part or all of the Licensed Program becomes embedded or contained in the file for the display of the font (&quot;Embedded Fonts&quot;). Embedded Fonts are used only in the display of characters in the particular Digital Document File within which they are embedded, and shall be distinguished from those in any Digital Font Program, which may be used for display of characters outside that particular Digital Document File.
   6. &quot;Computer&quot; shall include a server in this Agreement.
   7. &quot;Reproduction and Other Exploitation&quot; shall mean reproduction, transfer, distribution, lease, public transmission, presentation, exhibition, adaptation and any other exploitation.
   8. &quot;Recipient&quot; shall mean anyone who receives the Licensed Program under this Agreement, including one that receives the Licensed Program from a Recipient.
Article 2 (Grant of License)
The Licensor grants to the Recipient a license to use the Licensed Program in any and all countries in accordance with each of the provisions set forth in this Agreement. However, any and all rights underlying in the Licensed Program shall be held by the Licensor. In no sense is this Agreement intended to transfer any right relating to the Licensed Program held by the Licensor except as specifically set forth herein or any right relating to any trademark, trade name, or service mark to the Recipient.
   1. The Recipient may install the Licensed Program on any number of Computers and use the same in accordance with the provisions set forth in this Agreement.
   2. The Recipient may use the Licensed Program, with or without modification in printed materials or in Digital Content as an expression of character texts or the like.
   3. The Recipient may conduct Reproduction and Other Exploitation of the printed materials and Digital Content created in accordance with the preceding Paragraph, for commercial or non-commercial purposes and in any form of media including but not limited to broadcasting, communication and various recording media.
   4. If any Recipient extracts Embedded Fonts from a Digital Document File to create a Derived Program, such Derived Program shall be subject to the terms of this agreement.
   5. If any Recipient performs Reproduction or Other Exploitation of a Digital Document File in which Embedded Fonts of the Licensed Program are used only for rendering the Digital Content within such Digital Document File then such Recipient shall have no further obligations under this Agreement in relation to such actions.
   6. The Recipient may reproduce the Licensed Program as is without modification and transfer such copies, publicly transmit or otherwise redistribute the Licensed Program to a third party for commercial or non-commercial purposes (&quot;Redistribute&quot;), in accordance with the provisions set forth in Article 3 Paragraph 2.
   7. The Recipient may create, use, reproduce and/or Redistribute a Derived Program under the terms stated above for the Licensed Program: provided, that the Recipient shall follow the provisions set forth in Article 3 Paragraph 1 when Redistributing the Derived Program.
Article 3 (Restriction)
The license granted in the preceding Article shall be subject to the following restrictions:
   1. If a Derived Program is Redistributed pursuant to Paragraph 4 and 7 of the preceding Article, the following conditions must be met :
      (1) The following must be also Redistributed together with the Derived Program, or be made available online or by means of mailing mechanisms in exchange for a cost which does not exceed the total costs of postage, storage medium and handling fees:
         (a) a copy of the Derived Program; and
         (b) any additional file created by the font developing program in the course of creating the Derived Program that can be used for further modification of the Derived Program, if any.
      (2) It is required to also Redistribute means to enable recipients of the Derived Program to replace the Derived Program with the Licensed Program first released under this License (the &quot;Original Program&quot;). Such means may be to provide a difference file from the Original Program, or instructions setting out a method to replace the Derived Program with the Original Program.
      (3) The Recipient must license the Derived Program under the terms and conditions of this Agreement.
      (4) No one may use or include the name of the Licensed Program as a program name, font name or file name of the Derived Program.
      (5) Any material to be made available online or by means of mailing a medium to satisfy the requirements of this paragraph may be provided, verbatim, by any party wishing to do so.
   2. If the Recipient Redistributes the Licensed Program pursuant to Paragraph 6 of the preceding Article, the Recipient shall meet all of the following conditions:
      (1) The Recipient may not change the name of the Licensed Program.
      (2) The Recipient may not alter or otherwise modify the Licensed Program.
      (3) The Recipient must attach a copy of this Agreement to the Licensed Program.
   3. THIS LICENSED PROGRAM IS PROVIDED BY THE LICENSOR &quot;AS IS&quot; AND ANY EXPRESSED OR IMPLIED WARRANTY AS TO THE LICENSED PROGRAM OR ANY DERIVED PROGRAM, INCLUDING, BUT NOT LIMITED TO, WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY, OR FITNESS FOR A PARTICULAR PURPOSE, ARE DISCLAIMED. IN NO EVENT SHALL THE LICENSOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXTENDED, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO; PROCUREMENT OF SUBSTITUTED GOODS OR SERVICE; DAMAGES ARISING FROM SYSTEM FAILURE; LOSS OR CORRUPTION OF EXISTING DATA OR PROGRAM; LOST PROFITS), HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE INSTALLATION, USE, THE REPRODUCTION OR OTHER EXPLOITATION OF THE LICENSED PROGRAM OR ANY DERIVED PROGRAM OR THE EXERCISE OF ANY RIGHTS GRANTED HEREUNDER, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
   4. The Licensor is under no obligation to respond to any technical questions or inquiries, or provide any other user support in connection with the installation, use or the Reproduction and Other Exploitation of the Licensed Program or Derived Programs thereof.
Article 4 (Termination of Agreement)
   1. The term of this Agreement shall begin from the time of receipt of the Licensed Program by the Recipient and shall continue as long as the Recipient retains any such Licensed Program in any way.
   2. Notwithstanding the provision set forth in the preceding Paragraph, in the event of the breach of any of the provisions set forth in this Agreement by the Recipient, this Agreement shall automatically terminate without any notice. In the case of such termination, the Recipient may not use or conduct Reproduction and Other Exploitation of the Licensed Program or a Derived Program: provided that such termination shall not affect any rights of any other Recipient receiving the Licensed Program or the Derived Program from such Recipient who breached this Agreement.
Article 5 (Governing Law)
   1. IPA may publish revised and/or new versions of this License. In such an event, the Recipient may select either this Agreement or any subsequent version of the Agreement in using, conducting the Reproduction and Other Exploitation of, or Redistributing the Licensed Program or a Derived Program. Other matters not specified above shall be subject to the Copyright Law of Japan and other related laws and regulations of Japan.
   2. This Agreement shall be construed under the laws of Japan.
```


### ISC License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
ISC License
Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)
Copyright (c) 1995-2003 by Internet Software Consortium
Permission to use, copy, modify, and /or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot; AND ISC DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
```


### Info-ZIP License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Info-ZIP License
Copyright (c) 1990-2009 Info-ZIP. All rights reserved.
For the purposes of this copyright and license, &quot;Info-ZIP&quot; is defined as the following set of individuals:
Mark Adler, John Bush, Karl Davis, Harald Denker, Jean-Michel Dubois, Jean-loup Gailly, Hunter Goatley, Ed Gordon, Ian Gorman, Chris Herborth, Dirk Haase, Greg Hartwig, Robert Heath, Jonathan Hudson, Paul Kienitz, David Kirschbaum, Johnny Lee, Onno van der Linden, Igor Mandrichenko, Steve P. Miller, Sergio Monesi, Keith Owens, George Petrov, Greg Roelofs, Kai Uwe Rommel, Steve Salisbury, Dave Smith, Steven M. Schweda, Christian Spieler, Cosmin Truta, Antoine Verheijen, Paul von Behren, Rich Wales, Mike White.
This software is provided &quot;as is,&quot; without warranty of any kind, express or implied. In no event shall Info-ZIP or its contributors be held liable for any direct, indirect, incidental, special or consequential damages arising out of the use of or inability to use this software.
Permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the above disclaimer and the following restrictions:
   * Redistributions of source code (in whole or in part) must retain the above copyright notice, definition, disclaimer, and this list of conditions.
   * Redistributions in binary form (compiled executables and libraries) must reproduce the above copyright notice, definition, disclaimer, and this list of conditions in documentation and/or other materials provided with the distribution. Additional documentation is not needed for executables where a command line license option provides these and a note regarding this option is in the executable&#39;s startup banner. The sole exception to this condition is redistribution of a standard UnZipSFX binary (including SFXWiz) as part of a self-extracting archive; that is permitted without inclusion of this license, as long as the normal SFX banner has not been removed from the binary or disabled.
   * Altered versions--including, but not limited to, ports to new operating systems, existing ports with new graphical interfaces, versions with modified or added functionality, and dynamic, shared, or static library versions not from Info-ZIP--must be plainly marked as such and must not be misrepresented as being the original source or, if binaries, compiled from the original source. Such altered versions also must not be misrepresented as being Info-ZIP releases--including, but not limited to, labeling of the altered versions with the names &quot;Info-ZIP&quot; (or any variation thereof, including, but not limited to, different capitalizations), &quot;Pocket UnZip,&quot; &quot;WiZ&quot; or &quot;MacZip&quot; without the explicit permission of Info-ZIP. Such altered versions are further prohibited from misrepresentative use of the Zip-Bugs or Info-ZIP e-mail addresses or the Info-ZIP URL(s), such as to imply Info-ZIP will provide support for the altered versions.
   * Info-ZIP retains the right to use the names &quot;Info-ZIP,&quot; &quot;Zip,&quot; &quot;UnZip,&quot; &quot;UnZipSFX,&quot; &quot;WiZ,&quot; &quot;Pocket UnZip,&quot; &quot;Pocket Zip,&quot; and &quot;MacZip&quot; for its own source and binary releases.
```


### GNU Lesser General Public License v3.0 or later

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
GNU LESSER GENERAL PUBLIC LICENSE
Version 3, 29 June 2007
Copyright (C) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;
Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
This version of the GNU Lesser General Public License incorporates the terms and conditions of version 3 of the GNU General Public License, supplemented by the additional permissions listed below.
   0. Additional Definitions.
      
      As used herein, &quot;this License&quot; refers to version 3 of the GNU Lesser General Public License, and the &quot;GNU GPL&quot; refers to version 3 of the GNU General Public License.
      
      &quot;The Library&quot; refers to a covered work governed by this License, other than an Application or a Combined Work as defined below.
      
      An &quot;Application&quot; is any work that makes use of an interface provided by the Library, but which is not otherwise based on the Library. Defining a subclass of a class defined by the Library is deemed a mode of using an interface provided by the Library.
      
      A &quot;Combined Work&quot; is a work produced by combining or linking an Application with the Library. The particular version of the Library with which the Combined Work was made is also called the &quot;Linked Version&quot;.
      
      The &quot;Minimal Corresponding Source&quot; for a Combined Work means the Corresponding Source for the Combined Work, excluding any source code for portions of the Combined Work that, considered in isolation, are based on the Application, and not on the Linked Version.
      
      The &quot;Corresponding Application Code&quot; for a Combined Work means the object code and/or source code for the Application, including any data and utility programs needed for reproducing the Combined Work from the Application, but excluding the System Libraries of the Combined Work.
   1. Exception to Section 3 of the GNU GPL.
   You may convey a covered work under sections 3 and 4 of this License without being bound by section 3 of the GNU GPL.
   2. Conveying Modified Versions.
   If you modify a copy of the Library, and, in your modifications, a facility refers to a function or data to be supplied by an Application that uses the facility (other than as an argument passed when the facility is invoked), then you may convey a copy of the modified version:
      a) under this License, provided that you make a good faith effort to ensure that, in the event an Application does not supply the function or data, the facility still operates, and performs whatever part of its purpose remains meaningful, or
      b) under the GNU GPL, with none of the additional permissions of this License applicable to that copy.
   3. Object Code Incorporating Material from Library Header Files.
   The object code form of an Application may incorporate material from a header file that is part of the Library. You may convey such object code under terms of your choice, provided that, if the incorporated material is not limited to numerical parameters, data structure layouts and accessors, or small macros, inline functions and templates (ten or fewer lines in length), you do both of the following:
      a) Give prominent notice with each copy of the object code that the Library is used in it and that the Library and its use are covered by this License.
      b) Accompany the object code with a copy of the GNU GPL and this license document.
   4. Combined Works.
   You may convey a Combined Work under terms of your choice that, taken together, effectively do not restrict modification of the portions of the Library contained in the Combined Work and reverse engineering for debugging such modifications, if you also do each of the following:
      a) Give prominent notice with each copy of the Combined Work that the Library is used in it and that the Library and its use are covered by this License.
      b) Accompany the Combined Work with a copy of the GNU GPL and this license document.
      c) For a Combined Work that displays copyright notices during execution, include the copyright notice for the Library among these notices, as well as a reference directing the user to the copies of the GNU GPL and this license document.
      d) Do one of the following:
         0) Convey the Minimal Corresponding Source under the terms of this License, and the Corresponding Application Code in a form suitable for, and under terms that permit, the user to recombine or relink the Application with a modified version of the Linked Version to produce a modified Combined Work, in the manner specified by section 6 of the GNU GPL for conveying Corresponding Source.
         1) Use a suitable shared library mechanism for linking with the Library. A suitable mechanism is one that (a) uses at run time a copy of the Library already present on the user&#39;s computer system, and (b) will operate properly with a modified version of the Library that is interface-compatible with the Linked Version.
      e) Provide Installation Information, but only if you would otherwise be required to provide such information under section 6 of the GNU GPL, and only to the extent that such information is necessary to install and execute a modified version of the Combined Work produced by recombining or relinking the Application with a modified version of the Linked Version. (If you use option 4d0, the Installation Information must accompany the Minimal Corresponding Source and Corresponding Application Code. If you use option 4d1, you must provide the Installation Information in the manner specified by section 6 of the GNU GPL for conveying Corresponding Source.)
   5. Combined Libraries.
   You may place library facilities that are a work based on the Library side by side in a single library together with other library facilities that are not Applications and are not covered by this License, and convey such a combined library under terms of your choice, if you do both of the following:
      a) Accompany the combined library with a copy of the same work based on the Library, uncombined with any other library facilities, conveyed under the terms of this License.
      b) Give prominent notice with the combined library that part of it is a work based on the Library, and explaining where to find the accompanying uncombined form of the same work.
   6. Revised Versions of the GNU Lesser General Public License.
   The Free Software Foundation may publish revised and/or new versions of the GNU Lesser General Public License from time to time. Such new versions will be similar in spirit to the present version, but may differ in detail to address new problems or concerns.
   Each version is given a distinguishing version number. If the Library as you received it specifies that a certain numbered version of the GNU Lesser General Public License &quot;or any later version&quot; applies to it, you have the option of following the terms and conditions either of that published version or of any later version published by the Free Software Foundation. If the Library as you received it does not specify a version number of the GNU Lesser General Public License, you may choose any version of the GNU Lesser General Public License ever published by the Free Software Foundation.
   If the Library as you received it specifies that a proxy can decide whether future versions of the GNU Lesser General Public License shall apply, that proxy&#39;s public statement of acceptance of any version is permanent authorization for you to choose that version for the Library.
```


### MIT License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2012 Erik Rose

Copyright (c) 2013 Julian Berman

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2023 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2022 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 2023 Google LLC

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c) Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) is shown in the HTML footer. Default is True.


```
MIT License
Copyright (c) &lt;year&gt; &lt;copyright holders&gt;

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```


### Mozilla Public License 2.0

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Mozilla Public License Version 2.0
   1. Definitions
      1.1. &quot;Contributor&quot; means each individual or legal entity that creates, contributes to the creation of, or owns Covered Software.
      1.2. &quot;Contributor Version&quot; means the combination of the Contributions of others (if any) used by a Contributor and that particular Contributor&#39;s Contribution.
      1.3. &quot;Contribution&quot; means Covered Software of a particular Contributor.
      1.4. &quot;Covered Software&quot; means Source Code Form to which the initial Contributor has attached the notice in Exhibit A, the Executable Form of such Source Code Form, and Modifications of such Source Code Form, in each case including portions thereof.
      1.5. &quot;Incompatible With Secondary Licenses&quot; means
         (a) that the initial Contributor has attached the notice described in Exhibit B to the Covered Software; or
         (b) that the Covered Software was made available under the terms of version 1.1 or earlier of the License, but not also under the terms of a Secondary License.
      1.6. &quot;Executable Form&quot; means any form of the work other than Source Code Form.
      1.7. &quot;Larger Work&quot; means a work that combines Covered Software with other material, in a separate file or files, that is not Covered Software.
      1.8. &quot;License&quot; means this document.
      1.9. &quot;Licensable&quot; means having the right to grant, to the maximum extent possible, whether at the time of the initial grant or subsequently, any and all of the rights conveyed by this License.
      1.10. &quot;Modifications&quot; means any of the following:
         (a) any file in Source Code Form that results from an addition to, deletion from, or modification of the contents of Covered Software; or
         (b) any new file in Source Code Form that contains any Covered Software.
      1.11. &quot;Patent Claims&quot; of a Contributor means any patent claim(s), including without limitation, method, process, and apparatus claims, in any patent Licensable by such Contributor that would be infringed, but for the grant of the License, by the making, using, selling, offering for sale, having made, import, or transfer of either its Contributions or its Contributor Version.
      1.12. &quot;Secondary License&quot; means either the GNU General Public License, Version 2.0, the GNU Lesser General Public License, Version 2.1, the GNU Affero General Public License, Version 3.0, or any later versions of those licenses.
      1.13. &quot;Source Code Form&quot; means the form of the work preferred for making modifications.
      1.14. &quot;You&quot; (or &quot;Your&quot;) means an individual or a legal entity exercising rights under this License. For legal entities, &quot;You&quot; includes any entity that controls, is controlled by, or is under common control with You. For purposes of this definition, &quot;control&quot; means (a) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (b) ownership of more than fifty percent (50%) of the outstanding shares or beneficial ownership of such entity.
   2. License Grants and Conditions
      2.1. Grants
      Each Contributor hereby grants You a world-wide, royalty-free, non-exclusive license:
         (a) under intellectual property rights (other than patent or trademark) Licensable by such Contributor to use, reproduce, make available, modify, display, perform, distribute, and otherwise exploit its Contributions, either on an unmodified basis, with Modifications, or as part of a Larger Work; and
         (b) under Patent Claims of such Contributor to make, use, sell, offer for sale, have made, import, and otherwise transfer either its Contributions or its Contributor Version.
      2.2. Effective Date
      The licenses granted in Section 2.1 with respect to any Contribution become effective for each Contribution on the date the Contributor first distributes such Contribution.
      2.3. Limitations on Grant Scope
      The licenses granted in this Section 2 are the only rights granted under this License. No additional rights or licenses will be implied from the distribution or licensing of Covered Software under this License. Notwithstanding Section 2.1(b) above, no patent license is granted by a Contributor:
         (a) for any code that a Contributor has removed from Covered Software; or
         (b) for infringements caused by: (i) Your and any other third party&#39;s modifications of Covered Software, or (ii) the combination of its Contributions with other software (except as part of its Contributor Version); or
         (c) under Patent Claims infringed by Covered Software in the absence of its Contributions.
      This License does not grant any rights in the trademarks, service marks, or logos of any Contributor (except as may be necessary to comply with the notice requirements in Section 3.4).
      2.4. Subsequent Licenses
      No Contributor makes additional grants as a result of Your choice to distribute the Covered Software under a subsequent version of this License (see Section 10.2) or under the terms of a Secondary License (if permitted under the terms of Section 3.3).
      2.5. Representation
      Each Contributor represents that the Contributor believes its Contributions are its original creation(s) or it has sufficient rights to grant the rights to its Contributions conveyed by this License.
      2.6. Fair Use
      This License is not intended to limit any rights You have under applicable copyright doctrines of fair use, fair dealing, or other equivalents.
      2.7. Conditions
      Sections 3.1, 3.2, 3.3, and 3.4 are conditions of the licenses granted in Section 2.1.
   3. Responsibilities
      3.1. Distribution of Source Form
      All distribution of Covered Software in Source Code Form, including any Modifications that You create or to which You contribute, must be under the terms of this License. You must inform recipients that the Source Code Form of the Covered Software is governed by the terms of this License, and how they can obtain a copy of this License. You may not attempt to alter or restrict the recipients&#39; rights in the Source Code Form.
      3.2. Distribution of Executable Form
      If You distribute Covered Software in Executable Form then:
         (a) such Covered Software must also be made available in Source Code Form, as described in Section 3.1, and You must inform recipients of the Executable Form how they can obtain a copy of such Source Code Form by reasonable means in a timely manner, at a charge no more than the cost of distribution to the recipient; and
         (b) You may distribute such Executable Form under the terms of this License, or sublicense it under different terms, provided that the license for the Executable Form does not attempt to limit or alter the recipients&#39; rights in the Source Code Form under this License.
      3.3. Distribution of a Larger Work
      You may create and distribute a Larger Work under terms of Your choice, provided that You also comply with the requirements of this License for the Covered Software. If the Larger Work is a combination of Covered Software with a work governed by one or more Secondary Licenses, and the Covered Software is not Incompatible With Secondary Licenses, this License permits You to additionally distribute such Covered Software under the terms of such Secondary License(s), so that the recipient of the Larger Work may, at their option, further distribute the Covered Software under the terms of either this License or such Secondary License(s).
      3.4. Notices
      You may not remove or alter the substance of any license notices (including copyright notices, patent notices, disclaimers of warranty, or limitations of liability) contained within the Source Code Form of the Covered Software, except that You may alter any license notices to the extent required to remedy known factual inaccuracies.
      3.5. Application of Additional Terms
      You may choose to offer, and to charge a fee for, warranty, support, indemnity or liability obligations to one or more recipients of Covered Software. However, You may do so only on Your own behalf, and not on behalf of any Contributor. You must make it absolutely clear that any such warranty, support, indemnity, or liability obligation is offered by You alone, and You hereby agree to indemnify every Contributor for any liability incurred by such Contributor as a result of warranty, support, indemnity or liability terms You offer. You may include additional disclaimers of warranty and limitations of liability specific to any jurisdiction.
   4. Inability to Comply Due to Statute or Regulation
   If it is impossible for You to comply with any of the terms of this License with respect to some or all of the Covered Software due to statute, judicial order, or regulation then You must: (a) comply with the terms of this License to the maximum extent possible; and (b) describe the limitations and the code they affect. Such description must be placed in a text file included with all distributions of the Covered Software under this License. Except to the extent prohibited by statute or regulation, such description must be sufficiently detailed for a recipient of ordinary skill to be able to understand it.
   5. Termination
      5.1. The rights granted under this License will terminate automatically if You fail to comply with any of its terms. However, if You become compliant, then the rights granted under this License from a particular Contributor are reinstated (a) provisionally, unless and until such Contributor explicitly and finally terminates Your grants, and (b) on an ongoing basis, if such Contributor fails to notify You of the non-compliance by some reasonable means prior to 60 days after You have come back into compliance. Moreover, Your grants from a particular Contributor are reinstated on an ongoing basis if such Contributor notifies You of the non-compliance by some reasonable means, this is the first time You have received notice of non-compliance with this License from such Contributor, and You become compliant prior to 30 days after Your receipt of the notice.
      5.2. If You initiate litigation against any entity by asserting a patent infringement claim (excluding declaratory judgment actions, counter-claims, and cross-claims) alleging that a Contributor Version directly or indirectly infringes any patent, then the rights granted to You by any and all Contributors for the Covered Software under Section 2.1 of this License shall terminate.
      5.3. In the event of termination under Sections 5.1 or 5.2 above, all end user license agreements (excluding distributors and resellers) which have been validly granted by You or Your distributors under this License prior to termination shall survive termination.
   6. Disclaimer of Warranty
   Covered Software is provided under this License on an &quot;as is&quot; basis, without warranty of any kind, either expressed, implied, or statutory, including, without limitation, warranties that the Covered Software is free of defects, merchantable, fit for a particular purpose or non-infringing. The entire risk as to the quality and performance of the Covered Software is with You. Should any Covered Software prove defective in any respect, You (not any Contributor) assume the cost of any necessary servicing, repair, or correction. This disclaimer of warranty constitutes an essential part of this License. No use of any Covered Software is authorized under this License except under this disclaimer.
   7. Limitation of Liability
   Under no circumstances and under no legal theory, whether tort (including negligence), contract, or otherwise, shall any Contributor, or anyone who distributes Covered Software as permitted above, be liable to You for any direct, indirect, special, incidental, or consequential damages of any character including, without limitation, damages for lost profits, loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses, even if such party shall have been informed of the possibility of such damages. This limitation of liability shall not apply to liability for death or personal injury resulting from such party&#39;s negligence to the extent applicable law prohibits such limitation. Some jurisdictions do not allow the exclusion or limitation of incidental or consequential damages, so this exclusion and limitation may not apply to You.
   8. Litigation
   Any litigation relating to this License may be brought only in the courts of a jurisdiction where the defendant maintains its principal place of business and such litigation shall be governed by laws of that jurisdiction, without reference to its conflict-of-law provisions. Nothing in this Section shall prevent a party&#39;s ability to bring cross-claims or counter-claims.
   9. Miscellaneous
   This License represents the complete agreement concerning the subject matter hereof. If any provision of this License is held to be unenforceable, such provision shall be reformed only to the extent necessary to make it enforceable. Any law or regulation which provides that the language of a contract shall be construed against the drafter shall not be used to construe this License against a Contributor.
   10. Versions of the License
      10.1. New Versions
      Mozilla Foundation is the license steward. Except as provided in Section 10.3, no one other than the license steward has the right to modify or publish new versions of this License. Each version will be given a distinguishing version number.
      10.2. Effect of New Versions
      You may distribute the Covered Software under the terms of the version of the License under which You originally received the Covered Software, or under the terms of any subsequent version published by the license steward.
      10.3. Modified Versions
      If you create software not governed by this License, and you want to create a new license for such software, you may create and use a modified version of this License if you rename the license and remove any references to the name of the license steward (except to note that such modified license differs from this License).
      10.4. Distributing Source Code Form that is Incompatible With Secondary Licenses
      If You choose to distribute Source Code Form that is Incompatible With Secondary Licenses under the terms of this version of the License, the notice described in Exhibit B of this License must be attached. Exhibit A - Source Code Form License Notice
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
If it is not possible or desirable to put the notice in a particular file, then You may include the notice in a location (such as a LICENSE file in a relevant directory) where a recipient would be likely to look for such a notice.
You may add additional accurate notices of copyright ownership.
Exhibit B - &quot;Incompatible With Secondary Licenses&quot; Notice
This Source Code Form is &quot;Incompatible With Secondary Licenses&quot;, as defined by the Mozilla Public License, v. 2.0.
```


### University of Illinois/NCSA Open Source License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
University of Illinois/NCSA Open Source License
Copyright (c) &lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.
Developed by: 
&lt;Name of Development Group&gt;
&lt;Name of Institution&gt;
&lt;URL for Development Group/Institution&gt;
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal with the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
   * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimers.
   * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimers in the documentation and/or other materials provided with the distribution.
   * Neither the names of &lt;Name of Development Group, Name of Institution&gt; , nor the names of its contributors may be used to endorse or promote products derived from this Software without specific prior written permission.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
```


### Open LDAP Public License v1.1

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
The OpenLDAP Public License
Version 1.1, 25 August 1998
Copyright 1998, The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;
PREAMBLE
The intent of this document is to state the conditions under which a Package may be copied, such that the Copyright Holder maintains some semblance of artistic control over the development of the package, while giving the users of the package the right to use and distribute the Package in a more-or-less customary fashion, plus the right to make reasonable modifications.
Definitions:
&quot;Package&quot; refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
&quot;Standard Version&quot; refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder.
&quot;Copyright Holder&quot; is whoever is named in the copyright or copyrights for the package.
&quot;You&quot; is you, if you&#39;re thinking about copying or distributing this Package.
&quot;Reasonable copying fee&quot; is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
&quot;Freely Available&quot; means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as uunet.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
      b) use the modified Package only within your corporation or organization.
      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
      b) accompany the distribution with the machine-readable source of the Package with your modifications.
      c) accompany any non-standard executables with their corresponding Standard Version executables, giving the non-standard executables non-standard names, and clearly documenting the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
      d) make other distribution arrangements with the Copyright Holder.
   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own.
   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.
   7. C subroutines supplied by you and linked into this Package in order to emulate subroutines and variables of the language defined by this Package shall not be considered part of this Package, but are the equivalent of input as in Paragraph 6, provided these subroutines do not change the language in any way that would cause it to fail the regression tests for the language.
   8. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
   9. THIS PACKAGE IS PROVIDED &quot;AS IS&quot; AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE. The End
```


### Open Public License v1.0

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
OPEN PUBLIC LICENSE
Version 1.0
   1. Definitions.
      1.1. &quot;Contributor&quot; means each entity that creates or contributes to the creation of Modifications.
      1.2. &quot;Contributor Version&quot; means the combination of the Original Code, prior Modifications used by a Contributor, and the Modifications made by that particular Contributor.
      1.3. &quot;Covered Code&quot; means the Original Code or Modifications or the combination of the Original Code and Modifications, in each case including portions thereof.
      1.4. &quot;Electronic Distribution Mechanism&quot; means a mechanism generally accepted in the software development community for the electronic transfer of data.
      1.5. &quot;Executable&quot; means Covered Code in any form other than Source Code.
      1.6. &quot;Initial Developer&quot; means the individual or entity identified as the Initial Developer in the Source Code notice required by Exhibit A.
      1.7. &quot;Larger Work&quot; means a work, which combines Covered Code or portions thereof with code not governed by the terms of this License.
      1.8. &quot;License&quot; means this document and the corresponding addendum described in section 6.4 below.
      1.9. &quot;Modifications&quot; means any addition to or deletion from the substance or structure of either the Original Code or any previous Modifications. When Covered Code is released as a series of files, a Modification is:
         A. Any addition to or deletion from the contents of a file containing Original Code or previous Modifications.
         B. Any new file that contains any part of the Original Code or previous Modifications.
      1.10. &quot;Original Code&quot; means Source Code of computer software code which is described in the Source Code notice required by Exhibit A as Original Code, and which, at the time of its release under this License is not already Covered Code governed by this License.
      1.11. &quot;Source Code&quot; means the preferred form of the Covered Code for making modifications to it, including all modules it contains, plus any associated interface definition files, scripts used to control compilation and installation of an Executable, or a list of source code differential comparisons against either the Original Code or another well known, available Covered Code of the Contributor&#39;s choice. The Source Code can be in a compressed or archival form, provided the appropriate decompression or de-archiving software is widely available for no charge.
      1.12. &quot;You&quot; means an individual or a legal entity exercising rights under, and complying with all of the terms of, this License or a future version of this License issued under Section 6.1. For legal entities, &quot;You&#39;&#39; includes any entity which controls, is controlled by, or is under common control with You. For purposes of this definition, &quot;control&#39;&#39; means (a) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (b) ownership of fifty percent (50%) or more of the outstanding shares or beneficial ownership of such entity.
      1.13 &quot;License Author&quot; means Lutris Technologies, Inc.
   2. Source Code License.
      2.1. The Initial Developer Grant. The Initial Developer hereby grants You a worldwide, royalty-free, non-exclusive license, subject to third party intellectual property claims:
         (a) under intellectual property rights (other than patent or trademark) to use, reproduce, modify, display, perform, sublicense and distribute the Original Code (or portions thereof) with or without Modifications, or as part of a Larger Work; and
         (b) under patents now or hereafter owned or controlled by Initial Developer, to make, have made, use and sell (``offer to sell and import&#39;&#39;) the Original Code (or portions thereof), but solely to the extent that any such patent is reasonably necessary to enable You to Utilize the Original Code (or portions thereof) and not to any greater extent that may be necessary to Utilize further Modifications or combinations.
      2.2. Contributor Grant. Each Contributor hereby grants You a worldwide, royalty-free, non-exclusive license, subject to third party intellectual property claims:
         (a) under intellectual property rights (other than patent or trademark) to use, reproduce, modify, display, perform, sublicense and distribute the Modifications created by such Contributor (or portions thereof) either on an unmodified basis, with other Modifications, as Covered Code or as part of a Larger Work; and
         (b) under patents now or hereafter owned or controlled by Contributor, to to make, have made, use and sell (``offer to sell and import&#39;&#39;) the Contributor Version (or portions thereof), but solely to the extent that any such patent is reasonably necessary to enable You to Utilize the Contributor Version (or portions thereof), and not to any greater extent that may be necessary to Utilize further Modifications or combinations
   3. Distribution Obligations.
      3.1. Application of License. The Modifications which You create or to which You contribute are governed by the terms of this License, including without limitation Section 2.2. The Source Code version of Covered Code may be distributed only under the terms of this License or a future version of this License released under Section 6.1, and You must include a copy of this License with every copy of the Source Code You distribute. You may not offer or impose any terms on any Source Code version that alters or restricts the applicable version of this License or the recipients&#39; rights hereunder. However, You may include an additional document offering the additional rights described in Section 3.5.
      3.2. Availability of Source Code. Any Modification which You create or to which You contribute must be made available, prior to any use, except for internal development and practice, in Source Code form under the terms of this License either on the same media as an Executable version or via an accepted Electronic Distribution Mechanism to anyone to whom you made an Executable version available; and if made available via Electronic Distribution Mechanism, must remain available for at least twelve (12) months after the date it initially became available, or at least six (6) months after a subsequent version of that particular Modification has been made available to such recipients. You shall notify the Initial Developer of the Modification and the location of the Source Code via the contact means provided for in the Developer Specific license. Initial Developer will be acting as maintainer of the Source Code and may provide an Electronic Distribution mechanism for the Modification to be made available.
      3.3. Description of Modifications. You must cause all Covered Code to which you contribute to contain a file documenting the changes You made to create that Covered Code and the date of any change. You must include a prominent statement that the Modification is derived, directly or indirectly, from Original Code provided by the Initial Developer and including the name of the Initial Developer in (a) the Source Code, and (b) in any notice in an Executable version or related documentation in which You describe the origin or ownership of the Covered Code.
      3.4. Intellectual Property Matters
         (a) Third Party Claims. If You have knowledge that a party claims an intellectual property right in particular functionality or code (or its utilization under this License), you must include a text file with the source code distribution titled &quot;LEGAL&quot; which describes the claim and the party making the claim in sufficient detail that a recipient will know whom to contact. If you obtain such knowledge after You make Your Modification available as described in Section 3.2, You shall promptly modify the LEGAL file in all copies You make available thereafter and shall take other steps (such as notifying appropriate mailing lists or newsgroups) reasonably calculated to inform those who received the Covered Code that new knowledge has been obtained.
         (b) Representations. Contributor represents that, except as disclosed pursuant to Section 3.4(a) above, Contributor believes that Contributor&#39;s Modifications are Contributor&#39;s original creation(s) and/or Contributor has sufficient rights to grant the rights conveyed by this License.
      3.5. Required Notices. You must duplicate the notice in Exhibit A in each file of the Source Code, and this License in any documentation for the Source Code, where You describe recipients&#39; rights relating to Covered Code. If You created one or more Modification(s), You may add your name as a Contributor to the notice described in Exhibit A. If it is not possible to put such notice in a particular Source Code file due to its structure, then you must include such notice in a location (such as a relevant directory file) where a user would be likely to look for such a notice. You may choose to offer, and to charge a fee for, warranty, support, indemnity or liability obligations to one or more recipients of Covered Code. However, You may do so only on Your own behalf, and not on behalf of the Initial Developer or any Contributor. You must make it absolutely clear that any such warranty, support, indemnity or liability obligation is offered by You alone, and You hereby agree to indemnify the Initial Developer and every Contributor for any liability incurred by the Initial Developer or such Contributor as a result of warranty, support, indemnity or liability terms You offer.
      3.6. Distribution of Executable Versions. You may distribute Covered Code in Executable form only if the requirements of Section 3.1-3.5 have been met for that Covered Code, and if You include a notice stating that the Source Code version of the Covered Code is available under the terms of this License, including a description of how and where You have fulfilled the obligations of Section 3.2. The notice must be conspicuously included in any notice in an Executable version, related documentation or collateral in which You describe recipients&#39; rights relating to the Covered Code. You may distribute the Executable version of Covered Code under a license of Your choice, which may contain terms different from this License, provided that You are in compliance with the terms of this License and that the license for the Executable version does not attempt to limit or alter the recipient&#39;s rights in the Source Code version from the rights set forth in this License. If You distribute the Executable version under a different license You must make it absolutely clear that any terms which differ from this License are offered by You alone, not by the Initial Developer or any Contributor. You hereby agree to indemnify the Initial Developer and every Contributor for any liability incurred by the Initial Developer or such Contributor as a result of any such terms You offer. If you distribute executable versions containing Covered Code, you must reproduce the notice in Exhibit B in the documentation and/or other materials provided with the product.
      3.7. Larger Works. You may create a Larger Work by combining Covered Code with other code not governed by the terms of this License and distribute the Larger Work as a single product. In such a case, You must make sure the requirements of this License are fulfilled for the Covered Code.
   4. Inability to Comply Due to Statute or Regulation.
   If it is impossible for You to comply with any of the terms of this License with respect to some or all of the Covered Code due to statute or regulation then You must: (a) comply with the terms of this License to the maximum extent possible; and (b) Cite all of the statutes or regulations that prohibit you from complying fully with this license. (c) describe the limitations and the code they affect. Such description must be included in the LEGAL file described in Section 3.4 and must be included with all distributions of the Source Code. Except to the extent prohibited by statute or regulation, such description must be sufficiently detailed for a recipient of ordinary skill to be able to understand it.
   5. Application of this License.
   This License applies to code to which the Initial Developer has attached the notice in Exhibit A, and to related Covered Code.
   6. Versions of the License.
      6.1. New Versions. License Author may publish revised and/or new versions of the License from time to time. Each version will be given a distinguishing version number and shall be submitted to opensource.org for certification.
      6.2. Effect of New Versions. Once Covered Code has been published under a particular version of the License, You may always continue to use it under the terms of that version. You may also choose to use such Covered Code under the terms of any subsequent version of the License published by Initial Developer. No one other than Initial Developer has the right to modify the terms applicable to Covered Code created under this License.
      6.3. Derivative Works. If you create or use a modified version of this License, except in association with the required Developer Specific License described in section 6.4, (which you may only do in order to apply it to code which is not already Covered Code governed by this License), you must (a) rename Your license so that the phrases ``Open&#39;&#39;, ``OpenPL&#39;&#39;, ``OPL&#39;&#39; or any confusingly similar phrase do not appear anywhere in your license and (b) otherwise make it clear that your version of the license contains terms which differ from the Open Public License. (Filling in the name of the Initial Developer, Original Code or Contributor in the notice described in Exhibit A shall not of themselves be deemed to be modifications of this License.)
      6.4. Required Additional Developer Specific License
      This license is a union of the following two parts that should be found as text files in the same place (directory), in the order of preeminence:
         [1] A Developer specific license.
         [2] The contents of this file OPL_1_0.TXT, stating the general licensing policy of the software.
      In case of conflicting dispositions in the parts of this license, the terms of the lower-numbered part will always be superseded by the terms of the higher numbered part.
   7. DISCLAIMER OF WARRANTY.
   COVERED CODE IS PROVIDED UNDER THIS LICENSE ON AN &quot;AS IS&quot; BASIS, WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTIES THAT THE COVERED CODE IS FREE OF DEFECTS, MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE OR NON-INFRINGING. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE COVERED CODE IS WITH YOU. SHOULD ANY COVERED CODE PROVE DEFECTIVE IN ANY RESPECT, YOU (NOT THE INITIAL DEVELOPER OR ANY OTHER CONTRIBUTOR) ASSUME THE COST OF ANY NECESSARY SERVICING, REPAIR OR CORRECTION. THIS DISCLAIMER OF WARRANTY CONSTITUTES AN ESSENTIAL PART OF THIS LICENSE. NO USE OF ANY COVERED CODE IS AUTHORIZED HEREUNDER EXCEPT UNDER THIS DISCLAIMER.
   8. TERMINATION.
      8.1 Termination upon Breach
      This License and the rights granted hereunder will terminate automatically if You fail to comply with terms herein and fail to cure such breach within 30 days of becoming aware of the breach. All sublicenses to the Covered Code, which are properly granted, shall survive any termination of this License. Provisions that, by their nature, must remain in effect beyond the termination of this License shall survive.
      8.2. Termination Upon Litigation. If You initiate litigation by asserting a patent infringement claim (excluding declatory judgment actions) against Initial Developer or a Contributor (the Initial Developer or Contributor against whom You file such action is referred to as &quot;Participant&quot;) alleging that:
         (a) such Participant&#39;s Contributor Version directly or indirectly infringes any patent, then any and all rights granted by such Participant to You under Sections 2.1 and/or 2.2 of this License shall, upon 60 days notice from Participant terminate prospectively, unless if within 60 days after receipt of notice You either: (i) agree in writing to pay Participant a mutually agreeable reasonable royalty for Your past and future use of Modifications made by such Participant, or (ii) withdraw Your litigation claim with respect to the Contributor Version against such Participant. If within 60 days of notice, a reasonable royalty and payment arrangement are not mutually agreed upon in writing by the parties or the litigation claim is not withdrawn, the rights granted by Participant to You under Sections 2.1 and/or 2.2 automatically terminate at the expiration of the 60 day notice period specified above.
         (b) any software, hardware, or device, other than such Participant&#39;s Contributor Version, directly or indirectly infringes any patent, then any rights granted to You by such Participant under Sections 2.1(b) and 2.2(b) are revoked effective as of the date You first made, used, sold, distributed, or had made, Modifications made by that Participant.
      8.3. If You assert a patent infringement claim against Participant alleging that such Participant&#39;s Contributor Version directly or indirectly infringes any patent where such claim is resolved (such as by license or settlement) prior to the initiation of patent infringement litigation, then the reasonable value of the licenses granted by such Participant under Sections 2.1 or 2.2 shall be taken into account in determining the amount or value of any payment or license.
      8.4. In the event of termination under Sections 8.1 or 8.2 above, all end user license agreements (excluding distributors and resellers) which have been validly granted by You or any distributor hereunder prior to termination shall survive termination.
   9. LIMITATION OF LIABILITY.
   UNDER NO CIRCUMSTANCES AND UNDER NO LEGAL THEORY, WHETHER TORT (INCLUDING NEGLIGENCE), CONTRACT, OR OTHERWISE, SHALL THE INITIAL DEVELOPER, ANY OTHER CONTRIBUTOR, OR ANY DISTRIBUTOR OF COVERED CODE, OR ANY SUPPLIER OF ANY OF SUCH PARTIES, BE LIABLE TO YOU OR ANY OTHER PERSON FOR ANY INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES OF ANY CHARACTER INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF GOODWILL, WORK STOPPAGE, COMPUTER FAILURE OR MALFUNCTION, OR ANY AND ALL OTHER COMMERCIAL DAMAGES OR LOSSES, EVEN IF SUCH PARTY SHALL HAVE BEEN INFORMED OF THE POSSIBILITY OF SUCH DAMAGES. THIS LIMITATION OF LIABILITY SHALL NOT APPLY TO LIABILITY FOR DEATH OR PERSONAL INJURY RESULTING FROM SUCH PARTY&#39;S NEGLIGENCE TO THE EXTENT APPLICABLE LAW PROHIBITS SUCH LIMITATION. SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OR LIMITATION OF INCIDENTAL OR CONSEQUENTIAL DAMAGES, SO THAT EXCLUSION AND LIMITATION MAY NOT APPLY TO YOU.
   10. U.S. GOVERNMENT END USERS.
   The Covered Code is a ``commercial item,&#39;&#39; as that term is defined in 48 C.F.R. 2.101 (Oct. 1995), consisting of ``commercial computer software&#39;&#39; and ``commercial computer software documentation,&#39;&#39; as such terms are used in 48 C.F.R. 12.212 (Sept. 1995). Consistent with 48 C.F.R. 12.212 and 48 C.F.R. 227.7202-1 through 227.7202-4 (June 1995), all U.S. Government End Users acquire Covered Code with only those rights set forth herein.
   11. MISCELLANEOUS.
   his section was intentionally left blank. The contents of this section are found in the corresponding addendum described above.
   12. RESPONSIBILITY FOR CLAIMS.
Except in cases where another Contributor has failed to comply with Section 3.4, You are responsible for damages arising, directly or indirectly, out of Your utilization of rights under this License, based on the number of copies of Covered Code you made available, the revenues you received from utilizing such rights, and other relevant factors. You agree to work with affected parties to distribute with Initial Developer responsibility on an equitable basis. EXHIBIT A.
Text for this Exhibit A is found in the corresponding addendum, described in section 6.4 above, text file provided by the Initial Developer. This license is not valid or complete with out that file.
EXHIBIT B.
Text for this Exhibit B is found in the corresponding addendum, described in section 6.4 above, text file provided by the Initial Developer. This license is not valid or complete with out that file.
```


### Python Software License Agreement 2.0

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
PYTHON SOFTWARE FOUNDATION LICENSE VERSION 2

  1. This LICENSE AGREEMENT is between the Python Software Foundation (&quot;PSF&quot;), and the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using this software (&quot;Python&quot;) in source or binary form and its associated documentation.
  2. Subject to the terms and conditions of this License Agreement, PSF hereby grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python alone or in any derivative version, provided, however, that PSF&#39;s License Agreement and PSF&#39;s notice of copyright, i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.
  3. In the event Licensee prepares a derivative work that is based on or incorporates Python or any part thereof, and wants to make the derivative work available to others as provided herein, then Licensee hereby agrees to include in any such work a brief summary of the changes made to Python.
  4. PSF is making Python available to Licensee on an &quot;AS IS&quot; basis. PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
  5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
  6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
  7. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between PSF and Licensee. This License Agreement does not grant permission to use PSF trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
  8. By copying, installing or otherwise using Python, Licensee agrees to be bound by the terms and conditions of this License Agreement.
```


### Protobuf

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Copyright 2008 Google Inc.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.
    * Neither the name of Google Inc. nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
&quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Code generated by the Protocol Buffer compiler is owned by the owner
of the input file used when generating it.  This code is not
standalone and requires a support library to be linked with it.  This
support library is itself covered by the above license.
```


### Python License 2.0

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
PYTHON SOFTWARE FOUNDATION LICENSE VERSION 2
   1. This LICENSE AGREEMENT is between the Python Software Foundation (&quot;PSF&quot;), and the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using this software (&quot;Python&quot;) in source or binary form and its associated documentation.
   2. Subject to the terms and conditions of this License Agreement, PSF hereby grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python alone or in any derivative version, provided, however, that PSF&#39;s License Agreement and PSF&#39;s notice of copyright, i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python or any part thereof, and wants to make the derivative work available to others as provided herein, then Licensee hereby agrees to include in any such work a brief summary of the changes made to Python.
   4. PSF is making Python available to Licensee on an &quot;AS IS&quot; basis. PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between PSF and Licensee. This License Agreement does not grant permission to use PSF trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By copying, installing or otherwise using Python, Licensee agrees to be bound by the terms and conditions of this License Agreement. BEOPEN.COM LICENSE AGREEMENT FOR PYTHON 2.0
BEOPEN PYTHON OPEN SOURCE LICENSE AGREEMENT VERSION 1
   1. This LICENSE AGREEMENT is between BeOpen.com (&quot;BeOpen&quot;), having an office at 160 Saratoga Avenue, Santa Clara, CA 95051, and the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using this software in source or binary form and its associated documentation (&quot;the Software&quot;).
   2. Subject to the terms and conditions of this BeOpen Python License Agreement, BeOpen hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use the Software alone or in any derivative version, provided, however, that the BeOpen Python License is retained in the Software, alone or in any derivative version prepared by Licensee.
   3. BeOpen is making the Software available to Licensee on an &quot;AS IS&quot; basis. BEOPEN MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, BEOPEN MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF THE SOFTWARE WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   4. BEOPEN SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THE SOFTWARE, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   5. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   6. This License Agreement shall be governed by and interpreted in all respects by the law of the State of California, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between BeOpen and Licensee. This License Agreement does not grant permission to use BeOpen trademarks or trade names in a trademark sense to endorse or promote products or services of Licensee, or any third party. As an exception, the &quot;BeOpen Python&quot; logos available at http://www.pythonlabs.com/logos.html may be used according to the permissions granted on that web page.
   7. By copying, installing or otherwise using the software, Licensee agrees to be bound by the terms and conditions of this License Agreement. CNRI OPEN SOURCE LICENSE AGREEMENT (for Python 1.6b1) IMPORTANT: PLEASE READ THE FOLLOWING AGREEMENT CAREFULLY.
BY CLICKING ON &quot;ACCEPT&quot; WHERE INDICATED BELOW, OR BY COPYING, INSTALLING OR OTHERWISE USING PYTHON 1.6, beta 1 SOFTWARE, YOU ARE DEEMED TO HAVE AGREED TO THE TERMS AND CONDITIONS OF THIS LICENSE AGREEMENT.
   1. This LICENSE AGREEMENT is between the Corporation for National Research Initiatives, having an office at 1895 Preston White Drive, Reston, VA 20191 (&quot;CNRI&quot;), and the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using Python 1.6, beta 1 software in source or binary form and its associated documentation, as released at the www.python.org Internet site on August 4, 2000 (&quot;Python 1.6b1&quot;).
   2. Subject to the terms and conditions of this License Agreement, CNRI hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python 1.6b1 alone or in any derivative version, provided, however, that CNRIs License Agreement is retained in Python 1.6b1, alone or in any derivative version prepared by Licensee.
   Alternately, in lieu of CNRIs License Agreement, Licensee may substitute the following text (omitting the quotes): &quot;Python 1.6, beta 1, is made available subject to the terms and conditions in CNRIs License Agreement. This Agreement may be located on the Internet using the following unique, persistent identifier (known as a handle): 1895.22/1011. This Agreement may also be obtained from a proxy server on the Internet using the URL:http://hdl.handle.net/1895.22/1011&quot;.
   3. In the event Licensee prepares a derivative work that is based on or incorporates Python 1.6b1 or any part thereof, and wants to make the derivative work available to the public as provided herein, then Licensee hereby agrees to indicate in any such work the nature of the modifications made to Python 1.6b1.
   4. CNRI is making Python 1.6b1 available to Licensee on an &quot;AS IS&quot; basis. CNRI MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, CNRI MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON 1.6b1 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
   5. CNRI SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING PYTHON 1.6b1, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
   7. This License Agreement shall be governed by and interpreted in all respects by the law of the State of Virginia, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between CNRI and Licensee. This License Agreement does not grant permission to use CNRI trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
   8. By clicking on the &quot;ACCEPT&quot; button where indicated, or by copying, installing or otherwise using Python 1.6b1, Licensee agrees to be bound by the terms and conditions of this License Agreement. ACCEPT CWI LICENSE AGREEMENT FOR PYTHON 0.9.0 THROUGH 1.2
Copyright (c) 1991 - 1995, Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.
Permission to use, copy, modify, and distribute this software and its documentation for any purpose and without fee is hereby granted, provided that the above copyright notice appear in all copies and that both that copyright notice and this permission notice appear in supporting documentation, and that the name of Stichting Mathematisch Centrum or CWI not be used in advertising or publicity pertaining to distribution of the software without specific, written prior permission.
STICHTING MATHEMATISCH CENTRUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL STICHTING MATHEMATISCH CENTRUM BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
```


### SunPro Attribution License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Copyright (C) 1993 by Sun Microsystems, Inc. All rights reserved.
Developed at SunPro, a Sun Microsystems, Inc. business.

Permission to use, copy, modify, and distribute this
software is freely granted, provided that this notice
is preserved.
```


### The Unlicense

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
This is free and unencumbered software released into the public domain.
Anyone is free to copy, modify, publish, use, compile, sell, or distribute this software, either in source code form or as a compiled binary, for any purpose, commercial or non-commercial, and by any means.
In jurisdictions that recognize copyright laws, the author or authors of this software dedicate any and all copyright interest in the software to the public domain. We make this dedication for the benefit of the public at large and to the detriment of our heirs and
successors. We intend this dedication to be an overt act of relinquishment in perpetuity of all present and future rights to this software under copyright law.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
For more information, please refer to &lt;http://unlicense.org/&gt;
```


### X11 License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) year info

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
X11 License
Copyright (C) 1996 X Consortium
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
Except as contained in this notice, the name of the X Consortium shall not be used in advertising or otherwise to promote the sale, use or other dealings in this Software without prior written authorization from the X Consortium.
X Window System is a trademark of X Consortium, Inc.
```


### zlib License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2021 Orson Peters

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
zlib License Copyright (c) &lt;year&gt; &lt;copyright holders&gt;
This software is provided &#39;as-is&#39;, without any express or implied warranty. In no event will the authors be held liable for any damages arising from the use of this software.
Permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the following restrictions:
   1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
   2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.
```


### BSD 2-Clause with views sentence

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS&#39;&#39; AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those
of the authors and should not be interpreted as representing official policies,
either expressed or implied, of the FreeBSD Project.
```


### BSD 3-Clause Open MPI variant

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
  notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
  notice, this list of conditions and the following disclaimer listed
  in this license in the documentation and/or other materials
  provided with the distribution.

- Neither the name of the copyright holders nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

The copyright holders provide no reassurances that the source code
provided does not infringe any patent, copyright, or any other
intellectual property rights of third parties.  The copyright holders
disclaim any liability to any recipient for claims brought against
recipient by any third party for infringement of that parties
intellectual property rights.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
&quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
```


### Business Source License 1.1

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Terms

The Licensor hereby grants you the right to copy, modify, create derivative works, redistribute, and make non-production use of the Licensed Work. The Licensor may make an Additional Use Grant, above, permitting limited production use.

Effective on the Change Date, or the fourth anniversary of the first publicly available distribution of a specific version of the Licensed Work under this License, whichever comes first, the Licensor hereby grants you rights under the terms of the Change License, and the rights granted in the paragraph above terminate.

If your use of the Licensed Work does not comply with the requirements currently in effect as described in this License, you must purchase a commercial license from the Licensor, its affiliated entities, or authorized resellers, or you must refrain from using the Licensed Work.

All copies of the original and modified Licensed Work, and derivative works of the Licensed Work, are subject to this License. This License applies separately for each version of the Licensed Work and the Change Date may vary for each version of the Licensed Work released by Licensor.

You must conspicuously display this License on each original or modified copy of the Licensed Work. If you receive the Licensed Work in original or modified form from a third party, the terms and conditions set forth in this License apply to your use of that work.

Any use of the Licensed Work in violation of this License will automatically terminate your rights under this License for the current and all other versions of the Licensed Work.

This License does not grant you any right in any trademark or logo of Licensor or its affiliates (provided that you may use a trademark or logo of Licensor as expressly required by this License).TO THE EXTENT PERMITTED BY APPLICABLE LAW, THE LICENSED WORK IS PROVIDED ON AN “AS IS” BASIS. LICENSOR HEREBY DISCLAIMS ALL WARRANTIES AND CONDITIONS, EXPRESS OR IMPLIED, INCLUDING (WITHOUT LIMITATION) WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NON-INFRINGEMENT, AND TITLE.MariaDB hereby grants you permission to use this License’s text to license your works, and to refer to it using the trademark “Business Source License”, as long as you comply with the Covenants of Licensor below.
Covenants of Licensor

In consideration of the right to use this License’s text and the “Business Source License” name and trademark, Licensor covenants to MariaDB, and to all other recipients of the licensed work to be provided by Licensor:

To specify as the Change License the GPL Version 2.0 or any later version, or a license that is compatible with GPL Version 2.0 or a later version, where “compatible” means that software provided under the Change License can be included in a program with software provided under GPL Version 2.0 or a later version. Licensor may specify additional Change Licenses without limitation.
To either: (a) specify an additional grant of rights to use that does not impose any additional restriction on the right granted in this License, as the Additional Use Grant; or (b) insert the text “None”.
To specify a Change Date.
Not to modify this License in any other way.
Notice

The Business Source License (this document, or the “License”) is not an Open Source license. However, the Licensed Work will eventually be made available under an Open Source License, as stated in this License.

For more information on the use of the Business Source License for MariaDB products, please visit the MariaDB Business Source License FAQ. For more information on the use of the Business Source License generally, please visit the Adopting and Developing Business Source License FAQ.
```


### gpl-2.0 WITH bison-exception-2.2

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
﻿insert GPL v2 text here

Bison Exception

As a special exception, you may create a larger work that contains part or all of the Bison parser skeleton and distribute that work under terms of your choice, so long as that work isn&#39;t itself a parser generator using the skeleton or a modified version thereof as a parser skeleton. Alternatively, if you modify or redistribute the parser skeleton itself, you may (at your option) remove this special exception, which will cause the skeleton and the resulting Bison output files to be licensed under the GNU General Public License without this special exception.

This special exception was added by the Free Software Foundation in version 2.2 of Bison.
```


### MIT No Attribution

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Permission is hereby granted, free of charge, to any person obtaining a copy of this
software and associated documentation files (the &quot;Software&quot;), to deal in the Software
without restriction, including without limitation the rights to use, copy, modify,
merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
```


### MIT Szabolcs Nagy Variant

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Permission to use, copy, modify, and/or distribute this code
for any purpose with or without fee is hereby granted.
There is no warranty.
```


### MIT Old Style no advertising

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and
that both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the authors not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission. The authors
makes no representations about the suitability of this software for any
purpose. It is provided &quot;as is&quot; without express or implied warranty.
```


### MIT Taylor Variant

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Permission to use, copy, modify, and/or distribute this software for any purpose
with or without fee is hereby granted, provided that the above copyright notice
and this permission notice appear in all copies.

The software is  provided &quot;as is&quot;, without warranty of any kind, including all
implied warranties of merchantability and fitness. In no event shall the authors
or copyright holders be liable for any claim, damages, or other liability,
whether in an action of contract, tort, or otherwise, arising from, out of, or
in connection with the software or the use or other dealings in the software.
```


### Open Publication License v1.0

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
Open Publication License
v1.0, 8 June 1999

I. REQUIREMENTS ON BOTH UNMODIFIED AND MODIFIED VERSIONS

The Open Publication works may be reproduced and distributed in whole or in part, in any medium physical or electronic, provided that the terms of this license are adhered to, and that this license or an incorporation of it by reference (with any options elected by the author(s) and/or publisher) is displayed in the reproduction.

Proper form for an incorporation by reference is as follows:

    Copyright (c) &lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

The reference must be immediately followed with any options elected by the author(s) and/or publisher of the document (see section VI).

Commercial redistribution of Open Publication-licensed material is permitted.

Any publication in standard (paper) book form shall require the citation of the original publisher and author. The publisher and author&#39;s names shall appear on all outer surfaces of the book. On all outer surfaces of the book the original publisher&#39;s name shall be as large as the title of the work and cited as possessive with respect to the title.


II. COPYRIGHT

The copyright to each Open Publication is owned by its author(s) or designee.


III. SCOPE OF LICENSE

The following license terms apply to all Open Publication works, unless otherwise explicitly stated in the document.

Mere aggregation of Open Publication works or a portion of an Open Publication work with other works or programs on the same media shall not cause this license to apply to those other works. The aggregate work shall contain a notice specifying the inclusion of the Open Publication material and appropriate copyright notice.

SEVERABILITY. If any part of this license is found to be unenforceable in any jurisdiction, the remaining portions of the license remain in force.

NO WARRANTY. Open Publication works are licensed and provided &quot;as is&quot; without warranty of any kind, express or implied, including, but not limited to, the implied warranties of merchantability and fitness for a particular purpose or a warranty of non-infringement.


IV. REQUIREMENTS ON MODIFIED WORKS

All modified versions of documents covered by this license, including translations, anthologies, compilations and partial documents, must meet the following requirements:

   1. The modified version must be labeled as such.
   2. The person making the modifications must be identified and the modifications dated.
   3. Acknowledgement of the original author and publisher if applicable must be retained according to normal academic citation practices.
   4. The location of the original unmodified document must be identified.
   5. The original author&#39;s (or authors&#39;) name(s) may not be used to assert or imply endorsement of the resulting document without the original author&#39;s (or authors&#39;) permission. 


V. GOOD-PRACTICE RECOMMENDATIONS

In addition to the requirements of this license, it is requested from and strongly recommended of redistributors that:

   1. If you are distributing Open Publication works on hardcopy or CD-ROM, you provide email notification to the authors of your intent to redistribute at least thirty days before your manuscript or media freeze, to give the authors time to provide updated documents. This notification should describe modifications, if any, made to the document.
   2. All substantive modifications (including deletions) be either clearly marked up in the document or else described in an attachment to the document.
   3. Finally, while it is not mandatory under this license, it is considered good form to offer a free copy of any hardcopy and CD-ROM expression of an Open Publication-licensed work to its author(s). 


VI. LICENSE OPTIONS

The author(s) and/or publisher of an Open Publication-licensed document may elect certain options by appending language to the reference to or copy of the license. These options are considered part of the license instance and must be included with the license (or its incorporation by reference) in derived works.

A. To prohibit distribution of substantively modified versions without the explicit permission of the author(s). &quot;Substantive modification&quot; is defined as a change to the semantic content of the document, and excludes mere changes in format or typographical corrections.

To accomplish this, add the phrase `Distribution of substantively modified versions of this document is prohibited without the explicit permission of the copyright holder.&#39; to the license reference or copy.

B. To prohibit any publication of this work or derivative works in whole or in part in standard (paper) book form for commercial purposes unless prior permission is obtained from the copyright holder.

To accomplish this, add the phrase &#39;Distribution of the work or derivative of the work in any standard (paper) book form is prohibited unless prior permission is obtained from the copyright holder.&#39; to the license reference or copy.


OPEN PUBLICATION POLICY APPENDIX:

(This is not considered part of the license.)

Open Publication works are available in source format via the Open Publication home page at http://works.opencontent.org/.

Open Publication authors who want to include their own license on Open Publication works may do so, as long as their terms are not more restrictive than the Open Publication license.

If you have questions about the Open Publication License, please contact David Wiley, and/or the Open Publication Authors&#39; List at opal@opencontent.org, via email.

To subscribe to the Open Publication Authors&#39; List:
Send E-mail to opal-request@opencontent.org with the word &quot;subscribe&quot; in the body.

To post to the Open Publication Authors&#39; List:
Send E-mail to opal@opencontent.org or simply reply to a previous post.

To unsubscribe from the Open Publication Authors&#39; List:
Send E-mail to opal-request@opencontent.org with the word &quot;unsubscribe&quot; in the body.
```


### OpenSSL/SSLeay License

Copyright (c) 2017 Christopher Groskopf and contributors

Copyright (c) 2022 the contributors

Copyright (c) 2015 Hynek Schlawack and the attrs contributors

Copyright (c) 2025 TAHRI Ahmed R.

Copyright (c) 2014 Pallets

Copyright (c) 2010 Jonathan Hartley

Copyright (c) 2024 dbt Labs, Inc.

Copyright (c) 2021 dbt Labs, Inc.

Copyright (c) 2021 Starburst Data, Inc.

Copyright (c) 2014 - 2021 Sep Dehpour (Seperman) and contributors

Copyright (c) 2022 Max Bachmann

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006 

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team . All rights reserved.

Copyright (c) 2013-2016 Cameron Desrochers.

Copyright (c) 2016-2020 Yann Collet, Facebook, Inc.

Copyright (c) 2013-2021 Sebastian Bank

Copyright (c) 2013-2024 Sebastian Bank

Copyright (c) 2017 Manraj Singh

Copyright (c) 2013-2024 Kim Davies and contributors.

Copyright (c) 2009 Gerhard Weis . All rights reserved.

Copyright (c) 2007 Pallets

Copyright (c) 2013 Julian Berman

Copyright (c) 2022 Julian Berman

Copyright (c) 2016 Christopher Groskopf and contributors

Copyright (c) 2010 Pallets

Copyright (c) 2017 Alexander Tikhonov

Copyright (c) 2017 MariaDB Corporation Ab, All Rights Reserved.

Copyright (c) 2014 Pallets . All rights reserved.

Copyright (c) 1993 by Sun Microsystems, Inc. All rights reserved.

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.

Copyright (c) 1995-1998 Eric Young (eay@cryptsoft.com)

Copyright (c)  terms

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  to each Open Publication is owned by its author(s) or designee.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved.

Copyright (c)  or copyrights for the package.

Copyright (c)  of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 1990-2009 Info-ZIP. All rights reserved.

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c)  and certain other rights specified in the public license below. The following considerations are for informational purposes only, are not exhaustive, and do not form part of our licenses.

Copyright (c)  and certain other rights. Our licenses are irrevocable. Licensors should read and understand the terms and conditions of the license they choose before applying it. Licensors should also secure all rights necessary before applying our licenses so that the public can reuse the material as expected. Licensors should clearly mark any material not subject to the license. This includes other CC-licensed material, or material used under an exception or limitation to copyright. More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  More considerations for licensors : wiki.creativecommons.org/Considerations_for_licensors

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described.

Copyright (c)  and Similar Rights that is derived from or based upon the Licensed Material and in which the Licensed Material is translated, altered, arranged, transformed, or otherwise modified in a manner requiring permission under the Copyright and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights held by the Licensor. For purposes of this Public License, where the Licensed Material is a musical work, performance, or sound recording, Adapted Material is always produced where the Licensed Material is synched in timed relation with a moving image.

Copyright (c)  and Similar Rights in Your contributions to Adapted Material in accordance with the terms and conditions of this Public License.

Copyright (c)  and Similar Rights means copyright and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and/or similar rights closely related to copyright including, without limitation, performance, broadcast, sound recording, and Sui Generis Database Rights, without regard to how the rights are labeled or categorized. For purposes of this Public License, the rights specified in Section 2(b)(1)-(2) are not Copyright and Similar Rights.

Copyright (c)  and Similar Rights.

Copyright (c)  and Similar Rights that applies to Your use of the Licensed Material.

Copyright (c)  and Similar Rights that apply to Your use of the Licensed Material and that the Licensor has authority to license.

Copyright (c)  and Similar Rights licensed here. However, if You fail to comply with this Public License, then Your rights under this Public License terminate automatically.

Copyright (c)  AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

Copyright (c)  or rights arising from limitations or exceptions that are provided for in connection with the copyright protection under copyright law or other applicable laws.

Copyright (c)  protection under copyright law or other applicable laws.

Copyright (c)  Convention (as revised on July 24, 1971). These rights and subject matter take effect in the relevant jurisdiction in which the License terms are sought to be enforced according to the corresponding provisions of the implementation of those treaty provisions in the applicable national law. If the standard suite of rights granted under applicable copyright law includes additional rights not granted under this License, such additional rights are deemed to be included in the License; this License is not intended to restrict the license of any rights under applicable law.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c)  or any other

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c) 2012 Erik Rose

Copyright (c) 2004-2024 NetworkX Developers

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2001-2019 Python Software Foundation; All Rights

Copyright (c) 2015 Thomson Licensing, SAS

Copyright (c) 2012-2022 Elia Robyn Lake

Copyright (c)  Donald Stufft and individual contributors.

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c) 1996 X Consortium

Copyright (c) 2008 Google Inc.  All rights reserved.

Copyright (c) 2008 Google Inc.  All rights reserved. . All rights reserved.

Copyright (c) 2023 Google LLC

Copyright (c) 2017, 2018, 2019, 2020, 2021 Samuel Colvin and other contributors

Copyright (c) 2017 to present Pydantic Services Inc. and individual contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2017 dateutil contributors (see AUTHORS file)

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2015 dateutil contributors (see AUTHORS file)

Copyright (c)  Val Neekman @ Neekware Inc. http://neekware.com

Copyright (c) 2014 Will Roberts

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2020 present Max Bachmann

Copyright (c) 2011 Adam Cohen

Copyright (c) 2023 Julian Berman

Copyright (c) 2010-2024 Benjamin Peterson

Copyright (c) 2013-2023 Snowplow Analytics Ltd.

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2011-2020 Sergey Astanin and contributors

Copyright (c) 2008-2011 Volvox Development Team

Copyright (c)  or

Copyright (c)  of this Package, but belong to whoever generated

Copyright (c) 2012 Bryce Boe

Copyright (c) 2008-2020 Andrey Petrov and contributors.

Copyright (c) 2006 by Rob Landley &lt;rob@landley.net&gt;

Copyright (c) 2002 by AUTHOR PROFESSIONAL IDENTIFICATION * URL &quot;PROMOTIONAL SLOGAN FOR AUTHOR&#39;S PROFESSIONAL PRACTICE&quot;

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http s ://fsf.org/&gt;

Copyright (c)  quot; also means copyright-like laws that apply to other kinds of works, such as semiconductor masks.

Copyright (c)  quot; line and a pointer to where the full notice is found.

Copyright (c)  lt;year&gt; &lt;name of author&gt;

Copyright (c)  of this Package, but belong to whoever generated them, and may be sold commercially, and may be aggregated with this Package. If such scripts or library files are aggregated with this Package via the so-called &quot;undump&quot; or &quot;unexec&quot; methods of producing a binary executable image, then distribution of such an image shall neither be construed as a distribution of this Package nor shall it fall under the restrictions of Paragraphs 3 and 4, provided that you do not represent such an executable image as a Standard Version of this Package.

Copyright (c)  lt;year&gt; &lt;owner&gt;

Copyright (c)  xxxx]-[xxxx] [Owner Organization]

Copyright (c)  then that use is not regulated by the license. Our licenses grant only permissions under copyright and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c)  and certain other rights that a licensor has authority to grant. Use of the licensed material may still be restricted for other reasons, including because others have copyright or other rights in the material. A licensor may make special requests, such as asking that all changes be marked or described. Although not required by our licenses, you are encouraged to respect those requests where reasonable. More considerations for the public : wiki.creativecommons.org/Considerations_for_licensees Creative Commons Attribution 4.0 International Public License

Copyright (c) 2003-2019 Stuart Bishop &lt;stuart@stuartbishop.net&gt;

Copyright (c) 2016 Andi Albrecht &lt;albrecht.andi@gmail.com&gt;

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 2003-2011 Gustavo Niemeyer &lt;gustavo@niemeyer.net&gt;

Copyright (c) 2012-2014 Tomi Pieviläinen &lt;tomi.pievilainen@iki.fi&gt;

Copyright (c) 2014-2016 Yaron de Leeuw &lt;me@jarondl.net&gt;

Copyright (c) 2015 Paul Ganssle &lt;paul@ganssle.io&gt;

Copyright (c) 1989 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Copyright (c)  19yy &lt;name of author&gt;

Copyright (c)  19xx name of author Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w&#39;. This is free software, and you are welcome to redistribute it under certain conditions; type `show c&#39; for details.

Copyright (c) 1989, 1991 Free Software Foundation, Inc.

Copyright (c)  lt; yyyy &gt; &lt; name of author &gt;

Copyright (c) 2009 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;

Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (&quot;ISC&quot;)

Copyright (c) 1995-2003 by Internet Software Consortium

Copyright (c)  lt;year&gt; &lt;copyright holders&gt;

Copyright (c)  lt;Year&gt; &lt;Owner Organization Name&gt; . All rights reserved.

Copyright (c) 1998 The OpenLDAP Foundation. All Rights Reserved. Note: This license is derived from the &quot;Artistic License&quot; as distributed with the Perl Programming Language. Its terms are different from those of the &quot;Artistic License.&quot;

Copyright (c)  i.e., &quot;Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved&quot; are retained in Python alone or in any derivative version prepared by Licensee.

Copyright (c)  lt;year&gt; by &lt;author&#39;s name or designee&gt;. This material may be distributed only subject to the terms and conditions set forth in the Open Publication License, vX.Y or later (the latest version is presently available at http://www.opencontent.org/openpub/).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in

Copyright (c)  i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights

Copyright (c) 1998-2008 The OpenSSL Project. All rights reserved.

Copyright (c)  terms except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright (c)  remains Eric Young&#39;s, and as such any Copyright notices in the code are not to be removed. If this package is used in a product, Eric Young should be given attribution as the author of the parts of the library used. This can be in the form of a textual message at program startup or in documentation (online or textual) provided with the package.

Copyright (c) 2007 Free Software Foundation, Inc. &lt;http ://fsf.org/&gt;

Copyright (c) 2012-2023 Jukka Lehtosalo and contributors

Copyright (c) 2015-2023 Dropbox, Inc.

Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 

Copyright (c)  i.e., &quot;Copyright (c)

Copyright (c)  

Copyright (c) 1991 - 1995 Stichting Mathematisch Centrum Amsterdam,

Copyright (c) 2008 Google Inc. . All rights reserved.

Copyright (c) 2015 Jukka Lehtosalo and contributors

Copyright (c) 2014 pre-commit dev team: Anthony Sottile, Ken Struys

Copyright (c) 2004 Holger Krekel and others

Copyright (c) 2016 Bruno Oliveira]

Copyright (c) 2010 Holger Krekel and contributors.

Copyright (c) 2017 Paul Ganssle &lt;paul@ganssle.io&gt; . All rights reserved.

Copyright (c) 2017-2021 Ingy döt Net

Copyright (c) 2006-2016 Kirill Simonov

Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.

Copyright (c) 2013-2023 Snowplow Analytics

Copyright (c) 2004-2006 Mike Taylor

Copyright (c) 2006 Darshana Chhajed

Copyright (c) 2004-2019 Mike Taylor

Copyright (c) 2002-2006 Mark Pilgrim, All rights reserved.

Copyright (c) 2014-2017 Melissa O&#39;Neill &lt;oneill@pcg-random.org&gt;,

Copyright (c) 2008-2011 AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team

Copyright (c) 2009 Gerhard Weis

Copyright (c) 2009-2020 the sqlparse authors and contributors

Copyright (c) 2006 Andy Tompkins.

Copyright (c) 1996-2017 PostgreSQL Global Development PGGroup

Copyright (c) 1994 Regents of the University of California

Copyright (c) 2012 Julian Berman

Copyright (c) 2022 Tobias Gustafsson

Copyright (c) 2021 Max Bachmann

Copyright (c) 2022 present Max Bachmann

Copyright (c) 2023 Max Bachmann

Copyright (c) 2020 Max Bachmann

Copyright (c) 2021 present Max Bachmann

Copyright (c) 2017 present Ofek Lev &lt;oss@ofek.dev&gt;

Copyright (c)  Ahmed TAHRI @Ousret](https://github.com/Ousret).&lt;br

Copyright (c)  is shown in the HTML footer. Default is True.

Copyright (c) 2016 Dmitry Vyukov &lt;dvyukov@google.com&gt;

Copyright (c) 2019-2022 Pyodide contributors and Mozilla

Copyright (c)  years

Copyright (c)  text

Copyright (c) 2021 Orson Peters

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003

Copyright (c)  is claimed.


```
LICENSE ISSUES
  ==============

  The OpenSSL toolkit stays under a dual license, i.e. both the conditions of
  the OpenSSL License and the original SSLeay license apply to the toolkit.
  See below for the actual license texts. Actually both licenses are BSD-style
  Open Source licenses. In case of any license issues related to OpenSSL
  please contact openssl-core@openssl.org.

  OpenSSL License
  ---------------

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer. 

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. All advertising materials mentioning features or use of this
   software must display the following acknowledgment:
   &quot;This product includes software developed by the OpenSSL Project
   for use in the OpenSSL Toolkit. (http://www.openssl.org/)&quot;

4. The names &quot;OpenSSL Toolkit&quot; and &quot;OpenSSL Project&quot; must not be used to
   endorse or promote products derived from this software without
   prior written permission. For written permission, please contact
   openssl-core@openssl.org.

5. Products derived from this software may not be called &quot;OpenSSL&quot;
   nor may &quot;OpenSSL&quot; appear in their names without prior written
   permission of the OpenSSL Project.

6. Redistributions of any form whatsoever must retain the following
   acknowledgment:
   &quot;This product includes software developed by the OpenSSL Project
   for use in the OpenSSL Toolkit (http://www.openssl.org/)&quot;

THIS SOFTWARE IS PROVIDED BY THE OpenSSL PROJECT ``AS IS&#39;&#39; AND ANY
EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE OpenSSL PROJECT OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
OF THE POSSIBILITY OF SUCH DAMAGE.


This product includes cryptographic software written by Eric Young
(eay@cryptsoft.com).  This product includes software written by Tim
Hudson (tjh@cryptsoft.com).


 Original SSLeay License
 -----------------------

Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
All rights reserved.

This package is an SSL implementation written
by Eric Young (eay@cryptsoft.com).
The implementation was written so as to conform with Netscapes SSL.

This library is free for commercial and non-commercial use as long as
the following conditions are aheared to.  The following conditions
apply to all code found in this distribution, be it the RC4, RSA,
lhash, DES, etc., code; not just the SSL code.  The SSL documentation
included with this distribution is covered by the same copyright terms
except that the holder is Tim Hudson (tjh@cryptsoft.com).

Copyright remains Eric Young&#39;s, and as such any Copyright notices in
the code are not to be removed.
If this package is used in a product, Eric Young should be given attribution
as the author of the parts of the library used.
This can be in the form of a textual message at program startup or
in documentation (online or textual) provided with the package.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. All advertising materials mentioning features or use of this software
   must display the following acknowledgement:
   &quot;This product includes cryptographic software written by
    Eric Young (eay@cryptsoft.com)&quot;
   The word &#39;cryptographic&#39; can be left out if the rouines from the library
   being used are not cryptographic related :-).
4. If you include any Windows specific code (or a derivative thereof) from 
   the apps directory (application code) you must include an acknowledgement:
   &quot;This product includes software written by Tim Hudson (tjh@cryptsoft.com)&quot;

THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS&#39;&#39; AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.

The licence and distribution terms for any publically available version or
derivative of this code cannot be changed.  i.e. this code cannot simply be
copied and put under another distribution licence
[including the GNU Public Licence.]
```


### Proprietary License

Copyright (c) owned by the Transaction Processing Performance Council.

Copyright (c)  owned by the Transaction Processing Performance Council.

Copyright (c)  Gradient Systems Inc. 2003


```
This is a catch-all license used when we find many different proprietary licenses.
```


### PSF License Agreement for Python 3.7.2


```
PSF LICENSE AGREEMENT FOR PYTHON 3.7.2

1. This LICENSE AGREEMENT is between the Python Software Foundation (&quot;PSF&quot;), and
   the Individual or Organization (&quot;Licensee&quot;) accessing and otherwise using Python
   3.7.2 software in source or binary form and its associated documentation.

2. Subject to the terms and conditions of this License Agreement, PSF hereby
   grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce,
   analyze, test, perform and/or display publicly, prepare derivative works,
   distribute, and otherwise use Python 3.7.2 alone or in any derivative
   version, provided, however, that PSF&#39;s License Agreement and PSF&#39;s notice of
   copyright, i.e., &quot;Copyright © 2001-2019 Python Software Foundation; All Rights
   Reserved&quot; are retained in Python 3.7.2 alone or in any derivative version
   prepared by Licensee.

3. In the event Licensee prepares a derivative work that is based on or
   incorporates Python 3.7.2 or any part thereof, and wants to make the
   derivative work available to others as provided herein, then Licensee hereby
   agrees to include in any such work a brief summary of the changes made to Python
   3.7.2.

4. PSF is making Python 3.7.2 available to Licensee on an &quot;AS IS&quot; basis.
   PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.  BY WAY OF
   EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR
   WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE
   USE OF PYTHON 3.7.2 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.

5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON 3.7.2
   FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF
   MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON 3.7.2, OR ANY DERIVATIVE
   THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.

6. This License Agreement will automatically terminate upon a material breach of
   its terms and conditions.

7. Nothing in this License Agreement shall be deemed to create any relationship
   of agency, partnership, or joint venture between PSF and Licensee.  This License
   Agreement does not grant permission to use PSF trademarks or trade name in a
   trademark sense to endorse or promote products or services of Licensee, or any
   third party.

8. By copying, installing or otherwise using Python 3.7.2, Licensee agrees
   to be bound by the terms and conditions of this License Agreement.
```


### Public Domain

Copyright (c) is claimed.

Copyright (c)  is claimed.







[FOSSA]: # (Do not touch the comments below)

[FOSSA]: # (==depsig=38090da76eec6d7c625f769fa56207e6bbb36c6e19c3dcad2728d05c4fb90c64==)
